(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24200,        638]*)
(*NotebookOutlinePosition[     24828,        660]*)
(*  CellTagsIndexPosition[     24784,        656]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(Quit[]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]\ 
      Five\ point\ function\ in\ massive\ QED\ \((Fig  .1)\)\
\[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< KinematicsGen.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda ver:1.1"\)], "Print"],

Cell[BoxData[
    \("last modification 23 Jan 2007"\)], "Print"],

Cell[BoxData[
    \("Currently 4 & 5 pt functions..."\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ cyclic\ invariants, \ Eq . \ 6\ *) \)], "Input"],

Cell[BoxData[
    \(\(a = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
          p4^2 \[Rule] 0, p5^2 \[Rule] m^2};\)\)], "Input"],

Cell[BoxData[
    \(\(b = {s12, s23, s34, s45, s15};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(invariants = Kinematics[a, b]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] m\^2, p2\^2 \[Rule] m\^2, p3\^2 \[Rule] m\^2, 
      p4\^2 \[Rule] 0, p5\^2 \[Rule] m\^2, 
      p1\ p2 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s12)\), 
      p2\ p3 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s23)\), 
      p3\ p4 \[Rule] 1\/2\ \((\(-m\^2\) + s34)\), 
      p4\ p5 \[Rule] 1\/2\ \((\(-m\^2\) + s45)\), 
      p1\ p5 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s15)\), 
      p1\ p3 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s12 + s23 - s45)\), 
      p1\ p4 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s15 - s23 + s45)\), 
      p2\ p4 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) - s15 + s23 + s34)\), 
      p2\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s12 + s15 - s34)\), 
      p3\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-s12\) + s34 + s45)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[p1 + k1, 0, n1]*PR[p1 + p5 + k1, m, n2]*
            PR[p1 + p5 + p4 + k1, m, n3]\ PR[p1 + p5 + p4 + p3 + k1, 0, 
              n4]\ PR[k1, m, n5]}, {k1}];\)\)], "Input"],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]F\ polynomial\ directly\ from\ MB . 
          m\[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(FUPolynomials[
          DS[p1 + k1, 0, n1]*DS[p1 + p5 + k1, m, n2]*
            DS[p1 + p5 + p4 + k1, m, n3]\ DS[p1 + p5 + p4 + p3 + k1, 0, 
              n4]\ DS[k1, m, n5], {k1}, invariants]\)[\([1]\)] // 
      Expand\)], "Input"],

Cell[BoxData[
    \(m\^2\ x[1]\^2 + 2\ m\^2\ x[1]\ x[3] - s15\ x[1]\ x[3] + m\^2\ x[3]\^2 + 
      2\ m\^2\ x[1]\ x[4] - s23\ x[1]\ x[4] + m\^2\ x[2]\ x[4] - 
      s45\ x[2]\ x[4] + 2\ m\^2\ x[3]\ x[4] + m\^2\ x[4]\^2 - 
      s12\ x[2]\ x[5] + m\^2\ x[3]\ x[5] - s34\ x[3]\ x[5]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ starting\ AMBRE\ to\ simplify\ F\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m, n5]\ PR[
            k1 + p1, 0, n1]\ PR[k1 + p1 + p5, m, n2]\ PR[k1 + p1 + p4 + p5, 
            m, n3]\ PR[k1 + p1 + p3 + p4 + p5, 0, n4]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m, n5], 
          PR[ 
            Plus[ k1, p1], 0, n1], 
          PR[ 
            Plus[ k1, p1, p5], m, n2], 
          PR[ 
            Plus[ k1, p1, p4, p5], m, n3], 
          PR[ 
            Plus[ k1, p1, p3, p4, p5], 0, n4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3] + X[4]]\^2 - s15\ X[1]\ X[3] - s23\ X[1]\ X[4] + 
      m\^2\ X[2]\ X[4] - s45\ X[2]\ X[4] - s12\ X[2]\ X[5] + 
      m\^2\ X[3]\ X[5] - s34\ X[3]\ X[5]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \
\((m\^2)\)\^\(z1 + z4 + z7\)\ \((\(-s12\))\)\^z6\ \((\(-s15\))\)\^z2\ \
\((\(-s23\))\)\^z3\ \((\(-s34\))\)\^\(2 - eps - n1 - n2 - n3 - n4 - n5 - z1 - \
z2 - z3 - z4 - z5 - z6 - z7\)\ \((\(-s45\))\)\^z5\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-z4\)]\ Gamma[
                2 - eps - n1 - n2 - n3 - n5 - z1 - z2 - z3 - z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[\(-z6\)]\ Gamma[
                n1 + z4 + z5 + z6]\ Gamma[\(-z7\)]\ Gamma[\(-2\) + eps + n1 + 
                  n2 + n3 + n4 + n5 + z1 + z2 + z3 + z4 + z5 + z6 + 
                  z7]\ Gamma[\(-z8\)]\ Gamma[n5 + z2 + z3 + z8]\ Gamma[
                n3 + 2\ z1 + z3 + z4 + z5 - z8 - z9]\ Gamma[\(-z9\)]\ Gamma[
                2 - eps - n1 - n3 - n4 - n5 - z1 - z3 - z4 - z5 - z6 + 
                  z9]\ Gamma[\(-2\)\ z1 + z8 + z9])\)/\((Gamma[n1]\ Gamma[
                n2]\ Gamma[n3]\ Gamma[n4]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3 - n4 - n5]\ Gamma[
                n5]\ Gamma[\(-2\)\ z1])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]F\ polynomial\ is\ not\ optimal, \ 
      to\ make\ representation\ simpler, \ 
      we\ introduce\ \ \[IndentingNewLine]\[IndentingNewLine]s45\  \[Rule] \ \
\(s45p\  + \ m^2\ \ \ s34\  \[Rule] \ 
          s34p\  + \ m^2\ \ \[IndentingNewLine]\[IndentingNewLine]
        and\ modify\ F\ polynomial\ manually\ using\ Fauto[
            0]\ mode\)\ \[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fauto[0]\)], "Input"],

Cell[BoxData[
    \(Fmanual::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in MANUAL mode. Now you can \
modify F polynomial (fupc)."\)], "Message"],

Cell[BoxData[
    \("fupc=FUpolyfun[integral,momentum,invariants]"\)], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("fupc="\[InvisibleSpace]\(m\^2\ FX[X[1] + X[3] + \
X[4]]\^2 - s15\ X[1]\ X[3] - s23\ X[1]\ X[4] + m\^2\ X[2]\ X[4] - 
          s45\ X[2]\ X[4] - s12\ X[2]\ X[5] + m\^2\ X[3]\ X[5] - 
          s34\ X[3]\ X[5]\)\),
      SequenceForm[ "fupc=", 
        Plus[ 
          Times[ 
            Power[ m, 2], 
            Power[ 
              FX[ 
                Plus[ 
                  X[ 1], 
                  X[ 3], 
                  X[ 4]]], 2]], 
          Times[ -1, s15, 
            X[ 1], 
            X[ 3]], 
          Times[ -1, s23, 
            X[ 1], 
            X[ 4]], 
          Times[ 
            Power[ m, 2], 
            X[ 2], 
            X[ 4]], 
          Times[ -1, s45, 
            X[ 2], 
            X[ 4]], 
          Times[ -1, s12, 
            X[ 2], 
            X[ 5]], 
          Times[ 
            Power[ m, 2], 
            X[ 3], 
            X[ 5]], 
          Times[ -1, s34, 
            X[ 3], 
            X[ 5]]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fupc = \(fupc /. s45 \[Rule] s45p + m^2\) /. s34 \[Rule] s34p + m^2 // 
        Expand\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(s45p\\)\\\" is similar to existing symbol \\\
\"\\!\\(s45\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(s34p\\)\\\" is similar to existing symbol \\\
\"\\!\\(s34\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3] + X[4]]\^2 - s15\ X[1]\ X[3] - s23\ X[1]\ X[4] - 
      s45p\ X[2]\ X[4] - s12\ X[2]\ X[5] - s34p\ X[3]\ X[5]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("U & F polynomial was computed by user >>Fauto["\
\[InvisibleSpace]0\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "U & F polynomial was computed by user >>Fauto[", 0, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \((m\^2)\)\^z1\ \
\((\(-s12\))\)\^z5\ \((\(-s15\))\)\^z2\ \((\(-s23\))\)\^z3\ \((\(-s34p\))\)\^\
\(2 - eps - n1 - n2 - n3 - n4 - n5 - z1 - z2 - z3 - z4 - z5\)\ \
\((\(-s45p\))\)\^z4\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n1 - n2 - n3 - n5 - z1 - z2 - z3 - 
                  z4]\ Gamma[\(-z4\)]\ Gamma[\(-z5\)]\ Gamma[
                n1 + z4 + z5]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + n4 + n5 + 
                  z1 + z2 + z3 + z4 + z5]\ Gamma[\(-z6\)]\ Gamma[
                n5 + z2 + z3 + z6]\ Gamma[
                n3 + 2\ z1 + z3 + z4 - z6 - z7]\ Gamma[\(-z7\)]\ Gamma[
                2 - eps - n1 - n3 - n4 - n5 - z1 - z3 - z4 - z5 + 
                  z7]\ Gamma[\(-2\)\ z1 + z6 + z7])\)/\((Gamma[n1]\ Gamma[
                n2]\ Gamma[n3]\ Gamma[n4]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3 - n4 - n5]\ Gamma[
                n5]\ Gamma[\(-2\)\ z1])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ applying\ first\ Barnes\ Lemma\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z7, z6}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z7, z6}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]7\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 7, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z7...Barnes Lemma was applied.
2. Checking z6...Barnes Lemma was applied.\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z6, z7}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z6, z7}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]5\),
      SequenceForm[ "   Obtained representation has: dim=", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \((m\^2)\)\^z1\ \
\((\(-s12\))\)\^z5\ \((\(-s15\))\)\^z2\ \((\(-s23\))\)\^z3\ \((\(-s34p\))\)\^\
\(2 - eps - n1 - n2 - n3 - n4 - n5 - z1 - z2 - z3 - z4 - z5\)\ \
\((\(-s45p\))\)\^z4\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
            n5 + z2 + z3]\ Gamma[
            2 - eps - n1 - n2 - n3 - n5 - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[n3 + z3 + z4]\ Gamma[
            2 - eps - n1 - n4 + z1 + z2 + z3 - z5]\ Gamma[
            2 - eps - n1 - n3 - n4 - n5 - z1 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[
            n1 + z4 + z5]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + n4 + n5 + z1 + 
              z2 + z3 + z4 + z5])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[n3]\ Gamma[
            n4]\ Gamma[4 - 2\ eps - n1 - n2 - n3 - n4 - n5]\ Gamma[n5]\ Gamma[
            2 - eps - n1 - n4 - z1 + z2 + z3 - z5])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = % /. {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^z1\ \((\(-s12\))\)\^z5\ \((\(-s15\))\)\^z2\ \
\((\(-s23\))\)\^z3\ \((\(-s34p\))\)\^\(\(-3\) - eps - z1 - z2 - z3 - z4 - \
z5\)\ \((\(-s45p\))\)\^z4\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ \
Gamma[1 + z2 + z3]\ Gamma[\(-2\) - eps - z1 - z2 - z3 - 
                z4]\ Gamma[\(-z4\)]\ Gamma[
              1 + z3 + z4]\ Gamma[\(-eps\) + z1 + z2 + z3 - 
                z5]\ Gamma[\(-2\) - eps - z1 - z3 - z4 - 
                z5]\ Gamma[\(-z5\)]\ Gamma[1 + z4 + z5]\ Gamma[
              3 + eps + z1 + z2 + z3 + z4 + z5])\)/\((Gamma[\(-1\) - 
                2\ eps]\ Gamma[\(-eps\) - z1 + z2 + z3 - 
                z5])\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ numerical\ cross\ check\ using\ MB . m\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[repr, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(71\/64\)\)}, {z1 \[Rule] \(-\(1\/2\)\), 
        z2 \[Rule] \(-\(1\/4\)\), z3 \[Rule] \(-\(1\/8\)\), 
        z4 \[Rule] \(-\(1\/16\)\), z5 \[Rule] \(-\(29\/32\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(integrals = 
        MBcontinue[repr, eps \[Rule] 0, rules, 
          Verbose \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ser = MBexpand[integrals, Exp[eps\ EulerGamma], {eps, 0, 0}]\)], "Input"],

Cell[BoxData[
    \({MBint[\(\((m\^2)\)\^z1\ \((\(-s15\))\)\^\(\(-1\) - z1\)\ \
Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\)\/\(2\ eps\ s12\ s45p\ Gamma[\(-2\)\ z1]\) \
+ \(\((m\^2)\)\^z1\ \((\(-s15\))\)\^\(\(-1\) - z1\)\ Gamma[\(-z1\)]\^3\ \
Gamma[1 + z1]\ \((EulerGamma - Log[\(-s15\)] + 2\ Log[\(-s23\)] - 2\ \
Log[\(-s45p\)] + PolyGamma[0, 1 + z1])\)\)\/\(2\ s12\ s45p\ Gamma[\(-2\)\ z1]\
\), {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\)}}], 
      MBint[\(\(1\/Gamma[\(-2\)\ z1]\)\((\((m\^2)\)\^z1\ \
\((\(-s12\))\)\^\(\(-2\) + z3\)\ s12\ \((\(-s15\))\)\^\(\(-1\) - z1\)\ \
\((\(-s23\))\)\^z3\ \((\(-s34p\))\)\^\(-z3\)\ \((\(-s45p\))\)\^\(\(-1\) - \
z3\)\ Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[
              1 - z3]\ Gamma[\(-z1\) - z3]\ Gamma[\(-z3\)]\ Gamma[z3]\ Gamma[
              1 + z3]\ Gamma[\(-z1\) + z3])\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z3 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(\(1\/Gamma[\(-1\) - 
                2\ z1]\)\((\((m\^2)\)\^z1\ \((\(-s12\))\)\^z3\ \((\(-s15\))\)\
\^\(\(-2\) - z1\)\ s15\ \((\(-s23\))\)\^z3\ \((\(-s34p\))\)\^\(\(-1\) - z3\)\ \
\((\(-s45p\))\)\^\(\(-1\) - z3\)\ Gamma[\(-z1\)]\ Gamma[
              1 + z1]\ Gamma[\(-1\) - z1 - 
                z3]\ Gamma[\(-z3\)]\^2\ Gamma[1 + z3]\^2\ Gamma[\(-z1\) + 
                z3])\)\), {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z3 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\((m\^2)\)\^z1\ \((\(-s12\))\)\^\(\(-2\) - z1\)\ s12\ \
\((\(-s15\))\)\^\(\(-1\) - z1\)\ \((\(-s23\))\)\^\(\(-1\) - z1\)\ \
\((\(-s34p\))\)\^z1\ \((\(-s45p\))\)\^z1\ Gamma[\(-z1\)]\^3\ Gamma[1 + \
z1]\^3, {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\)}}], 
      MBint[\(\(1\/Gamma[\(-1\) - 
                2\ z1]\)\((\((m\^2)\)\^z1\ \((\(-s12\))\)\^z2\ \((\(-s15\))\)\
\^z2\ \((\(-s23\))\)\^\(\(-2\) - z1\)\ s23\ \((\(-s34p\))\)\^\(\(-1\) - z2\)\ \
\((\(-s45p\))\)\^\(\(-1\) - z2\)\ Gamma[\(-z1\)]\ Gamma[
              1 + z1]\ Gamma[\(-1\) - z1 - 
                z2]\ Gamma[\(-z2\)]\^2\ Gamma[1 + z2]\^2\ Gamma[\(-z1\) + 
                z2])\)\), {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(1\/4\)\)}}], 
      MBint[\(\((m\^2)\)\^z1\ \((\(-s15\))\)\^z2\ \((\(-s23\))\)\^\(\(-z1\) - \
z2\)\ Gamma[\(-z1\)]\^2\ Gamma[\(-1\) - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\ \
Gamma[1 + z1 + z2]\)\/\(s23\ s34p\ s45p\ Gamma[\(-1\) - 2\ z1]\), {{eps \
\[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), z2 \[Rule] \(-\(1\/4\)\)}}], 
      MBint[\(\(1\/Gamma[\(-1\) - 
                2\ z1]\)\((\((m\^2)\)\^z1\ \((\(-s12\))\)\^\(z1 + z2 + z3\)\ \
s12\ \((\(-s15\))\)\^z2\ \((\(-s23\))\)\^z3\ \((\(-s34p\))\)\^\(\(-2\) - z1 - \
z2 - z3\)\ \((\(-s45p\))\)\^\(\(-2\) - z1 - z2 - z3\)\ Gamma[\(-z1\)]\ Gamma[\
\(-1\) - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - z1 - z3]\ Gamma[\(-1\) - 
                z1 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
              1 + z2 + z3]\ Gamma[2 + z1 + z2 + z3]\^2)\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z2 \[Rule] \(-\(1\/4\)\), 
            z3 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(\(1\/Gamma[\(-2\)\ z1]\)\((\((m\^2)\)\^z1\ \((\(-s12\))\)\^\(z1 \
+ z2 + z3\)\ \((\(-s15\))\)\^z2\ \((\(-s23\))\)\^z3\ \
\((\(-s34p\))\)\^\(\(-2\) - z1 - z2 - z3\)\ s34p\ \((\(-s45p\))\)\^\(\(-2\) - \
z1 - z2 - z3\)\ Gamma[\(-z1\)]\ Gamma[\(-1\) - z1 - 
                z2]\ Gamma[\(-z2\)]\ Gamma[\(-z1\) - z3]\ Gamma[\(-z1\) - 
                z2 - z3]\ Gamma[\(-z3\)]\ Gamma[1 + z2 + z3]\ Gamma[
              1 + z1 + z2 + z3]\ Gamma[2 + z1 + z2 + z3])\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z2 \[Rule] \(-\(1\/4\)\), 
            z3 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(\(1\/Gamma[\(-2\)\ z1]\)\((\((m\^2)\)\^z1\ \((\(-s12\))\)\^\(z1 \
+ z2 + z3\)\ \((\(-s15\))\)\^z2\ \((\(-s23\))\)\^z3\ \
\((\(-s34p\))\)\^\(\(-3\) - z1 - z2 - z3\)\ s34p\ \((\(-s45p\))\)\^\(\(-1\) - \
z1 - z2 - z3\)\ Gamma[\(-z1\)]\ Gamma[\(-z1\) - 
                z2]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - z1 - z3]\ Gamma[\(-z1\) - 
                z2 - z3]\ Gamma[\(-z3\)]\ Gamma[1 + z2 + z3]\ Gamma[
              1 + z1 + z2 + z3]\ Gamma[2 + z1 + z2 + z3])\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z2 \[Rule] \(-\(1\/4\)\), 
            z3 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(\((m\^2)\)\^z1\ \((\(-s23\))\)\^\(\(-1\) - z1\)\ Gamma[\(-z1\)]\
\^3\ Gamma[1 + z1]\)\/\(2\ eps\ s12\ s34p\ Gamma[\(-2\)\ z1]\) + \(\((m\^2)\)\
\^z1\ \((\(-s23\))\)\^\(\(-1\) - z1\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ \
\((EulerGamma + 2\ Log[\(-s15\)] - Log[\(-s23\)] - 2\ Log[\(-s34p\)] + \
PolyGamma[0, 1 + z1])\)\)\/\(2\ s12\ s34p\ Gamma[\(-2\)\ z1]\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\)}}], 
      MBint[\(\(1\/Gamma[\(-2\)\ z1]\)\((\((m\^2)\)\^z1\ \
\((\(-s12\))\)\^\(\(-2\) + z2\)\ s12\ \((\(-s15\))\)\^z2\ \
\((\(-s23\))\)\^\(\(-1\) - z1\)\ \((\(-s34p\))\)\^\(\(-1\) - z2\)\ \((\(-s45p\
\))\)\^\(-z2\)\ Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[
              1 - z2]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\ Gamma[
              1 + z2]\ Gamma[\(-z1\) + z2])\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(1\/4\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[\(ser /. \ s45p \[Rule] s45 - m^2\)\  /. \ 
          s34p \[Rule] s34 - m^2, {s12 \[Rule] \(-1\)/2, s15 \[Rule] \(-3\), 
          s23 \[Rule] \(-5\), s34 \[Rule] \(-2\), s45 \[Rule] \(-10\), 
          m \[Rule] 1}, Verbose \[Rule] False] // AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({31.022394`7.94322030279792\ Second, {\(\(0.8258103657830245`\)\(\
\[InvisibleSpace]\)\) + 0.25345715745178865`\/eps, {0.00012909123975051327`, 
          0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\(\[IndentingNewLine]\)\(\ \)\(result\ from\ sector\ decomposition\ \
\[IndentingNewLine]
        0.8258169090430236`\[InvisibleSpace] + 
          0.2534571574517882`\/ep, {0.0001353616591903612`, 
          0}\)\(}\)\[IndentingNewLine]*) \)], "Input"]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{1014, 714},
WindowMargins->{{0, Automatic}, {0, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 39, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1818, 56, 40, 1, 27, "Input"],
Cell[1861, 59, 41, 1, 23, "Print"],
Cell[1905, 62, 51, 1, 23, "Print"],
Cell[1959, 65, 62, 1, 23, "Print"],
Cell[2024, 68, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2119, 74, 43, 1, 27, "Input"],
Cell[2165, 77, 56, 1, 23, "Print"],
Cell[2224, 80, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2299, 84, 144, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[2468, 91, 51, 1, 27, "Input"],
Cell[2522, 94, 53, 1, 23, "Print"],
Cell[2578, 97, 64, 1, 23, "Print"],
Cell[2645, 100, 66, 1, 23, "Print"]
}, Open  ]],
Cell[2726, 104, 73, 1, 27, "Input"],
Cell[2802, 107, 141, 2, 27, "Input"],
Cell[2946, 111, 67, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[3038, 116, 62, 1, 27, "Input"],
Cell[3103, 119, 755, 12, 116, "Output"]
}, Open  ]],
Cell[3873, 134, 214, 3, 43, "Input"],
Cell[4090, 139, 127, 2, 59, "Input"],

Cell[CellGroupData[{
Cell[4242, 145, 256, 5, 43, "Input"],
Cell[4501, 152, 294, 4, 47, "Output"]
}, Open  ]],
Cell[4810, 159, 75, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[4910, 164, 43, 1, 27, "Input"],
Cell[4956, 167, 143, 3, 23, "Print"],
Cell[5102, 172, 562, 15, 23, "Print"],
Cell[5667, 189, 143, 3, 23, "Print"],
Cell[5813, 194, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6024, 202, 55, 1, 27, "Input"],
Cell[6082, 205, 264, 4, 23, "Print"],
Cell[6349, 211, 257, 5, 23, "Print"],
Cell[6609, 218, 50, 1, 23, "Print"],
Cell[6662, 221, 65, 1, 23, "Print"],
Cell[6730, 224, 50, 1, 23, "Print"],
Cell[6783, 227, 206, 3, 25, "Print"],
Cell[6992, 232, 56, 1, 23, "Print"],
Cell[7051, 235, 1201, 19, 98, "Print"]
}, Open  ]],
Cell[8267, 257, 428, 7, 123, "Input"],

Cell[CellGroupData[{
Cell[8720, 268, 41, 1, 27, "Input"],
Cell[8764, 271, 172, 3, 20, "Message"],
Cell[8939, 276, 79, 1, 23, "Print"],
Cell[9021, 279, 50, 1, 23, "Print"],
Cell[9074, 282, 65, 1, 23, "Print"],
Cell[9142, 285, 50, 1, 23, "Print"],
Cell[9195, 288, 1036, 38, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10268, 331, 119, 2, 27, "Input"],
Cell[10390, 335, 355, 5, 20, "Message"],
Cell[10748, 342, 355, 5, 20, "Message"],
Cell[11106, 349, 164, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11307, 356, 62, 1, 27, "Input"],
Cell[11372, 359, 264, 4, 23, "Print"],
Cell[11639, 365, 253, 5, 23, "Print"],
Cell[11895, 372, 56, 1, 23, "Print"],
Cell[11954, 375, 1113, 18, 99, "Print"]
}, Open  ]],
Cell[13082, 396, 73, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[13180, 401, 53, 1, 27, "Input"],
Cell[13236, 404, 257, 5, 23, "Print"],
Cell[13496, 411, 226, 4, 23, "Print"],
Cell[13725, 417, 111, 4, 53, "Print"],
Cell[13839, 423, 80, 1, 23, "Print"],
Cell[13922, 426, 466, 12, 23, "Print"],
Cell[14391, 440, 197, 4, 23, "Print"],
Cell[14591, 446, 921, 14, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15549, 465, 126, 2, 27, "Input"],
Cell[15678, 469, 691, 11, 69, "Output"]
}, Open  ]],
Cell[16384, 483, 81, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[16490, 488, 89, 1, 27, "Input"],
Cell[16582, 491, 128, 2, 20, "Message"],
Cell[16713, 495, 128, 2, 20, "Message"],
Cell[16844, 499, 128, 2, 20, "Message"],
Cell[16975, 503, 334, 5, 20, "Message"],
Cell[17312, 510, 218, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17567, 518, 131, 3, 27, "Input"],
Cell[17701, 523, 365, 5, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18103, 533, 93, 1, 27, "Input"],
Cell[18199, 536, 5170, 78, 805, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23406, 619, 303, 4, 43, "Input"],
Cell[23712, 625, 193, 3, 47, "Output"]
}, Open  ]],
Cell[23920, 631, 276, 5, 83, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

