(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12417,        359]*)
(*NotebookOutlinePosition[     13047,        381]*)
(*  CellTagsIndexPosition[     13003,        377]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]\ 
      Five\ point\ function\ in\ massive\ QED\ \((Fig  .1)\)\
\[IndentingNewLine]*) \)], "Input"],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[p1 + k1, m, n1]*PR[p1 + p5 + k1, 0, n2]*
            PR[p1 + p5 + p4 + k1, m, n3]\ PR[p1 + p5 + p4 + p3 + k1, m, 
              n4]\ PR[k1, 0, n5]}, {k1}];\)\)], "Input"],

Cell[BoxData[
    \( (*\ invariants, \ Eq . \ 9\ *) \)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] 0, 
          p4^2 \[Rule] m^2, p5^2 \[Rule] m^2, 
          p1*p2 \[Rule] 1/2\ \((tp - 2  m^2)\), 
          p1*p3 \[Rule] 1/2\ \((t - tp - v1)\), 
          p1*p4 \[Rule] m^2 - 1/2\ \((s + t - v1)\), 
          p1*p5 \[Rule] 1/2\ \((s - 2  m^2)\), p2\ p3 \[Rule] 1/2\ v1, 
          p2\ p4 \[Rule] 1/2\ \((s - 2  m^2 - v1 - v2)\), 
          p2\ p5 \[Rule] m^2 - 1/2\ \((s + tp - v2)\), 
          p3\ p4 \[Rule] 1/2  v2, p3\ p5 \[Rule] 1/2\ \((tp - t - v2)\), 
          p4\ p5 \[Rule] 1/2\ \((t - 2\ m^2)\)};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, n5]\ PR[
            k1 + p1, m, n1]\ PR[k1 + p1 + p5, 0, n2]\ PR[k1 + p1 + p4 + p5, 
            m, n3]\ PR[k1 + p1 + p3 + p4 + p5, m, n4]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, n5], 
          PR[ 
            Plus[ k1, p1], m, n1], 
          PR[ 
            Plus[ k1, p1, p5], 0, n2], 
          PR[ 
            Plus[ k1, p1, p4, p5], m, n3], 
          PR[ 
            Plus[ k1, p1, p3, p4, p5], m, n4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[2] + X[4] + X[5]]\^2 - s\ X[1]\ X[3] - v1\ X[1]\ X[4] - 
      t\ X[2]\ X[4] - tp\ X[2]\ X[5] - v2\ X[3]\ X[5]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^z2\ \((\(-t\))\)\^z4\ \((\(-tp\))\)\^z5\ \((\(-v1\))\)\^z3\ \((\
\(-v2\))\)\^\(2 - eps - n1 - n2 - n3 - n4 - n5 - z1 - z2 - z3 - z4 - z5\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                n5 + z2 + z3]\ Gamma[\(-z4\)]\ Gamma[
                2 - eps - n1 - n3 - n4 - n5 - z1 - z3 - z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + 
                  n4 + n5 + z1 + z2 + z3 + z4 + z5]\ Gamma[\(-z6\)]\ Gamma[
                n1 + z4 + z5 + z6]\ Gamma[
                2 - eps - n1 - n2 - n3 - n5 + z1 - z2 - z3 - z4 - z6 - 
                  z7]\ Gamma[\(-z7\)]\ Gamma[
                n3 + z3 + z4 + z7]\ Gamma[\(-2\)\ z1 + z6 + z7])\)/\((Gamma[
                n1]\ Gamma[n2]\ Gamma[n3]\ Gamma[n4]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3 - n4 - n5]\ Gamma[
                n5]\ Gamma[\(-2\)\ z1])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ applying\ first\ Barnes\ Lemma\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z7, z6}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z7, z6}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]7\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 7, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z7...Barnes Lemma was applied.
2. Checking z6...Barnes Lemma was applied.\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z6, z7}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z6, z7}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]5\),
      SequenceForm[ "   Obtained representation has: dim=", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \((m\^2)\)\^z1\ \((\(-s\))\
\)\^z2\ \((\(-t\))\)\^z4\ \((\(-tp\))\)\^z5\ \((\(-v1\))\)\^z3\ \((\(-v2\))\)\
\^\(2 - eps - n1 - n2 - n3 - n4 - n5 - z1 - z2 - z3 - z4 - z5\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[n5 + z2 + z3]\ Gamma[
            2 - eps - n1 - n2 - n3 - n5 - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[n3 + z3 + z4]\ Gamma[
            2 - eps - n1 - n3 - n4 - n5 - z1 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[n1 + z4 + z5]\ Gamma[
            2 - eps - n2 - n5 + z1 - z2 + z4 + z5]\ Gamma[\(-2\) + eps + n1 + 
              n2 + n3 + n4 + n5 + z1 + z2 + z3 + z4 + z5])\)/\((Gamma[
            n1]\ Gamma[n2]\ Gamma[n3]\ Gamma[n4]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n4 - n5]\ Gamma[n5]\ Gamma[
            2 - eps - n2 - n5 - z1 - z2 + z4 + z5])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = % /. {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^z1\ \((\(-s\))\)\^z2\ \((\(-t\))\)\^z4\ \((\(-tp\))\
\)\^z5\ \((\(-v1\))\)\^z3\ \((\(-v2\))\)\^\(\(-3\) - eps - z1 - z2 - z3 - z4 \
- z5\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
              1 + z2 + z3]\ Gamma[\(-2\) - eps - z1 - z2 - z3 - 
                z4]\ Gamma[\(-z4\)]\ Gamma[
              1 + z3 + z4]\ Gamma[\(-2\) - eps - z1 - z3 - z4 - 
                z5]\ Gamma[\(-z5\)]\ Gamma[
              1 + z4 + z5]\ Gamma[\(-eps\) + z1 - z2 + z4 + z5]\ Gamma[
              3 + eps + z1 + z2 + z3 + z4 + z5])\)/\((Gamma[\(-1\) - 
                2\ eps]\ Gamma[\(-eps\) - z1 - z2 + z4 + 
                z5])\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ numerical\ cross\ check\ using\ MB . m\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(201\/256\)\)}, {z1 \[Rule] \(-\(9\/8\)\), 
        z2 \[Rule] \(-\(5\/8\)\), z3 \[Rule] \(-\(7\/32\)\), 
        z4 \[Rule] \(-\(3\/16\)\), z5 \[Rule] \(-\(5\/256\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(integrals = 
        MBcontinue[fin, eps \[Rule] 0, rules, 
          Verbose \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(ser = 
        MBexpand[integrals, Exp[eps\ EulerGamma], {eps, 0, 0}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsoluteTiming[
      MBintegrate[
        ser, {s \[Rule] \(-2\), t \[Rule] \(-3\), v2 \[Rule] \(-4\), 
          tp \[Rule] \(-5\), v1 \[Rule] \(-6\), m \[Rule] 1}, 
        Verbose \[Rule] False]]\)], "Input"],

Cell[BoxData[
    \({7.577458`7.331068531354003\ Second, {\(\(0.015427459420144063`\)\(\
\[InvisibleSpace]\)\) + 0.06664956082188417`\/eps, {0.000010951405563587216`, 
          0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\[IndentingNewLine]\ 
      result\ from\ sector\ decomposition\ \[IndentingNewLine]\
\[IndentingNewLine]{\(\(0.015424568073141243`\)\(\[InvisibleSpace]\)\) + 
            0.0666495605172588`\/ep, {0.000021518140469854386`, 
            0}}\[IndentingNewLine]\[IndentingNewLine]*) \)], "Input"]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{639, 662},
WindowMargins->{{178, Automatic}, {Automatic, 38}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 1, 27, "Input"],
Cell[1819, 56, 41, 1, 23, "Print"],
Cell[1863, 59, 51, 1, 23, "Print"],
Cell[1917, 62, 62, 1, 23, "Print"],
Cell[1982, 65, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2077, 71, 43, 1, 27, "Input"],
Cell[2123, 74, 56, 1, 23, "Print"],
Cell[2182, 77, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2257, 81, 144, 3, 59, "Input"],
Cell[2404, 86, 214, 3, 59, "Input"],
Cell[2621, 91, 65, 1, 27, "Input"],
Cell[2689, 94, 612, 10, 91, "Input"],

Cell[CellGroupData[{
Cell[3326, 108, 43, 1, 27, "Input"],
Cell[3372, 111, 143, 3, 23, "Print"],
Cell[3518, 116, 562, 15, 39, "Print"],
Cell[4083, 133, 143, 3, 23, "Print"],
Cell[4229, 138, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4440, 146, 62, 1, 27, "Input"],
Cell[4505, 149, 264, 4, 23, "Print"],
Cell[4772, 155, 257, 5, 23, "Print"],
Cell[5032, 162, 50, 1, 23, "Print"],
Cell[5085, 165, 65, 1, 23, "Print"],
Cell[5153, 168, 50, 1, 23, "Print"],
Cell[5206, 171, 154, 2, 41, "Print"],
Cell[5363, 175, 56, 1, 23, "Print"],
Cell[5422, 178, 1096, 18, 163, "Print"]
}, Open  ]],
Cell[6533, 199, 73, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[6631, 204, 59, 1, 27, "Input"],
Cell[6693, 207, 257, 5, 23, "Print"],
Cell[6953, 214, 226, 4, 23, "Print"],
Cell[7182, 220, 111, 4, 53, "Print"],
Cell[7296, 226, 80, 1, 23, "Print"],
Cell[7379, 229, 466, 12, 23, "Print"],
Cell[7848, 243, 197, 4, 23, "Print"],
Cell[8048, 249, 899, 13, 151, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8984, 267, 125, 2, 27, "Input"],
Cell[9112, 271, 693, 11, 118, "Output"]
}, Open  ]],
Cell[9820, 285, 81, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[9926, 290, 88, 1, 27, "Input"],
Cell[10017, 293, 128, 2, 20, "Message"],
Cell[10148, 297, 128, 2, 20, "Message"],
Cell[10279, 301, 128, 2, 20, "Message"],
Cell[10410, 305, 334, 5, 33, "Message"],
Cell[10747, 312, 221, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11005, 320, 130, 3, 27, "Input"],
Cell[11138, 325, 365, 5, 33, "Message"]
}, Open  ]],
Cell[11518, 333, 107, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[11650, 339, 232, 5, 59, "Input"],
Cell[11885, 346, 196, 3, 47, "Output"]
}, Open  ]],
Cell[12096, 352, 317, 5, 115, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

