(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42028,       1135]*)
(*NotebookOutlinePosition[     42969,       1164]*)
(*  CellTagsIndexPosition[     42925,       1160]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\[IndentingNewLine]\ \ \ \ 2 - 
        loop\ massive\ topology, \ \ Fig  .2\ \ \ \ \[IndentingNewLine]*) \
\)], "Input"],

Cell[BoxData[
    \(\(B1 = 
        Fullintegral[\[IndentingNewLine]{1}, \[IndentingNewLine]{PR[k1, m, 
                n1] PR[k1 + p1, 0, n2] PR[k1 + p1 + p2, m, n3] 
              PR[k1 - k2, 0, n4] PR[k2, m, n5] PR[k2 + p1 + p2, m, n6] 
              PR[k2 - p3, 0, n7]}, {k2, k1}];\)\)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
          p4^2 \[Rule] m^2, p1*p2 \[Rule] 1/2*s - m^2, 
          p3*p4 \[Rule] 1/2\ s - m^2, p1*p3 \[Rule] 1/2*t - m^2, 
          p2*p4 \[Rule] 1/2*t - m^2, p2*p3 \[Rule] 1/2*u - m^2, 
          p1*p4 \[Rule] 1/2*u - m^2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1 - k2, 0, n4]\ PR[
            k2, m, n5]\ PR[k2 + p1 + p2, m, n6]\ PR[k2 - p3, 0, n7]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ 
            Plus[ k1, 
              Times[ -1, k2]], 0, n4], 
          PR[ k2, m, n5], 
          PR[ 
            Plus[ k2, p1, p2], m, n6], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p3]], 0, n7]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[2] + X[3]]\^2 - PR[k1, m]\ X[1]\ X[2] - 
      PR[k1 + p1 + p2, m]\ X[1]\ X[3] - s\ X[2]\ X[3] - 
      PR[k1 - p3, 0]\ X[1]\ X[4] + 4\ m\^2\ X[3]\ X[4] - s\ X[3]\ X[4] - 
      t\ X[3]\ X[4] - u\ X[3]\ X[4]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k2..."\),
      SequenceForm[ "Representation after integrating over: ", "k2..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(n4 + n5 + n6 + n7 + z2 + z3 + z5\)\ 4\
\^z6\ \((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^z8\ \
\((\(-u\))\)\^\(2 - eps - n4 - n5 - n6 - n7 - z1 - z2 - z3 - z4 - z5 - z6 - \
z7 - z8\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                    2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                      z4]\ Gamma[\(-z4\)]\ Gamma[\(-z5\)]\ Gamma[
                    n4 + z2 + z3 + 
                      z5]\ Gamma[\(-z6\)]\ Gamma[\(-z7\)]\ Gamma[\(-z8\)]\ \
Gamma[\(-2\) + eps + n4 + n5 + n6 + n7 + z1 + z2 + z3 + z4 + z5 + z6 + z7 + 
                      z8]\ Gamma[
                    2 - eps - n4 - n5 - n7 + z1 - z2 - z5 - 
                      z9]\ Gamma[\(-z9\)]\ Gamma[\(-2\)\ z1 + z9]\ Gamma[
                    n5 + z2 + z4 + z9])\)/\((Gamma[n4]\ Gamma[n5]\ Gamma[
                    n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                    n7]\ Gamma[\(-2\)\ z1])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k1, m, z2]\ PR[k1 + p1 + p2, m, z3]\ PR[k1 - p3, 0, 
                z5]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]we\ get\ dim = 9\ representation, \ 
      eq  .13, \ \ \[IndentingNewLine]\[IndentingNewLine]note\ apperance\ of\ \
the\ element\ 4^z6\ which\ comes\ from\ F\ polynomial\ term\ 4  m^2\ x[3] 
        x[4], \ we\ can\ simply\ eliminate\ x[3] 
          x[4]\ term\ by\ changing\ \[IndentingNewLine]u\  \[Rule] \ 
        4\ m^2\  - \ s\  - \ t, \ eq  .15\ \[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fauto[0]\)], "Input"],

Cell[BoxData[
    \(Fmanual::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in MANUAL mode. Now you can \
modify F polynomial (fupc)."\)], "Message"],

Cell[BoxData[
    \("fupc=FUpolyfun[integral,momentum,invariants]"\)], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("fupc="\[InvisibleSpace]\(m\^2\ FX[X[2] + X[3]]\^2 - 
          PR[k1, m]\ X[1]\ X[2] - PR[k1 + p1 + p2, m]\ X[1]\ X[3] - 
          s\ X[2]\ X[3] - PR[k1 - p3, 0]\ X[1]\ X[4] + 4\ m\^2\ X[3]\ X[4] - 
          s\ X[3]\ X[4] - t\ X[3]\ X[4] - u\ X[3]\ X[4]\)\),
      SequenceForm[ "fupc=", 
        Plus[ 
          Times[ 
            Power[ m, 2], 
            Power[ 
              FX[ 
                Plus[ 
                  X[ 2], 
                  X[ 3]]], 2]], 
          Times[ -1, 
            PR[ k1, m], 
            X[ 1], 
            X[ 2]], 
          Times[ -1, 
            PR[ 
              Plus[ k1, p1, p2], m], 
            X[ 1], 
            X[ 3]], 
          Times[ -1, s, 
            X[ 2], 
            X[ 3]], 
          Times[ -1, 
            PR[ 
              Plus[ k1, 
                Times[ -1, p3]], 0], 
            X[ 1], 
            X[ 4]], 
          Times[ 4, 
            Power[ m, 2], 
            X[ 3], 
            X[ 4]], 
          Times[ -1, s, 
            X[ 3], 
            X[ 4]], 
          Times[ -1, t, 
            X[ 3], 
            X[ 4]], 
          Times[ -1, u, 
            X[ 3], 
            X[ 4]]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Executing\ Fauto[0]\ caused\ AR . 
          m\ to\ calculate\ F\ polynomial\ fupc, \ \[IndentingNewLine]now\ we\
\ are\ free\ to\ change\ it\ as\ we\ like\ to\ \[IndentingNewLine]*) \)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(fupc = fupc /. u \[Rule] 4\ m^2 - s - t // Expand\)], "Input"],

Cell[BoxData[
    \(m\^2\ FX[X[2] + X[3]]\^2 - PR[k1, m]\ X[1]\ X[2] - 
      PR[k1 + p1 + p2, m]\ X[1]\ X[3] - s\ X[2]\ X[3] - 
      PR[k1 - p3, 0]\ X[1]\ X[4]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Now\ we\ continue\ calculation\ with\ a\ new\ \
form\ of\ fupc\ \((F\ polynomial)\) . \ Note\ that\ in\ Fauto[
          0]\ SubLoop\ function\ does\ not\ coalculate\ F\ polynomial\ \
\[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("U & F polynomial was computed by user >>Fauto["\
\[InvisibleSpace]0\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "U & F polynomial was computed by user >>Fauto[", 0, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k2..."\),
      SequenceForm[ "Representation after integrating over: ", "k2..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps - z1 - z4\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^z4\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                    2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                    2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                      z4]\ Gamma[\(-z4\)]\ Gamma[\(-2\) + eps + n4 + n5 + 
                      n6 + n7 + z1 + z2 + z3 + z4]\ Gamma[
                    n6 + 2\ z1 + z3 + z4 - 
                      z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                    n5 + z2 + z4 + z5])\)/\((Gamma[n4]\ Gamma[n5]\ Gamma[
                    n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                    n7]\ Gamma[\(-2\)\ z1])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k1, m, z2]\ PR[k1 + p1 + p2, m, z3]\ PR[k1 - p3, 0, 
                2 - eps - n4 - n5 - n6 - n7 - z1 - z2 - z3 - z4]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]because\ we\ have\ built\ the\ representation\ \
using\ simpler\ F\ polynomial\ \((less\ terms)\), \ 
      dimension\ of\ the\ representation\ is\ smaller\ than\ before, \ 
      now\ \[IndentingNewLine]dim = 
        5\[IndentingNewLine]\[IndentingNewLine]we\ can\ continue\ now\ our\ \
calculations\ with\ the\ next\ subloop, \ 
      we\ do\ the\ same\ trick\ to\ the\ F\ polynomial\ as\ in\ the\ subloop\ \
during\ first\ iteration\[IndentingNewLine]\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m, n1 - z2]\ PR[
            k1 + p1, 0, n2]\ PR[k1 + p1 + p2, m, n3 - z3]\ PR[k1 - p3, 
            0, \(-2\) + eps + n4 + n5 + n6 + n7 + z1 + z2 + z3 + z4]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m, 
            Plus[ n1, 
              Times[ -1, z2]]], 
          PR[ 
            Plus[ k1, p1], 0, n2], 
          PR[ 
            Plus[ k1, p1, p2], m, 
            Plus[ n3, 
              Times[ -1, z3]]], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p3]], 0, 
            Plus[ -2, eps, n4, n5, n6, n7, z1, z2, z3, z4]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3]]\^2 - s\ X[1]\ X[3] - t\ X[2]\ X[4] + 
      4\ m\^2\ X[3]\ X[4] - s\ X[3]\ X[4] - t\ X[3]\ X[4] - 
      u\ X[3]\ X[4]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7\)\ 4\^z9\
\ \((m\^2)\)\^\(z1 + z6 + z9\)\ \((\(-s\))\)\^\(z10 + z4 + z7\)\ \((\(-t\))\)\
\^\(z11 + z8\)\ \((\(-u\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 \
- z1 - z10 - z11 - z4 - z6 - z7 - z8 - z9\)\ Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ \
Gamma[\(-z11\)]\ Gamma[\(-z12\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                  z4]\ Gamma[\(-z4\)]\ Gamma[
                n6 + 2\ z1 + z3 + z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                n5 + z2 + z4 + z5]\ Gamma[z12 - 2\ z6]\ Gamma[\(-z6\)]\ Gamma[
                2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - 
                  z7]\ Gamma[\(-z7\)]\ Gamma[n1 + z12 - z2 + z7]\ Gamma[
                4 - 2\ eps - n1 - n2 - n4 - n5 - n6 - n7 - z1 - z12 - z3 - 
                  z4 + z6 - z8]\ Gamma[\(-z8\)]\ Gamma[
                n2 + z8]\ Gamma[\(-z9\)]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + 
                  n3 + n4 + n5 + n6 + n7 + z1 + z10 + z11 + z4 + z6 + z7 + 
                  z8 + z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[
                n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                n7]\ Gamma[\(-2\)\ z1]\ Gamma[n1 - z2]\ Gamma[n3 - z3]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - 
                  z4]\ Gamma[\(-2\)\ z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fauto[0]\)], "Input"],

Cell[BoxData[
    \(Fmanual::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in MANUAL mode. Now you can \
modify F polynomial (fupc)."\)], "Message"],

Cell[BoxData[
    \("fupc=FUpolyfun[integral,momentum,invariants]"\)], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("fupc="\[InvisibleSpace]\(m\^2\ FX[X[1] + X[3]]\^2 - 
          s\ X[1]\ X[3] - t\ X[2]\ X[4] + 4\ m\^2\ X[3]\ X[4] - 
          s\ X[3]\ X[4] - t\ X[3]\ X[4] - u\ X[3]\ X[4]\)\),
      SequenceForm[ "fupc=", 
        Plus[ 
          Times[ 
            Power[ m, 2], 
            Power[ 
              FX[ 
                Plus[ 
                  X[ 1], 
                  X[ 3]]], 2]], 
          Times[ -1, s, 
            X[ 1], 
            X[ 3]], 
          Times[ -1, t, 
            X[ 2], 
            X[ 4]], 
          Times[ 4, 
            Power[ m, 2], 
            X[ 3], 
            X[ 4]], 
          Times[ -1, s, 
            X[ 3], 
            X[ 4]], 
          Times[ -1, t, 
            X[ 3], 
            X[ 4]], 
          Times[ -1, u, 
            X[ 3], 
            X[ 4]]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fupc = fupc /. u \[Rule] 4\ m^2 - s - t // Expand\)], "Input"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3]]\^2 - s\ X[1]\ X[3] - t\ X[2]\ X[4]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("U & F polynomial was computed by user >>Fauto["\
\[InvisibleSpace]0\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "U & F polynomial was computed by user >>Fauto[", 0, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7\)\ \
\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(4 - 2\ \
eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                  z4]\ Gamma[\(-z4\)]\ Gamma[
                n6 + 2\ z1 + z3 + z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                n5 + z2 + z4 + z5]\ Gamma[\(-z6\)]\ Gamma[
                2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - z7]\ Gamma[
                4 - 2\ eps - n1 - n3 - n4 - n5 - n6 - n7 - z1 - z4 - z6 - 
                  z7]\ Gamma[\(-z7\)]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + 
                  n4 + n5 + n6 + n7 + z1 + z4 + z6 + z7]\ Gamma[
                n3 - z3 + 2\ z6 + z7 - 
                  z8]\ Gamma[\(-z8\)]\ Gamma[\(-2\)\ z6 + z8]\ Gamma[
                n1 - z2 + z7 + z8])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[
                n5]\ Gamma[n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                n7]\ Gamma[\(-2\)\ z1]\ Gamma[n1 - z2]\ Gamma[n3 - z3]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - 
                  z4]\ Gamma[\(-2\)\ z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z8, z5, z3, z2}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z8, z5, z3, z2}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]8\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 8, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z8...Barnes Lemma was applied.
2. Checking z5...Barnes Lemma was applied.
3. Checking z3
4. Checking z2\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z5, z8}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z5, z8}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]6\),
      SequenceForm[ "   Obtained representation has: dim=", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7\)\ \((m\^2)\)\^\(z1 \
+ z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(4 - 2\ eps - n1 - n2 - n3 \
- n4 - n5 - n6 - n7 - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-z3\)]\ Gamma[2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
            2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[n5 + z2 + z4]\ Gamma[
            n6 + z3 + z4]\ Gamma[
            n5 + n6 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[
            2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - z7]\ Gamma[
            4 - 2\ eps - n1 - n3 - n4 - n5 - n6 - n7 - z1 - z4 - z6 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[n1 - z2 + z7]\ Gamma[
            n3 - z3 + z7]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + n5 + 
              n6 + n7 + z1 + z4 + z6 + z7]\ Gamma[
            n1 + n3 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[n2]\ Gamma[
            n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[n7]\ Gamma[n1 - z2]\ Gamma[
            n3 - z3]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - z4]\ Gamma[
            n5 + n6 + z2 + z3 + 2\ z4]\ Gamma[
            n1 + n3 - z2 - z3 + 2\ z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = % /. {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \
\((\(-t\))\)\^\(\(-3\) - 2\ eps - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\
\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - eps - 
                z1 - z2 - z3 - z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
              1 + z3 + z4]\ Gamma[
              2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[\(-1\) - 
                eps + z2 + z3 - z6 - z7]\ Gamma[\(-2\) - 2\ eps - z1 - z4 - 
                z6 - z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
              1 - z3 + z7]\ Gamma[3 + 2\ eps + z1 + z4 + z6 + z7]\ Gamma[
              2 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
              1 - z2]\ Gamma[1 - z3]\ Gamma[\(-1\) - 3\ eps - z1 - z4]\ Gamma[
              2 + z2 + z3 + 2\ z4]\ Gamma[
              2 - z2 - z3 + 2\ z7])\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]we\ can\ repeat\ derivation\ in\ an\ automatic\ \
way\ \ without\ using\ Fauto[0]\ mode\ by\ modifying\ \(invariants : \ 
            u\) \[Rule] 
        4\ m^2 - s - 
          t\ from\ very\ beginning\ \[IndentingNewLine]*) \)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
              p4^2 \[Rule] m^2, p1*p2 \[Rule] 1/2*s - m^2, 
              p3*p4 \[Rule] 1/2\ s - m^2, p1*p3 \[Rule] 1/2*t - m^2, 
              p2*p4 \[Rule] 1/2*t - m^2, p2*p3 \[Rule] 1/2*u - m^2, 
              p1*p4 \[Rule] 1/2*u - m^2} /. u \[Rule] 4\ m^2 - s - t // 
          Expand;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1 - k2, 0, n4]\ PR[
            k2, m, n5]\ PR[k2 + p1 + p2, m, n6]\ PR[k2 - p3, 0, n7]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ 
            Plus[ k1, 
              Times[ -1, k2]], 0, n4], 
          PR[ k2, m, n5], 
          PR[ 
            Plus[ k2, p1, p2], m, n6], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p3]], 0, n7]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[2] + X[3]]\^2 - PR[k1, m]\ X[1]\ X[2] - 
      PR[k1 + p1 + p2, m]\ X[1]\ X[3] - s\ X[2]\ X[3] - 
      PR[k1 - p3, 0]\ X[1]\ X[4]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k2..."\),
      SequenceForm[ "Representation after integrating over: ", "k2..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps - z1 - z4\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^z4\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                    2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                    2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                      z4]\ Gamma[\(-z4\)]\ Gamma[\(-2\) + eps + n4 + n5 + 
                      n6 + n7 + z1 + z2 + z3 + z4]\ Gamma[
                    n6 + 2\ z1 + z3 + z4 - 
                      z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                    n5 + z2 + z4 + z5])\)/\((Gamma[n4]\ Gamma[n5]\ Gamma[
                    n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                    n7]\ Gamma[\(-2\)\ z1])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k1, m, z2]\ PR[k1 + p1 + p2, m, z3]\ PR[k1 - p3, 0, 
                2 - eps - n4 - n5 - n6 - n7 - z1 - z2 - z3 - z4]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m, n1 - z2]\ PR[
            k1 + p1, 0, n2]\ PR[k1 + p1 + p2, m, n3 - z3]\ PR[k1 - p3, 
            0, \(-2\) + eps + n4 + n5 + n6 + n7 + z1 + z2 + z3 + z4]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m, 
            Plus[ n1, 
              Times[ -1, z2]]], 
          PR[ 
            Plus[ k1, p1], 0, n2], 
          PR[ 
            Plus[ k1, p1, p2], m, 
            Plus[ n3, 
              Times[ -1, z3]]], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p3]], 0, 
            Plus[ -2, eps, n4, n5, n6, n7, z1, z2, z3, z4]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3]]\^2 - s\ X[1]\ X[3] - t\ X[2]\ X[4]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7\)\ \
\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(4 - 2\ \
eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                  z4]\ Gamma[\(-z4\)]\ Gamma[
                n6 + 2\ z1 + z3 + z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                n5 + z2 + z4 + z5]\ Gamma[\(-z6\)]\ Gamma[
                2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - z7]\ Gamma[
                4 - 2\ eps - n1 - n3 - n4 - n5 - n6 - n7 - z1 - z4 - z6 - 
                  z7]\ Gamma[\(-z7\)]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + 
                  n4 + n5 + n6 + n7 + z1 + z4 + z6 + z7]\ Gamma[
                n3 - z3 + 2\ z6 + z7 - 
                  z8]\ Gamma[\(-z8\)]\ Gamma[\(-2\)\ z6 + z8]\ Gamma[
                n1 - z2 + z7 + z8])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[
                n5]\ Gamma[n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                n7]\ Gamma[\(-2\)\ z1]\ Gamma[n1 - z2]\ Gamma[n3 - z3]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - 
                  z4]\ Gamma[\(-2\)\ z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z8, z5, z3, z2}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z8, z5, z3, z2}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]8\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 8, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z8...Barnes Lemma was applied.
2. Checking z5...Barnes Lemma was applied.
3. Checking z3
4. Checking z2\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z5, z8}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z5, z8}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]6\),
      SequenceForm[ "   Obtained representation has: dim=", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7\)\ \((m\^2)\)\^\(z1 \
+ z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(4 - 2\ eps - n1 - n2 - n3 \
- n4 - n5 - n6 - n7 - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-z3\)]\ Gamma[2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
            2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[n5 + z2 + z4]\ Gamma[
            n6 + z3 + z4]\ Gamma[
            n5 + n6 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[
            2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - z7]\ Gamma[
            4 - 2\ eps - n1 - n3 - n4 - n5 - n6 - n7 - z1 - z4 - z6 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[n1 - z2 + z7]\ Gamma[
            n3 - z3 + z7]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + n5 + 
              n6 + n7 + z1 + z4 + z6 + z7]\ Gamma[
            n1 + n3 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[n2]\ Gamma[
            n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[n7]\ Gamma[n1 - z2]\ Gamma[
            n3 - z3]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - z1 - z4]\ Gamma[
            n5 + n6 + z2 + z3 + 2\ z4]\ Gamma[
            n1 + n3 - z2 - z3 + 2\ z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = % /. {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \
\((\(-t\))\)\^\(\(-3\) - 2\ eps - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\
\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - eps - 
                z1 - z2 - z3 - z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
              1 + z3 + z4]\ Gamma[
              2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[\(-1\) - 
                eps + z2 + z3 - z6 - z7]\ Gamma[\(-2\) - 2\ eps - z1 - z4 - 
                z6 - z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
              1 - z3 + z7]\ Gamma[3 + 2\ eps + z1 + z4 + z6 + z7]\ Gamma[
              2 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
              1 - z2]\ Gamma[1 - z3]\ Gamma[\(-1\) - 3\ eps - z1 - z4]\ Gamma[
              2 + z2 + z3 + 2\ z4]\ Gamma[
              2 - z2 - z3 + 2\ z7])\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ numerical\ checks\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(27\/32\)\)}, {z1 \[Rule] \(-\(1\/2\)\), 
        z2 \[Rule] \(-\(1\/4\)\), z3 \[Rule] \(-\(1\/8\)\), 
        z4 \[Rule] \(-\(5\/32\)\), z6 \[Rule] \(-\(21\/64\)\), 
        z7 \[Rule] \(-\(17\/64\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(integrals = 
        MBcontinue[fin, eps \[Rule] 0, rules, 
          Verbose \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ser = 
      MBexpand[{integrals}, 
        Exp[2*eps\ EulerGamma], \[IndentingNewLine]{eps, 
          0, \(-1\)}]\)], "Input"],

Cell[BoxData[
    \({MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\
\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                    1 + z6]\)\/\(8\ eps\^2\ t\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\) - \(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - \
z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\
\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 4\ PolyGamma[0, \(-2\)\ z1] - 4\ \
PolyGamma[0, \(-z1\)] + 3\ PolyGamma[0, 1 + z1] - PolyGamma[0, 1 + z6])\)\)\/\
\(8\ eps\ t\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z6 \[Rule] \(-\(21\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(4\ eps\ t\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\
\ Gamma[\(-2\)\ z6]\), {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(1\/4\)\), z6 \[Rule] \(-\(21\/64\)\)}}], 
      MBint[\(3\ \((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\)\/\(4\ \
eps\^2\ t\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\) + \(\(1\/\(4\ eps\ t\ \
Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[
                1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 4\ Log[\(-t\)] + 
                  2\ PolyGamma[0, \(-2\)\ z1] - 2\ PolyGamma[0, \(-z1\)] + 
                  3\ PolyGamma[0, 1 + z1] + 2\ PolyGamma[0, \(-2\)\ z6] - 
                  2\ PolyGamma[0, \(-z6\)] - 
                  PolyGamma[0, 1 + z6])\))\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z6 \[Rule] \(-\(21\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-3\) - z1 - z6\)\ s\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(eps\ t\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\ \
Gamma[\(-2\)\ z6]\), {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(1\/4\)\), z6 \[Rule] \(-\(21\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                    1 + z6]\)\/\(8\ eps\^2\ t\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\) - \(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - \
z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\
\ \((2\ EulerGamma - 2\ Log[\(-s\)] + PolyGamma[0, 1 + z1] + 4\ PolyGamma[0, \
\(-2\)\ z6] - 4\ PolyGamma[0, \(-z6\)] + PolyGamma[0, 1 + z6])\)\)\/\(8\ eps\ \
t\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\), z6 \[Rule] \(-\(21\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(4\ eps\ t\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\
\ Gamma[\(-2\)\ z6]\), {{eps \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(21\/64\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser, {s \[Rule] \(-1\)/2, t \[Rule] \(-3\), m \[Rule] 1}, 
        Verbose \[Rule] False] // AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({9.954516`7.449565142476257\ Second, {\(\(0.`\)\(\[InvisibleSpace]\)\) \
- 0.1423564587`\/eps\^2 + 
          0.16668131914999995`\/eps, {0.000020168636621700584`\/eps\^2 + 
            0.00004428856718463647`\/eps, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser, {s \[Rule] \(-2\), t \[Rule] \(-3\), m \[Rule] 1}, 
        Verbose \[Rule] False] // AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({7.149197`7.305802257946921\ Second, {\(\(0.`\)\(\[InvisibleSpace]\)\) \
- 0.09635424159999999`\/eps\^2 + 
          0.1064669757`\/eps, {0.00001292435834468886`\/eps\^2 + 
            0.000030726226381276664`\/eps, 0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]sectors\ decomposition\ gives\ the\ same, \ \
\[IndentingNewLine]also\ MBexample1 . nb\ by\ M . \ 
          Czakon\ [2]\ \[IndentingNewLine]*) \)], "Input"]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{1014, 714},
WindowMargins->{{0, Automatic}, {0, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "gluza", \
"papers", "MBRbuilder", "examples"}, "warsawIteration.ps", CharacterEncoding \
-> "iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 1, 27, "Input"],
Cell[1819, 56, 41, 1, 23, "Print"],
Cell[1863, 59, 51, 1, 23, "Print"],
Cell[1917, 62, 62, 1, 23, "Print"],
Cell[1982, 65, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2077, 71, 43, 1, 27, "Input"],
Cell[2123, 74, 56, 1, 23, "Print"],
Cell[2182, 77, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2257, 81, 144, 3, 59, "Input"],
Cell[2404, 86, 300, 5, 75, "Input"],
Cell[2707, 93, 330, 5, 43, "Input"],

Cell[CellGroupData[{
Cell[3062, 102, 43, 1, 27, "Input"],
Cell[3108, 105, 143, 3, 23, "Print"],
Cell[3254, 110, 487, 14, 23, "Print"],
Cell[3744, 126, 143, 3, 23, "Print"],
Cell[3890, 131, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4101, 139, 50, 1, 27, "Input"],
Cell[4154, 142, 264, 4, 23, "Print"],
Cell[4421, 148, 257, 5, 23, "Print"],
Cell[4681, 155, 50, 1, 23, "Print"],
Cell[4734, 158, 58, 1, 23, "Print"],
Cell[4795, 161, 50, 1, 23, "Print"],
Cell[4848, 164, 251, 4, 43, "Print"],
Cell[5102, 170, 215, 4, 23, "Print"],
Cell[5320, 176, 1436, 28, 122, "Output"]
}, Open  ]],
Cell[6771, 207, 434, 6, 123, "Input"],

Cell[CellGroupData[{
Cell[7230, 217, 41, 1, 27, "Input"],
Cell[7274, 220, 172, 3, 20, "Message"],
Cell[7449, 225, 79, 1, 23, "Print"],
Cell[7531, 228, 50, 1, 23, "Print"],
Cell[7584, 231, 58, 1, 23, "Print"],
Cell[7645, 234, 50, 1, 23, "Print"],
Cell[7698, 237, 1247, 45, 43, "Print"]
}, Open  ]],
Cell[8960, 285, 242, 4, 75, "Input"],

Cell[CellGroupData[{
Cell[9227, 293, 82, 1, 27, "Input"],
Cell[9312, 296, 175, 3, 29, "Output"]
}, Open  ]],
Cell[9502, 302, 263, 4, 75, "Input"],

Cell[CellGroupData[{
Cell[9790, 310, 50, 1, 27, "Input"],
Cell[9843, 313, 264, 4, 23, "Print"],
Cell[10110, 319, 253, 5, 23, "Print"],
Cell[10366, 326, 215, 4, 23, "Print"],
Cell[10584, 332, 1221, 24, 106, "Output"]
}, Open  ]],
Cell[11820, 359, 517, 8, 155, "Input"],

Cell[CellGroupData[{
Cell[12362, 371, 43, 1, 27, "Input"],
Cell[12408, 374, 143, 3, 23, "Print"],
Cell[12554, 379, 692, 19, 23, "Print"],
Cell[13249, 400, 143, 3, 23, "Print"],
Cell[13395, 405, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13606, 413, 55, 1, 27, "Input"],
Cell[13664, 416, 264, 4, 23, "Print"],
Cell[13931, 422, 257, 5, 23, "Print"],
Cell[14191, 429, 50, 1, 23, "Print"],
Cell[14244, 432, 58, 1, 23, "Print"],
Cell[14305, 435, 50, 1, 23, "Print"],
Cell[14358, 438, 173, 3, 25, "Print"],
Cell[14534, 443, 56, 1, 23, "Print"],
Cell[14593, 446, 1624, 25, 146, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16254, 476, 41, 1, 27, "Input"],
Cell[16298, 479, 172, 3, 20, "Message"],
Cell[16473, 484, 79, 1, 23, "Print"],
Cell[16555, 487, 50, 1, 23, "Print"],
Cell[16608, 490, 58, 1, 23, "Print"],
Cell[16669, 493, 50, 1, 23, "Print"],
Cell[16722, 496, 882, 32, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17641, 533, 82, 1, 27, "Input"],
Cell[17726, 536, 90, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17853, 542, 62, 1, 27, "Input"],
Cell[17918, 545, 264, 4, 23, "Print"],
Cell[18185, 551, 253, 5, 23, "Print"],
Cell[18441, 558, 56, 1, 23, "Print"],
Cell[18500, 561, 1473, 24, 130, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20010, 590, 53, 1, 27, "Input"],
Cell[20066, 593, 273, 5, 23, "Print"],
Cell[20342, 600, 226, 4, 23, "Print"],
Cell[20571, 606, 141, 6, 83, "Print"],
Cell[20715, 614, 80, 1, 23, "Print"],
Cell[20798, 617, 466, 12, 23, "Print"],
Cell[21267, 631, 197, 4, 23, "Print"],
Cell[21467, 637, 1265, 20, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22769, 662, 153, 2, 27, "Input"],
Cell[22925, 666, 903, 13, 102, "Output"]
}, Open  ]],
Cell[23843, 682, 284, 5, 75, "Input"],
Cell[24130, 689, 395, 6, 59, "Input"],

Cell[CellGroupData[{
Cell[24550, 699, 43, 1, 27, "Input"],
Cell[24596, 702, 143, 3, 23, "Print"],
Cell[24742, 707, 487, 14, 23, "Print"],
Cell[25232, 723, 143, 3, 23, "Print"],
Cell[25378, 728, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25589, 736, 50, 1, 27, "Input"],
Cell[25642, 739, 264, 4, 23, "Print"],
Cell[25909, 745, 257, 5, 23, "Print"],
Cell[26169, 752, 50, 1, 23, "Print"],
Cell[26222, 755, 58, 1, 23, "Print"],
Cell[26283, 758, 50, 1, 23, "Print"],
Cell[26336, 761, 174, 3, 25, "Print"],
Cell[26513, 766, 215, 4, 23, "Print"],
Cell[26731, 772, 1221, 24, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27989, 801, 43, 1, 27, "Input"],
Cell[28035, 804, 143, 3, 23, "Print"],
Cell[28181, 809, 692, 19, 23, "Print"],
Cell[28876, 830, 143, 3, 23, "Print"],
Cell[29022, 835, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29233, 843, 55, 1, 27, "Input"],
Cell[29291, 846, 264, 4, 23, "Print"],
Cell[29558, 852, 257, 5, 23, "Print"],
Cell[29818, 859, 50, 1, 23, "Print"],
Cell[29871, 862, 58, 1, 23, "Print"],
Cell[29932, 865, 50, 1, 23, "Print"],
Cell[29985, 868, 89, 1, 25, "Print"],
Cell[30077, 871, 56, 1, 23, "Print"],
Cell[30136, 874, 1473, 24, 130, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31646, 903, 53, 1, 27, "Input"],
Cell[31702, 906, 273, 5, 23, "Print"],
Cell[31978, 913, 226, 4, 23, "Print"],
Cell[32207, 919, 141, 6, 83, "Print"],
Cell[32351, 927, 80, 1, 23, "Print"],
Cell[32434, 930, 466, 12, 23, "Print"],
Cell[32903, 944, 197, 4, 23, "Print"],
Cell[33103, 950, 1265, 20, 134, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34405, 975, 153, 2, 27, "Input"],
Cell[34561, 979, 903, 13, 102, "Output"]
}, Open  ]],
Cell[35479, 995, 60, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[35564, 1000, 88, 1, 27, "Input"],
Cell[35655, 1003, 128, 2, 20, "Message"],
Cell[35786, 1007, 128, 2, 20, "Message"],
Cell[35917, 1011, 128, 2, 20, "Message"],
Cell[36048, 1015, 334, 5, 20, "Message"],
Cell[36385, 1022, 255, 4, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36677, 1031, 130, 3, 27, "Input"],
Cell[36810, 1036, 365, 5, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37212, 1046, 148, 4, 43, "Input"],
Cell[37363, 1052, 3555, 49, 599, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40955, 1106, 152, 2, 27, "Input"],
Cell[41110, 1110, 254, 4, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41401, 1119, 150, 2, 27, "Input"],
Cell[41554, 1123, 254, 4, 47, "Output"]
}, Open  ]],
Cell[41823, 1130, 201, 3, 75, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

