(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     24480,        714]*)
(*NotebookOutlinePosition[     25108,        736]*)
(*  CellTagsIndexPosition[     25064,        732]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Example\ of\ 4 - loop\ Self - 
        Energy\ diagram, \ see\ Fig  .7\ \[IndentingNewLine]*) \)], "Input"],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[k1, 0, n1] PR[k1 + p1, 0, n2] 
            PR[k2 - k1, 0, n3] PR[k2, 0, n4] PR[k4, 0, n5] 
            PR[k2 + k4 + p1, 0, n6] PR[k3, 0, n7] PR[k3 - k2 - k4, 0, n8] 
            PR[k3 + p1, 0, n9]}, {k1, k3, k4, k2}];\)\)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] s};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, 
            n1]\ PR[\(-k1\) + k2, 0, n3]\ PR[k1 + p1, 0, n2]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, n1], 
          PR[ 
            Plus[ 
              Times[ -1, k1], k2], 0, n3], 
          PR[ 
            Plus[ k1, p1], 0, n2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k2, 0]\)\ X[1]\ X[2] - s\ X[1]\ X[3] - 
      PR[k2 + p1, 0]\ X[2]\ X[3]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k1..."\),
      SequenceForm[ "Representation after integrating over: ", "k1..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps - z2\)\ \((\(-s\))\)\^z2\ \
Gamma[2 - eps - n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[
                    2 - eps - n1 - n2 - z2]\ Gamma[\(-z2\)]\ Gamma[
                    n1 + z1 + z2]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + 
                      z2])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
                    4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k2, 0, z1]\ PR[k2 + p1, 0, 
                2 - eps - n1 - n2 - n3 - z1 - z2]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k3, 0, 
            n7]\ PR[\(-k2\) + k3 - k4, 0, n8]\ PR[k3 + p1, 0, n9]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k3, 0, n7], 
          PR[ 
            Plus[ 
              Times[ -1, k2], k3, 
              Times[ -1, k4]], 0, n8], 
          PR[ 
            Plus[ k3, p1], 0, n9]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k3\),
      SequenceForm[ "momentum=", k3],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k3\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k3, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k2 + k4, 0]\)\ X[1]\ X[2] - s\ X[1]\ X[3] - 
      PR[k2 + k4 + p1, 0]\ X[2]\ X[3]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k1...k3..."\),
      SequenceForm[ "Representation after integrating over: ", "k1...k3..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop2", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(4 - 2\ eps - z2 - z4\)\ \
\((\(-s\))\)\^\(z2 + z4\)\ Gamma[
                    2 - eps - n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[
                    2 - eps - n1 - n2 - z2]\ Gamma[\(-z2\)]\ Gamma[
                    n1 + z1 + z2]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + 
                      z2]\ Gamma[
                    2 - eps - n7 - n8 - z3]\ Gamma[\(-z3\)]\ Gamma[
                    2 - eps - n7 - n9 - z4]\ Gamma[\(-z4\)]\ Gamma[
                    n7 + z3 + z4]\ Gamma[\(-2\) + eps + n7 + n8 + n9 + z3 + 
                      z4])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
                    4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[n7]\ Gamma[
                    n8]\ Gamma[4 - 2\ eps - n7 - n8 - n9]\ Gamma[n9])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k2 + k4, 0, z3]\ PR[k2 + k4 + p1, 0, 
                2 - eps - n7 - n8 - n9 - z3 - z4]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[3]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k4, 0, n5]\ PR[
            k2 + k4, 0, \(-z3\)]\ PR[k2 + k4 + p1, 
            0, \(-2\) + eps + n6 + n7 + n8 + n9 + z3 + z4]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k4, 0, n5], 
          PR[ 
            Plus[ k2, k4], 0, 
            Times[ -1, z3]], 
          PR[ 
            Plus[ k2, k4, p1], 0, 
            Plus[ -2, eps, n6, n7, n8, n9, z3, z4]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k4\),
      SequenceForm[ "momentum=", k4],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]3\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k4\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 3, ": >>Integrating over ", k4, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k2, 0]\)\ X[1]\ X[2] - PR[k2 + p1, 0]\ X[1]\ X[3] - 
      s\ X[2]\ X[3]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k1...k3...k4..."\),
      SequenceForm[ 
      "Representation after integrating over: ", "k1...k3...k4..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop3", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps + n5 + n6 + n7 + n8 + n9 - z2 \
+ z5 + z6\)\ \((\(-s\))\)\^\(4 - 2\ eps - n5 - n6 - n7 - n8 - n9 + z2 - z5 - \
z6\)\ Gamma[2 - eps - n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[
                    2 - eps - n1 - n2 - z2]\ Gamma[\(-z2\)]\ Gamma[
                    n1 + z1 + z2]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + 
                      z2]\ Gamma[2 - eps - n7 - n8 - z3]\ Gamma[
                    2 - eps - n7 - n9 - z4]\ Gamma[\(-z4\)]\ Gamma[
                    n7 + z3 + z4]\ Gamma[\(-2\) + eps + n7 + n8 + n9 + z3 + 
                      z4]\ Gamma[
                    2 - eps - n5 + z3 - z5]\ Gamma[\(-z5\)]\ Gamma[
                    4 - 2\ eps - n5 - n6 - n7 - n8 - n9 - z3 - z4 - 
                      z6]\ Gamma[\(-z6\)]\ Gamma[
                    n5 + z5 + z6]\ Gamma[\(-4\) + 2\ eps + n5 + n6 + n7 + 
                      n8 + n9 + z4 + z5 + z6])\)/\((Gamma[n1]\ Gamma[
                    n2]\ Gamma[4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[
                    n5]\ Gamma[n7]\ Gamma[n8]\ Gamma[
                    4 - 2\ eps - n7 - n8 - n9]\ Gamma[n9]\ Gamma[
                    6 - 3\ eps - n5 - n6 - n7 - n8 - n9 - z4]\ Gamma[\(-2\) + 
                      eps + n6 + n7 + n8 + n9 + z3 + z4])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          StyleBox[\(PR[k2, 0, z5]\ PR[k2 + p1, 0, z6]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[4]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k2, 0, 
            n4 - z1 - z5]\ PR[k2 + p1, 
            0, \(-2\) + eps + n1 + n2 + n3 + z1 + z2 - z6]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k2, 0, 
            Plus[ n4, 
              Times[ -1, z1], 
              Times[ -1, z5]]], 
          PR[ 
            Plus[ k2, p1], 0, 
            Plus[ -2, eps, n1, n2, n3, z1, z2, 
              Times[ -1, z6]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]4\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 4, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-s\)\ X[1]\ X[2]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8 + \
n9\)\ \((\(-s\))\)\^\(8 - 4\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - n9\
\)\ Gamma[2 - eps - n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[
                2 - eps - n1 - n2 - z2]\ Gamma[\(-z2\)]\ Gamma[
                n1 + z1 + z2]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + 
                  z2]\ Gamma[2 - eps - n7 - n8 - z3]\ Gamma[
                2 - eps - n7 - n9 - z4]\ Gamma[\(-z4\)]\ Gamma[
                n7 + z3 + z4]\ Gamma[\(-2\) + eps + n7 + n8 + n9 + z3 + 
                  z4]\ Gamma[2 - eps - n5 + z3 - z5]\ Gamma[\(-z5\)]\ Gamma[
                2 - eps - n4 + z1 + z5]\ Gamma[
                4 - 2\ eps - n5 - n6 - n7 - n8 - n9 - z3 - z4 - 
                  z6]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + z2 - z5 - 
                  z6]\ Gamma[\(-z6\)]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3 - z1 - z2 + z6]\ Gamma[
                n5 + z5 + z6]\ Gamma[\(-4\) + 2\ eps + n5 + n6 + n7 + n8 + 
                  n9 + z4 + z5 + z6])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[n5]\ Gamma[
                n7]\ Gamma[n8]\ Gamma[4 - 2\ eps - n7 - n8 - n9]\ Gamma[
                n9]\ Gamma[
                6 - 3\ eps - n5 - n6 - n7 - n8 - n9 - z4]\ Gamma[\(-2\) + 
                  eps + n6 + n7 + n8 + n9 + z3 + z4]\ Gamma[
                n4 - z1 - z5]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + z2 - 
                  z6]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - z2 + z5 + z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z6, z5, z4, z3, z2, z1}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z6, z5, z4, z3, z2, z1}, 
        " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]6\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 6, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z6
2. Checking z5
3. Checking z4
4. Checking z3
5. Checking z2
6. Checking z1\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"   Could not apply Barnes-Lemma\"\>",
        FontColor->RGBColor[1, 0, 0]],
      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8 + n9\)\ \
\((\(-s\))\)\^\(8 - 4\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - n9\)\ \
Gamma[2 - eps - n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[
            2 - eps - n1 - n2 - z2]\ Gamma[\(-z2\)]\ Gamma[
            n1 + z1 + z2]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + 
              z2]\ Gamma[2 - eps - n7 - n8 - z3]\ Gamma[
            2 - eps - n7 - n9 - z4]\ Gamma[\(-z4\)]\ Gamma[
            n7 + z3 + z4]\ Gamma[\(-2\) + eps + n7 + n8 + n9 + z3 + 
              z4]\ Gamma[2 - eps - n5 + z3 - z5]\ Gamma[\(-z5\)]\ Gamma[
            2 - eps - n4 + z1 + z5]\ Gamma[
            4 - 2\ eps - n5 - n6 - n7 - n8 - n9 - z3 - z4 - 
              z6]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + z2 - z5 - 
              z6]\ Gamma[\(-z6\)]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - z1 - z2 + z6]\ Gamma[
            n5 + z5 + z6]\ Gamma[\(-4\) + 2\ eps + n5 + n6 + n7 + n8 + n9 + 
              z4 + z5 + z6])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[n5]\ Gamma[
            n7]\ Gamma[n8]\ Gamma[4 - 2\ eps - n7 - n8 - n9]\ Gamma[
            n9]\ Gamma[
            6 - 3\ eps - n5 - n6 - n7 - n8 - n9 - z4]\ Gamma[\(-2\) + eps + 
              n6 + n7 + n8 + n9 + z3 + z4]\ Gamma[
            n4 - z1 - z5]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + z2 - 
              z6]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - z2 + z5 + z6])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = %\  /. {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1, n6 \[Rule] 1, n8 \[Rule] 1, n7 \[Rule] 1, 
          n9 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\(-\(\((\((\(-s\))\)\^\(\(-1\) - 4\ eps\)\ Gamma[\(-eps\) - 
                z1]\ Gamma[\(-z1\)]\ Gamma[\(-eps\) - 
                z2]\ Gamma[\(-z2\)]\ Gamma[1 + z1 + z2]\ Gamma[
              1 + eps + z1 + z2]\ Gamma[\(-eps\) - z3]\ Gamma[\(-eps\) - 
                z4]\ Gamma[\(-z4\)]\ Gamma[1 + z3 + z4]\ Gamma[
              1 + eps + z3 + z4]\ Gamma[
              1 - eps + z3 - z5]\ Gamma[\(-z5\)]\ Gamma[
              1 - eps + z1 + z5]\ Gamma[\(-1\) - 2\ eps - z3 - z4 - 
                z6]\ Gamma[2\ eps + z2 - z5 - z6]\ Gamma[\(-z6\)]\ Gamma[
              1 - 2\ eps - z1 - z2 + z6]\ Gamma[1 + z5 + z6]\ Gamma[
              1 + 2\ eps + z4 + z5 + z6])\)/\((Gamma[1 - 2\ eps]\^2\ Gamma[
              1 - 3\ eps - z4]\ Gamma[2 + eps + z3 + z4]\ Gamma[
              1 - z1 - z5]\ Gamma[1 + eps + z1 + z2 - z6]\ Gamma[
              2 - 3\ eps - z2 + z5 + z6])\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[repr, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(1\/24\)\)}, {z1 \[Rule] \(-\(7\/24\)\), 
        z2 \[Rule] \(-\(11\/24\)\), z3 \[Rule] \(-\(37\/96\)\), 
        z4 \[Rule] \(-\(3\/16\)\), z5 \[Rule] \(-\(37\/192\)\), 
        z6 \[Rule] \(-\(85\/192\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals = 
      MBcontinue[repr, eps \[Rule] 0, rules, 
        Verbose \[Rule] False]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({MBint[\(-\(\((\((\(-s\))\)\^\(\(-1\) - 4\ eps\)\ Gamma[\(-eps\) - 
                    z1]\ Gamma[\(-z1\)]\ Gamma[\(-eps\) - 
                    z2]\ Gamma[\(-z2\)]\ Gamma[1 + z1 + z2]\ Gamma[
                  1 + eps + z1 + z2]\ Gamma[\(-eps\) - z3]\ Gamma[\(-eps\) - 
                    z4]\ Gamma[\(-z4\)]\ Gamma[1 + z3 + z4]\ Gamma[
                  1 + eps + z3 + z4]\ Gamma[
                  1 - eps + z3 - z5]\ Gamma[\(-z5\)]\ Gamma[
                  1 - eps + z1 + z5]\ Gamma[\(-1\) - 2\ eps - z3 - z4 - 
                    z6]\ Gamma[2\ eps + z2 - z5 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 - 2\ eps - z1 - z2 + z6]\ Gamma[1 + z5 + z6]\ Gamma[
                  1 + 2\ eps + z4 + z5 + 
                    z6])\)/\((Gamma[1 - 2\ eps]\^2\ Gamma[
                  1 - 3\ eps - z4]\ Gamma[2 + eps + z3 + z4]\ Gamma[
                  1 - z1 - z5]\ Gamma[1 + eps + z1 + z2 - z6]\ Gamma[
                  2 - 3\ eps - z2 + z5 + z6])\)\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(7\/24\)\), z2 \[Rule] \(-\(11\/24\)\), 
            z3 \[Rule] \(-\(37\/96\)\), z4 \[Rule] \(-\(3\/16\)\), 
            z5 \[Rule] \(-\(37\/192\)\), 
            z6 \[Rule] \(-\(85\/192\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ser0 = 
        MBexpand[{integrals}, 
          Exp[4*eps\ EulerGamma], {eps, 0, 0}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser0, {s \[Rule] \(-1\)/2}, Verbose -> False] // 
      AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({41.544644`8.070060035306122\ Second, {\(-111.054307`\), {0.496006731`, 
          0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ eq . \ 4.101\ by\ V . \ Smirnov\ [6]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(441/8\ Zeta[7]/s /. s \[Rule] \(-1\)/2 // N\)], "Input"],

Cell[BoxData[
    \(\(-111.170507831357`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser0, {s \[Rule] \(-1\)/7}]\)], "Input"],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 0 1-dimensional integrations", "Print"],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart10"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]6\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart10", " (dim ", 6, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart10"\),
      SequenceForm[ "Running ", "MBpart10"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-388.747113`\), {1.7659742`, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(441/8\ Zeta[7]/s /. s \[Rule] \(-1\)/7 // N\)], "Input"],

Cell[BoxData[
    \(\(-389.0967774097495`\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ser = 
        MBexpand[{integrals}, 
          Exp[4*eps\ EulerGamma], {eps, 0, 2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser, {s \[Rule] \(-1\)/2}, Verbose \[Rule] False] // 
      AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({871.35236`9.391738805287236\ Second, {\(-111.388544`\) - 
          657.731539`\ eps - 
          4445.932`\ eps\^2, {\(\(0.490011945`\)\(\[InvisibleSpace]\)\) + 
            6.1445719`\ eps + 68.3395148`\ eps\^2, 0}}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{537, 689},
WindowMargins->{{Automatic, 0}, {Automatic, 25}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 1, 27, "Input"],
Cell[1819, 56, 41, 1, 23, "Print"],
Cell[1863, 59, 51, 1, 23, "Print"],
Cell[1917, 62, 62, 1, 23, "Print"],
Cell[1982, 65, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2077, 71, 43, 1, 27, "Input"],
Cell[2123, 74, 56, 1, 23, "Print"],
Cell[2182, 77, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2257, 81, 151, 2, 59, "Input"],
Cell[2411, 85, 276, 4, 91, "Input"],
Cell[2690, 91, 67, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2782, 96, 43, 1, 27, "Input"],
Cell[2828, 99, 143, 3, 23, "Print"],
Cell[2974, 104, 385, 11, 23, "Print"],
Cell[3362, 117, 143, 3, 23, "Print"],
Cell[3508, 122, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3719, 130, 50, 1, 27, "Input"],
Cell[3772, 133, 264, 4, 23, "Print"],
Cell[4039, 139, 257, 5, 23, "Print"],
Cell[4299, 146, 50, 1, 23, "Print"],
Cell[4352, 149, 51, 1, 23, "Print"],
Cell[4406, 152, 50, 1, 23, "Print"],
Cell[4459, 155, 111, 2, 23, "Print"],
Cell[4573, 159, 215, 4, 23, "Print"],
Cell[4791, 165, 860, 19, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5688, 189, 43, 1, 27, "Input"],
Cell[5734, 192, 143, 3, 23, "Print"],
Cell[5880, 197, 421, 12, 23, "Print"],
Cell[6304, 211, 143, 3, 23, "Print"],
Cell[6450, 216, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6661, 224, 50, 1, 27, "Input"],
Cell[6714, 227, 264, 4, 23, "Print"],
Cell[6981, 233, 257, 5, 23, "Print"],
Cell[7241, 240, 50, 1, 23, "Print"],
Cell[7294, 243, 51, 1, 23, "Print"],
Cell[7348, 246, 50, 1, 23, "Print"],
Cell[7401, 249, 121, 2, 23, "Print"],
Cell[7525, 253, 225, 4, 23, "Print"],
Cell[7753, 259, 1243, 25, 177, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9033, 289, 43, 1, 27, "Input"],
Cell[9079, 292, 143, 3, 23, "Print"],
Cell[9225, 297, 494, 13, 39, "Print"],
Cell[9722, 312, 143, 3, 23, "Print"],
Cell[9868, 317, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10079, 325, 50, 1, 27, "Input"],
Cell[10132, 328, 264, 4, 23, "Print"],
Cell[10399, 334, 257, 5, 23, "Print"],
Cell[10659, 341, 50, 1, 23, "Print"],
Cell[10712, 344, 51, 1, 23, "Print"],
Cell[10766, 347, 50, 1, 23, "Print"],
Cell[10819, 350, 111, 2, 23, "Print"],
Cell[10933, 354, 242, 5, 23, "Print"],
Cell[11178, 361, 1681, 30, 273, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12896, 396, 43, 1, 27, "Input"],
Cell[12942, 399, 143, 3, 23, "Print"],
Cell[13088, 404, 503, 14, 39, "Print"],
Cell[13594, 420, 143, 3, 23, "Print"],
Cell[13740, 425, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13951, 433, 62, 1, 27, "Input"],
Cell[14016, 436, 264, 4, 23, "Print"],
Cell[14283, 442, 257, 5, 23, "Print"],
Cell[14543, 449, 50, 1, 23, "Print"],
Cell[14596, 452, 44, 1, 23, "Print"],
Cell[14643, 455, 50, 1, 23, "Print"],
Cell[14696, 458, 51, 1, 23, "Print"],
Cell[14750, 461, 56, 1, 23, "Print"],
Cell[14809, 464, 1697, 27, 285, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16543, 496, 53, 1, 27, "Input"],
Cell[16599, 499, 298, 6, 39, "Print"],
Cell[16900, 507, 226, 4, 23, "Print"],
Cell[17129, 513, 115, 8, 113, "Print"],
Cell[17247, 523, 80, 1, 23, "Print"],
Cell[17330, 526, 190, 4, 23, "Print"],
Cell[17523, 532, 1494, 24, 323, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19054, 561, 195, 3, 43, "Input"],
Cell[19252, 566, 916, 14, 194, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20205, 585, 89, 1, 27, "Input"],
Cell[20297, 588, 261, 4, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20595, 597, 122, 3, 27, "Input"],
Cell[20720, 602, 365, 5, 46, "Message"],
Cell[21088, 609, 1241, 19, 289, "Output"]
}, Open  ]],
Cell[22344, 631, 123, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[22492, 638, 115, 2, 43, "Input"],
Cell[22610, 642, 121, 2, 27, "Output"]
}, Open  ]],
Cell[22746, 647, 77, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[22848, 652, 76, 1, 27, "Input"],
Cell[22927, 655, 56, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23020, 661, 72, 1, 27, "Input"],
Cell[23095, 664, 55, 1, 23, "Print"],
Cell[23153, 667, 56, 0, 23, "Print"],
Cell[23212, 669, 63, 1, 23, "Print"],
Cell[23278, 672, 244, 4, 23, "Print"],
Cell[23525, 678, 157, 3, 23, "Print"],
Cell[23685, 683, 69, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23791, 689, 76, 1, 27, "Input"],
Cell[23870, 692, 57, 1, 27, "Output"]
}, Open  ]],
Cell[23942, 696, 122, 3, 43, "Input"],

Cell[CellGroupData[{
Cell[24089, 703, 119, 2, 43, "Input"],
Cell[24211, 707, 253, 4, 47, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

