(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     59378,       1535]*)
(*NotebookOutlinePosition[     60006,       1557]*)
(*  CellTagsIndexPosition[     59962,       1553]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 21 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Pentabox, \ 
      Fig  .7\ \[IndentingNewLine]we\ use\ kinematics, \ Eq  .6, 
      and\ perform\ calculations\ for\ two\ different\ orders\ of\ \
\(integrations : \[IndentingNewLine]\t\(example : \ 
            ONE\  - \ {k2, k1}\[IndentingNewLine]
          \ 
          example : \ TWO\  - \ {k1, k2}\)\)\[IndentingNewLine]*) \)], "Input"],

Cell[BoxData[
    \( (**************************************************************) \)], \
"Input"],

Cell[BoxData[
    \( (*\ example : \ ONE\ *) \)], "Input"],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[k1, 0, n5] PR[k1 - k2, 0, n2] 
            PR[k1 + p1 + p2, 0, n8] PR[k1 - p4 - p5, 0, n7] 
            PR[k1 - p5, 0, n6] PR[k2, 0, n1] PR[k2 + p1, 0, n4] 
            PR[k2 + p1 + p2, 0, n3]}, {k2, k1}];\)\)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, 
          p4^2 \[Rule] 0, p5^2 \[Rule] 0, p1*p2 \[Rule] s12/2, 
          p2*p3 \[Rule] s23/2, p3*p4 \[Rule] s34/2, p4*p5 \[Rule] s45/2, 
          p1*p5 \[Rule] s15/2, p1*p3 \[Rule] \((\(-s12\) - s23 + s45)\)/2, 
          p1*p4 \[Rule] \((\(-s15\) + s23 - s45)\)/2, 
          p2*p4 \[Rule] \((s15 - s23 - s34)\)/2, 
          p2*p5 \[Rule] \((\(-s12\) - s15 + s34)\)/2, 
          p3*p5 \[Rule] \((s12 - s34 - s45)\)/2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1 - k2, 0, n2]\ PR[
            k2, 0, n1]\ PR[k2 + p1, 0, n4]\ PR[k2 + p1 + p2, 0, n3]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ 
            Plus[ k1, 
              Times[ -1, k2]], 0, n2], 
          PR[ k2, 0, n1], 
          PR[ 
            Plus[ k2, p1], 0, n4], 
          PR[ 
            Plus[ k2, p1, p2], 0, n3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k1, 0]\)\ X[1]\ X[2] - PR[k1 + p1, 0]\ X[1]\ X[3] - 
      PR[k1 + p1 + p2, 0]\ X[1]\ X[4] - s12\ X[2]\ X[4]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k2..."\),
      SequenceForm[ "Representation after integrating over: ", "k2..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + z1 + z2 + z3\)\ \
\((\(-s12\))\)\^\(2 - eps - n1 - n2 - n3 - n4 - z1 - z2 - z3\)\ \
Gamma[\(-z1\)]\ Gamma[
                    2 - eps - n1 - n2 - n4 - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[
                    n4 + z2]\ Gamma[
                    2 - eps - n2 - n3 - n4 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
                    n2 + z1 + z2 + z3]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + 
                      n4 + z1 + z2 + z3])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
                    n3]\ Gamma[4 - 2\ eps - n1 - n2 - n3 - n4]\ Gamma[
                    n4])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k1, 0, z1]\ PR[k1 + p1, 0, z2]\ PR[k1 + p1 + p2, 0, 
                z3]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, n5 - z1]\ PR[
            k1 + p1, 0, \(-z2\)]\ PR[k1 + p1 + p2, 0, n8 - z3]\ PR[k1 - p5, 
            0, n6]\ PR[k1 - p4 - p5, 0, n7]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, 
            Plus[ n5, 
              Times[ -1, z1]]], 
          PR[ 
            Plus[ k1, p1], 0, 
            Times[ -1, z2]], 
          PR[ 
            Plus[ k1, p1, p2], 0, 
            Plus[ n8, 
              Times[ -1, z3]]], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p5]], 0, n6], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p4], 
              Times[ -1, p5]], 0, n7]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-s12\)\ X[1]\ X[3] - s15\ X[2]\ X[4] - s34\ X[3]\ X[4] - 
      s45\ X[1]\ X[5] - s23\ X[2]\ X[5]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(2 - eps - n1 - n2 - n3 - n4 - z1 - z2 - z3 + z4\)\ \
\((\(-s15\))\)\^z5\ \((\(-s23\))\)\^\(2 - eps - n5 - n6 - n7 - n8 + z1 + z2 + \
z3 - z4 - z5 - z6 - z7\)\ \((\(-s34\))\)\^z6\ \((\(-s45\))\)\^z7\ Gamma[\(-z1\
\)]\ Gamma[2 - eps - n1 - n2 - n4 - z1 - z2]\ Gamma[n4 + z2]\ Gamma[
                2 - eps - n2 - n3 - n4 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
                n2 + z1 + z2 + z3]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + n4 + 
                  z1 + z2 + z3]\ Gamma[\(-z4\)]\ Gamma[\(-z5\)]\ Gamma[
                2 - eps - n5 - n6 - n8 + z1 + z2 + z3 - z4 - z5 - 
                  z6]\ Gamma[\(-z6\)]\ Gamma[n8 - z3 + z4 + z6]\ Gamma[
                n6 + z5 + z6]\ Gamma[
                2 - eps - n5 - n6 - n7 - n8 + z1 + z3 - z4 - z6 - 
                  z7]\ Gamma[\(-z7\)]\ Gamma[
                n5 - z1 + z4 + z7]\ Gamma[\(-2\) + eps + n5 + n6 + n7 + n8 - 
                  z1 - z2 - z3 + z4 + z5 + z6 + z7])\)/\((Gamma[n1]\ Gamma[
                n2]\ Gamma[n3]\ Gamma[4 - 2\ eps - n1 - n2 - n3 - n4]\ Gamma[
                n4]\ Gamma[n6]\ Gamma[n7]\ Gamma[n5 - z1]\ Gamma[
                n8 - z3]\ Gamma[
                4 - 2\ eps - n5 - n6 - n7 - n8 + z1 + z2 + z3])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{}\[InvisibleSpace]" <<"\),
      SequenceForm[ ">> Barnes 1st Lemma will be checked for: ", {}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]7\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 7, " representation..."],
      Editable->False]], "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"   Could not apply Barnes-Lemma\"\>",
        FontColor->RGBColor[1, 0, 0]],
      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(2 - eps - n1 - n2 - n3 - n4 - z1 - z2 - z3 + z4\)\ \
\((\(-s15\))\)\^z5\ \((\(-s23\))\)\^\(2 - eps - n5 - n6 - n7 - n8 + z1 + z2 + \
z3 - z4 - z5 - z6 - z7\)\ \((\(-s34\))\)\^z6\ \((\(-s45\))\)\^z7\ Gamma[\(-z1\
\)]\ Gamma[2 - eps - n1 - n2 - n4 - z1 - z2]\ Gamma[n4 + z2]\ Gamma[
            2 - eps - n2 - n3 - n4 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
            n2 + z1 + z2 + z3]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + n4 + z1 + 
              z2 + z3]\ Gamma[\(-z4\)]\ Gamma[\(-z5\)]\ Gamma[
            2 - eps - n5 - n6 - n8 + z1 + z2 + z3 - z4 - z5 - 
              z6]\ Gamma[\(-z6\)]\ Gamma[n8 - z3 + z4 + z6]\ Gamma[
            n6 + z5 + z6]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 + z1 + z3 - z4 - z6 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[
            n5 - z1 + z4 + z7]\ Gamma[\(-2\) + eps + n5 + n6 + n7 + n8 - z1 - 
              z2 - z3 + z4 + z5 + z6 + z7])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
            n3]\ Gamma[4 - 2\ eps - n1 - n2 - n3 - n4]\ Gamma[n4]\ Gamma[
            n6]\ Gamma[n7]\ Gamma[n5 - z1]\ Gamma[n8 - z3]\ Gamma[
            4 - 2\ eps - n5 - n6 - n7 - n8 + z1 + z2 + z3])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = %\  /. \ {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, 
          n4 \[Rule] 1, n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1, 
          n8 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\((\((\(-s12\))\)\^\(\(-2\) - eps - z1 - z2 - z3 + z4\)\ \((\(-s15\))\)\
\^z5\ \((\(-s23\))\)\^\(\(-2\) - eps + z1 + z2 + z3 - z4 - z5 - z6 - z7\)\ \
\((\(-s34\))\)\^z6\ \((\(-s45\))\)\^z7\ Gamma[\(-z1\)]\ Gamma[\(-1\) - eps - 
              z1 - z2]\ Gamma[
            1 + z2]\ Gamma[\(-1\) - eps - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
            1 + z1 + z2 + z3]\ Gamma[
            2 + eps + z1 + z2 + 
              z3]\ Gamma[\(-z4\)]\ Gamma[\(-z5\)]\ Gamma[\(-1\) - eps + z1 + 
              z2 + z3 - z4 - z5 - z6]\ Gamma[\(-z6\)]\ Gamma[
            1 - z3 + z4 + z6]\ Gamma[
            1 + z5 + z6]\ Gamma[\(-2\) - eps + z1 + z3 - z4 - z6 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[1 - z1 + z4 + z7]\ Gamma[
            2 + eps - z1 - z2 - z3 + z4 + z5 + z6 + 
              z7])\)/\((Gamma[\(-2\)\ eps]\ Gamma[1 - z1]\ Gamma[
            1 - z3]\ Gamma[\(-2\)\ eps + z1 + z2 + z3])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[repr, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(\(\(-2\)\) - \(\(2\\ \
eps\)\) - z2 - z6\)]"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(45\/64\)\)}, {z1 \[Rule] \(-\(1\/4\)\), 
        z2 \[Rule] \(-\(17\/32\)\), z3 \[Rule] \(-\(1\/8\)\), 
        z4 \[Rule] \(-\(153\/256\)\), z5 \[Rule] \(-\(25\/64\)\), 
        z6 \[Rule] \(-\(33\/64\)\), 
        z7 \[Rule] \(-\(161\/256\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(integrals = 
        MBcontinue[repr, eps \[Rule] 0, rules, 
          Verbose \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(ser = 
        MBexpand[{integrals}, 
          Exp[2\ eps\ EulerGamma], {eps, 0, \(-1\)}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AbsoluteTiming[
      MBintegrate[
        ser, {s12 \[Rule] \(-2\), s15 \[Rule] \(-1\)/2, s23 \[Rule] \(-4\), 
          s34 \[Rule] \(-5\), s45 \[Rule] \(-6\)}, 
        Verbose \[Rule] False]]\)], "Input"],

Cell[BoxData[
    \({36.485341`8.013663403115116\ Second, {0.159375`\/eps\^4 + 
          0.3193080330282121`\/eps\^3 + 0.4227442036090081`\/eps\^2 + 
          0.26448382493909656`\/eps, {0.00007196060953586187`\/eps, 
          0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \({0.159375`\/ep\^4 + 0.3193080330282121`\/ep\^3 + 
        0.4227454388047334`\/ep\^2 + 
        0.2644808232951413`\/ep, {0.00006874560282634233`\/ep, 0}}\)], "Input"],

Cell[BoxData[
    \( (*\ example : \ TWO\ *) \)], "Input"],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[k1, 0, n5] PR[k1 - k2, 0, n2] 
            PR[k1 + p1 + p2, 0, n8] PR[k1 - p4 - p5, 0, n7] 
            PR[k1 - p5, 0, n6] PR[k2, 0, n1] PR[k2 + p1, 0, n4] 
            PR[k2 + p1 + p2, 0, n3]}, {k1, k2}];\)\)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, 
          p4^2 \[Rule] 0, p5^2 \[Rule] 0, p1*p2 \[Rule] s12/2, 
          p2*p3 \[Rule] s23/2, p3*p4 \[Rule] s34/2, p4*p5 \[Rule] s45/2, 
          p1*p5 \[Rule] s15/2, p1*p3 \[Rule] \((\(-s12\) - s23 + s45)\)/2, 
          p1*p4 \[Rule] \((\(-s15\) + s23 - s45)\)/2, 
          p2*p4 \[Rule] \((s15 - s23 - s34)\)/2, 
          p2*p5 \[Rule] \((\(-s12\) - s15 + s34)\)/2, 
          p3*p5 \[Rule] \((s12 - s34 - s45)\)/2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, n5]\ PR[
            k1 - k2, 0, n2]\ PR[k1 + p1 + p2, 0, n8]\ PR[k1 - p5, 0, n6]\ PR[
            k1 - p4 - p5, 0, n7]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, n5], 
          PR[ 
            Plus[ k1, 
              Times[ -1, k2]], 0, n2], 
          PR[ 
            Plus[ k1, p1, p2], 0, n8], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p5]], 0, n6], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p4], 
              Times[ -1, p5]], 0, n7]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momenta="\[InvisibleSpace]k1\),
      SequenceForm[ "momenta=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k2, 0]\)\ X[1]\ X[2] - s12\ X[1]\ X[3] - 
      PR[k2 + p1 + p2, 0]\ X[2]\ X[3] - PR[k2 - p5, 0]\ X[2]\ X[4] - 
      s34\ X[3]\ X[4] - s45\ X[1]\ X[5] - 
      PR[\(-k2\) + p4 + p5, 0]\ X[2]\ X[5]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k1..."\),
      SequenceForm[ "Representation after integrating over: ", "k1..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps - z2 - z5 - z6\)\ \
\((\(-s12\))\)\^z2\ \((\(-s34\))\)\^z5\ \((\(-s45\))\)\^z6\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-z4\)]\ Gamma[
                    2 - eps - n2 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
                      z5]\ Gamma[\(-z5\)]\ Gamma[n8 + z2 + z3 + z5]\ Gamma[
                    n6 + z4 + z5]\ Gamma[
                    2 - eps - n5 - n6 - n7 - n8 - z2 - z5 - 
                      z6]\ Gamma[\(-z6\)]\ Gamma[
                    n5 + z1 + z2 + z6]\ Gamma[\(-2\) + eps + n2 + n5 + n6 + 
                      n7 + n8 + z1 + z2 + z3 + z4 + z5 + z6])\)/\((Gamma[
                    n2]\ Gamma[n5]\ Gamma[n6]\ Gamma[n7]\ Gamma[
                    4 - 2\ eps - n2 - n5 - n6 - n7 - n8]\ Gamma[n8])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k2, 0, z1]\ PR[k2 + p1 + p2, 0, z3]\ PR[k2 - p5, 0, 
                z4]\ PR[\(-k2\) + p4 + p5, 0, 
                2 - eps - n2 - n5 - n6 - n7 - n8 - z1 - z2 - z3 - z4 - z5 - 
                  z6]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k2, 0, n1 - z1]\ PR[
            k2 + p1, 0, n4]\ PR[k2 + p1 + p2, 0, n3 - z3]\ PR[k2 - p5, 
            0, \(-z4\)]\ PR[\(-k2\) + p4 + p5, 
            0, \(-2\) + eps + n2 + n5 + n6 + n7 + n8 + z1 + z2 + z3 + z4 + 
              z5 + z6]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k2, 0, 
            Plus[ n1, 
              Times[ -1, z1]]], 
          PR[ 
            Plus[ k2, p1], 0, n4], 
          PR[ 
            Plus[ k2, p1, p2], 0, 
            Plus[ n3, 
              Times[ -1, z3]]], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p5]], 0, 
            Times[ -1, z4]], 
          PR[ 
            Plus[ 
              Times[ -1, k2], p4, p5], 0, 
            Plus[ -2, eps, n2, n5, n6, n7, n8, z1, z2, z3, z4, z5, z6]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momenta="\[InvisibleSpace]k2\),
      SequenceForm[ "momenta=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-s12\)\ X[1]\ X[3] - s15\ X[2]\ X[4] - s34\ X[3]\ X[4] - 
      s45\ X[1]\ X[5] - s23\ X[2]\ X[5]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(2 + n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\
\)\ \((\(-s12\))\)\^\(z2 + z7\)\ \((\(-s15\))\)\^z8\ \((\(-s23\))\)\^\(4 - 2\ \
eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - z6 - z7 - z8 - \
z9\)\ \((\(-s34\))\)\^\(z5 + z9\)\ \((\(-s45\))\)\^\(z10 + z6\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n2 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[n8 + z2 + z3 + z5]\ Gamma[
                n6 + z4 + z5]\ Gamma[
                2 - eps - n5 - n6 - n7 - n8 - z2 - z5 - 
                  z6]\ Gamma[\(-z6\)]\ Gamma[
                n5 + z1 + z2 + z6]\ Gamma[\(-z7\)]\ Gamma[
                n1 - z1 + z10 + z7]\ Gamma[\(-z8\)]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3 - n5 - n6 - n7 - n8 - z10 - z2 - 
                  z5 - z6 - z7 - z9]\ Gamma[
                2 - eps - n1 - n3 - n4 + z1 + z3 + z4 - z7 - z8 - 
                  z9]\ Gamma[\(-z9\)]\ Gamma[
                n3 - z3 + z7 + z9]\ Gamma[\(-z4\) + z8 + z9]\ Gamma[\(-4\) + 
                  2\ eps + n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8 + z10 + z2 + 
                  z5 + z6 + z7 + z8 + z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[
                n5]\ Gamma[n6]\ Gamma[n7]\ Gamma[
                4 - 2\ eps - n2 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
                n1 - z1]\ Gamma[n3 - z3]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z2 - 
                  z5 - z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(2 + n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z2 + z7\)\ \((\(-s15\))\)\^z8\ \((\(-s23\))\)\^\(4 - 2\ eps \
- n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - z6 - z7 - z8 - z9\)\
\ \((\(-s34\))\)\^\(z5 + z9\)\ \((\(-s45\))\)\^\(z10 + z6\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z10\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
            2 - eps - n2 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[n8 + z2 + z3 + z5]\ Gamma[
            n6 + z4 + z5]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 - z2 - z5 - 
              z6]\ Gamma[\(-z6\)]\ Gamma[
            n5 + z1 + z2 + z6]\ Gamma[\(-z7\)]\ Gamma[
            n1 - z1 + z10 + z7]\ Gamma[\(-z8\)]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - 
              z6 - z7 - z9]\ Gamma[
            2 - eps - n1 - n3 - n4 + z1 + z3 + z4 - z7 - z8 - 
              z9]\ Gamma[\(-z9\)]\ Gamma[
            n3 - z3 + z7 + z9]\ Gamma[\(-z4\) + z8 + z9]\ Gamma[\(-4\) + 
              2\ eps + n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8 + z10 + z2 + 
              z5 + z6 + z7 + z8 + z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[
            n5]\ Gamma[n6]\ Gamma[n7]\ Gamma[
            4 - 2\ eps - n2 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
            n1 - z1]\ Gamma[n3 - z3]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z2 - z5 - 
              z6])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z4, z3, z1}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z4, z3, z1}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]10\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 10, " representation..."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z4"}],
      SequenceForm[ 1, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\" Barnes Lemma was applied for \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", "z4"}],
      SequenceForm[ 
        StyleForm[ 
        " Barnes Lemma was applied for ", FontColor -> RGBColor[ 1, 0, 0]], 
        z4],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(2 + n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z2 + z7\)\ \((\(-s15\))\)\^z8\ \((\(-s23\))\)\^\(4 - 2\ eps \
- n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - z6 - z7 - z8 - z9\)\
\ \((\(-s34\))\)\^\(z5 + z9\)\ \((\(-s45\))\)\^\(z10 + z6\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z10\)]\ Gamma[\(-z2\)]\ Gamma[
            2 - eps - n2 - n5 - n8 - z1 - z2 - 
              z3]\ Gamma[\(-z3\)]\ Gamma[\(-z5\)]\ Gamma[
            n8 + z2 + z3 + z5]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 - z2 - z5 - 
              z6]\ Gamma[\(-z6\)]\ Gamma[n5 + z1 + z2 + z6]\ Gamma[
            2 - eps - n1 - n3 - n4 + z1 + z3 - z7]\ Gamma[\(-z7\)]\ Gamma[
            n1 - z1 + z10 + z7]\ Gamma[\(-z8\)]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - 
              z6 - z7 - z9]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n8 - z2 - z5 - z7 - 
              z8 - z9]\ Gamma[\(-z9\)]\ Gamma[n3 - z3 + z7 + z9]\ Gamma[
            n6 + z5 + z8 + z9]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + 
              n5 + n6 + n7 + n8 + z10 + z2 + z5 + z6 + z7 + z8 + 
              z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            n7]\ Gamma[4 - 2\ eps - n2 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
            n1 - z1]\ Gamma[n3 - z3]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z2 - z5 - 
              z6]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n8 - z2 - z7])\)\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z3"}],
      SequenceForm[ 2, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"3", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z1"}],
      SequenceForm[ 3, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z4}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]9\),
      SequenceForm[ "   Obtained representation has: dim=", 9],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(2 + n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z2 + z7\)\ \((\(-s15\))\)\^z8\ \((\(-s23\))\)\^\(4 - 2\ eps \
- n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - z6 - z7 - z8 - z9\)\
\ \((\(-s34\))\)\^\(z5 + z9\)\ \((\(-s45\))\)\^\(z10 + z6\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z10\)]\ Gamma[\(-z2\)]\ Gamma[
            2 - eps - n2 - n5 - n8 - z1 - z2 - 
              z3]\ Gamma[\(-z3\)]\ Gamma[\(-z5\)]\ Gamma[
            n8 + z2 + z3 + z5]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 - z2 - z5 - 
              z6]\ Gamma[\(-z6\)]\ Gamma[n5 + z1 + z2 + z6]\ Gamma[
            2 - eps - n1 - n3 - n4 + z1 + z3 - z7]\ Gamma[\(-z7\)]\ Gamma[
            n1 - z1 + z10 + z7]\ Gamma[\(-z8\)]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n5 - n6 - n7 - n8 - z10 - z2 - z5 - 
              z6 - z7 - z9]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n8 - z2 - z5 - z7 - 
              z8 - z9]\ Gamma[\(-z9\)]\ Gamma[n3 - z3 + z7 + z9]\ Gamma[
            n6 + z5 + z8 + z9]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + 
              n5 + n6 + n7 + n8 + z10 + z2 + z5 + z6 + z7 + z8 + 
              z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            n7]\ Gamma[4 - 2\ eps - n2 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
            n1 - z1]\ Gamma[n3 - z3]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z2 - z5 - 
              z6]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n8 - z2 - 
              z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = %\  /. \ {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, 
          n4 \[Rule] 1, n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1, 
          n8 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\((\((\(-s12\))\)\^\(z2 + z7\)\ \((\(-s15\))\)\^z8\ \
\((\(-s23\))\)\^\(\(-4\) - 2\ eps - z10 - z2 - z5 - z6 - z7 - z8 - z9\)\ \
\((\(-s34\))\)\^\(z5 + z9\)\ \((\(-s45\))\)\^\(z10 + z6\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z10\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - eps - z1 - z2 - 
              z3]\ Gamma[\(-z3\)]\ Gamma[\(-z5\)]\ Gamma[
            1 + z2 + z3 + z5]\ Gamma[\(-2\) - eps - z2 - z5 - 
              z6]\ Gamma[\(-z6\)]\ Gamma[
            1 + z1 + z2 + z6]\ Gamma[\(-1\) - eps + z1 + z3 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[
            1 - z1 + z10 + z7]\ Gamma[\(-z8\)]\ Gamma[\(-3\) - 2\ eps - z10 - 
              z2 - z5 - z6 - z7 - z9]\ Gamma[\(-3\) - 2\ eps - z2 - z5 - z7 - 
              z8 - z9]\ Gamma[\(-z9\)]\ Gamma[1 - z3 + z7 + z9]\ Gamma[
            1 + z5 + z8 + z9]\ Gamma[
            4 + 2\ eps + z10 + z2 + z5 + z6 + z7 + z8 + 
              z9])\)/\((Gamma[\(-1\) - 2\ eps]\ Gamma[1 - z1]\ Gamma[
            1 - z3]\ Gamma[\(-2\) - 3\ eps - z2 - z5 - z6]\ Gamma[\(-2\) - 
              2\ eps - z2 - z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[repr, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(\(\(-1\)\) - eps - \
z1 - z2 - z3\)]"\)], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(\(\(-1\)\) + eps + \
z1 - z10 - z5 - z6\)]"\)], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(\(\(-eps\)\) + z10 - \
z2\)]"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBresidues :: \\\"contour\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(65843\/57344\)\)}, {z1 \[Rule] \
\(-\(84443\/516096\)\), z10 \[Rule] \(-\(29\/384\)\), 
        z2 \[Rule] \(-\(133799\/172032\)\), 
        z3 \[Rule] \(-\(59131\/516096\)\), z5 \[Rule] \(-\(157\/2688\)\), 
        z6 \[Rule] \(-\(1213\/73728\)\), z7 \[Rule] \(-\(234571\/516096\)\), 
        z8 \[Rule] \(-\(160507\/516096\)\), 
        z9 \[Rule] \(-\(61\/9216\)\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(integrals = 
        MBcontinue[repr, eps \[Rule] 0, rules, 
          Verbose \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(\(ser = 
        MBexpand[{integrals}, 
          Exp[2\ eps\ EulerGamma], {eps, 0, \(-1\)}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[
        ser, {s12 \[Rule] \(-2\), s15 \[Rule] \(-1\)/2, s23 \[Rule] \(-4\), 
          s34 \[Rule] \(-5\), s45 \[Rule] \(-6\)}, Verbose \[Rule] False] // 
      AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({68.447122`8.286900185545296\ Second, {0.159375`\/eps\^4 + 
          0.31930803269010694`\/eps\^3 + 0.4227445613032026`\/eps\^2 + 
          0.2644803649100913`\/eps, {6.8655292227247265`*^-6\/eps\^2 + 
            0.00020496920732689079`\/eps, 0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ previous\ result\ *) \)], "Input"],

Cell[BoxData[
    \({0.159375`\/ep\^4 + 0.3193080330282121`\/ep\^3 + 
        0.4227454388047334`\/ep\^2 + 
        0.2644808232951413`\/ep, {0.00006874560282634233`\/ep, 0}}\)], "Input"],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Now\ let\ us\ see\ how\ important\ is\ a\ \
choice\ of\ momenta\ flow\ for\ the\ same\ invariants, \ 
      below\ is\ an\ example\ where\ external\ momenta\ are\ chosen\ in\ a\ \
different\ way\ \[IndentingNewLine]*) \)], "Input"],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[k1, 0, n1] PR[k1 + p1, 0, n2] 
            PR[k1 + p1 + p2, 0, n3] PR[k2, 0, n4] PR[k1 - k2, 0, n5] 
            PR[k2 + p1 + p2, 0, n6] PR[k2 - p3 - p4, 0, n7] 
            PR[k2 - p3, 0, n8]}, {k2, k1}];\)\)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, 
          p4^2 \[Rule] 0, p5^2 \[Rule] 0, p1*p2 \[Rule] s12/2, 
          p2*p3 \[Rule] s23/2, p3*p4 \[Rule] s34/2, p4*p5 \[Rule] s45/2, 
          p1*p5 \[Rule] s15/2, p1*p3 \[Rule] \((\(-s12\) - s23 + s45)\)/2, 
          p1*p4 \[Rule] \((\(-s15\) + s23 - s45)\)/2, 
          p2*p4 \[Rule] \((s15 - s23 - s34)\)/2, 
          p2*p5 \[Rule] \((\(-s12\) - s15 + s34)\)/2, 
          p3*p5 \[Rule] \((s12 - s34 - s45)\)/2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1 - k2, 0, n5]\ PR[
            k2, 0, n4]\ PR[k2 + p1 + p2, 0, n6]\ PR[k2 - p3, 0, n8]\ PR[
            k2 - p3 - p4, 0, n7]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ 
            Plus[ k1, 
              Times[ -1, k2]], 0, n5], 
          PR[ k2, 0, n4], 
          PR[ 
            Plus[ k2, p1, p2], 0, n6], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p3]], 0, n8], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p3], 
              Times[ -1, p4]], 0, n7]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momenta="\[InvisibleSpace]k2\),
      SequenceForm[ "momenta=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k1, 0]\)\ X[1]\ X[2] - PR[k1 + p1 + p2, 0]\ X[1]\ X[3] - 
      s12\ X[2]\ X[3] - PR[k1 - p3, 0]\ X[1]\ X[4] - s45\ X[3]\ X[4] - 
      PR[\(-k1\) + p3 + p4, 0]\ X[1]\ X[5] - s34\ X[2]\ X[5]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k2..."\),
      SequenceForm[ "Representation after integrating over: ", "k2..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(n4 + n5 + n6 + n7 + n8 + z1 + z2 + z4 \
+ z6\)\ \((\(-s12\))\)\^z3\ \((\(-s34\))\)\^\(2 - eps - n4 - n5 - n6 - n7 - \
n8 - z1 - z2 - z3 - z4 - z5 - z6\)\ \((\(-s45\))\)\^z5\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-z4\)]\ Gamma[
                    2 - eps - n4 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
                      z5]\ Gamma[\(-z5\)]\ Gamma[n6 + z2 + z3 + z5]\ Gamma[
                    n8 + z4 + z5]\ Gamma[
                    2 - eps - n5 - n6 - n7 - n8 - z2 - z4 - z5 - 
                      z6]\ Gamma[\(-z6\)]\ Gamma[
                    n5 + z1 + z2 + z4 + z6]\ Gamma[\(-2\) + eps + n4 + n5 + 
                      n6 + n7 + n8 + z1 + z2 + z3 + z4 + z5 + z6])\)/\((Gamma[
                    n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[n7]\ Gamma[
                    4 - 2\ eps - n4 - n5 - n6 - n7 - n8]\ Gamma[n8])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k1, 0, z1]\ PR[k1 + p1 + p2, 0, z2]\ PR[k1 - p3, 0, 
                z4]\ PR[\(-k1\) + p3 + p4, 0, z6]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, n1 - z1]\ PR[
            k1 + p1, 0, n2]\ PR[k1 + p1 + p2, 0, n3 - z2]\ PR[k1 - p3, 
            0, \(-z4\)]\ PR[\(-k1\) + p3 + p4, 0, \(-z6\)]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, 
            Plus[ n1, 
              Times[ -1, z1]]], 
          PR[ 
            Plus[ k1, p1], 0, n2], 
          PR[ 
            Plus[ k1, p1, p2], 0, 
            Plus[ n3, 
              Times[ -1, z2]]], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p3]], 0, 
            Times[ -1, z4]], 
          PR[ 
            Plus[ 
              Times[ -1, k1], p3, p4], 0, 
            Times[ -1, z6]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momenta="\[InvisibleSpace]k1\),
      SequenceForm[ "momenta=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4] + X[5]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-s12\)\ X[1]\ X[3] + s12\ X[2]\ X[4] + s23\ X[2]\ X[4] - 
      s45\ X[2]\ X[4] - s45\ X[3]\ X[4] - s34\ X[1]\ X[5] + s12\ X[2]\ X[5] + 
      s15\ X[2]\ X[5] - s34\ X[2]\ X[5]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z3 + z7\)\ s12\^\(z13 + z8\)\ s15\^z14\ s23\^z9\ \
\((\(-s34\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - \
z11 - z13 - z14 - z3 - z5 - z7 - z8 - z9\)\ \((\(-s45\))\)\^\(z10 + z11 + \
z5\)\ Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ Gamma[\(-z11\)]\ Gamma[\(-z12\)]\ \
Gamma[\(-z13\)]\ Gamma[\(-z14\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n4 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[n6 + z2 + z3 + z5]\ Gamma[
                n8 + z4 + z5]\ Gamma[
                2 - eps - n5 - n6 - n7 - n8 - z2 - z4 - z5 - z6]\ Gamma[
                n5 + z1 + z2 + z4 + z6]\ Gamma[\(-2\) + eps + n4 + n5 + n6 + 
                  n7 + n8 + z1 + z2 + z3 + z4 + z5 + z6]\ Gamma[
                2 - eps - n1 - n3 + z1 - z11 - z12 + z2 + z4 + z6 - 
                  z7]\ Gamma[\(-z7\)]\ Gamma[n1 - z1 + z12 + z7]\ Gamma[
                n3 + z11 - z2 + z7]\ Gamma[\(-z8\)]\ Gamma[
                2 - eps - n1 - n2 - n3 + z1 - z10 - z11 + z2 + z4 - z7 - z8 - 
                  z9]\ Gamma[\(-z9\)]\ Gamma[
                z10 + z11 - z4 + z8 + z9]\ Gamma[\(-2\) + eps + n1 + n2 + 
                  n3 - z1 + z10 + z11 + z12 + z13 + z14 - z2 - z4 - z6 + z7 + 
                  z8 + z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[
                n6]\ Gamma[n7]\ Gamma[
                4 - 2\ eps - n4 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
                n1 - z1]\ Gamma[n3 - z2]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3 + z1 + z2 + z4 + z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z3 + z7\)\ s12\^\(z13 + z8\)\ s15\^z14\ s23\^z9\ \
\((\(-s34\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - \
z11 - z13 - z14 - z3 - z5 - z7 - z8 - z9\)\ \((\(-s45\))\)\^\(z10 + z11 + \
z5\)\ Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ Gamma[\(-z11\)]\ Gamma[\(-z12\)]\ \
Gamma[\(-z13\)]\ Gamma[\(-z14\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
            2 - eps - n4 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[n6 + z2 + z3 + z5]\ Gamma[
            n8 + z4 + z5]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 - z2 - z4 - z5 - z6]\ Gamma[
            n5 + z1 + z2 + z4 + z6]\ Gamma[\(-2\) + eps + n4 + n5 + n6 + n7 + 
              n8 + z1 + z2 + z3 + z4 + z5 + z6]\ Gamma[
            2 - eps - n1 - n3 + z1 - z11 - z12 + z2 + z4 + z6 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[n1 - z1 + z12 + z7]\ Gamma[
            n3 + z11 - z2 + z7]\ Gamma[\(-z8\)]\ Gamma[
            2 - eps - n1 - n2 - n3 + z1 - z10 - z11 + z2 + z4 - z7 - z8 - 
              z9]\ Gamma[\(-z9\)]\ Gamma[
            z10 + z11 - z4 + z8 + z9]\ Gamma[\(-2\) + eps + n1 + n2 + n3 - 
              z1 + z10 + z11 + z12 + z13 + z14 - z2 - z4 - z6 + z7 + z8 + 
              z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            n7]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
            n1 - z1]\ Gamma[n3 - z2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 + z1 + z2 + z4 + z6])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z6, z4, z2, z12, z1}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z6, z4, z2, z12, z1}, 
        " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]14\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 14, " representation..."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"1", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z6"}],
      SequenceForm[ 1, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z6],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"2", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z4"}],
      SequenceForm[ 2, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"3", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z2"}],
      SequenceForm[ 3, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"4", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z12"}],
      SequenceForm[ 4, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z12],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\" Barnes Lemma was applied for \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", "z12"}],
      SequenceForm[ 
        StyleForm[ 
        " Barnes Lemma was applied for ", FontColor -> RGBColor[ 1, 0, 0]], 
        z12],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z3 + z7\)\ s12\^\(z13 + z8\)\ s15\^z14\ s23\^z9\ \
\((\(-s34\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - \
z11 - z13 - z14 - z3 - z5 - z7 - z8 - z9\)\ \((\(-s45\))\)\^\(z10 + z11 + \
z5\)\ Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ Gamma[\(-z11\)]\ Gamma[\(-z13\)]\ \
Gamma[\(-z14\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
            2 - eps - n4 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[n6 + z2 + z3 + z5]\ Gamma[
            n8 + z4 + z5]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 - z2 - z4 - z5 - z6]\ Gamma[
            n5 + z1 + z2 + z4 + z6]\ Gamma[
            2 - eps - n3 - z11 + z2 + z4 + z6]\ Gamma[\(-2\) + eps + n4 + 
              n5 + n6 + n7 + n8 + z1 + z2 + z3 + z4 + z5 + 
              z6]\ Gamma[\(-z7\)]\ Gamma[n1 - z1 + z7]\ Gamma[
            n3 + z11 - z2 + z7]\ Gamma[\(-z8\)]\ Gamma[
            2 - eps - n1 - n2 - n3 + z1 - z10 - z11 + z2 + z4 - z7 - z8 - 
              z9]\ Gamma[\(-z9\)]\ Gamma[
            n2 + z10 + z13 + z14 + z8 + z9]\ Gamma[
            z10 + z11 - z4 + z8 + z9]\ Gamma[\(-2\) + eps + n1 + n2 + n3 - 
              z1 + z10 + z11 + z13 + z14 - z2 - z4 - z6 + z7 + z8 + 
              z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            n7]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
            n1 - z1]\ Gamma[n3 - z2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 + z1 + z2 + z4 + z6]\ Gamma[
            n1 + n2 - z1 + z10 + z13 + z14 + z7 + z8 + z9])\)\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"5", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", 
        TagBox[
          StyleBox["\<\"Checking \"\>",
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], 
        "\[InvisibleSpace]", "z1"}],
      SequenceForm[ 5, ". ", 
        StyleForm[ "Checking ", FontColor -> RGBColor[ 0, 0, 1]], z1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z12}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z12}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]13\),
      SequenceForm[ "   Obtained representation has: dim=", 13],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 + n8\)\ \
\((\(-s12\))\)\^\(z3 + z7\)\ s12\^\(z13 + z8\)\ s15\^z14\ s23\^z9\ \
\((\(-s34\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 - n8 - z10 - \
z11 - z13 - z14 - z3 - z5 - z7 - z8 - z9\)\ \((\(-s45\))\)\^\(z10 + z11 + \
z5\)\ Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ Gamma[\(-z11\)]\ Gamma[\(-z13\)]\ \
Gamma[\(-z14\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
            2 - eps - n4 - n5 - n6 - n8 - z1 - z2 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[n6 + z2 + z3 + z5]\ Gamma[
            n8 + z4 + z5]\ Gamma[
            2 - eps - n5 - n6 - n7 - n8 - z2 - z4 - z5 - z6]\ Gamma[
            n5 + z1 + z2 + z4 + z6]\ Gamma[
            2 - eps - n3 - z11 + z2 + z4 + z6]\ Gamma[\(-2\) + eps + n4 + 
              n5 + n6 + n7 + n8 + z1 + z2 + z3 + z4 + z5 + 
              z6]\ Gamma[\(-z7\)]\ Gamma[n1 - z1 + z7]\ Gamma[
            n3 + z11 - z2 + z7]\ Gamma[\(-z8\)]\ Gamma[
            2 - eps - n1 - n2 - n3 + z1 - z10 - z11 + z2 + z4 - z7 - z8 - 
              z9]\ Gamma[\(-z9\)]\ Gamma[
            n2 + z10 + z13 + z14 + z8 + z9]\ Gamma[
            z10 + z11 - z4 + z8 + z9]\ Gamma[\(-2\) + eps + n1 + n2 + n3 - 
              z1 + z10 + z11 + z13 + z14 - z2 - z4 - z6 + z7 + z8 + 
              z9])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            n7]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7 - n8]\ Gamma[n8]\ Gamma[
            n1 - z1]\ Gamma[n3 - z2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3 + z1 + z2 + z4 + z6]\ Gamma[
            n1 + n2 - z1 + z10 + z13 + z14 + z7 + z8 + z9])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr = % /. \ {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1, n8 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\((\((\(-s12\))\)\^\(z3 + z7\)\ s12\^\(z13 + z8\)\ s15\^z14\ s23\^z9\ \
\((\(-s34\))\)\^\(\(-4\) - 2\ eps - z10 - z11 - z13 - z14 - z3 - z5 - z7 - z8 \
- z9\)\ \((\(-s45\))\)\^\(z10 + z11 + z5\)\ Gamma[\(-z1\)]\ Gamma[\(-z10\)]\ \
Gamma[\(-z11\)]\ Gamma[\(-z13\)]\ Gamma[\(-z14\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-z3\)]\ Gamma[\(-2\) - eps - z1 - z2 - z3 - z4 - 
              z5]\ Gamma[\(-z5\)]\ Gamma[1 + z2 + z3 + z5]\ Gamma[
            1 + z4 + z5]\ Gamma[\(-2\) - eps - z2 - z4 - z5 - z6]\ Gamma[
            1 + z1 + z2 + z4 + z6]\ Gamma[
            1 - eps - z11 + z2 + z4 + z6]\ Gamma[
            3 + eps + z1 + z2 + z3 + z4 + z5 + z6]\ Gamma[\(-z7\)]\ Gamma[
            1 - z1 + z7]\ Gamma[
            1 + z11 - z2 + z7]\ Gamma[\(-z8\)]\ Gamma[\(-1\) - eps + z1 - 
              z10 - z11 + z2 + z4 - z7 - z8 - z9]\ Gamma[\(-z9\)]\ Gamma[
            1 + z10 + z13 + z14 + z8 + z9]\ Gamma[
            z10 + z11 - z4 + z8 + z9]\ Gamma[
            1 + eps - z1 + z10 + z11 + z13 + z14 - z2 - z4 - z6 + z7 + z8 + 
              z9])\)/\((Gamma[\(-1\) - 2\ eps]\ Gamma[1 - z1]\ Gamma[
            1 - z2]\ Gamma[1 - 2\ eps + z1 + z2 + z4 + z6]\ Gamma[
            2 - z1 + z10 + z13 + z14 + z7 + z8 + z9])\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ so\ we\ got\ 13  dimensional\ integral\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[repr, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(\(\(-eps\)\) - z11 + \
z3\)]"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(\(\(-1\)\) - \(\(2\\ \
eps\)\) - z3\)]"\)], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(8705\/8192\)\)}, {z1 \[Rule] \(-\(3\/32\)\), 
        z10 \[Rule] \(-\(13\/128\)\), z11 \[Rule] \(-\(13\/32\)\), 
        z13 \[Rule] \(-\(19\/1024\)\), z14 \[Rule] \(-\(19\/256\)\), 
        z2 \[Rule] \(-\(5491\/131072\)\), z3 \[Rule] \(-\(118157\/131072\)\), 
        z4 \[Rule] \(-\(8339\/16384\)\), z5 \[Rule] \(-\(39\/1024\)\), 
        z6 \[Rule] \(-\(46277\/131072\)\), z7 \[Rule] \(-\(43707\/131072\)\), 
        z8 \[Rule] \(-\(19\/32768\)\), 
        z9 \[Rule] \(-\(19\/65536\)\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(integrals = 
        MBcontinue[repr, eps \[Rule] 0, rules, 
          Verbose \[Rule] False];\)\)], "Input"],

Cell[BoxData[
    \(\(ser = 
        MBexpand[{integrals}, 
          Exp[2\ eps\ EulerGamma], {eps, 0, \(-3\)}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[
        ser, {s12 \[Rule] \(-2\), s15 \[Rule] \(-1\)/2, s23 \[Rule] \(-4\), 
          s34 \[Rule] \(-5\), s45 \[Rule] \(-6\)}, Verbose \[Rule] False] // 
      AbsoluteTiming\)], "Input"],

Cell[BoxData[
    \({158.670319`8.652040688366279\ Second, \
{\(\(0.`\)\(\[InvisibleSpace]\)\) - 0.002569469330000001`\/eps\^4 - 
          0.004144987055000007`\/eps\^3, {1.3403578430339416`*^-6\/eps\^4 + 
            6.336253599356314`*^-6\/eps\^3, 0}}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{615, 689},
WindowMargins->{{Automatic, 23}, {0, Automatic}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 1, 27, "Input"],
Cell[1819, 56, 41, 1, 23, "Print"],
Cell[1863, 59, 51, 1, 23, "Print"],
Cell[1917, 62, 62, 1, 23, "Print"],
Cell[1982, 65, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2077, 71, 43, 1, 27, "Input"],
Cell[2123, 74, 56, 1, 23, "Print"],
Cell[2182, 77, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2257, 81, 387, 7, 139, "Input"],
Cell[2647, 90, 101, 2, 27, "Input"],
Cell[2751, 94, 58, 1, 27, "Input"],
Cell[2812, 97, 264, 4, 75, "Input"],
Cell[3079, 103, 523, 8, 91, "Input"],

Cell[CellGroupData[{
Cell[3627, 115, 43, 1, 27, "Input"],
Cell[3673, 118, 143, 3, 23, "Print"],
Cell[3819, 123, 460, 13, 39, "Print"],
Cell[4282, 138, 143, 3, 23, "Print"],
Cell[4428, 143, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4639, 151, 50, 1, 27, "Input"],
Cell[4692, 154, 264, 4, 23, "Print"],
Cell[4959, 160, 257, 5, 23, "Print"],
Cell[5219, 167, 50, 1, 23, "Print"],
Cell[5272, 170, 58, 1, 23, "Print"],
Cell[5333, 173, 50, 1, 23, "Print"],
Cell[5386, 176, 147, 2, 39, "Print"],
Cell[5536, 180, 215, 4, 23, "Print"],
Cell[5754, 186, 1069, 23, 113, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6860, 214, 43, 1, 27, "Input"],
Cell[6906, 217, 143, 3, 23, "Print"],
Cell[7052, 222, 749, 23, 39, "Print"],
Cell[7804, 247, 143, 3, 23, "Print"],
Cell[7950, 252, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8161, 260, 62, 1, 27, "Input"],
Cell[8226, 263, 264, 4, 23, "Print"],
Cell[8493, 269, 257, 5, 23, "Print"],
Cell[8753, 276, 50, 1, 23, "Print"],
Cell[8806, 279, 65, 1, 23, "Print"],
Cell[8874, 282, 50, 1, 23, "Print"],
Cell[8927, 285, 132, 2, 23, "Print"],
Cell[9062, 289, 56, 1, 23, "Print"],
Cell[9121, 292, 1424, 22, 223, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10582, 319, 53, 1, 27, "Input"],
Cell[10638, 322, 238, 4, 23, "Print"],
Cell[10879, 328, 226, 4, 23, "Print"],
Cell[11108, 334, 80, 1, 23, "Print"],
Cell[11191, 337, 190, 4, 23, "Print"],
Cell[11384, 343, 1236, 18, 227, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12657, 366, 183, 3, 27, "Input"],
Cell[12843, 371, 928, 15, 147, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13808, 391, 89, 1, 27, "Input"],
Cell[13900, 394, 175, 3, 33, "Message"],
Cell[14078, 399, 128, 2, 20, "Message"],
Cell[14209, 403, 128, 2, 20, "Message"],
Cell[14340, 407, 128, 2, 20, "Message"],
Cell[14471, 411, 334, 5, 33, "Message"],
Cell[14808, 418, 299, 5, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15144, 428, 131, 3, 27, "Input"],
Cell[15278, 433, 365, 5, 33, "Message"]
}, Open  ]],
Cell[15658, 441, 128, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[15811, 448, 228, 5, 59, "Input"],
Cell[16042, 455, 248, 4, 73, "Output"]
}, Open  ]],
Cell[16305, 462, 187, 3, 87, "Input"],
Cell[16495, 467, 58, 1, 27, "Input"],
Cell[16556, 470, 264, 4, 75, "Input"],
Cell[16823, 476, 523, 8, 91, "Input"],

Cell[CellGroupData[{
Cell[17371, 488, 43, 1, 27, "Input"],
Cell[17417, 491, 143, 3, 23, "Print"],
Cell[17563, 496, 634, 19, 39, "Print"],
Cell[18200, 517, 141, 3, 23, "Print"],
Cell[18344, 522, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18555, 530, 50, 1, 27, "Input"],
Cell[18608, 533, 264, 4, 23, "Print"],
Cell[18875, 539, 257, 5, 23, "Print"],
Cell[19135, 546, 50, 1, 23, "Print"],
Cell[19188, 549, 65, 1, 23, "Print"],
Cell[19256, 552, 50, 1, 23, "Print"],
Cell[19309, 555, 236, 4, 55, "Print"],
Cell[19548, 561, 215, 4, 23, "Print"],
Cell[19766, 567, 1372, 27, 177, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21175, 599, 43, 1, 27, "Input"],
Cell[21221, 602, 143, 3, 23, "Print"],
Cell[21367, 607, 889, 25, 55, "Print"],
Cell[22259, 634, 141, 3, 23, "Print"],
Cell[22403, 639, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22614, 647, 57, 1, 27, "Input"],
Cell[22674, 650, 264, 4, 23, "Print"],
Cell[22941, 656, 257, 5, 23, "Print"],
Cell[23201, 663, 50, 1, 23, "Print"],
Cell[23254, 666, 65, 1, 23, "Print"],
Cell[23322, 669, 50, 1, 23, "Print"],
Cell[23375, 672, 132, 2, 23, "Print"],
Cell[23510, 676, 56, 1, 23, "Print"],
Cell[23569, 679, 1655, 27, 241, "Print"],
Cell[25227, 708, 1460, 24, 261, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26724, 737, 53, 1, 27, "Input"],
Cell[26780, 740, 265, 5, 23, "Print"],
Cell[27048, 747, 228, 4, 23, "Print"],
Cell[27279, 753, 446, 10, 23, "Print"],
Cell[27728, 765, 436, 12, 23, "Print"],
Cell[28167, 779, 1546, 24, 273, "Print"],
Cell[29716, 805, 446, 10, 23, "Print"],
Cell[30165, 817, 446, 10, 23, "Print"],
Cell[30614, 829, 80, 1, 23, "Print"],
Cell[30697, 832, 458, 12, 23, "Print"],
Cell[31158, 846, 197, 4, 23, "Print"],
Cell[31358, 852, 1562, 25, 277, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32957, 882, 183, 3, 27, "Input"],
Cell[33143, 887, 1078, 17, 179, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34258, 909, 89, 1, 27, "Input"],
Cell[34350, 912, 168, 3, 33, "Message"],
Cell[34521, 917, 174, 3, 33, "Message"],
Cell[34698, 922, 160, 3, 20, "Message"],
Cell[34861, 927, 337, 5, 33, "Message"],
Cell[35201, 934, 128, 2, 20, "Message"],
Cell[35332, 938, 128, 2, 20, "Message"],
Cell[35463, 942, 128, 2, 20, "Message"],
Cell[35594, 946, 334, 5, 33, "Message"],
Cell[35931, 953, 422, 7, 116, "Output"]
}, Open  ]],
Cell[36368, 963, 131, 3, 27, "Input"],
Cell[36502, 968, 128, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[36655, 975, 221, 4, 43, "Input"],
Cell[36879, 981, 284, 4, 89, "Output"]
}, Open  ]],
Cell[37178, 988, 59, 1, 27, "Input"],
Cell[37240, 991, 187, 3, 87, "Input"],
Cell[37430, 996, 275, 4, 107, "Input"],
Cell[37708, 1002, 264, 4, 75, "Input"],
Cell[37975, 1008, 523, 8, 91, "Input"],

Cell[CellGroupData[{
Cell[38523, 1020, 43, 1, 27, "Input"],
Cell[38569, 1023, 143, 3, 23, "Print"],
Cell[38715, 1028, 634, 19, 39, "Print"],
Cell[39352, 1049, 141, 3, 23, "Print"],
Cell[39496, 1054, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39707, 1062, 50, 1, 27, "Input"],
Cell[39760, 1065, 264, 4, 23, "Print"],
Cell[40027, 1071, 257, 5, 23, "Print"],
Cell[40287, 1078, 50, 1, 23, "Print"],
Cell[40340, 1081, 65, 1, 23, "Print"],
Cell[40408, 1084, 50, 1, 23, "Print"],
Cell[40461, 1087, 229, 3, 55, "Print"],
Cell[40693, 1092, 215, 4, 23, "Print"],
Cell[40911, 1098, 1372, 26, 213, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42320, 1129, 43, 1, 27, "Input"],
Cell[42366, 1132, 143, 3, 23, "Print"],
Cell[42512, 1137, 757, 23, 39, "Print"],
Cell[43272, 1162, 141, 3, 23, "Print"],
Cell[43416, 1167, 174, 3, 33, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43627, 1175, 57, 1, 27, "Input"],
Cell[43687, 1178, 264, 4, 23, "Print"],
Cell[43954, 1184, 257, 5, 23, "Print"],
Cell[44214, 1191, 50, 1, 23, "Print"],
Cell[44267, 1194, 65, 1, 23, "Print"],
Cell[44335, 1197, 50, 1, 23, "Print"],
Cell[44388, 1200, 211, 3, 39, "Print"],
Cell[44602, 1205, 56, 1, 23, "Print"],
Cell[44661, 1208, 1759, 27, 273, "Print"],
Cell[46423, 1237, 1555, 23, 277, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48015, 1265, 53, 1, 27, "Input"],
Cell[48071, 1268, 292, 6, 23, "Print"],
Cell[48366, 1276, 228, 4, 23, "Print"],
Cell[48597, 1282, 446, 10, 23, "Print"],
Cell[49046, 1294, 446, 10, 23, "Print"],
Cell[49495, 1306, 446, 10, 23, "Print"],
Cell[49944, 1318, 448, 10, 23, "Print"],
Cell[50395, 1330, 438, 12, 23, "Print"],
Cell[50836, 1344, 1623, 25, 289, "Print"],
Cell[52462, 1371, 446, 10, 23, "Print"],
Cell[52911, 1383, 80, 1, 23, "Print"],
Cell[52994, 1386, 460, 12, 23, "Print"],
Cell[53457, 1400, 199, 4, 23, "Print"],
Cell[53659, 1406, 1624, 25, 293, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55320, 1436, 170, 2, 27, "Input"],
Cell[55493, 1440, 1249, 19, 211, "Output"]
}, Open  ]],
Cell[56757, 1462, 81, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[56863, 1467, 89, 1, 27, "Input"],
Cell[56955, 1470, 160, 3, 20, "Message"],
Cell[57118, 1475, 128, 2, 20, "Message"],
Cell[57249, 1479, 128, 2, 20, "Message"],
Cell[57380, 1483, 128, 2, 20, "Message"],
Cell[57511, 1487, 334, 5, 33, "Message"],
Cell[57848, 1494, 170, 3, 20, "Message"],
Cell[58021, 1499, 546, 8, 116, "Output"]
}, Open  ]],
Cell[58582, 1510, 131, 3, 27, "Input"],
Cell[58716, 1515, 128, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[58869, 1522, 221, 4, 43, "Input"],
Cell[59093, 1528, 269, 4, 75, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

