(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    183047,       3943]*)
(*NotebookOutlinePosition[    183988,       3972]*)
(*  CellTagsIndexPosition[    183944,       3968]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\[IndentingNewLine]\ \ \ \ 2 - 
        loop\ massive\ topology, \ \ Fig  .5, \ 
      with\ a\ special\ numerator\ \ \ \ \[IndentingNewLine]*) \)\(\
\[IndentingNewLine]\)\)\)], "Input"],

Cell[BoxData[
    \(\(int = 
        Fullintegral[\[IndentingNewLine]{1}, \[IndentingNewLine]{PR[k1, m, 
                n1] PR[k1 + p1, 0, n2] PR[k1 + p1 + p2, m, n3] 
              PR[k1 - k2, 0, n4] PR[k2, m, n5] PR[k2 + p1 + p2, m, n6] 
              PR[k2 + p1 + p2 + p4, 0, n7]\ PR[k1 + p1 + p2 + p4, 
                0, \(-n8\)]}, {k2, k1}];\)\)], "Input"],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
            p4^2 \[Rule] m^2, p1*p2 \[Rule] 1/2*s - m^2, 
            p3*p4 \[Rule] 1/2\ s - m^2, p1*p3 \[Rule] 1/2*t - m^2, 
            p2*p4 \[Rule] 1/2*t - m^2, p2*p3 \[Rule] 1/2*u - m^2, 
            p1*p4 \[Rule] 1/2*u - m^2} /. 
          u \[Rule] 4\ m^2 - s - t;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1 - k2, 0, n4]\ PR[
            k2, m, n5]\ PR[k2 + p1 + p2, m, n6]\ PR[k2 + p1 + p2 + p4, 0, 
            n7]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ 
            Plus[ k1, 
              Times[ -1, k2]], 0, n4], 
          PR[ k2, m, n5], 
          PR[ 
            Plus[ k2, p1, p2], m, n6], 
          PR[ 
            Plus[ k2, p1, p2, p4], 0, n7]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[2] + X[3]]\^2 - PR[k1, m]\ X[1]\ X[2] - 
      PR[k1 + p1 + p2, m]\ X[1]\ X[3] - s\ X[2]\ X[3] - 
      PR[k1 + p1 + p2 + p4, 0]\ X[1]\ X[4]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k2..."\),
      SequenceForm[ "Representation after integrating over: ", "k2..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps - z1 - z4\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^z4\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                    2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                    2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                      z4]\ Gamma[\(-z4\)]\ Gamma[\(-2\) + eps + n4 + n5 + 
                      n6 + n7 + z1 + z2 + z3 + z4]\ Gamma[
                    n6 + 2\ z1 + z3 + z4 - 
                      z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                    n5 + z2 + z4 + z5])\)/\((Gamma[n4]\ Gamma[n5]\ Gamma[
                    n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                    n7]\ Gamma[\(-2\)\ z1])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          
          StyleBox[\(PR[k1, m, z2]\ PR[k1 + p1 + p2, m, z3]\ PR[
                k1 + p1 + p2 + p4, 0, 
                2 - eps - n4 - n5 - n6 - n7 - z1 - z2 - z3 - z4]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m, n1 - z2]\ PR[
            k1 + p1, 0, n2]\ PR[k1 + p1 + p2, m, n3 - z3]\ PR[
            k1 + p1 + p2 + p4, 
            0, \(-2\) + eps + n4 + n5 + n6 + n7 - n8 + z1 + z2 + z3 + z4]\)\),
      
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m, 
            Plus[ n1, 
              Times[ -1, z2]]], 
          PR[ 
            Plus[ k1, p1], 0, n2], 
          PR[ 
            Plus[ k1, p1, p2], m, 
            Plus[ n3, 
              Times[ -1, z3]]], 
          PR[ 
            Plus[ k1, p1, p2, p4], 0, 
            Plus[ -2, eps, n4, n5, n6, n7, 
              Times[ -1, n8], z1, z2, z3, z4]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3]]\^2 - s\ X[1]\ X[3] - t\ X[2]\ X[4]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 - n8\)\ \
\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(4 - 2\ \
eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 + n8 - z1 - z4 - z6 - z7\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
                2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
                2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
                  z4]\ Gamma[\(-z4\)]\ Gamma[\(-2\) + eps + n4 + n5 + n6 + 
                  n7 + z1 + z2 + z3 + z4]\ Gamma[
                n6 + 2\ z1 + z3 + z4 - 
                  z5]\ Gamma[\(-z5\)]\ Gamma[\(-2\)\ z1 + z5]\ Gamma[
                n5 + z2 + z4 + z5]\ Gamma[\(-z6\)]\ Gamma[
                2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - z7]\ Gamma[
                4 - 2\ eps - n1 - n3 - n4 - n5 - n6 - n7 + n8 - z1 - z4 - 
                  z6 - z7]\ Gamma[\(-z7\)]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + 
                  n3 + n4 + n5 + n6 + n7 - n8 + z1 + z4 + z6 + z7]\ Gamma[
                n3 - z3 + 2\ z6 + z7 - 
                  z8]\ Gamma[\(-z8\)]\ Gamma[\(-2\)\ z6 + z8]\ Gamma[
                n1 - z2 + z7 + z8])\)/\((Gamma[n2]\ Gamma[n4]\ Gamma[
                n5]\ Gamma[n6]\ Gamma[4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[
                n7]\ Gamma[\(-2\)\ z1]\ Gamma[n1 - z2]\ Gamma[n3 - z3]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 + n8 - z1 - 
                  z4]\ Gamma[\(-2\) + eps + n4 + n5 + n6 + n7 - n8 + z1 + 
                  z2 + z3 + z4]\ Gamma[\(-2\)\ z6])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rep1 = BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z8, z5, z3, z2}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z8, z5, z3, z2}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]8\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 8, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z8...Barnes Lemma was applied.
2. Checking z5...Barnes Lemma was applied.
3. Checking z3
4. Checking z2\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z5, z8}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z5, z8}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]6\),
      SequenceForm[ "   Obtained representation has: dim=", 6],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6 + n7 - n8\)\ \
\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(4 - 2\ \
eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 + n8 - z1 - z4 - z6 - z7\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[
            2 - eps - n5 - n6 - n7 - z1 - z4]\ Gamma[
            2 - eps - n4 - n5 - n6 - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[n5 + z2 + z4]\ Gamma[
            n6 + z3 + z4]\ Gamma[\(-2\) + eps + n4 + n5 + n6 + n7 + z1 + z2 + 
              z3 + z4]\ Gamma[
            n5 + n6 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[
            2 - eps - n1 - n2 - n3 + z2 + z3 - z6 - z7]\ Gamma[
            4 - 2\ eps - n1 - n3 - n4 - n5 - n6 - n7 + n8 - z1 - z4 - z6 - 
              z7]\ Gamma[\(-z7\)]\ Gamma[n1 - z2 + z7]\ Gamma[
            n3 - z3 + z7]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + n5 + 
              n6 + n7 - n8 + z1 + z4 + z6 + z7]\ Gamma[
            n1 + n3 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[n2]\ Gamma[
            n4]\ Gamma[n5]\ Gamma[n6]\ Gamma[
            4 - 2\ eps - n4 - n5 - n6 - n7]\ Gamma[n7]\ Gamma[n1 - z2]\ Gamma[
            n3 - z3]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - n7 + n8 - z1 - 
              z4]\ Gamma[\(-2\) + eps + n4 + n5 + n6 + n7 - n8 + z1 + z2 + 
              z3 + z4]\ Gamma[n5 + n6 + z2 + z3 + 2\ z4]\ Gamma[
            n1 + n3 - z2 - z3 + 2\ z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = 
      rep1\  /. \ {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1, n7 \[Rule] 1, 
          n8 \[Rule] 1}\)], "Input"],

Cell[BoxData[
    \(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(\
\(-2\) - 2\ eps - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\
\(-z3\)]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
            1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
            2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[\(-1\) - 
              eps + z2 + z3 - z6 - z7]\ Gamma[\(-1\) - 2\ eps - z1 - z4 - 
              z6 - z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
            1 - z3 + z7]\ Gamma[2 + 2\ eps + z1 + z4 + z6 + z7]\ Gamma[
            2 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
            1 - z2]\ Gamma[1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
            1 + eps + z1 + z2 + z3 + z4]\ Gamma[2 + z2 + z3 + 2\ z4]\ Gamma[
            2 - z2 - z3 + 2\ z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBoptimizedRules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = 
      rep1\  /. \ {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1, n6 \[Rule] 1, n7 \[Rule] 1, n7 \[Rule] 1, 
          n8 \[Rule] 1 + eta}\)], "Input"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(6 - eta\)\ \((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\)\^\(\(-2\) - 2\ eps + eta - z1 - z4 - \
z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-1\) - 
              eps - z1 - z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
            1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
            2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[\(-1\) - 
              eps + z2 + z3 - z6 - z7]\ Gamma[\(-1\) - 2\ eps + eta - z1 - 
              z4 - z6 - z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
            1 - z3 + z7]\ Gamma[2 + 2\ eps - eta + z1 + z4 + z6 + z7]\ Gamma[
            2 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
            1 - z2]\ Gamma[1 - z3]\ Gamma[\(-3\)\ eps + eta - z1 - z4]\ Gamma[
            1 + eps - eta + z1 + z2 + z3 + z4]\ Gamma[
            2 + z2 + z3 + 2\ z4]\ Gamma[2 - z2 - z3 + 2\ z7])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = 
      MBoptimizedRules[fin, 
        eta \[Rule] 0, {z1 > \(-1\)/2, z2 > z1}, {eps, eta}]\)], "Input"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(265\/512\)\), 
        eta \[Rule] \(-\(1025\/1024\)\)}, {z1 \[Rule] \(-\(1\/4\)\), 
        z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
        z4 \[Rule] \(-\(69\/256\)\), z6 \[Rule] \(-\(19\/64\)\), 
        z7 \[Rule] \(-\(665\/1024\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Step1cont = MBcontinue[fin, eta \[Rule] 0, rules];\)\)], "Input"],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 2\ eps + eta - z1 - z4 - 
          z6\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z7, " = ", 
        Plus[ -2, 
          Times[ -2, eps], eta, 
          Times[ -1, z1], 
          Times[ -1, z4], 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]2\),
      SequenceForm[ "Level ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1}\),
      SequenceForm[ "Integral ", {1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 2, " integral(s) found"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(after = MBexpand[Step1cont, 1, {eta, 0, 0}]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(after\\)\\\" is similar to existing symbol \
\\\"\\!\\(After\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - 2\ eps - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 
                  4\ eps - 2\ z1 - z2 - z3 - 2\ z4]\ Gamma[\(-1\) - eps - 
                  z1 - z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
                  z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-1\) - 2\ eps - z1 - 
                  z2 - z4 - z6]\ Gamma[\(-1\) - 2\ eps - z1 - z3 - z4 - 
                  z6]\ Gamma[\(-z6\)]\ Gamma[
                2 + 2\ eps + z1 + z4 + z6])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
                1 - z2]\ Gamma[1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                2 + z2 + z3 + 2\ z4]\ Gamma[\(-2\) - 4\ eps - 2\ z1 - z2 - 
                  z3 - 2\ z4 - 2\ z6])\), {{eps \[Rule] \(-\(265\/512\)\), 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
            z4 \[Rule] \(-\(69\/256\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \((\(-t\))\
\)\^\(\(-2\) - 2\ eps - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-z3\)]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - eps - z1 - z2 - 
                  z3 - z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-z6\)]\ Gamma[\(-1\) - 
                  eps + z2 + z3 - z6 - z7]\ Gamma[\(-1\) - 2\ eps - z1 - z4 - 
                  z6 - z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
                1 - z3 + z7]\ Gamma[
                2 + 2\ eps + z1 + z4 + z6 + z7]\ Gamma[\(-z2\) - z3 + 
                  2\ \((1 + z6 + z7)\)])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
                1 - z2]\ Gamma[1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                1 + eps + z1 + z2 + z3 + z4]\ Gamma[
                2 + z2 + z3 + 2\ z4]\ Gamma[
                2 - z2 - z3 + 2\ z7])\), {{eps \[Rule] \(-\(265\/512\)\), 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
            z4 \[Rule] \(-\(69\/256\)\), z6 \[Rule] \(-\(19\/64\)\), 
            z7 \[Rule] \(-\(665\/1024\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals = 
      after /. MBint[integrand_, rules_] \[RuleDelayed] 
          MBcontinue[integrand, eps \[Rule] 0, rules]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 4\ eps - 2\ z1 - z2 - 
          2\ z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z3, " = ", 
        Plus[ -2, 
          Times[ -4, eps], 
          Times[ -2, z1], 
          Times[ -1, z2], 
          Times[ -2, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z1\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z1 - z2 - z3\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - z1 - z2 - z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z6, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - z1 - z3 - z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z6, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z3], 
          Times[ -1, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]2\),
      SequenceForm[ "Level ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1}\),
      SequenceForm[ "Integral ", {1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 4\ eps - 2\ z1 - z2\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -4, eps], 
          Times[ -2, z1], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 3\ eps - z1\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -3, eps], 
          Times[ -1, z1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - z1 - z2 - z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z6, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2}\),
      SequenceForm[ "Integral ", {2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3}\),
      SequenceForm[ "Integral ", {3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{4}\),
      SequenceForm[ "Integral ", {4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{5}\),
      SequenceForm[ "Integral ", {5}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]3\),
      SequenceForm[ "Level ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1}\),
      SequenceForm[ "Integral ", {1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps + z1\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z6, " = ", 
        Plus[ 
          Times[ 2, eps], z1]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 2}\),
      SequenceForm[ "Integral ", {1, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 3}\),
      SequenceForm[ "Integral ", {1, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 4\ eps - 2\ z1 - z2\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -4, eps], 
          Times[ -2, z1], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 1}\),
      SequenceForm[ "Integral ", {2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1}\),
      SequenceForm[ "Integral ", {3, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]4\),
      SequenceForm[ "Level ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1, 1}\),
      SequenceForm[ "Integral ", {1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 2, 1}\),
      SequenceForm[ "Integral ", {1, 2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 3, 1}\),
      SequenceForm[ "Integral ", {1, 3, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 1, 1}\),
      SequenceForm[ "Integral ", {2, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 1}\),
      SequenceForm[ "Integral ", {3, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(16\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 16, " integral(s) found"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z1\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z1 - z2 - z3\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    \("...no contribution"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps + z2 + z3 - z6\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z7, " = ", 
        Plus[ -1, 
          Times[ -1, eps], z2, z3, 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 2\ eps - z1 - z4 - z6\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z7, " = ", 
        Plus[ -2, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z4], 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]2\),
      SequenceForm[ "Level ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1}\),
      SequenceForm[ "Integral ", {1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps + z2 + z3 - z6\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z7, " = ", 
        Plus[ -1, 
          Times[ -1, eps], z2, z3, 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z6\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z7, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2}\),
      SequenceForm[ "Integral ", {2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z1 - z2 - z3\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3}\),
      SequenceForm[ "Integral ", {3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 4\ eps - 2\ z1 - z2 - 
          2\ z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z3, " = ", 
        Plus[ -2, 
          Times[ -4, eps], 
          Times[ -2, z1], 
          Times[ -1, z2], 
          Times[ -2, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z1 - z2 - z3\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - z1 - z2 - z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z6, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - z1 - z3 - z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z6, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z3], 
          Times[ -1, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]3\),
      SequenceForm[ "Level ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1}\),
      SequenceForm[ "Integral ", {1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z6\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z7, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 2}\),
      SequenceForm[ "Integral ", {1, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 3}\),
      SequenceForm[ "Integral ", {1, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 1}\),
      SequenceForm[ "Integral ", {2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 2}\),
      SequenceForm[ "Integral ", {2, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1}\),
      SequenceForm[ "Integral ", {3, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 4\ eps - 2\ z1 - z2\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -4, eps], 
          Times[ -2, z1], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 3\ eps - z1\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -3, eps], 
          Times[ -1, z1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - z1 - z2 - z4\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z6, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -1, z1], 
          Times[ -1, z2], 
          Times[ -1, z4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 2}\),
      SequenceForm[ "Integral ", {3, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps - z2\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ 
          Times[ 2, eps], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 3}\),
      SequenceForm[ "Integral ", {3, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 4}\),
      SequenceForm[ "Integral ", {3, 4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]4\),
      SequenceForm[ "Level ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1, 1}\),
      SequenceForm[ "Integral ", {1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z7\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - z6\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z7, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, z6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1, 2}\),
      SequenceForm[ "Integral ", {1, 1, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 2, 1}\),
      SequenceForm[ "Integral ", {1, 2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 1, 1}\),
      SequenceForm[ "Integral ", {2, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 2, 1}\),
      SequenceForm[ "Integral ", {2, 2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 1}\),
      SequenceForm[ "Integral ", {3, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z6\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps + z1\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z6, " = ", 
        Plus[ 
          Times[ 2, eps], z1]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 2}\),
      SequenceForm[ "Integral ", {3, 1, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 3}\),
      SequenceForm[ "Integral ", {3, 1, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"-"\[InvisibleSpace]"residue in "\[InvisibleSpace]z4\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 4\ eps - 2\ z1 - z2\)\),
      SequenceForm[ "Taking ", "-", "residue in ", z4, " = ", 
        Plus[ -1, 
          Times[ -4, eps], 
          Times[ -2, z1], 
          Times[ -1, z2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 2, 1}\),
      SequenceForm[ "Integral ", {3, 2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(2\ eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Times[ 2, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]5\),
      SequenceForm[ "Level ", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1, 1, 1}\),
      SequenceForm[ "Integral ", {1, 1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 2, 1, 1}\),
      SequenceForm[ "Integral ", {1, 2, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 2, 1, 1}\),
      SequenceForm[ "Integral ", {2, 2, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 1, 1}\),
      SequenceForm[ "Integral ", {3, 1, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 2, 1}\),
      SequenceForm[ "Integral ", {3, 1, 2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 3, 1}\),
      SequenceForm[ "Integral ", {3, 1, 3, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 2, 1, 1}\),
      SequenceForm[ "Integral ", {3, 2, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(29\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 29, " integral(s) found"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{{{MBint[\(-\(\(1\/\(s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                          1 - 4\ eps - 2\ z1 - 
                            z2]\)\)\((\((m\^2)\)\^\(2\ eps + 2\ z1\)\ \((\(-s\
\))\)\^\(\(-4\)\ eps - 2\ z1\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-2\)\ eps - 
                          z1]\ Gamma[\(-z1\)]\ Gamma[\(-4\)\ eps - 2\ z1 - 
                          z2]\ Gamma[\(-eps\) - z1 - 
                          z2]\ Gamma[\(-z2\)]\ Gamma[3\ eps + z1 + z2]\ Gamma[
                        1 + 4\ eps + 2\ z1 + z2])\)\)\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-z1\)]\ Gamma[\(-4\)\ eps - 2\ z1 - 
                        z2]\ Gamma[\(-eps\) - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[
                      3\ eps + z1 + z2]\ Gamma[
                      1 + 4\ eps + 2\ z1 + z2]\ Gamma[\(-2\)\ eps - z1 - 
                        z6]\ Gamma[2\ eps + z1 - z6]\ Gamma[\(-z6\)]\ Gamma[
                      1 - 2\ eps - z1 - z2 + 
                        z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z2]\ Gamma[
                      1 - 4\ eps - 2\ z1 - 
                        z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, \
{{MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - \
z6\)\ Gamma[\(-4\)\ eps]\ Gamma[
                          2\ eps]\ Gamma[\(-3\)\ eps - z1]\ Gamma[\(-eps\) - 
                            z1]\ Gamma[\(-z1\)]\ Gamma[
                          1 + 3\ eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                          eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6])\)/\((s\^2\ Gamma[
                          1 - 2\ eps]\ Gamma[\(-4\)\ eps - 
                            2\ z1]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 
                      0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ \
eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                        1 + 3\ eps + z1]\ Gamma[\(-eps\) - z1 - 
                          z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                          z2]\ Gamma[\(-3\)\ eps - z1 + z2]\ Gamma[
                        eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                          z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 - eps + 
                          z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ \
eps - 2\ z1]\ Gamma[1 - z2]\ Gamma[
                        1 - 2\ eps + 
                          z2]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, {{MBint[\(\(1\/\(s\^2\ \
Gamma[\(-2\)\ eps]\ Gamma[
                        1 - 4\ eps - 2\ z1 - 
                          z2]\)\)\((\((m\^2)\)\^\(2\ eps + 2\ z1\)\ \
\((\(-s\))\)\^\(\(-4\)\ eps - 2\ z1\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-2\)\ eps \
- z1]\ Gamma[\(-z1\)]\ Gamma[\(-4\)\ eps - 2\ z1 - z2]\ Gamma[\(-eps\) - z1 - 
                        z2]\ Gamma[\(-z2\)]\ Gamma[3\ eps + z1 + z2]\ Gamma[
                      1 + 4\ eps + 2\ z1 + z2])\)\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\)}}]}, 
            MBint[\(-\(\((\((m\^2)\)\^\(\(-2\)\ eps - z2 - z4\)\ \((\(-s\))\)\
\^\(z2 + z4\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\
\) - eps - z1 - z4]\ Gamma[\(-1\) - 4\ eps - 2\ z1 - z2 - 
                          z4]\ Gamma[\(-z4\)]\ Gamma[
                        1 + 3\ eps + z1 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
                        1 + 2\ eps + z1 + z2 + z4]\ Gamma[
                        2 + 4\ eps + 2\ z1 + z2 + 
                          2\ z4])\)/\((m\^2\ s\ Gamma[\(-2\)\ eps]\ \
Gamma[\(-4\)\ eps - 2\ z1]\ Gamma[
                        3 + 4\ eps + 2\ z1 + z2 + 
                          2\ z4])\)\)\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\)}}]}, 
          MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 \
- z6\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - 
                      eps - z1 - z4]\ Gamma[\(-1\) - 4\ eps - 2\ z1 - z2 - 
                      z4]\ Gamma[\(-z4\)]\ Gamma[1 + 3\ eps + z1 + z4]\ Gamma[
                    1 + z2 + z4]\ Gamma[
                    2 + 4\ eps + 2\ z1 + z2 + 2\ z4]\ Gamma[\(-1\) - 2\ eps - 
                      z1 - z2 - z4 - z6]\ Gamma[
                    1 + 2\ eps + z1 + z2 + z4 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    2 + 2\ eps + z1 + z4 + 
                      z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ eps - 
                      2\ z1]\ Gamma[1 - z2]\ Gamma[
                    3 + 4\ eps + 2\ z1 + z2 + 
                      2\ z4]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\), 
                
                z6 \[Rule] \(-\(19\/64\)\)}}]}, {{{MBint[\((\((m\^2)\)\^\(z1 \
+ z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ \
Gamma[\(-2\)\ eps]\ Gamma[1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                        eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                        1 + eps + z1]\ Gamma[\(-3\)\ eps - 
                          z6]\ Gamma[\(-eps\) - z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 + eps + 
                          z6])\)/\((s\^2\ Gamma[1 - 2\ eps]\^2\ Gamma[\(-2\)\ \
z1]\ Gamma[\(-4\)\ eps - 2\ z6])\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                      1 + eps + z1]\ Gamma[
                      eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                        z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[\(-eps\) - z2 - 
                        z6]\ Gamma[\(-3\)\ eps + z2 - 
                        z6]\ Gamma[\(-z6\)]\ Gamma[
                      1 + eps + z6])\)/\((s\^2\ Gamma[
                      1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[
                      1 - 2\ eps + z2]\ Gamma[\(-4\)\ eps - 
                        2\ z6])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
          MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[
                    1 + eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 + 
                      z2]\ Gamma[\(-z2\) - z3]\ Gamma[\(-2\)\ eps - z2 - 
                      z3]\ Gamma[\(-z3\)]\ Gamma[\(-eps\) - z1 + z3]\ Gamma[
                    1 + z2 + z3]\ Gamma[\(-2\)\ eps + z2 + 
                      z3]\ Gamma[\(-eps\) - z2 - z6]\ Gamma[\(-eps\) - z3 - 
                      z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + eps + z6])\)/\((s\^2\ Gamma[
                    1 - 2\ eps]\ Gamma[\(-2\)\ eps]\ Gamma[1 - z2]\ Gamma[
                    1 - z3]\ Gamma[\(-2\)\ eps - 2\ z1 + z2 + 
                      z3]\ Gamma[\(-2\)\ eps - z2 - z3 - 
                      2\ z6])\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z6 \[Rule] \(-\(19\/64\)\)}}]}, {{{MBint[\((\((m\^2)\)\^\(z1 \
+ z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[
                        2\ eps]\ Gamma[\(-3\)\ eps - z1]\ Gamma[\(-eps\) - 
                          z1]\ Gamma[\(-z1\)]\ Gamma[
                        1 + 3\ eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                        eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 - eps + z6])\)/\((s\^2\ Gamma[
                        1 - 2\ eps]\ Gamma[\(-4\)\ eps - 
                          2\ z1]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                      1 + 3\ eps + z1]\ Gamma[\(-eps\) - z1 - 
                        z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                        z2]\ Gamma[\(-3\)\ eps - z1 + z2]\ Gamma[
                      eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                        z6]\ Gamma[\(-z6\)]\ Gamma[
                      1 - eps + 
                        z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ eps \
- 2\ z1]\ Gamma[1 - z2]\ Gamma[
                      1 - 2\ eps + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
                    0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
          MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[\(-eps\) - z1 - 
                      z2]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 - 
                      z3]\ Gamma[\(-2\)\ eps - z2 - 
                      z3]\ Gamma[\(-z3\)]\ Gamma[
                    z2 + z3]\ Gamma[\(-2\)\ eps + z2 + z3]\ Gamma[
                    1 + eps + z1 + z2 + z3]\ Gamma[\(-eps\) + z2 - 
                      z6]\ Gamma[\(-eps\) + z3 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + eps - z2 - z3 + 
                      z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                    1 - z2]\ Gamma[
                    1 - z3]\ Gamma[\(-2\)\ eps - 2\ z1 - z2 - z3]\ Gamma[
                    1 - 2\ eps + z2 + z3]\ Gamma[\(-2\)\ eps + z2 + z3 - 
                      2\ z6])\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z6 \[Rule] \(-\(19\/64\)\)}}]}, {MBint[\(-\(\((\((m\^2)\)\^\(\
\(-2\)\ eps - z2 - z4\)\ \((\(-s\))\)\^\(z2 + z4\)\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 4\ eps - 2\ z1 - z2 - z3 - 
                        2\ z4]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - 
                        eps - z1 - z2 - z3 - z4]\ Gamma[\(-z4\)]\ Gamma[
                      1 + z2 + z4]\ Gamma[1 + 2\ eps + z1 + z2 + z4]\ Gamma[
                      1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                      2 + 2\ z1 + z2 + z3 + 
                        2\ z4])\)/\((m\^2\ s\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                      2 + z2 + z3 + 2\ z4])\)\)\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z4 \[Rule] \(-\(69\/256\)\)}}]}, \
{MBint[\(-\(\((\((m\^2)\)\^\(\(-2\)\ eps - z3 - z4\)\ \((\(-s\))\)\^\(z3 + z4\
\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 4\ eps - 
                        2\ z1 - z2 - z3 - 2\ z4]\ Gamma[\(-1\) - eps - z1 - 
                        z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
                        z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                      1 + z3 + z4]\ Gamma[1 + 2\ eps + z1 + z3 + z4]\ Gamma[
                      2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                      2 + 2\ z1 + z2 + z3 + 
                        2\ z4])\)/\((m\^2\ s\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z2]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                      2 + z2 + z3 + 2\ z4])\)\)\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z4 \[Rule] \(-\(69\/256\)\)}}]}, 
        MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - 2\ eps - \
z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 
                    4\ eps - 2\ z1 - z2 - z3 - 2\ z4]\ Gamma[\(-1\) - eps - 
                    z1 - z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
                    z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                  1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                  2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-1\) - 2\ eps - z1 - 
                    z2 - z4 - z6]\ Gamma[\(-1\) - 2\ eps - z1 - z3 - z4 - 
                    z6]\ Gamma[\(-z6\)]\ Gamma[
                  2 + 2\ eps + z1 + z4 + z6])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
                  1 - z2]\ Gamma[1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                  2 + z2 + z3 + 2\ z4]\ Gamma[\(-2\) - 4\ eps - 2\ z1 - z2 - 
                    z3 - 2\ z4 - 2\ z6])\), {{eps \[Rule] 0, 
              eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
              z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
              z4 \[Rule] \(-\(69\/256\)\), 
              z6 \[Rule] \(-\(19\/64\)\)}}]}, {{{{{MBint[\(-\(\((\((m\^2)\)\^\
\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ \
Gamma[\(-2\)\ eps]\ Gamma[1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-3\)\ eps - 
                              z6]\ Gamma[\(-eps\) - 
                              z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 + eps + 
                              z6])\)/\((s\^2\ Gamma[1 - 2\ eps]\^2\ \
Gamma[\(-2\)\ z1]\ Gamma[\(-4\)\ eps - 2\ z6])\)\)\), {{eps \[Rule] 0, 
                      eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z6 \[Rule] \(-\(19\/64\)\)}}]}, 
              MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-eps\) - z1 \
+ z7\)\ \((\(-t\))\)\^\(\(-eps\) - z6 - z7\)\ Gamma[\(-2\)\ eps]\ Gamma[
                        1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                        eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                        1 + eps + z1]\ Gamma[\(-z6\)]\ Gamma[\(-eps\) - z6 - 
                          z7]\ Gamma[\(-1\) + eps - z6 - 
                          z7]\ Gamma[\(-z7\)]\ Gamma[1 + z7]\ Gamma[
                        1 - 2\ eps + z7]\ Gamma[1 + eps + z6 + z7]\ Gamma[
                        2 - 2\ eps + 2\ z6 + 
                          2\ z7])\)/\((s\ t\ Gamma[1 - 2\ eps]\^2\ Gamma[
                        2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[
                        2 - 2\ eps + 2\ z7])\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z6 \[Rule] \(-\(19\/64\)\), 
                    z7 \[Rule] \(-\(665\/1024\)\)}}]}, \
{MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\
\)\ Gamma[\(-4\)\ eps]\ Gamma[1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[\(-eps\) - 
                            z2 - z6]\ Gamma[\(-3\)\ eps + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 + eps + z6])\)/\((s\^2\ Gamma[
                          1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + z2]\ Gamma[\(-4\)\ eps - 
                            2\ z6])\)\)\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-eps\) - z1 + \
z7\)\ \((\(-t\))\)\^\(\(-eps\) - z6 - z7\)\ Gamma[
                      1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[1 + eps + z1]\ Gamma[
                      eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                        z2]\ Gamma[\(-eps\) - z1 + 
                        z2]\ Gamma[\(-z6\)]\ Gamma[\(-eps\) - z6 - 
                        z7]\ Gamma[\(-1\) + eps - z6 - 
                        z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
                      1 - 2\ eps + z2 + z7]\ Gamma[1 + eps + z6 + z7]\ Gamma[
                      2 - 2\ eps + 2\ z6 + 2\ z7])\)/\((s\ t\ Gamma[
                      1 - 2\ eps]\ Gamma[2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[
                      1 - z2]\ Gamma[1 - 2\ eps + z2]\ Gamma[
                      2 - 2\ eps + 2\ z7])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\), 
                  z7 \[Rule] \(-\(665\/1024\)\)}}]}, {{{MBint[\(-\(\((2\ \
EulerGamma\ \((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                              1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                              eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                              1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                              eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                              1 - eps + z6])\)/\((s\^2\ Gamma[
                              1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\)\)\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ Log[\(-s\)])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) - \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ Log[\(-t\)])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) - \((2\ \((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[
                            0, \(-2\)\ eps])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[0, 
                            1 + 2\ eps])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[0, 
                            eps - z1])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) - \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[
                            0, \(-2\)\ z1])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[0, 
                            eps - z6])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) - \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[
                            0, \(-2\)\ z6])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\) - \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \
\((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[\(-2\)\ eps]\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-eps\) - z1]\ Gamma[
                            eps - z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6]\ PolyGamma[0, 
                            1 - eps + z6])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6])\), {{eps \[Rule] 0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z6 \[Rule] \(-\(19\/64\)\)}}]}, 
              MBint[\(-\(\((2\ EulerGamma\ \((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                            1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                            1 + eps + z1]\ Gamma[
                            eps - z1 - 
                              z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                              z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                            eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                              z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + 
                              z6])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                            1 - z2]\ Gamma[
                            1 - 2\ eps + 
                              z2]\ Gamma[\(-2\)\ z6])\)\)\) + \((\((m\^2)\)\^\
\(z1 + z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ \
Gamma[1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + 
                            z6]\ Log[\(-s\)])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ \
Gamma[1 - z2]\ Gamma[1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + 
                            z6]\ Log[\(-t\)])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ \
Gamma[1 - z2]\ Gamma[1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[0, 
                          1 - 2\ eps])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[
                          0, \(-2\)\ eps])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ \
Gamma[1 - z2]\ Gamma[1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) + \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[0, 
                          1 + 2\ eps])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[
                          0, \(-2\)\ z1])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) + \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[0, 
                          eps - z1 - z2])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[
                          0, \(-2\)\ eps + 
                            z2])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) + \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[0, 
                          1 - 2\ eps + 
                            z2])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) + \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[0, 
                          eps - z2 - z6])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[
                          0, \(-2\)\ z6])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-z1\) - z6\)\ \((\(-t\))\)\^\(\(-2\)\ eps\)\ Gamma[
                          1 + 2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + eps + z1]\ Gamma[
                          eps - z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-eps\) - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6]\ PolyGamma[0, 
                          1 - eps + z6])\)/\((s\^2\ Gamma[\(-2\)\ z1]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 + z2 + z3 - z6\)\ \((\(-t\))\)\^\(\(-z2\) - z3\)\ Gamma[\(-z1\)]\ Gamma[
                      1 + eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 + 
                        z2]\ Gamma[\(-z2\) - z3]\ Gamma[
                      1 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[\(-eps\) - z1 + 
                        z3]\ Gamma[
                      1 + z2 + 
                        z3]\ Gamma[\(-2\)\ eps + z2 + z3]\^2\ Gamma[\(-eps\) \
+ z2 - z6]\ Gamma[\(-eps\) + z3 - z6]\ Gamma[\(-z6\)]\ Gamma[
                      1 + eps - z2 - z3 + z6])\)/\((s\^2\ Gamma[
                      1 - 2\ eps]\ Gamma[\(-2\)\ eps]\ Gamma[1 - z2]\ Gamma[
                      1 - z3]\ Gamma[\(-2\)\ eps - 2\ z1 + z2 + 
                        z3]\ Gamma[\(-2\)\ eps + z2 + z3 - 
                        2\ z6])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, {MBint[\(-\(\((\((m\^2)\)\^\
\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[
                        1 + eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 + 
                          z2]\ Gamma[\(-z2\) - z3]\ Gamma[\(-2\)\ eps - z2 - 
                          z3]\ Gamma[\(-z3\)]\ Gamma[\(-eps\) - z1 + 
                          z3]\ Gamma[
                        1 + z2 + z3]\ Gamma[\(-2\)\ eps + z2 + 
                          z3]\ Gamma[\(-eps\) - z2 - z6]\ Gamma[\(-eps\) - 
                          z3 - z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 + eps + z6])\)/\((s\^2\ Gamma[
                        1 - 2\ eps]\ Gamma[\(-2\)\ eps]\ Gamma[1 - z2]\ Gamma[
                        1 - z3]\ Gamma[\(-2\)\ eps - 2\ z1 + z2 + 
                          z3]\ Gamma[\(-2\)\ eps - z2 - z3 - 
                          2\ z6])\)\)\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, 
          MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-eps\) - z1 + \
z7\)\ \((\(-t\))\)\^\(\(-eps\) - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[
                    1 + eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 + 
                      z2]\ Gamma[\(-z2\) - 
                      z3]\ Gamma[\(-z3\)]\ Gamma[\(-eps\) - z1 + z3]\ Gamma[
                    1 + z2 + z3]\ Gamma[\(-2\)\ eps + z2 + 
                      z3]\ Gamma[\(-z6\)]\ Gamma[\(-eps\) - z6 - 
                      z7]\ Gamma[\(-1\) - eps + z2 + z3 - z6 - 
                      z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
                    1 - z3 + z7]\ Gamma[1 + eps + z6 + z7]\ Gamma[
                    2 - z2 - z3 + 2\ z6 + 2\ z7])\)/\((s\ t\ Gamma[
                    1 - 2\ eps]\ Gamma[\(-2\)\ eps]\ Gamma[1 - z2]\ Gamma[
                    1 - z3]\ Gamma[
                    z2 + z3]\ Gamma[\(-2\)\ eps - 2\ z1 + z2 + z3]\ Gamma[
                    2 - z2 - z3 + 2\ z7])\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z6 \[Rule] \(-\(19\/64\)\), 
                z7 \[Rule] \(-\(665\/1024\)\)}}]}, \
{{{MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(eps + z4 - z6\)\ \((\(-t\
\))\)\^\(\(-3\)\ eps - z1 - z4\)\ Gamma[\(-z1\)]\ Gamma[\(-1\) - 3\ eps - 
                          z1 - z4]\ Gamma[\(-1\) - eps - z1 - 
                          z4]\ Gamma[\(-z4\)]\ Gamma[1 + z4]\ Gamma[
                        1 + 2\ eps + z4]\ Gamma[2 + 3\ eps + z1 + z4]\ Gamma[
                        2 + 2\ eps + 2\ z1 + 2\ z4]\ Gamma[\(-eps\) - 
                          z6]\ Gamma[eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 - eps + z6])\)/\((s\ t\ Gamma[1 - 2\ eps]\ Gamma[
                        2 + 2\ eps + 
                          2\ z4]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z4 \[Rule] \(-\(69\/256\)\), 
                    z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(eps + z4 - z6\)\
\ \((\(-t\))\)\^\(\(-3\)\ eps - z1 - z4\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-2\)\ eps + z2]\ Gamma[\(-1\) - 3\ eps - z1 - z4]\ Gamma[\(-1\) - 
                        eps - z1 - z4]\ Gamma[\(-z4\)]\ Gamma[
                      2 + 3\ eps + z1 + z4]\ Gamma[
                      1 + 2\ eps - z2 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
                      2 + 2\ eps + 2\ z1 + 2\ z4]\ Gamma[
                      eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                        z6]\ Gamma[\(-z6\)]\ Gamma[
                      1 - eps + z6])\)/\((s\ t\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z2]\ Gamma[1 - 2\ eps + z2]\ Gamma[
                      2 + 2\ eps + 
                        2\ z4]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, \
{{{MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ \
Gamma[\(-4\)\ eps]\ Gamma[
                          2\ eps]\ Gamma[\(-3\)\ eps - z1]\ Gamma[\(-eps\) - 
                            z1]\ Gamma[\(-z1\)]\ Gamma[
                          1 + 3\ eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                          eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6])\)/\((s\^2\ Gamma[
                          1 - 2\ eps]\ Gamma[\(-4\)\ eps - 
                            2\ z1]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                      eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z6 \[Rule] \(-\(19\/64\)\)}}]}, 
              MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                        1 + 3\ eps + z1]\ Gamma[\(-eps\) - z1 - 
                          z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                          z2]\ Gamma[\(-3\)\ eps - z1 + z2]\ Gamma[
                        eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                          z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 - eps + 
                          z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ \
eps - 2\ z1]\ Gamma[1 - z2]\ Gamma[
                        1 - 2\ eps + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
                      0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[\(-eps\) - z1 - 
                        z2]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 - 
                        z3]\ Gamma[\(-2\)\ eps - z2 - 
                        z3]\ Gamma[\(-z3\)]\ Gamma[
                      z2 + z3]\ Gamma[\(-2\)\ eps + z2 + z3]\ Gamma[
                      1 + eps + z1 + z2 + z3]\ Gamma[\(-eps\) + z2 - 
                        z6]\ Gamma[\(-eps\) + z3 - z6]\ Gamma[\(-z6\)]\ Gamma[
                      1 + eps - z2 - z3 + 
                        z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z2]\ Gamma[
                      1 - z3]\ Gamma[\(-2\)\ eps - 2\ z1 - z2 - z3]\ Gamma[
                      1 - 2\ eps + z2 + z3]\ Gamma[\(-2\)\ eps + z2 + z3 - 
                        2\ z6])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, 
          MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-eps\) + z2 + \
z3 + z4 - z6\)\ \((\(-t\))\)\^\(\(-eps\) - z1 - z2 - z3 - z4\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\)\ eps + z2 + 
                      z3]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - 
                      eps - z1 - z2 - z3 - z4]\ Gamma[\(-eps\) - z1 - z2 - 
                      z3 - z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                    1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                    2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-eps\) + z2 - 
                      z6]\ Gamma[\(-eps\) + z3 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + eps - z2 - z3 + 
                      z6])\)/\((s\ t\ Gamma[\(-2\)\ eps]\ Gamma[
                    1 - z2]\ Gamma[
                    1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                    2 + z2 + z3 + 2\ z4]\ Gamma[\(-2\)\ eps + z2 + z3 - 
                      2\ z6])\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z4 \[Rule] \(-\(69\/256\)\), 
                z6 \[Rule] \(-\(19\/64\)\)}}]}, {{{{MBint[\(\(1\/\(s\^2\ \
Gamma[\(-2\)\ eps]\ Gamma[
                          1 - 4\ eps - 2\ z1 - 
                            z2]\)\)\((\((m\^2)\)\^\(2\ eps + 2\ z1\)\ \((\(-s\
\))\)\^\(\(-4\)\ eps - 2\ z1\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-2\)\ eps - 
                          z1]\ Gamma[\(-z1\)]\ Gamma[\(-4\)\ eps - 2\ z1 - 
                          z2]\ Gamma[\(-eps\) - z1 - 
                          z2]\ Gamma[\(-z2\)]\ Gamma[3\ eps + z1 + z2]\ Gamma[
                        1 + 4\ eps + 2\ z1 + z2])\)\), {{eps \[Rule] 0, 
                      eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z2 \[Rule] \(-\(1\/8\)\)}}]}, 
              MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ \
eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-z1\)]\ Gamma[\(-4\)\ eps - 
                            2\ z1 - z2]\ Gamma[\(-eps\) - z1 - 
                            z2]\ Gamma[\(-z2\)]\ Gamma[
                          3\ eps + z1 + z2]\ Gamma[
                          1 + 4\ eps + 2\ z1 + z2]\ Gamma[\(-2\)\ eps - z1 - 
                            z6]\ Gamma[
                          2\ eps + z1 - z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - 2\ eps - z1 - z2 + 
                            z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                          1 - z2]\ Gamma[
                          1 - 4\ eps - 2\ z1 - 
                            z2]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), 
                    z6 \[Rule] \(-\(19\/64\)\)}}]}, \
{{MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ \
Gamma[\(-4\)\ eps]\ Gamma[
                          2\ eps]\ Gamma[\(-3\)\ eps - z1]\ Gamma[\(-eps\) - 
                            z1]\ Gamma[\(-z1\)]\ Gamma[
                          1 + 3\ eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                          eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + z6])\)/\((s\^2\ Gamma[
                          1 - 2\ eps]\ Gamma[\(-4\)\ eps - 
                            2\ z1]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 0, 
                      eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z6 \[Rule] \(-\(19\/64\)\)}}]}, 
              MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - \
z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                        1 + 3\ eps + z1]\ Gamma[\(-eps\) - z1 - 
                          z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                          z2]\ Gamma[\(-3\)\ eps - z1 + z2]\ Gamma[
                        eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                          z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 - eps + 
                          z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ \
eps - 2\ z1]\ Gamma[1 - z2]\ Gamma[
                        1 - 2\ eps + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
                      0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), 
                    z6 \[Rule] \(-\(19\/64\)\)}}]}, {{MBint[\(-\(\(1\/\(s\^2\ \
Gamma[\(-2\)\ eps]\ Gamma[1 - 4\ eps - 2\ z1 - 
                              z2]\)\)\((\((m\^2)\)\^\(2\ eps + 2\ z1\)\ \
\((\(-s\))\)\^\(\(-4\)\ eps - 2\ z1\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-2\)\ eps \
- z1]\ Gamma[\(-z1\)]\ Gamma[\(-4\)\ eps - 2\ z1 - z2]\ Gamma[\(-eps\) - z1 - 
                            z2]\ Gamma[\(-z2\)]\ Gamma[
                          3\ eps + z1 + z2]\ Gamma[
                          1 + 4\ eps + 2\ z1 + z2])\)\)\), {{eps \[Rule] 0, 
                      eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z2 \[Rule] \(-\(1\/8\)\)}}]}, 
              MBint[\((\((m\^2)\)\^\(\(-2\)\ eps - z2 - z4\)\ \
\((\(-s\))\)\^\(z2 + z4\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\
\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - 4\ eps - 2\ z1 - z2 - 
                          z4]\ Gamma[\(-z4\)]\ Gamma[
                        1 + 3\ eps + z1 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
                        1 + 2\ eps + z1 + z2 + z4]\ Gamma[
                        2 + 4\ eps + 2\ z1 + z2 + 
                          2\ z4])\)/\((m\^2\ s\ Gamma[\(-2\)\ eps]\ \
Gamma[\(-4\)\ eps - 2\ z1]\ Gamma[
                        3 + 4\ eps + 2\ z1 + z2 + 2\ z4])\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), 
                    z4 \[Rule] \(-\(69\/256\)\)}}]}, 
            MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ \
eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - 4\ eps - 2\ z1 - z2 - 
                          z4]\ Gamma[\(-z4\)]\ Gamma[
                        1 + 3\ eps + z1 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
                        2 + 4\ eps + 2\ z1 + z2 + 2\ z4]\ Gamma[\(-1\) - 
                          2\ eps - z1 - z2 - z4 - z6]\ Gamma[
                        1 + 2\ eps + z1 + z2 + z4 - 
                          z6]\ Gamma[\(-z6\)]\ Gamma[
                        2 + 2\ eps + z1 + z4 + 
                          z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ \
eps - 2\ z1]\ Gamma[1 - z2]\ Gamma[
                        3 + 4\ eps + 2\ z1 + z2 + 
                          2\ z4]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, {{{MBint[\(-\(\((\((m\^2)\)\
\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ \
Gamma[2\ eps]\ Gamma[\(-3\)\ eps - z1]\ Gamma[\(-eps\) - 
                              z1]\ Gamma[\(-z1\)]\ Gamma[
                            1 + 3\ eps + z1]\ Gamma[\(-eps\) - z6]\ Gamma[
                            eps - z6]\ Gamma[\(-z6\)]\ Gamma[
                            1 - eps + z6])\)/\((s\^2\ Gamma[
                            1 - 2\ eps]\ Gamma[\(-4\)\ eps - 
                              2\ z1]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 
                        0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                      z6 \[Rule] \(-\(19\/64\)\)}}]}, 
              MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ \
eps - z1 - z6\)\ Gamma[\(-4\)\ eps]\ Gamma[2\ eps]\ Gamma[\(-z1\)]\ Gamma[
                          1 + 3\ eps + z1]\ Gamma[\(-eps\) - z1 - 
                            z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps + 
                            z2]\ Gamma[\(-3\)\ eps - z1 + z2]\ Gamma[
                          eps - z2 - z6]\ Gamma[\(-eps\) + z2 - 
                            z6]\ Gamma[\(-z6\)]\ Gamma[
                          1 - eps + 
                            z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[\(-4\)\ \
eps - 2\ z1]\ Gamma[1 - z2]\ Gamma[
                          1 - 2\ eps + 
                            z2]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 0, 
                    eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                    z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
            MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ \
eps - z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[\(-eps\) - z1 - 
                          z2]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) - z1 - 
                          z3]\ Gamma[\(-2\)\ eps - z2 - 
                          z3]\ Gamma[\(-z3\)]\ Gamma[
                        z2 + z3]\ Gamma[\(-2\)\ eps + z2 + z3]\ Gamma[
                        1 + eps + z1 + z2 + z3]\ Gamma[\(-eps\) + z2 - 
                          z6]\ Gamma[\(-eps\) + z3 - 
                          z6]\ Gamma[\(-z6\)]\ Gamma[
                        1 + eps - z2 - z3 + 
                          z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                        1 - z2]\ Gamma[
                        1 - z3]\ Gamma[\(-2\)\ eps - 2\ z1 - z2 - z3]\ Gamma[
                        1 - 2\ eps + z2 + z3]\ Gamma[\(-2\)\ eps + z2 + z3 - 
                          2\ z6])\)\)\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                  z6 \[Rule] \(-\(19\/64\)\)}}]}, \
{MBint[\((\((m\^2)\)\^\(\(-2\)\ eps - z2 - z4\)\ \((\(-s\))\)\^\(z2 + z4\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 4\ eps - 
                        2\ z1 - z2 - z3 - 2\ z4]\ Gamma[\(-1\) - eps - z1 - 
                        z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
                        z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                      1 + 2\ eps + z1 + z2 + z4]\ Gamma[1 + z3 + z4]\ Gamma[
                      2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                      2 + 2\ z1 + z2 + z3 + 
                        2\ z4])\)/\((m\^2\ s\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                      2 + z2 + z3 + 2\ z4])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                  z4 \[Rule] \(-\(69\/256\)\)}}]}, \
{MBint[\((\((m\^2)\)\^\(\(-2\)\ eps - z3 - z4\)\ \((\(-s\))\)\^\(z3 + z4\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 4\ eps - 
                        2\ z1 - z2 - z3 - 2\ z4]\ Gamma[\(-1\) - eps - z1 - 
                        z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
                        z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                      1 + z3 + z4]\ Gamma[1 + 2\ eps + z1 + z3 + z4]\ Gamma[
                      2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                      2 + 2\ z1 + z2 + z3 + 
                        2\ z4])\)/\((m\^2\ s\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z2]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                      2 + z2 + z3 + 2\ z4])\), {{eps \[Rule] 0, 
                  eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                  z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                  z4 \[Rule] \(-\(69\/256\)\)}}]}, 
          MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\)\ eps \
- z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-2\) - 
                        4\ eps - 2\ z1 - z2 - z3 - 2\ z4]\ Gamma[\(-1\) - 
                        eps - z1 - z4]\ Gamma[\(-1\) - eps - z1 - z2 - z3 - 
                        z4]\ Gamma[\(-z4\)]\ Gamma[1 + z2 + z4]\ Gamma[
                      1 + z3 + z4]\ Gamma[2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                      2 + 2\ z1 + z2 + z3 + 2\ z4]\ Gamma[\(-1\) - 2\ eps - 
                        z1 - z2 - z4 - z6]\ Gamma[\(-1\) - 2\ eps - z1 - z3 - 
                        z4 - z6]\ Gamma[\(-z6\)]\ Gamma[
                      2 + 2\ eps + z1 + z4 + 
                        z6])\)/\((s\^2\ Gamma[\(-2\)\ eps]\ Gamma[
                      1 - z2]\ Gamma[
                      1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                      2 + z2 + z3 + 2\ z4]\ Gamma[\(-2\) - 4\ eps - 2\ z1 - 
                        z2 - z3 - 2\ z4 - 2\ z6])\)\)\), {{eps \[Rule] 0, 
                eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
                z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
                z4 \[Rule] \(-\(69\/256\)\), z6 \[Rule] \(-\(19\/64\)\)}}]}, 
        MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(z4 + z7\)\ \
\((\(-t\))\)\^\(\(-2\) - 2\ eps - z1 - z4 - z6 - z7\)\ Gamma[\(-z1\)]\ Gamma[\
\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-1\) - eps - z1 - z4]\ Gamma[\(-1\) - eps - 
                    z1 - z2 - z3 - z4]\ Gamma[\(-z4\)]\ Gamma[
                  1 + z2 + z4]\ Gamma[1 + z3 + z4]\ Gamma[
                  2 + eps + z1 + z2 + z3 + z4]\ Gamma[
                  2 + 2\ z1 + z2 + z3 + 
                    2\ z4]\ Gamma[\(-z6\)]\ Gamma[\(-1\) - eps + z2 + z3 - 
                    z6 - z7]\ Gamma[\(-1\) - 2\ eps - z1 - z4 - z6 - 
                    z7]\ Gamma[\(-z7\)]\ Gamma[1 - z2 + z7]\ Gamma[
                  1 - z3 + z7]\ Gamma[
                  2 + 2\ eps + z1 + z4 + z6 + z7]\ Gamma[\(-z2\) - z3 + 
                    2\ \((1 + z6 + z7)\)])\)/\((Gamma[\(-2\)\ eps]\ Gamma[
                  1 - z2]\ Gamma[1 - z3]\ Gamma[\(-3\)\ eps - z1 - z4]\ Gamma[
                  1 + eps + z1 + z2 + z3 + z4]\ Gamma[
                  2 + z2 + z3 + 2\ z4]\ Gamma[
                  2 - z2 - z3 + 2\ z7])\), {{eps \[Rule] 0, 
              eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
              z2 \[Rule] \(-\(1\/8\)\), z3 \[Rule] \(-\(19\/128\)\), 
              z4 \[Rule] \(-\(69\/256\)\), z6 \[Rule] \(-\(19\/64\)\), 
              z7 \[Rule] \(-\(665\/1024\)\)}}]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ser = 
      MBexpand[{integrals}, Exp[2*eps*EulerGamma], {eps, 0, 0}]\)], "Input"],

Cell[BoxData[
    \({MBint[\(-\(\(\((m\^2)\)\^\(2\ z1\)\ \((\(-s\))\)\^\(\(-2\)\ \((1 + z1)\
\)\)\ Gamma[\(-z1\)]\^2\ Gamma[\(-2\)\ z1 - z2]\ Gamma[\(-z1\) - 
                    z2]\ Gamma[\(-z2\)]\ Gamma[z1 + z2]\ Gamma[
                  1 + 2\ z1 + z2]\)\/\(2\ Gamma[
                  1 - 2\ z1 - z2]\)\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[\(-2\)\ z1 - z2]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ \
Gamma[z1 + z2]\ Gamma[1 + 2\ z1 + z2]\ Gamma[\(-z1\) - z6]\ Gamma[z1 - z6]\ \
Gamma[\(-z6\)]\ Gamma[1 - z1 - z2 + z6]\)\/\(2\ Gamma[1 - z2]\ Gamma[1 - 2\ \
z1 - z2]\ Gamma[\(-2\)\ z6]\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\)\/\(8\ \
eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\) + \(\(1\/\(8\ eps\ \
Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[
                1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  4\ PolyGamma[0, \(-2\)\ z1] - 4\ PolyGamma[0, \(-z1\)] + 
                  3\ PolyGamma[0, 1 + z1] - 
                  PolyGamma[0, 
                    1 + z6])\))\)\) + \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z1]\^2 + 
                  48\ PolyGamma[0, \(-z1\)]\^2 + 
                  36\ EulerGamma\ PolyGamma[0, 1 + z1] - 
                  36\ Log[\(-s\)]\ PolyGamma[0, 1 + z1] + 
                  27\ PolyGamma[0, 1 + z1]\^2 - 
                  24\ PolyGamma[
                      0, \(-z1\)]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        3\ PolyGamma[0, 1 + z1] - PolyGamma[0, 1 + z6])\) + 
                  24\ PolyGamma[
                      0, \(-2\)\ z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z1\)] + 3\ PolyGamma[0, 1 + z1] - 
                        PolyGamma[0, 1 + z6])\) - 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] + 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  18\ PolyGamma[0, 1 + z1]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 - 48\ PolyGamma[1, \(-2\)\ z1] + 
                  30\ PolyGamma[1, \(-z1\)] + 27\ PolyGamma[1, 1 + z1] + 
                  6\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\ Gamma[
                    1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                    z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                    z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[
                    1 - z2]\ Gamma[
                    1 + z2]\ Gamma[\(-2\)\ z6]\)\)\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    4\ PolyGamma[0, \(-2\)\ z1] + 3\ PolyGamma[0, 1 + z1] - 
                    PolyGamma[0, \(-z1\) - z2] - 2\ PolyGamma[0, z2] + 
                    2\ PolyGamma[0, 1 + z2] - 3\ PolyGamma[0, \(-z1\) + z2] + 
                    PolyGamma[0, \(-z2\) - z6] - PolyGamma[0, z2 - z6] - 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(2\ z1\)\ \((\(-s\))\)\^\(\(-2\)\ \((1 + z1)\)\)\ \
Gamma[\(-z1\)]\^2\ Gamma[\(-2\)\ z1 - z2]\ Gamma[\(-z1\) - z2]\ \
Gamma[\(-z2\)]\ Gamma[z1 + z2]\ Gamma[1 + 2\ z1 + z2]\)\/\(2\ Gamma[1 - 2\ z1 \
- z2]\), {{eps \[Rule] 0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(\(1\/\(2\ Gamma[\(-2\)\ z1]\ Gamma[
                3 + 2\ z1 + z2 + 
                  2\ z4]\)\)\((\((m\^2)\)\^\(\(-1\) - z2 - z4\)\ \((\(-s\))\)\
\^\(\(-1\) + z2 + z4\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - z1 - 
                z4]\ Gamma[\(-1\) - 2\ z1 - z2 - z4]\ Gamma[\(-z4\)]\ Gamma[
              1 + z1 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
              1 + z1 + z2 + z4]\ Gamma[
              2 + 2\ z1 + z2 + 2\ z4])\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\)}}], 
      MBint[\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - z1 - z4]\ Gamma[\(-1\) - 
                  2\ z1 - z2 - z4]\ Gamma[\(-z4\)]\ Gamma[1 + z1 + z4]\ Gamma[
                1 + z2 + z4]\ Gamma[
                2 + 2\ z1 + z2 + 2\ z4]\ Gamma[\(-1\) - z1 - z2 - z4 - 
                  z6]\ Gamma[1 + z1 + z2 + z4 - z6]\ Gamma[\(-z6\)]\ Gamma[
                2 + z1 + z4 + z6])\)/\((2\ Gamma[\(-2\)\ z1]\ Gamma[
                1 - z2]\ Gamma[
                3 + 2\ z1 + z2 + 2\ z4]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\)\/\(8\ \
eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\) + \(\(1\/\(8\ eps\ \
Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[
                1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  PolyGamma[0, 1 + z1] + 4\ PolyGamma[0, \(-2\)\ z6] - 
                  4\ PolyGamma[0, \(-z6\)] + 
                  PolyGamma[0, 
                    1 + z6])\))\)\) + \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  3\ PolyGamma[0, 1 + z1]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z6]\^2 - 
                  48\ EulerGamma\ PolyGamma[0, \(-z6\)] + 
                  48\ Log[\(-s\)]\ PolyGamma[0, \(-z6\)] + 
                  48\ PolyGamma[0, \(-z6\)]\^2 + 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] - 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  24\ PolyGamma[0, \(-z6\)]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 + 
                  24\ PolyGamma[
                      0, \(-2\)\ z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z6\)] + PolyGamma[0, 1 + z6])\) + 
                  6\ PolyGamma[0, 
                      1 + z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        4\ PolyGamma[0, \(-2\)\ z6] - 
                        4\ PolyGamma[0, \(-z6\)] + PolyGamma[0, 1 + z6])\) + 
                  6\ PolyGamma[1, \(-z1\)] + 3\ PolyGamma[1, 1 + z1] - 
                  48\ PolyGamma[1, \(-2\)\ z6] + 30\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\ Gamma[
                    1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                    z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                    z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[
                    1 - z2]\ Gamma[
                    1 + z2]\ Gamma[\(-2\)\ z6]\)\)\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    PolyGamma[0, 1 + z1] + PolyGamma[0, \(-z1\) - z2] - 
                    2\ PolyGamma[0, z2] + 2\ PolyGamma[0, 1 + z2] - 
                    PolyGamma[0, \(-z1\) + z2] - PolyGamma[0, \(-z2\) - z6] - 
                    3\ PolyGamma[0, z2 - z6] + 4\ PolyGamma[0, \(-2\)\ z6] + 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                    1 + z6]\)\/\(8\ eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\) - \(\(1\/\(8\ eps\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\
\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  4\ PolyGamma[0, \(-2\)\ z1] - 4\ PolyGamma[0, \(-z1\)] + 
                  3\ PolyGamma[0, 1 + z1] - 
                  PolyGamma[0, 
                    1 + z6])\))\)\) - \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z1]\^2 + 
                  48\ PolyGamma[0, \(-z1\)]\^2 + 
                  36\ EulerGamma\ PolyGamma[0, 1 + z1] - 
                  36\ Log[\(-s\)]\ PolyGamma[0, 1 + z1] + 
                  27\ PolyGamma[0, 1 + z1]\^2 - 
                  24\ PolyGamma[
                      0, \(-z1\)]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        3\ PolyGamma[0, 1 + z1] - PolyGamma[0, 1 + z6])\) + 
                  24\ PolyGamma[
                      0, \(-2\)\ z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z1\)] + 3\ PolyGamma[0, 1 + z1] - 
                        PolyGamma[0, 1 + z6])\) - 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] + 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  18\ PolyGamma[0, 1 + z1]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 - 48\ PolyGamma[1, \(-2\)\ z1] + 
                  30\ PolyGamma[1, \(-z1\)] + 27\ PolyGamma[1, 1 + z1] + 
                  6\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\ \
Gamma[\(-2\)\ z6]\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    4\ PolyGamma[0, \(-2\)\ z1] + 3\ PolyGamma[0, 1 + z1] - 
                    PolyGamma[0, \(-z1\) - z2] - 2\ PolyGamma[0, z2] + 
                    2\ PolyGamma[0, 1 + z2] - 3\ PolyGamma[0, \(-z1\) + z2] + 
                    PolyGamma[0, \(-z2\) - z6] - PolyGamma[0, z2 - z6] - 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                    1 + z6]\)\/\(8\ eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\) - \(\(1\/\(8\ eps\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\
\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  PolyGamma[0, 1 + z1] + 4\ PolyGamma[0, \(-2\)\ z6] - 
                  4\ PolyGamma[0, \(-z6\)] + 
                  PolyGamma[0, 
                    1 + z6])\))\)\) - \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  3\ PolyGamma[0, 1 + z1]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z6]\^2 - 
                  48\ EulerGamma\ PolyGamma[0, \(-z6\)] + 
                  48\ Log[\(-s\)]\ PolyGamma[0, \(-z6\)] + 
                  48\ PolyGamma[0, \(-z6\)]\^2 + 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] - 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  24\ PolyGamma[0, \(-z6\)]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 + 
                  24\ PolyGamma[
                      0, \(-2\)\ z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z6\)] + PolyGamma[0, 1 + z6])\) + 
                  6\ PolyGamma[0, 
                      1 + z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        4\ PolyGamma[0, \(-2\)\ z6] - 
                        4\ PolyGamma[0, \(-z6\)] + PolyGamma[0, 1 + z6])\) + 
                  6\ PolyGamma[1, \(-z1\)] + 3\ PolyGamma[1, 1 + z1] - 
                  48\ PolyGamma[1, \(-2\)\ z6] + 30\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 + z7\)\ s\ \
\((\(-t\))\)\^\(\(-1\) - z6 - z7\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ \
Gamma[\(-z6\)]\ Gamma[\(-1\) - z6 - z7]\ Gamma[\(-z6\) - z7]\ Gamma[\(-z7\)]\ \
Gamma[1 + z7]\^2\ Gamma[1 + z6 + z7]\ Gamma[2\ \((1 + z6 + z7)\)]\)\/\(Gamma[\
\(-2\)\ z1]\ Gamma[2\ \((1 + z7)\)]\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\), z7 \[Rule] \(-\(665\/1024\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\ \
Gamma[\(-2\)\ z6]\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    PolyGamma[0, 1 + z1] + PolyGamma[0, \(-z1\) - z2] - 
                    2\ PolyGamma[0, z2] + 2\ PolyGamma[0, 1 + z2] - 
                    PolyGamma[0, \(-z1\) + z2] - PolyGamma[0, \(-z2\) - z6] - 
                    3\ PolyGamma[0, z2 - z6] + 4\ PolyGamma[0, \(-2\)\ z6] + 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\)\/\(2\ \
eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\) + \(\(1\/\(2\ eps\ \
Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[
                1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((EulerGamma - Log[\(-s\)] - Log[\(-t\)] + 
                  PolyGamma[0, \(-2\)\ z1] - PolyGamma[0, \(-z1\)] + 
                  PolyGamma[0, 1 + z1] + PolyGamma[0, \(-2\)\ z6] - 
                  PolyGamma[
                    0, \(-z6\)])\))\)\) - \(\(1\/\(12\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((4\ \[Pi]\^2 + 12\ EulerGamma\ Log[\(-t\)] - 
                  12\ Log[\(-s\)]\ Log[\(-t\)] - 
                  6\ EulerGamma\ PolyGamma[0, 1 + z1] + 
                  6\ Log[\(-s\)]\ PolyGamma[0, 1 + z1] + 
                  6\ Log[\(-t\)]\ PolyGamma[0, 1 + z1] - 
                  3\ PolyGamma[0, 1 + z1]\^2 + 
                  12\ Log[\(-t\)]\ PolyGamma[0, \(-2\)\ z6] - 
                  6\ PolyGamma[0, 1 + z1]\ PolyGamma[0, \(-2\)\ z6] - 
                  12\ Log[\(-t\)]\ PolyGamma[0, \(-z6\)] + 
                  6\ PolyGamma[0, 1 + z1]\ PolyGamma[0, \(-z6\)] + 
                  6\ EulerGamma\ PolyGamma[0, 1 + z6] - 
                  6\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] + 
                  6\ Log[\(-t\)]\ PolyGamma[0, 1 + z6] + 
                  6\ PolyGamma[0, \(-2\)\ z6]\ PolyGamma[0, 1 + z6] - 
                  6\ PolyGamma[0, \(-z6\)]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 + 
                  6\ PolyGamma[
                      0, \(-2\)\ z1]\ \((2\ Log[\(-t\)] - 
                        PolyGamma[0, 1 + z1] + PolyGamma[0, 1 + z6])\) - 
                  6\ PolyGamma[
                      0, \(-z1\)]\ \((2\ Log[\(-t\)] - PolyGamma[0, 1 + z1] + 
                        PolyGamma[0, 1 + z6])\) - 3\ PolyGamma[1, 1 + z1] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\ Gamma[
                    1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                    z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                    z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + z6]\)\/\(2\ eps\ Gamma[\(-2\)\ z1]\ Gamma[
                    1 - z2]\ Gamma[
                    1 + z2]\ Gamma[\(-2\)\ z6]\)\)\) + \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((\(-2\)\ EulerGamma + 2\ Log[\(-s\)] - 
                    2\ PolyGamma[0, \(-2\)\ z1] - PolyGamma[0, 1 + z1] + 
                    PolyGamma[0, \(-z1\) - z2] + PolyGamma[0, \(-z1\) + z2] + 
                    PolyGamma[0, \(-z2\) - z6] + PolyGamma[0, z2 - z6] - 
                    2\ PolyGamma[0, \(-2\)\ z6] - 
                    PolyGamma[0, 1 + z6])\))\)/\((2\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-1\) + z4 - z6\)\ \
\((\(-t\))\)\^\(\(-1\) - z1 - z4\)\ Gamma[\(-z1\)]\ Gamma[\(-1\) - z1 - \
z4]\^2\ Gamma[\(-z4\)]\ Gamma[1 + z4]\^2\ Gamma[2\ \((1 + z1 + z4)\)]\ \
Gamma[2 + z1 + z4]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\)\/\(Gamma[2\ \((1 + z4)\
\)]\ Gamma[\(-2\)\ z6]\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z4 \[Rule] \(-\(69\/256\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                    1 + z6]\)\/\(8\ eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\) - \(\(1\/\(8\ eps\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\
\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  4\ PolyGamma[0, \(-2\)\ z1] - 4\ PolyGamma[0, \(-z1\)] + 
                  3\ PolyGamma[0, 1 + z1] - 
                  PolyGamma[0, 
                    1 + z6])\))\)\) - \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z1]\^2 + 
                  48\ PolyGamma[0, \(-z1\)]\^2 + 
                  36\ EulerGamma\ PolyGamma[0, 1 + z1] - 
                  36\ Log[\(-s\)]\ PolyGamma[0, 1 + z1] + 
                  27\ PolyGamma[0, 1 + z1]\^2 - 
                  24\ PolyGamma[
                      0, \(-z1\)]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        3\ PolyGamma[0, 1 + z1] - PolyGamma[0, 1 + z6])\) + 
                  24\ PolyGamma[
                      0, \(-2\)\ z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z1\)] + 3\ PolyGamma[0, 1 + z1] - 
                        PolyGamma[0, 1 + z6])\) - 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] + 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  18\ PolyGamma[0, 1 + z1]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 - 48\ PolyGamma[1, \(-2\)\ z1] + 
                  30\ PolyGamma[1, \(-z1\)] + 27\ PolyGamma[1, 1 + z1] + 
                  6\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\ \
Gamma[\(-2\)\ z6]\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    4\ PolyGamma[0, \(-2\)\ z1] + 3\ PolyGamma[0, 1 + z1] - 
                    PolyGamma[0, \(-z1\) - z2] - 2\ PolyGamma[0, z2] + 
                    2\ PolyGamma[0, 1 + z2] - 3\ PolyGamma[0, \(-z1\) + z2] + 
                    PolyGamma[0, \(-z2\) - z6] - PolyGamma[0, z2 - z6] - 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(2\ z1\)\ \((\(-s\))\)\^\(\(-2\)\ \((1 + z1)\)\)\ \
Gamma[\(-z1\)]\^2\ Gamma[\(-2\)\ z1 - z2]\ Gamma[\(-z1\) - z2]\ \
Gamma[\(-z2\)]\ Gamma[z1 + z2]\ Gamma[1 + 2\ z1 + z2]\)\/\(2\ Gamma[1 - 2\ z1 \
- z2]\), {{eps \[Rule] 0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\ Gamma[\(-2\)\ z1 - z2]\ Gamma[\(-z1\) - 
                    z2]\ Gamma[\(-z2\)]\ Gamma[z1 + z2]\ Gamma[
                  1 + 2\ z1 + z2]\ Gamma[\(-z1\) - z6]\ Gamma[
                  z1 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 - z1 - z2 + z6]\)\/\(2\ Gamma[1 - z2]\ Gamma[
                  1 - 2\ z1 - z2]\ Gamma[\(-2\)\ z6]\)\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                    1 + z6]\)\/\(8\ eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\) - \(\(1\/\(8\ eps\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ \
z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\
\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  4\ PolyGamma[0, \(-2\)\ z1] - 4\ PolyGamma[0, \(-z1\)] + 
                  3\ PolyGamma[0, 1 + z1] - 
                  PolyGamma[0, 
                    1 + z6])\))\)\) - \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z1]\^2 + 
                  48\ PolyGamma[0, \(-z1\)]\^2 + 
                  36\ EulerGamma\ PolyGamma[0, 1 + z1] - 
                  36\ Log[\(-s\)]\ PolyGamma[0, 1 + z1] + 
                  27\ PolyGamma[0, 1 + z1]\^2 - 
                  24\ PolyGamma[
                      0, \(-z1\)]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        3\ PolyGamma[0, 1 + z1] - PolyGamma[0, 1 + z6])\) + 
                  24\ PolyGamma[
                      0, \(-2\)\ z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z1\)] + 3\ PolyGamma[0, 1 + z1] - 
                        PolyGamma[0, 1 + z6])\) - 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] + 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  18\ PolyGamma[0, 1 + z1]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 - 48\ PolyGamma[1, \(-2\)\ z1] + 
                  30\ PolyGamma[1, \(-z1\)] + 27\ PolyGamma[1, 1 + z1] + 
                  6\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\ Gamma[1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\
\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[z2 - z6]\ Gamma[\(-z6\)]\ \
Gamma[1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[1 - z2]\ Gamma[1 + z2]\ \
Gamma[\(-2\)\ z6]\) + \((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    4\ PolyGamma[0, \(-2\)\ z1] + 3\ PolyGamma[0, 1 + z1] - 
                    PolyGamma[0, \(-z1\) - z2] - 2\ PolyGamma[0, z2] + 
                    2\ PolyGamma[0, 1 + z2] - 3\ PolyGamma[0, \(-z1\) + z2] + 
                    PolyGamma[0, \(-z2\) - z6] - PolyGamma[0, z2 - z6] - 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(2\ z1\)\ \((\(-s\))\)\^\(\(-2\)\ \((1 + \
z1)\)\)\ Gamma[\(-z1\)]\^2\ Gamma[\(-2\)\ z1 - z2]\ Gamma[\(-z1\) - 
                    z2]\ Gamma[\(-z2\)]\ Gamma[z1 + z2]\ Gamma[
                  1 + 2\ z1 + z2]\)\/\(2\ Gamma[
                  1 - 2\ z1 - z2]\)\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\)}}], 
      MBint[\(-\(\(1\/\(2\ Gamma[\(-2\)\ z1]\ Gamma[
                  3 + 2\ z1 + z2 + 
                    2\ z4]\)\)\((\((m\^2)\)\^\(\(-1\) - z2 - z4\)\ \((\(-s\))\
\)\^\(\(-1\) + z2 + z4\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - z1 - 
                  z4]\ Gamma[\(-1\) - 2\ z1 - z2 - z4]\ Gamma[\(-z4\)]\ Gamma[
                1 + z1 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
                1 + z1 + z2 + z4]\ Gamma[
                2 + 2\ z1 + z2 + 2\ z4])\)\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\)}}], 
      MBint[\(-\(\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\
\)\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[\(-1\) - z1 - z4]\ Gamma[\(-1\) - 
                    2\ z1 - z2 - z4]\ Gamma[\(-z4\)]\ Gamma[
                  1 + z1 + z4]\ Gamma[1 + z2 + z4]\ Gamma[
                  2 + 2\ z1 + z2 + 2\ z4]\ Gamma[\(-1\) - z1 - z2 - z4 - 
                    z6]\ Gamma[1 + z1 + z2 + z4 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  2 + z1 + z4 + z6])\)/\((2\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[
                  3 + 2\ z1 + z2 + 
                    2\ z4]\ Gamma[\(-2\)\ z6])\)\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), z4 \[Rule] \(-\(69\/256\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ \
Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[1 + z6]\)\/\(8\ \
eps\^2\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\) + \(\(1\/\(8\ eps\ \
Gamma[\(-2\)\ z1]\ Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \
\((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\^3\ Gamma[
                1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                  4\ PolyGamma[0, \(-2\)\ z1] - 4\ PolyGamma[0, \(-z1\)] + 
                  3\ PolyGamma[0, 1 + z1] - 
                  PolyGamma[0, 
                    1 + z6])\))\)\) + \(\(1\/\(48\ Gamma[\(-2\)\ z1]\ \
Gamma[\(-2\)\ z6]\)\)\((\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 \
- z6\)\ Gamma[\(-z1\)]\^3\ Gamma[1 + z1]\ Gamma[\(-z6\)]\^3\ Gamma[
                1 + z6]\ \((12\ EulerGamma\^2 + 8\ \[Pi]\^2 - 
                  24\ EulerGamma\ Log[\(-s\)] + 12\ Log[\(-s\)]\^2 + 
                  48\ PolyGamma[0, \(-2\)\ z1]\^2 + 
                  48\ PolyGamma[0, \(-z1\)]\^2 + 
                  36\ EulerGamma\ PolyGamma[0, 1 + z1] - 
                  36\ Log[\(-s\)]\ PolyGamma[0, 1 + z1] + 
                  27\ PolyGamma[0, 1 + z1]\^2 - 
                  24\ PolyGamma[
                      0, \(-z1\)]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                        3\ PolyGamma[0, 1 + z1] - PolyGamma[0, 1 + z6])\) + 
                  24\ PolyGamma[
                      0, \(-2\)\ z1]\ \((2\ EulerGamma - 2\ Log[\(-s\)] - 
                        4\ PolyGamma[0, \(-z1\)] + 3\ PolyGamma[0, 1 + z1] - 
                        PolyGamma[0, 1 + z6])\) - 
                  12\ EulerGamma\ PolyGamma[0, 1 + z6] + 
                  12\ Log[\(-s\)]\ PolyGamma[0, 1 + z6] - 
                  18\ PolyGamma[0, 1 + z1]\ PolyGamma[0, 1 + z6] + 
                  3\ PolyGamma[0, 1 + z6]\^2 - 48\ PolyGamma[1, \(-2\)\ z1] + 
                  30\ PolyGamma[1, \(-z1\)] + 27\ PolyGamma[1, 1 + z1] + 
                  6\ PolyGamma[1, \(-z6\)] + 
                  3\ PolyGamma[1, 1 + z6])\))\)\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}], 
      MBint[\(-\(\(\((m\^2)\)\^\(z1 + z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - \
z6\)\ Gamma[\(-z1\)]\ Gamma[
                    1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                    z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                    z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                    1 + z6]\)\/\(4\ eps\ Gamma[\(-2\)\ z1]\ Gamma[
                    1 - z2]\ Gamma[
                    1 + z2]\ Gamma[\(-2\)\ z6]\)\)\) - \((\((m\^2)\)\^\(z1 + \
z6\)\ \((\(-s\))\)\^\(\(-2\) - z1 - z6\)\ Gamma[\(-z1\)]\ Gamma[
                  1 + z1]\ Gamma[\(-z1\) - z2]\ Gamma[\(-z2\)]\ Gamma[
                  z2]\ Gamma[\(-z1\) + z2]\ Gamma[\(-z2\) - z6]\ Gamma[
                  z2 - z6]\ Gamma[\(-z6\)]\ Gamma[
                  1 + z6]\ \((2\ EulerGamma - 2\ Log[\(-s\)] + 
                    4\ PolyGamma[0, \(-2\)\ z1] + 3\ PolyGamma[0, 1 + z1] - 
                    PolyGamma[0, \(-z1\) - z2] - 2\ PolyGamma[0, z2] + 
                    2\ PolyGamma[0, 1 + z2] - 3\ PolyGamma[0, \(-z1\) + z2] + 
                    PolyGamma[0, \(-z2\) - z6] - PolyGamma[0, z2 - z6] - 
                    PolyGamma[0, 1 + z6])\))\)/\((4\ Gamma[\(-2\)\ z1]\ Gamma[
                  1 - z2]\ Gamma[1 + z2]\ Gamma[\(-2\)\ z6])\), {{eps \[Rule] 
              0, eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/4\)\), 
            z2 \[Rule] \(-\(1\/8\)\), 
            z6 \[Rule] \(-\(19\/64\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[
      ser, {s \[Rule] \(-1\)/2, t \[Rule] \(-3\), m \[Rule] 1}]\)], "Input"],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 0 1-dimensional integrations", "Print"],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart1eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]4\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart1eps0", " (dim ", 4, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart2eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]4\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart2eps0", " (dim ", 4, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart3eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart3eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart4eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart4eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart5eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart5eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart6eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart6eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart7eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart7eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart8eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart8eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart9eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart9eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart10eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart10eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart11eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart11eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart12eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart12eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart13eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart13eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart14eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart14eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart15eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart15eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart16eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart16eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart17eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart17eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart18eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart18eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart19eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart19eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart20eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart20eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart21eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart21eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart22eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart22eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart23eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart23eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart24eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart24eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart25eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart25eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart26eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart26eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart27eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart27eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart28eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart28eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart29eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart29eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart30eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart30eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart31eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart31eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart32eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart32eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart33eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart33eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart34eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart34eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart35eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart35eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart36eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart36eps-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart37eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart37eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart38eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart38eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart39eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart39eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart40eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart40eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart41eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart41eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart42eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart42eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart43eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart43eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart44eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart44eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart45eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart45eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart46eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart46eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart47eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart47eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart48eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart48eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart49eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart49eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart50eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart50eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart51eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart51eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart52eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart52eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart1eps0"\),
      SequenceForm[ "Running ", "MBpart1eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart2eps0"\),
      SequenceForm[ "Running ", "MBpart2eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart3eps0"\),
      SequenceForm[ "Running ", "MBpart3eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart4eps0"\),
      SequenceForm[ "Running ", "MBpart4eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart5eps0"\),
      SequenceForm[ "Running ", "MBpart5eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart6eps0"\),
      SequenceForm[ "Running ", "MBpart6eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart7eps0"\),
      SequenceForm[ "Running ", "MBpart7eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart8eps0"\),
      SequenceForm[ "Running ", "MBpart8eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart9eps0"\),
      SequenceForm[ "Running ", "MBpart9eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart10eps0"\),
      SequenceForm[ "Running ", "MBpart10eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart11eps0"\),
      SequenceForm[ "Running ", "MBpart11eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart12eps0"\),
      SequenceForm[ "Running ", "MBpart12eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart13eps0"\),
      SequenceForm[ "Running ", "MBpart13eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart14eps0"\),
      SequenceForm[ "Running ", "MBpart14eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart15eps0"\),
      SequenceForm[ "Running ", "MBpart15eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart16eps0"\),
      SequenceForm[ "Running ", "MBpart16eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart17eps0"\),
      SequenceForm[ "Running ", "MBpart17eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart18eps0"\),
      SequenceForm[ "Running ", "MBpart18eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart19eps0"\),
      SequenceForm[ "Running ", "MBpart19eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart20eps0"\),
      SequenceForm[ "Running ", "MBpart20eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart21eps0"\),
      SequenceForm[ "Running ", "MBpart21eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart22eps0"\),
      SequenceForm[ "Running ", "MBpart22eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart23eps0"\),
      SequenceForm[ "Running ", "MBpart23eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart24eps0"\),
      SequenceForm[ "Running ", "MBpart24eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart25eps0"\),
      SequenceForm[ "Running ", "MBpart25eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart26eps0"\),
      SequenceForm[ "Running ", "MBpart26eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart27eps0"\),
      SequenceForm[ "Running ", "MBpart27eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart28eps0"\),
      SequenceForm[ "Running ", "MBpart28eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart29eps-1"\),
      SequenceForm[ "Running ", "MBpart29eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart30eps-1"\),
      SequenceForm[ "Running ", "MBpart30eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart31eps-1"\),
      SequenceForm[ "Running ", "MBpart31eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart32eps-1"\),
      SequenceForm[ "Running ", "MBpart32eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart33eps-1"\),
      SequenceForm[ "Running ", "MBpart33eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart34eps-1"\),
      SequenceForm[ "Running ", "MBpart34eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart35eps-1"\),
      SequenceForm[ "Running ", "MBpart35eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart36eps-1"\),
      SequenceForm[ "Running ", "MBpart36eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart37eps-1"\),
      SequenceForm[ "Running ", "MBpart37eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart38eps-1"\),
      SequenceForm[ "Running ", "MBpart38eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart39eps-1"\),
      SequenceForm[ "Running ", "MBpart39eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart40eps-1"\),
      SequenceForm[ "Running ", "MBpart40eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart41eps-1"\),
      SequenceForm[ "Running ", "MBpart41eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart42eps-1"\),
      SequenceForm[ "Running ", "MBpart42eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart43eps-1"\),
      SequenceForm[ "Running ", "MBpart43eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart44eps-1"\),
      SequenceForm[ "Running ", "MBpart44eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart45eps-2"\),
      SequenceForm[ "Running ", "MBpart45eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart46eps-2"\),
      SequenceForm[ "Running ", "MBpart46eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart47eps-2"\),
      SequenceForm[ "Running ", "MBpart47eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart48eps-2"\),
      SequenceForm[ "Running ", "MBpart48eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart49eps-2"\),
      SequenceForm[ "Running ", "MBpart49eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart50eps-2"\),
      SequenceForm[ "Running ", "MBpart50eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart51eps-2"\),
      SequenceForm[ "Running ", "MBpart51eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart52eps-2"\),
      SequenceForm[ "Running ", "MBpart52eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-3.9010397694000023`\) + 0.320302117`\/eps\^2 - 
        0.2667238854999998`\/eps, {\(\(0.004427752735772746`\)\(\
\[InvisibleSpace]\)\) + 0.000047883518295092014`\/eps\^2 + 
          0.00008750804213050676`\/eps, 0}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      sectors : \[IndentingNewLine]2\ part0[\([2]\)] + part2[\([2]\)] - 
            2\ part1[\([2]\)] // 
        Expand\[IndentingNewLine]\[IndentingNewLine]{{0.3203772836085565`\/ep\
\^2 - 0.26661944018488715`\/ep, \(-\(0.00030840055074709047`\/ep\^2\)\) - 
                0.0030136395958849436`\/ep, \(-\(0.001357853530901787`\/ep\^2\
\)\) + 0.07127306807466487`\/ep}}\[IndentingNewLine]*) \)\(\[IndentingNewLine]\
\)\)\)], "Input"],

Cell[BoxData[
    \( (*\ result\ from\ [12], \ expanded\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(B7l4m1Nms = \((\((ms^2*\((24*ep*\((\(-z3\) + 6*ep*z4)\) + 
                  29*ep^2*Log[ms]^4 + 
                  4*ep*Log[ms]^3*\((13 - 12*ep*Log[x])\) - 
                  12*Log[ms]^2*\((\(-3\) + 34*ep^2*z2 + 4*ep*Log[x])\) + 
                  16*ep*Log[
                      ms]*\((\(-3\)*z2 + 24*ep*z2*Log[x] + ep*Log[x]^3 - 
                        3*ep*\((6*z2 + Log[x]^2)\)*Log[1 + x])\) + 
                  24*ep^2*
                    Log[ms]*\((7*z3 - 4*Log[x]*PolyLog[2, \(-x\)] + 
                        4*PolyLog[3, \(-x\)])\))\))\)/\((24*
              ep^2)\))\)\)], "Input"],

Cell[BoxData[
    \(\(1\/\(24\ ep\^2\)\) \((ms\^2\ \((24\ ep\ \((\(-z3\) + 6\ ep\ z4)\) + 
              29\ ep\^2\ Log[ms]\^4 + 
              4\ ep\ Log[ms]\^3\ \((13 - 12\ ep\ Log[x])\) - 
              12\ Log[ms]\^2\ \((\(-3\) + 34\ ep\^2\ z2 + 4\ ep\ Log[x])\) + 
              16\ ep\ Log[
                  ms]\ \((\(-3\)\ z2 + 24\ ep\ z2\ Log[x] + ep\ Log[x]\^3 - 
                    3\ ep\ \((6\ z2 + Log[x]\^2)\)\ Log[1 + x])\) + 
              24\ ep\^2\ Log[
                  ms]\ \((7\ z3 - 4\ Log[x]\ PolyLog[2, \(-x\)] + 
                    4\ PolyLog[3, \(-x\)])\))\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\(\(\(\(\(\(% /. z2 \[Rule] Zeta[2]\) /. z3 \[Rule] Zeta[3]\) /. 
                  z4 \[Rule] Zeta[4]\) /. ms \[Rule] \(-1\)/s\) /. 
              x \[Rule] t/s\) /. s \[Rule] \(-100\)\) /. t \[Rule] \(-3\)] // 
      Expand\)], "Input"],

Cell[BoxData[
    \(\(-0.020088587942813804`\) + 0.0031811388662870395`\/ep\^2 - 
      0.004892692633587863`\/ep\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[
      ser, {s \[Rule] \(-100\), t \[Rule] \(-3\), m \[Rule] 1}]\)], "Input"],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 0 1-dimensional integrations", "Print"],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart1ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]4\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart1ep0", " (dim ", 4, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart2ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]4\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart2ep0", " (dim ", 4, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart3ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart3ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart4ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart4ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart5ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart5ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart6ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart6ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart7ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart7ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart8ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart8ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart9ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart9ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart10ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart10ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart11ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart11ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart12ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart12ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart13ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart13ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart14ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart14ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart15ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart15ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart16ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart16ep0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart17ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart17ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart18ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart18ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart19ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart19ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart20ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart20ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart21ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart21ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart22ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart22ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart23ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart23ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart24ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart24ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart25ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart25ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart26ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart26ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart27ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart27ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart28ep0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart28ep0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart29ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart29ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart30ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart30ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart31ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart31ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart32ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart32ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart33ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart33ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart34ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart34ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart35ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart35ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart36ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart36ep-1", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart37ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart37ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart38ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart38ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart39ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart39ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart40ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart40ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart41ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart41ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart42ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart42ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart43ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart43ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart44ep-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart44ep-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart45ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart45ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart46ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart46ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart47ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart47ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart48ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart48ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart49ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart49ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart50ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart50ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart51ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart51ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart52ep-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart52ep-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart1ep0"\),
      SequenceForm[ "Running ", "MBpart1ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart2ep0"\),
      SequenceForm[ "Running ", "MBpart2ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart3ep0"\),
      SequenceForm[ "Running ", "MBpart3ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart4ep0"\),
      SequenceForm[ "Running ", "MBpart4ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart5ep0"\),
      SequenceForm[ "Running ", "MBpart5ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart6ep0"\),
      SequenceForm[ "Running ", "MBpart6ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart7ep0"\),
      SequenceForm[ "Running ", "MBpart7ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart8ep0"\),
      SequenceForm[ "Running ", "MBpart8ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart9ep0"\),
      SequenceForm[ "Running ", "MBpart9ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart10ep0"\),
      SequenceForm[ "Running ", "MBpart10ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart11ep0"\),
      SequenceForm[ "Running ", "MBpart11ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart12ep0"\),
      SequenceForm[ "Running ", "MBpart12ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart13ep0"\),
      SequenceForm[ "Running ", "MBpart13ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart14ep0"\),
      SequenceForm[ "Running ", "MBpart14ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart15ep0"\),
      SequenceForm[ "Running ", "MBpart15ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart16ep0"\),
      SequenceForm[ "Running ", "MBpart16ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart17ep0"\),
      SequenceForm[ "Running ", "MBpart17ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart18ep0"\),
      SequenceForm[ "Running ", "MBpart18ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart19ep0"\),
      SequenceForm[ "Running ", "MBpart19ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart20ep0"\),
      SequenceForm[ "Running ", "MBpart20ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart21ep0"\),
      SequenceForm[ "Running ", "MBpart21ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart22ep0"\),
      SequenceForm[ "Running ", "MBpart22ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart23ep0"\),
      SequenceForm[ "Running ", "MBpart23ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart24ep0"\),
      SequenceForm[ "Running ", "MBpart24ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart25ep0"\),
      SequenceForm[ "Running ", "MBpart25ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart26ep0"\),
      SequenceForm[ "Running ", "MBpart26ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart27ep0"\),
      SequenceForm[ "Running ", "MBpart27ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart28ep0"\),
      SequenceForm[ "Running ", "MBpart28ep0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart29ep-1"\),
      SequenceForm[ "Running ", "MBpart29ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart30ep-1"\),
      SequenceForm[ "Running ", "MBpart30ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart31ep-1"\),
      SequenceForm[ "Running ", "MBpart31ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart32ep-1"\),
      SequenceForm[ "Running ", "MBpart32ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart33ep-1"\),
      SequenceForm[ "Running ", "MBpart33ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart34ep-1"\),
      SequenceForm[ "Running ", "MBpart34ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart35ep-1"\),
      SequenceForm[ "Running ", "MBpart35ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart36ep-1"\),
      SequenceForm[ "Running ", "MBpart36ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart37ep-1"\),
      SequenceForm[ "Running ", "MBpart37ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart38ep-1"\),
      SequenceForm[ "Running ", "MBpart38ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart39ep-1"\),
      SequenceForm[ "Running ", "MBpart39ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart40ep-1"\),
      SequenceForm[ "Running ", "MBpart40ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart41ep-1"\),
      SequenceForm[ "Running ", "MBpart41ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart42ep-1"\),
      SequenceForm[ "Running ", "MBpart42ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart43ep-1"\),
      SequenceForm[ "Running ", "MBpart43ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart44ep-1"\),
      SequenceForm[ "Running ", "MBpart44ep-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart45ep-2"\),
      SequenceForm[ "Running ", "MBpart45ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart46ep-2"\),
      SequenceForm[ "Running ", "MBpart46ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart47ep-2"\),
      SequenceForm[ "Running ", "MBpart47ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart48ep-2"\),
      SequenceForm[ "Running ", "MBpart48ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart49ep-2"\),
      SequenceForm[ "Running ", "MBpart49ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart50ep-2"\),
      SequenceForm[ "Running ", "MBpart50ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart51ep-2"\),
      SequenceForm[ "Running ", "MBpart51ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart52ep-2"\),
      SequenceForm[ "Running ", "MBpart52ep-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-0.024657977598000015`\) + 0.0030850238199999994`\/ep\^2 - 
        0.004805724930000002`\/ep, {\(\(0.000011991651159980758`\)\(\
\[InvisibleSpace]\)\) + 4.660425957592778`*^-7\/ep\^2 + 
          2.0602063528768976`*^-6\/ep, 0}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
WindowSize->{1014, 714},
WindowMargins->{{0, Automatic}, {0, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "gluza", \
"papers", "MBRbuilder", "examples"}, "warsawIteration.ps", CharacterEncoding \
-> "iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 1, 27, "Input"],
Cell[1819, 56, 41, 1, 23, "Print"],
Cell[1863, 59, 51, 1, 23, "Print"],
Cell[1917, 62, 62, 1, 23, "Print"],
Cell[1982, 65, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2077, 71, 43, 1, 27, "Input"],
Cell[2123, 74, 56, 1, 23, "Print"],
Cell[2182, 77, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2257, 81, 213, 4, 75, "Input"],
Cell[2473, 87, 363, 6, 75, "Input"],
Cell[2839, 95, 377, 6, 43, "Input"],

Cell[CellGroupData[{
Cell[3241, 105, 43, 1, 27, "Input"],
Cell[3287, 108, 143, 3, 23, "Print"],
Cell[3433, 113, 491, 14, 23, "Print"],
Cell[3927, 129, 143, 3, 23, "Print"],
Cell[4073, 134, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4284, 142, 50, 1, 27, "Input"],
Cell[4337, 145, 264, 4, 23, "Print"],
Cell[4604, 151, 257, 5, 23, "Print"],
Cell[4864, 158, 50, 1, 23, "Print"],
Cell[4917, 161, 58, 1, 23, "Print"],
Cell[4978, 164, 50, 1, 23, "Print"],
Cell[5031, 167, 184, 3, 25, "Print"],
Cell[5218, 172, 215, 4, 23, "Print"],
Cell[5436, 178, 1248, 25, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6721, 208, 43, 1, 27, "Input"],
Cell[6767, 211, 143, 3, 23, "Print"],
Cell[6913, 216, 739, 21, 23, "Print"],
Cell[7655, 239, 143, 3, 23, "Print"],
Cell[7801, 244, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8012, 252, 62, 1, 27, "Input"],
Cell[8077, 255, 264, 4, 23, "Print"],
Cell[8344, 261, 257, 5, 23, "Print"],
Cell[8604, 268, 50, 1, 23, "Print"],
Cell[8657, 271, 58, 1, 23, "Print"],
Cell[8718, 274, 50, 1, 23, "Print"],
Cell[8771, 277, 89, 1, 25, "Print"],
Cell[8863, 280, 56, 1, 23, "Print"],
Cell[8922, 283, 1663, 26, 146, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10622, 314, 60, 1, 27, "Input"],
Cell[10685, 317, 273, 5, 23, "Print"],
Cell[10961, 324, 226, 4, 23, "Print"],
Cell[11190, 330, 141, 6, 83, "Print"],
Cell[11334, 338, 80, 1, 23, "Print"],
Cell[11417, 341, 466, 12, 23, "Print"],
Cell[11886, 355, 197, 4, 23, "Print"],
Cell[12086, 361, 1462, 23, 150, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13585, 389, 206, 4, 27, "Input"],
Cell[13794, 395, 942, 13, 118, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14773, 413, 80, 1, 27, "Input"],
Cell[14856, 416, 128, 2, 20, "Message"],
Cell[14987, 420, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15060, 426, 212, 4, 27, "Input"],
Cell[15275, 432, 1014, 14, 118, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16326, 451, 131, 3, 27, "Input"],
Cell[16460, 456, 128, 2, 20, "Message"],
Cell[16591, 460, 307, 5, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16935, 470, 87, 1, 27, "Input"],
Cell[17025, 473, 42, 1, 23, "Print"],
Cell[17070, 476, 444, 11, 23, "Print"],
Cell[17517, 489, 135, 3, 23, "Print"],
Cell[17655, 494, 145, 3, 23, "Print"],
Cell[17803, 499, 159, 3, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17999, 507, 76, 1, 27, "Input"],
Cell[18078, 510, 358, 5, 20, "Message"],
Cell[18439, 517, 2435, 35, 254, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20911, 557, 156, 3, 27, "Input"],
Cell[21070, 562, 365, 5, 20, "Message"],
Cell[21438, 569, 42, 1, 23, "Print"],
Cell[21483, 572, 439, 11, 23, "Print"],
Cell[21925, 585, 355, 8, 23, "Print"],
Cell[22283, 595, 419, 10, 23, "Print"],
Cell[22705, 607, 422, 10, 23, "Print"],
Cell[23130, 619, 422, 10, 23, "Print"],
Cell[23555, 631, 135, 3, 23, "Print"],
Cell[23693, 636, 145, 3, 23, "Print"],
Cell[23841, 641, 393, 9, 23, "Print"],
Cell[24237, 652, 358, 8, 23, "Print"],
Cell[24598, 662, 422, 10, 23, "Print"],
Cell[25023, 674, 145, 3, 23, "Print"],
Cell[25171, 679, 344, 8, 23, "Print"],
Cell[25518, 689, 145, 3, 23, "Print"],
Cell[25666, 694, 344, 8, 23, "Print"],
Cell[26013, 704, 145, 3, 23, "Print"],
Cell[26161, 709, 145, 3, 23, "Print"],
Cell[26309, 714, 135, 3, 23, "Print"],
Cell[26447, 719, 151, 3, 23, "Print"],
Cell[26601, 724, 321, 7, 23, "Print"],
Cell[26925, 733, 151, 3, 23, "Print"],
Cell[27079, 738, 294, 6, 23, "Print"],
Cell[27376, 746, 151, 3, 23, "Print"],
Cell[27530, 751, 393, 9, 23, "Print"],
Cell[27926, 762, 151, 3, 23, "Print"],
Cell[28080, 767, 294, 6, 23, "Print"],
Cell[28377, 775, 151, 3, 23, "Print"],
Cell[28531, 780, 294, 6, 23, "Print"],
Cell[28828, 788, 135, 3, 23, "Print"],
Cell[28966, 793, 157, 3, 23, "Print"],
Cell[29126, 798, 157, 3, 23, "Print"],
Cell[29286, 803, 157, 3, 23, "Print"],
Cell[29446, 808, 157, 3, 23, "Print"],
Cell[29606, 813, 157, 3, 23, "Print"],
Cell[29766, 818, 161, 3, 23, "Print"],
Cell[29930, 823, 42, 1, 23, "Print"],
Cell[29975, 826, 355, 8, 23, "Print"],
Cell[30333, 836, 419, 10, 23, "Print"],
Cell[30755, 848, 53, 1, 23, "Print"],
Cell[30811, 851, 373, 8, 23, "Print"],
Cell[31187, 861, 422, 10, 23, "Print"],
Cell[31612, 873, 135, 3, 23, "Print"],
Cell[31750, 878, 145, 3, 23, "Print"],
Cell[31898, 883, 344, 8, 23, "Print"],
Cell[32245, 893, 373, 8, 23, "Print"],
Cell[32621, 903, 355, 8, 23, "Print"],
Cell[32979, 913, 145, 3, 23, "Print"],
Cell[33127, 918, 344, 8, 23, "Print"],
Cell[33474, 928, 419, 10, 23, "Print"],
Cell[33896, 940, 145, 3, 23, "Print"],
Cell[34044, 945, 439, 11, 23, "Print"],
Cell[34486, 958, 419, 10, 23, "Print"],
Cell[34908, 970, 422, 10, 23, "Print"],
Cell[35333, 982, 422, 10, 23, "Print"],
Cell[35758, 994, 135, 3, 23, "Print"],
Cell[35896, 999, 151, 3, 23, "Print"],
Cell[36050, 1004, 294, 6, 23, "Print"],
Cell[36347, 1012, 355, 8, 23, "Print"],
Cell[36705, 1022, 151, 3, 23, "Print"],
Cell[36859, 1027, 344, 8, 23, "Print"],
Cell[37206, 1037, 151, 3, 23, "Print"],
Cell[37360, 1042, 151, 3, 23, "Print"],
Cell[37514, 1047, 294, 6, 23, "Print"],
Cell[37811, 1055, 151, 3, 23, "Print"],
Cell[37965, 1060, 344, 8, 23, "Print"],
Cell[38312, 1070, 151, 3, 23, "Print"],
Cell[38466, 1075, 393, 9, 23, "Print"],
Cell[38862, 1086, 358, 8, 23, "Print"],
Cell[39223, 1096, 422, 10, 23, "Print"],
Cell[39648, 1108, 151, 3, 23, "Print"],
Cell[39802, 1113, 344, 8, 23, "Print"],
Cell[40149, 1123, 151, 3, 23, "Print"],
Cell[40303, 1128, 151, 3, 23, "Print"],
Cell[40457, 1133, 135, 3, 23, "Print"],
Cell[40595, 1138, 157, 3, 23, "Print"],
Cell[40755, 1143, 355, 8, 23, "Print"],
Cell[41113, 1153, 157, 3, 23, "Print"],
Cell[41273, 1158, 157, 3, 23, "Print"],
Cell[41433, 1163, 294, 6, 23, "Print"],
Cell[41730, 1171, 157, 3, 23, "Print"],
Cell[41890, 1176, 157, 3, 23, "Print"],
Cell[42050, 1181, 294, 6, 23, "Print"],
Cell[42347, 1189, 157, 3, 23, "Print"],
Cell[42507, 1194, 321, 7, 23, "Print"],
Cell[42831, 1203, 157, 3, 23, "Print"],
Cell[42991, 1208, 294, 6, 23, "Print"],
Cell[43288, 1216, 157, 3, 23, "Print"],
Cell[43448, 1221, 393, 9, 23, "Print"],
Cell[43844, 1232, 157, 3, 23, "Print"],
Cell[44004, 1237, 294, 6, 23, "Print"],
Cell[44301, 1245, 135, 3, 23, "Print"],
Cell[44439, 1250, 163, 3, 23, "Print"],
Cell[44605, 1255, 163, 3, 23, "Print"],
Cell[44771, 1260, 163, 3, 23, "Print"],
Cell[44937, 1265, 163, 3, 23, "Print"],
Cell[45103, 1270, 163, 3, 23, "Print"],
Cell[45269, 1275, 163, 3, 23, "Print"],
Cell[45435, 1280, 163, 3, 23, "Print"],
Cell[45601, 1285, 161, 3, 23, "Print"],
Cell[45765, 1290, 54848, 855, 5066, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[100650, 2150, 103, 2, 24, "Input"],
Cell[100756, 2154, 34952, 546, 4445, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135745, 2705, 109, 2, 27, "Input"],
Cell[135857, 2709, 55, 1, 23, "Print"],
Cell[135915, 2712, 56, 0, 23, "Print"],
Cell[135974, 2714, 63, 1, 23, "Print"],
Cell[136040, 2717, 250, 4, 23, "Print"],
Cell[136293, 2723, 250, 4, 23, "Print"],
Cell[136546, 2729, 250, 4, 23, "Print"],
Cell[136799, 2735, 250, 4, 23, "Print"],
Cell[137052, 2741, 250, 4, 23, "Print"],
Cell[137305, 2747, 250, 4, 23, "Print"],
Cell[137558, 2753, 250, 4, 23, "Print"],
Cell[137811, 2759, 250, 4, 23, "Print"],
Cell[138064, 2765, 250, 4, 23, "Print"],
Cell[138317, 2771, 252, 4, 23, "Print"],
Cell[138572, 2777, 252, 4, 23, "Print"],
Cell[138827, 2783, 252, 4, 23, "Print"],
Cell[139082, 2789, 252, 4, 23, "Print"],
Cell[139337, 2795, 252, 4, 23, "Print"],
Cell[139592, 2801, 252, 4, 23, "Print"],
Cell[139847, 2807, 252, 4, 23, "Print"],
Cell[140102, 2813, 252, 4, 23, "Print"],
Cell[140357, 2819, 252, 4, 23, "Print"],
Cell[140612, 2825, 252, 4, 23, "Print"],
Cell[140867, 2831, 252, 4, 23, "Print"],
Cell[141122, 2837, 252, 4, 23, "Print"],
Cell[141377, 2843, 252, 4, 23, "Print"],
Cell[141632, 2849, 252, 4, 23, "Print"],
Cell[141887, 2855, 252, 4, 23, "Print"],
Cell[142142, 2861, 252, 4, 23, "Print"],
Cell[142397, 2867, 252, 4, 23, "Print"],
Cell[142652, 2873, 252, 4, 23, "Print"],
Cell[142907, 2879, 252, 4, 23, "Print"],
Cell[143162, 2885, 254, 4, 23, "Print"],
Cell[143419, 2891, 254, 4, 23, "Print"],
Cell[143676, 2897, 254, 4, 23, "Print"],
Cell[143933, 2903, 254, 4, 23, "Print"],
Cell[144190, 2909, 254, 4, 23, "Print"],
Cell[144447, 2915, 254, 4, 23, "Print"],
Cell[144704, 2921, 254, 4, 23, "Print"],
Cell[144961, 2927, 254, 4, 23, "Print"],
Cell[145218, 2933, 254, 4, 23, "Print"],
Cell[145475, 2939, 254, 4, 23, "Print"],
Cell[145732, 2945, 254, 4, 23, "Print"],
Cell[145989, 2951, 254, 4, 23, "Print"],
Cell[146246, 2957, 254, 4, 23, "Print"],
Cell[146503, 2963, 254, 4, 23, "Print"],
Cell[146760, 2969, 254, 4, 23, "Print"],
Cell[147017, 2975, 254, 4, 23, "Print"],
Cell[147274, 2981, 254, 4, 23, "Print"],
Cell[147531, 2987, 254, 4, 23, "Print"],
Cell[147788, 2993, 254, 4, 23, "Print"],
Cell[148045, 2999, 254, 4, 23, "Print"],
Cell[148302, 3005, 254, 4, 23, "Print"],
Cell[148559, 3011, 254, 4, 23, "Print"],
Cell[148816, 3017, 254, 4, 23, "Print"],
Cell[149073, 3023, 254, 4, 23, "Print"],
Cell[149330, 3029, 163, 3, 23, "Print"],
Cell[149496, 3034, 163, 3, 23, "Print"],
Cell[149662, 3039, 163, 3, 23, "Print"],
Cell[149828, 3044, 163, 3, 23, "Print"],
Cell[149994, 3049, 163, 3, 23, "Print"],
Cell[150160, 3054, 163, 3, 23, "Print"],
Cell[150326, 3059, 163, 3, 23, "Print"],
Cell[150492, 3064, 163, 3, 23, "Print"],
Cell[150658, 3069, 163, 3, 23, "Print"],
Cell[150824, 3074, 165, 3, 23, "Print"],
Cell[150992, 3079, 165, 3, 23, "Print"],
Cell[151160, 3084, 165, 3, 23, "Print"],
Cell[151328, 3089, 165, 3, 23, "Print"],
Cell[151496, 3094, 165, 3, 23, "Print"],
Cell[151664, 3099, 165, 3, 23, "Print"],
Cell[151832, 3104, 165, 3, 23, "Print"],
Cell[152000, 3109, 165, 3, 23, "Print"],
Cell[152168, 3114, 165, 3, 23, "Print"],
Cell[152336, 3119, 165, 3, 23, "Print"],
Cell[152504, 3124, 165, 3, 23, "Print"],
Cell[152672, 3129, 165, 3, 23, "Print"],
Cell[152840, 3134, 165, 3, 23, "Print"],
Cell[153008, 3139, 165, 3, 23, "Print"],
Cell[153176, 3144, 165, 3, 23, "Print"],
Cell[153344, 3149, 165, 3, 23, "Print"],
Cell[153512, 3154, 165, 3, 23, "Print"],
Cell[153680, 3159, 165, 3, 23, "Print"],
Cell[153848, 3164, 165, 3, 23, "Print"],
Cell[154016, 3169, 167, 3, 23, "Print"],
Cell[154186, 3174, 167, 3, 23, "Print"],
Cell[154356, 3179, 167, 3, 23, "Print"],
Cell[154526, 3184, 167, 3, 23, "Print"],
Cell[154696, 3189, 167, 3, 23, "Print"],
Cell[154866, 3194, 167, 3, 23, "Print"],
Cell[155036, 3199, 167, 3, 23, "Print"],
Cell[155206, 3204, 167, 3, 23, "Print"],
Cell[155376, 3209, 167, 3, 23, "Print"],
Cell[155546, 3214, 167, 3, 23, "Print"],
Cell[155716, 3219, 167, 3, 23, "Print"],
Cell[155886, 3224, 167, 3, 23, "Print"],
Cell[156056, 3229, 167, 3, 23, "Print"],
Cell[156226, 3234, 167, 3, 23, "Print"],
Cell[156396, 3239, 167, 3, 23, "Print"],
Cell[156566, 3244, 167, 3, 23, "Print"],
Cell[156736, 3249, 167, 3, 23, "Print"],
Cell[156906, 3254, 167, 3, 23, "Print"],
Cell[157076, 3259, 167, 3, 23, "Print"],
Cell[157246, 3264, 167, 3, 23, "Print"],
Cell[157416, 3269, 167, 3, 23, "Print"],
Cell[157586, 3274, 167, 3, 23, "Print"],
Cell[157756, 3279, 167, 3, 23, "Print"],
Cell[157926, 3284, 167, 3, 23, "Print"],
Cell[158096, 3289, 255, 4, 47, "Output"]
}, Open  ]],
Cell[158366, 3296, 467, 8, 139, "Input"],
Cell[158836, 3306, 73, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[158934, 3311, 617, 11, 91, "Input"],
Cell[159554, 3324, 604, 10, 85, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160195, 3339, 260, 4, 27, "Input"],
Cell[160458, 3345, 127, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160622, 3352, 109, 2, 27, "Input"],
Cell[160734, 3356, 55, 1, 23, "Print"],
Cell[160792, 3359, 56, 0, 23, "Print"],
Cell[160851, 3361, 63, 1, 23, "Print"],
Cell[160917, 3364, 248, 4, 23, "Print"],
Cell[161168, 3370, 248, 4, 23, "Print"],
Cell[161419, 3376, 248, 4, 23, "Print"],
Cell[161670, 3382, 248, 4, 23, "Print"],
Cell[161921, 3388, 248, 4, 23, "Print"],
Cell[162172, 3394, 248, 4, 23, "Print"],
Cell[162423, 3400, 248, 4, 23, "Print"],
Cell[162674, 3406, 248, 4, 23, "Print"],
Cell[162925, 3412, 248, 4, 23, "Print"],
Cell[163176, 3418, 250, 4, 23, "Print"],
Cell[163429, 3424, 250, 4, 23, "Print"],
Cell[163682, 3430, 250, 4, 23, "Print"],
Cell[163935, 3436, 250, 4, 23, "Print"],
Cell[164188, 3442, 250, 4, 23, "Print"],
Cell[164441, 3448, 250, 4, 23, "Print"],
Cell[164694, 3454, 250, 4, 23, "Print"],
Cell[164947, 3460, 250, 4, 23, "Print"],
Cell[165200, 3466, 250, 4, 23, "Print"],
Cell[165453, 3472, 250, 4, 23, "Print"],
Cell[165706, 3478, 250, 4, 23, "Print"],
Cell[165959, 3484, 250, 4, 23, "Print"],
Cell[166212, 3490, 250, 4, 23, "Print"],
Cell[166465, 3496, 250, 4, 23, "Print"],
Cell[166718, 3502, 250, 4, 23, "Print"],
Cell[166971, 3508, 250, 4, 23, "Print"],
Cell[167224, 3514, 250, 4, 23, "Print"],
Cell[167477, 3520, 250, 4, 23, "Print"],
Cell[167730, 3526, 250, 4, 23, "Print"],
Cell[167983, 3532, 252, 4, 23, "Print"],
Cell[168238, 3538, 252, 4, 23, "Print"],
Cell[168493, 3544, 252, 4, 23, "Print"],
Cell[168748, 3550, 252, 4, 23, "Print"],
Cell[169003, 3556, 252, 4, 23, "Print"],
Cell[169258, 3562, 252, 4, 23, "Print"],
Cell[169513, 3568, 252, 4, 23, "Print"],
Cell[169768, 3574, 252, 4, 23, "Print"],
Cell[170023, 3580, 252, 4, 23, "Print"],
Cell[170278, 3586, 252, 4, 23, "Print"],
Cell[170533, 3592, 252, 4, 23, "Print"],
Cell[170788, 3598, 252, 4, 23, "Print"],
Cell[171043, 3604, 252, 4, 23, "Print"],
Cell[171298, 3610, 252, 4, 23, "Print"],
Cell[171553, 3616, 252, 4, 23, "Print"],
Cell[171808, 3622, 252, 4, 23, "Print"],
Cell[172063, 3628, 252, 4, 23, "Print"],
Cell[172318, 3634, 252, 4, 23, "Print"],
Cell[172573, 3640, 252, 4, 23, "Print"],
Cell[172828, 3646, 252, 4, 23, "Print"],
Cell[173083, 3652, 252, 4, 23, "Print"],
Cell[173338, 3658, 252, 4, 23, "Print"],
Cell[173593, 3664, 252, 4, 23, "Print"],
Cell[173848, 3670, 252, 4, 23, "Print"],
Cell[174103, 3676, 161, 3, 23, "Print"],
Cell[174267, 3681, 161, 3, 23, "Print"],
Cell[174431, 3686, 161, 3, 23, "Print"],
Cell[174595, 3691, 161, 3, 23, "Print"],
Cell[174759, 3696, 161, 3, 23, "Print"],
Cell[174923, 3701, 161, 3, 23, "Print"],
Cell[175087, 3706, 161, 3, 23, "Print"],
Cell[175251, 3711, 161, 3, 23, "Print"],
Cell[175415, 3716, 161, 3, 23, "Print"],
Cell[175579, 3721, 163, 3, 23, "Print"],
Cell[175745, 3726, 163, 3, 23, "Print"],
Cell[175911, 3731, 163, 3, 23, "Print"],
Cell[176077, 3736, 163, 3, 23, "Print"],
Cell[176243, 3741, 163, 3, 23, "Print"],
Cell[176409, 3746, 163, 3, 23, "Print"],
Cell[176575, 3751, 163, 3, 23, "Print"],
Cell[176741, 3756, 163, 3, 23, "Print"],
Cell[176907, 3761, 163, 3, 23, "Print"],
Cell[177073, 3766, 163, 3, 23, "Print"],
Cell[177239, 3771, 163, 3, 23, "Print"],
Cell[177405, 3776, 163, 3, 23, "Print"],
Cell[177571, 3781, 163, 3, 23, "Print"],
Cell[177737, 3786, 163, 3, 23, "Print"],
Cell[177903, 3791, 163, 3, 23, "Print"],
Cell[178069, 3796, 163, 3, 23, "Print"],
Cell[178235, 3801, 163, 3, 23, "Print"],
Cell[178401, 3806, 163, 3, 23, "Print"],
Cell[178567, 3811, 163, 3, 23, "Print"],
Cell[178733, 3816, 165, 3, 23, "Print"],
Cell[178901, 3821, 165, 3, 23, "Print"],
Cell[179069, 3826, 165, 3, 23, "Print"],
Cell[179237, 3831, 165, 3, 23, "Print"],
Cell[179405, 3836, 165, 3, 23, "Print"],
Cell[179573, 3841, 165, 3, 23, "Print"],
Cell[179741, 3846, 165, 3, 23, "Print"],
Cell[179909, 3851, 165, 3, 23, "Print"],
Cell[180077, 3856, 165, 3, 23, "Print"],
Cell[180245, 3861, 165, 3, 23, "Print"],
Cell[180413, 3866, 165, 3, 23, "Print"],
Cell[180581, 3871, 165, 3, 23, "Print"],
Cell[180749, 3876, 165, 3, 23, "Print"],
Cell[180917, 3881, 165, 3, 23, "Print"],
Cell[181085, 3886, 165, 3, 23, "Print"],
Cell[181253, 3891, 165, 3, 23, "Print"],
Cell[181421, 3896, 165, 3, 23, "Print"],
Cell[181589, 3901, 165, 3, 23, "Print"],
Cell[181757, 3906, 165, 3, 23, "Print"],
Cell[181925, 3911, 165, 3, 23, "Print"],
Cell[182093, 3916, 165, 3, 23, "Print"],
Cell[182261, 3921, 165, 3, 23, "Print"],
Cell[182429, 3926, 165, 3, 23, "Print"],
Cell[182597, 3931, 165, 3, 23, "Print"],
Cell[182765, 3936, 266, 4, 49, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

