(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25076,        804]*)
(*NotebookOutlinePosition[     25706,        826]*)
(*  CellTagsIndexPosition[     25662,        822]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input"],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 21 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(int1 = 
        Fullintegral[{1}, {PR[k1, m1, n1]\ PR[k1 + p1, m2, n2]\ PR[k1 - p2, 
                m3, n3]}, {k1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(invariants = {p1^2 \[Rule] M1^2, p2^2 \[Rule] M2^2, 
        p1*p2 \[Rule] 1/2\ s - \ 1/2\ M1^2 - 1/2\ M2^2}\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] M1\^2, p2\^2 \[Rule] M2\^2, 
      p1\ p2 \[Rule] \(-\(M1\^2\/2\)\) - M2\^2\/2 + s\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m1, n1]\ PR[
            k1 + p1, m2, n2]\ PR[k1 - p2, m3, n3]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m1, n1], 
          PR[ 
            Plus[ k1, p1], m2, n2], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p2]], m3, n3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m1\^2\ X[1]\^2 + m1\^2\ X[1]\ X[2] - M1\^2\ X[1]\ X[2] + 
      m2\^2\ X[1]\ X[2] + m2\^2\ X[2]\^2 + m1\^2\ X[1]\ X[3] - 
      M2\^2\ X[1]\ X[3] + m3\^2\ X[1]\ X[3] + m2\^2\ X[2]\ X[3] + 
      m3\^2\ X[2]\ X[3] - s\ X[2]\ X[3] + m3\^2\ X[3]\^2\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3\)\ \((m1\^2)\)\^\(z1 + z2 + \
z6\)\ \((\(-M1\^2\))\)\^z3\ \((m2\^2)\)\^\(z4 + z5 + z9\)\ \
\((\(-M2\^2\))\)\^z7\ \((m3\^2)\)\^\(2 - eps - n1 - n2 - n3 - z1 - z11 - z2 - \
z3 - z4 - z5 - z6 - z7 - z9\)\ \((\(-s\))\)\^z11\ Gamma[\(-z1\)]\ \
Gamma[\(-z10\)]\ Gamma[\(-z11\)]\ Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-z4\
\)]\ Gamma[\(-z5\)]\ Gamma[\(-z6\)]\ Gamma[\(-z7\)]\ Gamma[\(-z8\)]\ Gamma[
                n1 + 2\ z1 + z2 + z3 + z4 + z6 + z7 + z8]\ Gamma[
                4 - 2\ eps - 2\ n1 - 2\ n2 - n3 - 2\ z1 - z10 - z11 - 2\ z2 - 
                  2\ z3 - 2\ z4 - 2\ z5 - z6 - z7 - z8 - 
                  z9]\ Gamma[\(-z9\)]\ Gamma[
                n2 + z10 + z11 + z2 + z3 + z4 + 2\ z5 + z9]\ Gamma[\(-2\) + 
                  eps + n1 + n2 + n3 + z1 + z10 + z11 + z2 + z3 + z4 + z5 + 
                  z6 + z7 + z8 + z9])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fauto[0]\)], "Input"],

Cell[BoxData[
    \(Fmanual::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in MANUAL mode. Now you can \
modify F polynomial (fupc)."\)], "Message"],

Cell[BoxData[
    \("fupc=FUpolyfun[integral,momentum,invariants]"\)], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("fupc="\[InvisibleSpace]\(m1\^2\ X[1]\^2 + 
          m1\^2\ X[1]\ X[2] - M1\^2\ X[1]\ X[2] + m2\^2\ X[1]\ X[2] - 
          M1\^2\ X[2]\^2 + m2\^2\ X[2]\^2 + m1\^2\ X[1]\ X[3] - 
          M2\^2\ X[1]\ X[3] + m3\^2\ X[1]\ X[3] - M1\^2\ X[2]\ X[3] + 
          m2\^2\ X[2]\ X[3] - M2\^2\ X[2]\ X[3] + m3\^2\ X[2]\ X[3] - 
          M2\^2\ X[3]\^2 + 
          m3\^2\ X[3]\^2 + \(M1\^2\ X[1]\ X[2]\^2\)\/\(X[1] + X[2] + X[3]\) + \
\(M1\^2\ X[2]\^3\)\/\(X[1] + X[2] + X[3]\) + \(M1\^2\ X[1]\ X[2]\ \
X[3]\)\/\(X[1] + X[2] + X[3]\) + \(M2\^2\ X[1]\ X[2]\ X[3]\)\/\(X[1] + X[2] + \
X[3]\) - \(s\ X[1]\ X[2]\ X[3]\)\/\(X[1] + X[2] + X[3]\) + \(2\ M1\^2\ \
X[2]\^2\ X[3]\)\/\(X[1] + X[2] + X[3]\) + \(M2\^2\ X[2]\^2\ X[3]\)\/\(X[1] + \
X[2] + X[3]\) - \(s\ X[2]\^2\ X[3]\)\/\(X[1] + X[2] + X[3]\) + \(M2\^2\ X[1]\ \
X[3]\^2\)\/\(X[1] + X[2] + X[3]\) + \(M1\^2\ X[2]\ X[3]\^2\)\/\(X[1] + X[2] + \
X[3]\) + \(2\ M2\^2\ X[2]\ X[3]\^2\)\/\(X[1] + X[2] + X[3]\) - \(s\ X[2]\ \
X[3]\^2\)\/\(X[1] + X[2] + X[3]\) + \(M2\^2\ X[3]\^3\)\/\(X[1] + X[2] + \
X[3]\)\)\),
      SequenceForm[ "fupc=", 
        Plus[ 
          Times[ 
            Power[ m1, 2], 
            Power[ 
              X[ 1], 2]], 
          Times[ 
            Power[ m1, 2], 
            X[ 1], 
            X[ 2]], 
          Times[ -1, 
            Power[ M1, 2], 
            X[ 1], 
            X[ 2]], 
          Times[ 
            Power[ m2, 2], 
            X[ 1], 
            X[ 2]], 
          Times[ -1, 
            Power[ M1, 2], 
            Power[ 
              X[ 2], 2]], 
          Times[ 
            Power[ m2, 2], 
            Power[ 
              X[ 2], 2]], 
          Times[ 
            Power[ m1, 2], 
            X[ 1], 
            X[ 3]], 
          Times[ -1, 
            Power[ M2, 2], 
            X[ 1], 
            X[ 3]], 
          Times[ 
            Power[ m3, 2], 
            X[ 1], 
            X[ 3]], 
          Times[ -1, 
            Power[ M1, 2], 
            X[ 2], 
            X[ 3]], 
          Times[ 
            Power[ m2, 2], 
            X[ 2], 
            X[ 3]], 
          Times[ -1, 
            Power[ M2, 2], 
            X[ 2], 
            X[ 3]], 
          Times[ 
            Power[ m3, 2], 
            X[ 2], 
            X[ 3]], 
          Times[ -1, 
            Power[ M2, 2], 
            Power[ 
              X[ 3], 2]], 
          Times[ 
            Power[ m3, 2], 
            Power[ 
              X[ 3], 2]], 
          Times[ 
            Power[ M1, 2], 
            X[ 1], 
            Power[ 
              X[ 2], 2], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M1, 2], 
            Power[ 
              X[ 2], 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M1, 2], 
            X[ 1], 
            X[ 2], 
            X[ 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M2, 2], 
            X[ 1], 
            X[ 2], 
            X[ 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ -1, s, 
            X[ 1], 
            X[ 2], 
            X[ 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 2, 
            Power[ M1, 2], 
            Power[ 
              X[ 2], 2], 
            X[ 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M2, 2], 
            Power[ 
              X[ 2], 2], 
            X[ 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ -1, s, 
            Power[ 
              X[ 2], 2], 
            X[ 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M2, 2], 
            X[ 1], 
            Power[ 
              X[ 3], 2], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M1, 2], 
            X[ 2], 
            Power[ 
              X[ 3], 2], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 2, 
            Power[ M2, 2], 
            X[ 2], 
            Power[ 
              X[ 3], 2], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ -1, s, 
            X[ 2], 
            Power[ 
              X[ 3], 2], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]], 
          Times[ 
            Power[ M2, 2], 
            Power[ 
              X[ 3], 3], 
            Power[ 
              Plus[ 
                X[ 1], 
                X[ 2], 
                X[ 3]], -1]]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[fupc] // Expand\)], "Input"],

Cell[BoxData[
    \(m1\^2\ X[1]\^2 + m1\^2\ X[1]\ X[2] - M1\^2\ X[1]\ X[2] + 
      m2\^2\ X[1]\ X[2] + m2\^2\ X[2]\^2 + m1\^2\ X[1]\ X[3] - 
      M2\^2\ X[1]\ X[3] + m3\^2\ X[1]\ X[3] + m2\^2\ X[2]\ X[3] + 
      m3\^2\ X[2]\ X[3] - s\ X[2]\ X[3] + m3\^2\ X[3]\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fupc = \(\(% /. 
            m1\^2\ X[1]\ X[2] - M1\^2\ X[1]\ X[2] + m2\^2\ X[1]\ X[2] \[Rule] 
              MM1\ X[1]\ X[2]\) /. 
          m1\^2\ X[1]\ X[3] - M2\^2\ X[1]\ X[3] + m3\^2\ X[1]\ X[3] \[Rule] 
            MM2\ X[1]\ X[3]\) /. \(-M1\^2\)\ X[2]\ X[3] + m2\^2\ X[2]\ X[3] - 
            M2\^2\ X[2]\ X[3] + m3\^2\ X[2]\ X[3] - s\ X[2]\ X[3] \[Rule] 
          MM3\ X[2]\ X[3]\)], "Input"],

Cell[BoxData[
    \(m1\^2\ X[1]\^2 + MM1\ X[1]\ X[2] + m2\^2\ X[2]\^2 + MM2\ X[1]\ X[3] + 
      m2\^2\ X[2]\ X[3] + m3\^2\ X[2]\ X[3] - s\ X[2]\ X[3] + 
      m3\^2\ X[3]\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("U & F polynomial was computed by user >>Fauto["\
\[InvisibleSpace]0\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "U & F polynomial was computed by user >>Fauto[", 0, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3\)\ \((m1\^2)\)\^z1\ \
\((m2\^2)\)\^\(z3 + z5\)\ \((m3\^2)\)\^\(2 - eps - n1 - n2 - n3 - z1 - z2 - \
z3 - z4 - z5 - z7\)\ MM1\^z2\ MM2\^z4\ \((\(-s\))\)\^z7\ Gamma[\(-z1\)]\ \
Gamma[\(-z2\)]\ Gamma[\(-z3\)]\ Gamma[\(-z4\)]\ Gamma[
                n1 + 2\ z1 + z2 + z4]\ Gamma[\(-z5\)]\ Gamma[\(-z6\)]\ Gamma[
                4 - 2\ eps - 2\ n1 - 2\ n2 - n3 - 2\ z1 - 2\ z2 - 2\ z3 - 
                  z4 - z5 - z6 - z7]\ Gamma[\(-z7\)]\ Gamma[
                n2 + z2 + 2\ z3 + z5 + z6 + z7]\ Gamma[\(-2\) + eps + n1 + 
                  n2 + n3 + z1 + z2 + z3 + z4 + z5 + z6 + z7])\)/\((Gamma[
                n1]\ Gamma[n2]\ Gamma[4 - 2\ eps - n1 - n2 - n3]\ Gamma[
                n3])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(repr /. z3 \[Rule] z3 - z5 // Simplify\)], "Input"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3\)\ \((m1\^2)\)\^z1\ \((m2\^2)\)\^z3\ m3\
\^4\ \((m3\^2)\)\^\(\(-eps\) - n1 - n2 - n3 - z1 - z2 - z3 - z4 - z7\)\ \
MM1\^z2\ MM2\^z4\ \((\(-s\))\)\^z7\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ \
Gamma[\(-z4\)]\ Gamma[
            n1 + 2\ z1 + z2 + z4]\ Gamma[\(-z5\)]\ Gamma[\(-z3\) + 
              z5]\ Gamma[\(-z6\)]\ Gamma[
            4 - 2\ eps - 2\ n1 - 2\ n2 - n3 - 2\ z1 - 2\ z2 - 2\ z3 - z4 + 
              z5 - z6 - z7]\ Gamma[\(-z7\)]\ Gamma[\(-2\) + eps + n1 + n2 + 
              n3 + z1 + z2 + z3 + z4 + z6 + z7]\ Gamma[
            n2 + z2 + 2\ z3 - z5 + z6 + z7])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = BarnesLemma[%, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z6, z5}\[InvisibleSpace]" <<"\),
      SequenceForm[ 
      ">> Barnes 1st Lemma will be checked for: ", {z6, z5}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]7\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 7, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z6...Barnes Lemma was applied.
2. Checking z5...Barnes Lemma was applied.\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z5, z6}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z5, z6}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]5\),
      SequenceForm[ "   Obtained representation has: dim=", 5],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3\)\ \((m1\^2)\)\^z1\ \((m2\^2)\)\^z3\ m3\
\^4\ \((m3\^2)\)\^\(\(-eps\) - n1 - n2 - n3 - z1 - z2 - z3 - z4 - z7\)\ \
MM1\^z2\ MM2\^z4\ \((\(-s\))\)\^z7\ Gamma[\(-z1\)]\ Gamma[\(-z2\)]\ Gamma[
            2 - eps - n1 - n2 - z1 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
            4 - 2\ eps - 2\ n1 - n2 - n3 - 2\ z1 - z2 - 
              z4]\ Gamma[\(-z4\)]\ Gamma[
            n1 + 2\ z1 + z2 + z4]\ Gamma[\(-z7\)]\ Gamma[
            n2 + z2 + z3 + z7]\ Gamma[\(-2\) + eps + n1 + n2 + n3 + z1 + z2 + 
              z3 + z4 + z7])\)/\((Gamma[n1]\ Gamma[n2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[
            2 - eps - n1 - z1 + z7])\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ qed\ *) \)], "Input"],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[k1, 0, n1]\ PR[k1 + p1, m, n2]\ PR[k1 - p2, m, 
              n3]}, {k1}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(invariants = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, 
        p1*p2 \[Rule] 1/2\ s - \ 1/2\ m^2 - 1/2\ m^2}\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] m\^2, p2\^2 \[Rule] m\^2, 
      p1\ p2 \[Rule] \(-m\^2\) + s\/2}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, n1]\ PR[
            k1 + p1, m, n2]\ PR[k1 - p2, m, n3]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, n1], 
          PR[ 
            Plus[ k1, p1], m, n2], 
          PR[ 
            Plus[ k1, 
              Times[ -1, p2]], m, n3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[2] + X[3]]\^2 - s\ X[2]\ X[3]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^\(2 - eps - n1 - n2 - n3 - z1\)\ Gamma[\(-z1\)]\ Gamma[\(-2\) + 
                  eps + n1 + n2 + n3 + z1]\ Gamma[
                2 - eps - n1 - n2 + z1 - 
                  z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + z2]\ Gamma[
                2 - eps - n1 - n3 - z1 + z2])\)/\((Gamma[n2]\ Gamma[
                4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[\(-2\)\ z1])\)\),
        
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z2}\[InvisibleSpace]" <<"\),
      SequenceForm[ ">> Barnes 1st Lemma will be checked for: ", {z2}, " <<"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]2\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 2, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z2...Barnes Lemma was applied.\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z2}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]1\),
      SequenceForm[ "   Obtained representation has: dim=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3\)\ \((m\^2)\)\^z1\ \((\(-s\))\)\^\(2 - \
eps - n1 - n2 - n3 - z1\)\ Gamma[4 - 2\ eps - 2\ n1 - n2 - n3]\ Gamma[
            2 - eps - n1 - n2 - z1]\ Gamma[
            2 - eps - n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + 
              n1 + n2 + n3 + z1])\)/\((Gamma[n2]\ Gamma[
            4 - 2\ eps - n1 - n2 - n3]\ Gamma[n3]\ Gamma[
            4 - 2\ eps - 2\ n1 - n2 - n3 - 2\ z1])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = \(\(% /. n1 \[Rule] 1\) /. n2 \[Rule] 1\) /. 
        n3 \[Rule] 1\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((m\^2)\)\^z1\ \((\(-s\))\)\^\(\(-1\) - eps - z1\)\ \
Gamma[\(-2\)\ eps]\ Gamma[\(-eps\) - z1]\^2\ Gamma[\(-z1\)]\ Gamma[
              1 + eps + z1]\)\/\(Gamma[
              1 - 2\ eps]\ Gamma[\(-2\)\ eps - 2\ z1]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(1\/4\)\)}, {z1 \[Rule] \(-\(1\/2\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals = MBcontinue[fin, eps \[Rule] 0, rules]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\(1\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 1, " integral(s) found"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({MBint[\(-\(\(\((m\^2)\)\^z1\ \((\(-s\))\)\^\(\(-1\) - eps - z1\)\ \
Gamma[\(-2\)\ eps]\ Gamma[\(-eps\) - z1]\^2\ Gamma[\(-z1\)]\ Gamma[
                  1 + eps + z1]\)\/\(Gamma[
                  1 - 2\ eps]\ Gamma[\(-2\)\ eps - 
                    2\ z1]\)\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/2\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ser = 
        MBexpand[integrals, Exp[eps*EulerGamma], {eps, 0, 2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser, {m \[Rule] 1, s \[Rule] \(-100\)}]\)], "Input"],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 4 1-dimensional integrations...1...2...3...4", "Print"],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    \({\(-0.0898174765355979`\) + 0.04535063569737534`\/eps + 
        0.14949715061584012`\ eps - 0.19397919368907335`\ eps\^2, 
      0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ 
      sector\ decomposition\ \[IndentingNewLine]{4.232264000000024`\ Second, \
{{\(-0.08981820887176988`\) + 0.04535064702691313`\/ep + 
                0.14945558869695458`\ ep - 
                0.1945264833260732`\ ep\^2, \(-0.1048735733289627`\) + 
                0.04535064702691313`\/ep + 0.20024119689357514`\ ep - 
                0.2918293074664134`\ ep\^2, \(-0.10505273215579441`\) + 
                0.04535064702691313`\/ep + 0.19983929827795252`\ ep + 
                0.3571964382422373`\ ep\^2}}}\[IndentingNewLine]*) \)], \
"Input"]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
WindowSize->{1014, 689},
WindowMargins->{{0, Automatic}, {Automatic, 25}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 1, 27, "Input"],
Cell[1819, 56, 41, 1, 23, "Print"],
Cell[1863, 59, 51, 1, 23, "Print"],
Cell[1917, 62, 62, 1, 23, "Print"],
Cell[1982, 65, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2077, 71, 43, 1, 27, "Input"],
Cell[2123, 74, 56, 1, 23, "Print"],
Cell[2182, 77, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2257, 81, 154, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[2436, 88, 141, 2, 27, "Input"],
Cell[2580, 92, 135, 2, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2752, 99, 43, 1, 27, "Input"],
Cell[2798, 102, 143, 3, 23, "Print"],
Cell[2944, 107, 386, 11, 23, "Print"],
Cell[3333, 120, 143, 3, 23, "Print"],
Cell[3479, 125, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3690, 133, 62, 1, 27, "Input"],
Cell[3755, 136, 264, 4, 23, "Print"],
Cell[4022, 142, 257, 5, 23, "Print"],
Cell[4282, 149, 50, 1, 23, "Print"],
Cell[4335, 152, 51, 1, 23, "Print"],
Cell[4389, 155, 50, 1, 23, "Print"],
Cell[4442, 158, 278, 4, 43, "Print"],
Cell[4723, 164, 56, 1, 23, "Print"],
Cell[4782, 167, 1110, 17, 98, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5929, 189, 41, 1, 27, "Input"],
Cell[5973, 192, 172, 3, 20, "Message"],
Cell[6148, 197, 79, 1, 23, "Print"],
Cell[6230, 200, 50, 1, 23, "Print"],
Cell[6283, 203, 51, 1, 23, "Print"],
Cell[6337, 206, 50, 1, 23, "Print"],
Cell[6390, 209, 5429, 204, 146, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11856, 418, 57, 1, 27, "Input"],
Cell[11916, 421, 279, 4, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12232, 430, 421, 7, 47, "Input"],
Cell[12656, 439, 188, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12881, 447, 62, 1, 27, "Input"],
Cell[12946, 450, 264, 4, 23, "Print"],
Cell[13213, 456, 253, 5, 23, "Print"],
Cell[13469, 463, 56, 1, 23, "Print"],
Cell[13528, 466, 875, 14, 82, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14440, 485, 71, 1, 27, "Input"],
Cell[14514, 488, 724, 11, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15275, 504, 56, 1, 27, "Input"],
Cell[15334, 507, 257, 5, 23, "Print"],
Cell[15594, 514, 226, 4, 23, "Print"],
Cell[15823, 520, 111, 4, 53, "Print"],
Cell[15937, 526, 80, 1, 23, "Print"],
Cell[16020, 529, 466, 12, 23, "Print"],
Cell[16489, 543, 197, 4, 23, "Print"],
Cell[16689, 549, 721, 11, 86, "Output"]
}, Open  ]],
Cell[17425, 563, 46, 1, 27, "Input"],
Cell[17474, 566, 133, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[17632, 572, 137, 2, 27, "Input"],
Cell[17772, 576, 114, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17923, 583, 43, 1, 27, "Input"],
Cell[17969, 586, 143, 3, 23, "Print"],
Cell[18115, 591, 380, 11, 23, "Print"],
Cell[18498, 604, 143, 3, 23, "Print"],
Cell[18644, 609, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18855, 617, 62, 1, 27, "Input"],
Cell[18920, 620, 264, 4, 23, "Print"],
Cell[19187, 626, 257, 5, 23, "Print"],
Cell[19447, 633, 50, 1, 23, "Print"],
Cell[19500, 636, 51, 1, 23, "Print"],
Cell[19554, 639, 50, 1, 23, "Print"],
Cell[19607, 642, 73, 1, 25, "Print"],
Cell[19683, 645, 56, 1, 23, "Print"],
Cell[19742, 648, 601, 11, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20380, 664, 53, 1, 27, "Input"],
Cell[20436, 667, 249, 5, 23, "Print"],
Cell[20688, 674, 226, 4, 23, "Print"],
Cell[20917, 680, 68, 3, 38, "Print"],
Cell[20988, 685, 80, 1, 23, "Print"],
Cell[21071, 688, 458, 12, 23, "Print"],
Cell[21532, 702, 197, 4, 23, "Print"],
Cell[21732, 708, 464, 7, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22233, 720, 105, 2, 27, "Input"],
Cell[22341, 724, 263, 4, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22641, 733, 88, 1, 27, "Input"],
Cell[22732, 736, 91, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22860, 742, 82, 1, 27, "Input"],
Cell[22945, 745, 365, 5, 20, "Message"],
Cell[23313, 752, 42, 1, 23, "Print"],
Cell[23358, 755, 159, 3, 23, "Print"],
Cell[23520, 760, 363, 6, 50, "Output"]
}, Open  ]],
Cell[23898, 769, 106, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[24029, 775, 84, 1, 27, "Input"],
Cell[24116, 778, 55, 1, 23, "Print"],
Cell[24174, 781, 72, 0, 23, "Print"],
Cell[24249, 783, 63, 1, 23, "Print"],
Cell[24315, 786, 166, 3, 47, "Output"]
}, Open  ]],
Cell[24496, 792, 576, 10, 134, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

