(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11056,        298]*)
(*NotebookOutlinePosition[     11870,        327]*)
(*  CellTagsIndexPosition[     11782,        321]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< KinematicsGen.m\)], "Input"],

Cell[BoxData[
    \("by K.Kajda ver:1.2"\)], "Print"],

Cell[BoxData[
    \("last modification 01 Feb 2007"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Kinematics\)\)], "Input"],

Cell[BoxData[
    \("Usage: Kinematics[kinematics,choice], kinematics is a list of squared \
external momenta and choice sets independent Mandelstam variables e.g.\n \
kinematics={p1^2->m^2,p2^2->m^2,p3^2->m^2,p4^2->m^2}\n choice={s,t}\n\n NOTE \
1: All external momenta are set as IN and clocwise, use ?s, ?u, ?t to see \
Mandelstam variables.\n\n NOTE 2: For 5pt function use:\n {s12, s23, s34, \
s45, s15}.\n\n NOTE 3: For 6pt function use:\n {s12, s23, s34, s45, s56, s16, \
s123, s234, s345}.\n\n NOTE 4: For 5 and 6 point functions independent \
kinematical variables must be chosen in a cyclic way. See examples."\)], \
"Print",
  CellTags->"Info3384091453-5952939"]
}, Open  ]],

Cell[BoxData[
    \( (*\ 4 - point\ *) \)], "Input"],

Cell[BoxData[
    \(\(inv = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
          p4^2 \[Rule] m^2};\)\)], "Input"],

Cell[BoxData[
    \(\(choice = {s, t};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[inv, choice]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] m\^2, p2\^2 \[Rule] m\^2, p3\^2 \[Rule] m\^2, 
      p4\^2 \[Rule] m\^2, p1\ p2 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s)\), 
      p1\ p3 \[Rule] 1\/2\ \((2\ m\^2 - s - t)\), 
      p2\ p3 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + t)\), 
      p1\ p4 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + t)\), 
      p2\ p4 \[Rule] 1\/2\ \((2\ m\^2 - s - t)\), 
      p3\ p4 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(inv = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] m^2, 
          p4^2 \[Rule] m^2};\)\)], "Input"],

Cell[BoxData[
    \(\(choice = {s, t, u};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[inv, choice]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] 0, p2\^2 \[Rule] 0, p3\^2 \[Rule] m\^2, 
      p4\^2 \[Rule] m\^2, p1\ p2 \[Rule] s\/2, 
      p1\ p3 \[Rule] 1\/2\ \((\(-m\^2\) + u)\), 
      p2\ p3 \[Rule] 1\/2\ \((\(-m\^2\) + t)\), 
      p1\ p4 \[Rule] 1\/2\ \((\(-m\^2\) + t)\), 
      p2\ p4 \[Rule] 1\/2\ \((\(-m\^2\) + u)\), 
      p3\ p4 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(inv = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, 
          p4^2 \[Rule] 0};\)\)], "Input"],

Cell[BoxData[
    \(\(choice = {s, u};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[inv, choice]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] 0, p2\^2 \[Rule] 0, p3\^2 \[Rule] 0, p4\^2 \[Rule] 0, 
      p1\ p2 \[Rule] s\/2, p1\ p3 \[Rule] u\/2, 
      p2\ p3 \[Rule] 1\/2\ \((\(-s\) - u)\), 
      p1\ p4 \[Rule] 1\/2\ \((\(-s\) - u)\), p2\ p4 \[Rule] u\/2, 
      p3\ p4 \[Rule] s\/2}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (********************************************) \)\(\
\[IndentingNewLine]\)\( (*\ 5\ point\ *) \)\)\)], "Input"],

Cell[BoxData[
    \(\(a = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, p4^2 \[Rule] 0, 
          p5^2 \[Rule] 0};\)\)], "Input"],

Cell[BoxData[
    \(\(b = {s12, s23, s34, s45, s15};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[a, b]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] 0, p2\^2 \[Rule] 0, p3\^2 \[Rule] 0, p4\^2 \[Rule] 0, 
      p5\^2 \[Rule] 0, p1\ p2 \[Rule] s12\/2, p2\ p3 \[Rule] s23\/2, 
      p3\ p4 \[Rule] s34\/2, p4\ p5 \[Rule] s45\/2, p1\ p5 \[Rule] s15\/2, 
      p1\ p3 \[Rule] \(-\(1\/2\)\)\ \((s12 + s23 - s45)\), 
      p1\ p4 \[Rule] \(-\(1\/2\)\)\ \((s15 - s23 + s45)\), 
      p2\ p4 \[Rule] \(-\(1\/2\)\)\ \((\(-s15\) + s23 + s34)\), 
      p2\ p5 \[Rule] \(-\(1\/2\)\)\ \((s12 + s15 - s34)\), 
      p3\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-s12\) + s34 + s45)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(a = {p1^2 \[Rule] m1^2, p2^2 \[Rule] m1^2, p3^2 \[Rule] 0, 
          p4^2 \[Rule] m2^2, p5^2 \[Rule] m2^2};\)\)], "Input"],

Cell[BoxData[
    \(\(b = {s12, s23, s34, s45, s15};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[a, b]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] m1\^2, p2\^2 \[Rule] m1\^2, p3\^2 \[Rule] 0, 
      p4\^2 \[Rule] m2\^2, p5\^2 \[Rule] m2\^2, 
      p1\ p2 \[Rule] 1\/2\ \((\(-2\)\ m1\^2 + s12)\), 
      p2\ p3 \[Rule] 1\/2\ \((\(-m1\^2\) + s23)\), 
      p3\ p4 \[Rule] 1\/2\ \((\(-m2\^2\) + s34)\), 
      p4\ p5 \[Rule] 1\/2\ \((\(-2\)\ m2\^2 + s45)\), 
      p1\ p5 \[Rule] 1\/2\ \((\(-m1\^2\) - m2\^2 + s15)\), 
      p1\ p3 \[Rule] \(-\(1\/2\)\)\ \((\(-m1\^2\) + s12 + s23 - s45)\), 
      p1\ p4 \[Rule] \(-\(1\/2\)\)\ \((\(-m2\^2\) + s15 - s23 + s45)\), 
      p2\ p4 \[Rule] \(-\(1\/2\)\)\ \((\(-s15\) + s23 + s34)\), 
      p2\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-m1\^2\) + s12 + s15 - s34)\), 
      p3\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-m2\^2\) - s12 + s34 + 
              s45)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (******************************************) \)\(\
\[IndentingNewLine]\)\( (*\ 6\ point\ *) \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(choice = {s12, s23, s34, s45, s56, s16, s123, s234, 
          s345};\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(s123\\)\\\" is similar to existing symbol \\\
\"\\!\\(s23\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(s234\\)\\\" is similar to existing symbol \\\
\"\\!\\(s34\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(s345\\)\\\" is similar to existing symbol \\\
\"\\!\\(s45\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(General :: \\\"spell1\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(rul = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
          p4^2 \[Rule] m^2, p5^2 \[Rule] m^2, p6^2 \[Rule] m^2};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[rul, choice]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] m\^2, p2\^2 \[Rule] m\^2, p3\^2 \[Rule] m\^2, 
      p4\^2 \[Rule] m\^2, p5\^2 \[Rule] m\^2, p6\^2 \[Rule] m\^2, 
      p1\ p2 \[Rule] \(-m\^2\) + s12\/2, p2\ p3 \[Rule] \(-m\^2\) + s23\/2, 
      p3\ p4 \[Rule] \(-m\^2\) + s34\/2, p4\ p5 \[Rule] \(-m\^2\) + s45\/2, 
      p5\ p6 \[Rule] \(-m\^2\) + s56\/2, p1\ p6 \[Rule] \(-m\^2\) + s16\/2, 
      p1\ p3 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s12 - s123 + s23)\), 
      p2\ p4 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s23 - s234 + s34)\), 
      p3\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s34 - s345 + s45)\), 
      p1\ p4 \[Rule] \(-\(1\/2\)\)\ \((s123 - s23 + s234 - s56)\), 
      p1\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s16 - s234 + s56)\), 
      p2\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-s16\) + s234 - s34 + s345)\), 
      p2\ p6 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) + s12 + s16 - s345)\), 
      p3\ p6 \[Rule] \(-\(1\/2\)\)\ \((\(-s12\) + s123 + s345 - s45)\), 
      p4\ p6 \[Rule] \(-\(1\/2\)\)\ \((\(-m\^2\) - s123 + s45 + 
              s56)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(choice = {s12, s23, s34, s45, s56, s16, s123, s234, 
          s345};\)\)], "Input"],

Cell[BoxData[
    \(\(rul = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, 
          p4^2 \[Rule] 0, p5^2 \[Rule] 0, p6^2 \[Rule] 0};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kinematics[rul, choice]\)], "Input"],

Cell[BoxData[
    \({p1\^2 \[Rule] 0, p2\^2 \[Rule] 0, p3\^2 \[Rule] 0, p4\^2 \[Rule] 0, 
      p5\^2 \[Rule] 0, p6\^2 \[Rule] 0, p1\ p2 \[Rule] s12\/2, 
      p2\ p3 \[Rule] s23\/2, p3\ p4 \[Rule] s34\/2, p4\ p5 \[Rule] s45\/2, 
      p5\ p6 \[Rule] s56\/2, p1\ p6 \[Rule] s16\/2, 
      p1\ p3 \[Rule] \(-\(1\/2\)\)\ \((s12 - s123 + s23)\), 
      p2\ p4 \[Rule] \(-\(1\/2\)\)\ \((s23 - s234 + s34)\), 
      p3\ p5 \[Rule] \(-\(1\/2\)\)\ \((s34 - s345 + s45)\), 
      p1\ p4 \[Rule] \(-\(1\/2\)\)\ \((s123 - s23 + s234 - s56)\), 
      p1\ p5 \[Rule] \(-\(1\/2\)\)\ \((s16 - s234 + s56)\), 
      p2\ p5 \[Rule] \(-\(1\/2\)\)\ \((\(-s16\) + s234 - s34 + s345)\), 
      p2\ p6 \[Rule] \(-\(1\/2\)\)\ \((s12 + s16 - s345)\), 
      p3\ p6 \[Rule] \(-\(1\/2\)\)\ \((\(-s12\) + s123 + s345 - s45)\), 
      p4\ p6 \[Rule] \(-\(1\/2\)\)\ \((\(-s123\) + s45 + s56)\)}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
WindowSize->{518, 600},
WindowMargins->{{208, Automatic}, {65, Automatic}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3384091453-5952939"->{
    Cell[2038, 68, 673, 10, 295, "Print",
      CellTags->"Info3384091453-5952939"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3384091453-5952939", 11671, 314}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 51, 1, 27, "Input"],
Cell[1830, 56, 53, 1, 23, "Print"],
Cell[1886, 59, 64, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1987, 65, 48, 1, 27, "Input"],
Cell[2038, 68, 673, 10, 295, "Print",
  CellTags->"Info3384091453-5952939"]
}, Open  ]],
Cell[2726, 81, 52, 1, 27, "Input"],
Cell[2781, 84, 127, 2, 27, "Input"],
Cell[2911, 88, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[2989, 93, 56, 1, 27, "Input"],
Cell[3048, 96, 424, 7, 141, "Output"]
}, Open  ]],
Cell[3487, 106, 123, 2, 27, "Input"],
Cell[3613, 110, 56, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[3694, 115, 56, 1, 27, "Input"],
Cell[3753, 118, 384, 7, 113, "Output"]
}, Open  ]],
Cell[4152, 128, 119, 2, 27, "Input"],
Cell[4274, 132, 53, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[4352, 137, 56, 1, 27, "Input"],
Cell[4411, 140, 292, 5, 77, "Output"]
}, Open  ]],
Cell[4718, 148, 136, 2, 43, "Input"],
Cell[4857, 152, 133, 2, 27, "Input"],
Cell[4993, 156, 67, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[5085, 161, 49, 1, 27, "Input"],
Cell[5137, 164, 558, 8, 177, "Output"]
}, Open  ]],
Cell[5710, 175, 145, 2, 43, "Input"],
Cell[5858, 179, 67, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[5950, 184, 49, 1, 27, "Input"],
Cell[6002, 187, 788, 13, 321, "Output"]
}, Open  ]],
Cell[6805, 203, 134, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[6964, 209, 106, 2, 27, "Input"],
Cell[7073, 213, 355, 5, 46, "Message"],
Cell[7431, 220, 355, 5, 46, "Message"],
Cell[7789, 227, 355, 5, 46, "Message"],
Cell[8147, 234, 333, 5, 33, "Message"]
}, Open  ]],
Cell[8495, 242, 163, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[8683, 248, 56, 1, 27, "Input"],
Cell[8742, 251, 1059, 15, 429, "Output"]
}, Open  ]],
Cell[9816, 269, 106, 2, 27, "Input"],
Cell[9925, 273, 151, 2, 43, "Input"],

Cell[CellGroupData[{
Cell[10101, 279, 56, 1, 27, "Input"],
Cell[10160, 282, 880, 13, 357, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

