(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     51192,       1566]*)
(*NotebookOutlinePosition[     52299,       1601]*)
(*  CellTagsIndexPosition[     52210,       1595]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 29 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< KinematicsGen.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("by K.Kajda ver:1.2"\)], "Print"],

Cell[BoxData[
    \("last modification 01 Feb 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(inv = {p1^2 \[Rule] m^2, p2^2 \[Rule] m^2, p3^2 \[Rule] m^2, 
          p4^2 \[Rule] m^2};\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(choice = {s, t};\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(invariants = Kinematics[inv, choice]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({p1\^2 \[Rule] m\^2, p2\^2 \[Rule] m\^2, p3\^2 \[Rule] m\^2, 
      p4\^2 \[Rule] m\^2, p1\ p2 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s)\), 
      p1\ p3 \[Rule] 1\/2\ \((2\ m\^2 - s - t)\), 
      p2\ p3 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + t)\), 
      p1\ p4 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + t)\), 
      p2\ p4 \[Rule] 1\/2\ \((2\ m\^2 - s - t)\), 
      p3\ p4 \[Rule] 1\/2\ \((\(-2\)\ m\^2 + s)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\[IndentingNewLine]construction\ of\ the\ MB - 
        integral\ for\ topology\ B5l2m2\ which\ is\ discussed\ in\ \
\[IndentingNewLine]Czakon, \ J . G . , T . R . , \ PRD71, 
      073009\ \((2005)\)\ \ \ \ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(Fullintegral[\[IndentingNewLine]{1}, \[IndentingNewLine]{PR[k1, 0, 
              n1]*PR[k2 - p2, 0, n2]*PR[k1 + k2, m, n3]*
            PR[k2 + p3, 0, n4]\ PR[k2 - p1 - p2, m, n5]}, {k1, 
          k2}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, 0, n1]\ PR[
            k1 + k2, m, n3]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, 0, n1], 
          PR[ 
            Plus[ k1, k2], m, n3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-PR[k2, m]\)\ X[1]\ X[2] + m\^2\ X[2]\^2\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k1..."\),
      SequenceForm[ "Representation after integrating over: ", "k1..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\(\((\(-1\))\)\^\(n1 + n3 + z1\)\ \((m\^2)\)\^\(2 - eps \
- n1 - n3 - z1\)\ Gamma[4 - 2\ eps - 2\ n1 - n3 - z1]\ Gamma[\(-z1\)]\ Gamma[
                    n1 + z1]\ Gamma[\(-2\) + eps + n1 + n3 + z1]\)\/\(Gamma[
                    n1]\ Gamma[4 - 2\ eps - n1 - n3]\ Gamma[n3]\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          StyleBox[\(PR[k2, m, z1]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k2, m, \(-z1\)]\ PR[
            k2 - p2, 0, n2]\ PR[k2 - p1 - p2, m, n5]\ PR[k2 + p3, 0, n4]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k2, m, 
            Times[ -1, z1]], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p2]], 0, n2], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p1], 
              Times[ -1, p2]], m, n5], 
          PR[ 
            Plus[ k2, p3], 0, n4]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[3]]\^2 - s\ X[1]\ X[3] - t\ X[2]\ X[4]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \((m\^2)\)\^\(2 \
- eps - n1 - n3 - z1 + z2\)\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(2 - eps - n2 - \
n4 - n5 + z1 - z2 - z3\)\ Gamma[4 - 2\ eps - 2\ n1 - n3 - z1]\ Gamma[
                n1 + z1]\ Gamma[\(-2\) + eps + n1 + n3 + 
                  z1]\ Gamma[\(-z2\)]\ Gamma[
                2 - eps - n2 - n5 + z1 - z2 - z3]\ Gamma[
                2 - eps - n4 - n5 + z1 - z2 - 
                  z3]\ Gamma[\(-z3\)]\ Gamma[\(-2\) + eps + n2 + n4 + n5 - 
                  z1 + z2 + z3]\ Gamma[
                n5 + 2\ z2 + z3 - z4]\ Gamma[\(-z4\)]\ Gamma[\(-2\)\ z2 + 
                  z4]\ Gamma[\(-z1\) + z3 + z4])\)/\((Gamma[n1]\ Gamma[
                n2]\ Gamma[4 - 2\ eps - n1 - n3]\ Gamma[n3]\ Gamma[n4]\ Gamma[
                n5]\ Gamma[
                4 - 2\ eps - n2 - n4 - n5 + z1]\ Gamma[\(-2\)\ z2])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z4}\[InvisibleSpace]" <<"\),
      SequenceForm[ ">> Barnes 1st Lemma will be checked for: ", {z4}, " <<"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]4\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 4, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z4...Barnes Lemma was applied.\
\>", "Print"],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z4}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z4}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]3\),
      SequenceForm[ "   Obtained representation has: dim=", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5\)\ \((m\^2)\)\^\(2 - eps - n1 \
- n3 - z1 + z2\)\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(2 - eps - n2 - n4 - n5 + \
z1 - z2 - z3\)\ Gamma[4 - 2\ eps - 2\ n1 - n3 - z1]\ Gamma[
            n1 + z1]\ Gamma[\(-2\) + eps + n1 + n3 + 
              z1]\ Gamma[\(-z2\)]\ Gamma[
            2 - eps - n2 - n5 + z1 - z2 - z3]\ Gamma[
            2 - eps - n4 - n5 + z1 - z2 - z3]\ Gamma[\(-z3\)]\ Gamma[
            n5 + z3]\ Gamma[\(-z1\) + z3]\ Gamma[\(-2\) + eps + n2 + n4 + 
              n5 - z1 + z2 + z3]\ Gamma[n5 - z1 + 2\ z2 + 2\ z3])\)/\((Gamma[
            n1]\ Gamma[n2]\ Gamma[4 - 2\ eps - n1 - n3]\ Gamma[n3]\ Gamma[
            n4]\ Gamma[n5]\ Gamma[4 - 2\ eps - n2 - n4 - n5 + z1]\ Gamma[
            n5 - z1 + 2\ z3])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = % /. {n1 \[Rule] 1, n2 \[Rule] 1, n3 \[Rule] 1, n4 \[Rule] 1, 
          n5 \[Rule] 1}\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^\(\(-eps\) - z1 + z2\)\ \((\(-s\))\)\^z3\ \
\((\(-t\))\)\^\(\(-1\) - eps + z1 - z2 - z3\)\ Gamma[1 - 2\ eps - z1]\ Gamma[
              1 + z1]\ Gamma[
              eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) + z1 - z2 - z3]\^2\ \
Gamma[\(-z3\)]\ Gamma[1 + z3]\ Gamma[\(-z1\) + z3]\ Gamma[
              1 + eps - z1 + z2 + z3]\ Gamma[
              1 - z1 + 2\ z2 + 2\ z3])\)/\((Gamma[2 - 2\ eps]\ Gamma[
              1 - 2\ eps + z1]\ Gamma[1 - z1 + 2\ z3])\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]numerical\ checks\ using\ MB . 
          m\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(1 - eps + \(\(2\\ z2\
\)\)\)]"\)], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(1 - eps + \(\(2\\ z2\
\)\)\)]"\)], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(1 - eps + \(\(2\\ z2\
\)\)\)]"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBresidues :: \\\"contour\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \({{eps \[Rule] 29\/96}, {z1 \[Rule] \(-\(5\/48\)\), 
        z2 \[Rule] \(-\(3\/8\)\), z3 \[Rule] \(-\(1\/16\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals = MBcontinue[fin, eps \[Rule] 0, rules]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z1\
\[InvisibleSpace]" = "\[InvisibleSpace]\(-eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z1, " = ", 
        Times[ -1, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]2\),
      SequenceForm[ "Level ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1}\),
      SequenceForm[ "Integral ", {1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(-eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Times[ -1, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]3\),
      SequenceForm[ "Level ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1}\),
      SequenceForm[ "Integral ", {1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(3\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 3, " integral(s) found"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{MBint[\(\((m\^2)\)\^z2\ \((\(-s\))\)\^\(-eps\)\ \
\((\(-t\))\)\^\(\(-eps\) - z2\)\ Gamma[1 - eps]\^2\ Gamma[eps]\ \
Gamma[\(-eps\) - z2]\^2\ Gamma[\(-z2\)]\ Gamma[1 + eps + z2]\ Gamma[1 - eps + \
2\ z2]\)\/\(t\ Gamma[1 - 3\ eps]\ Gamma[2 - 2\ eps]\), {{eps \[Rule] 
                  0}, {z2 \[Rule] \(-\(3\/8\)\)}}]}, 
        MBint[\(\((m\^2)\)\^z2\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(\(-2\)\ eps \
- z2 - z3\)\ Gamma[1 - eps]\^2\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps - z2 - \
z3]\^2\ Gamma[\(-z3\)]\ Gamma[1 + z3]\ Gamma[eps + z3]\ Gamma[1 + 2\ eps + z2 \
+ z3]\ Gamma[1 + eps + 2\ z2 + 2\ z3]\)\/\(t\ Gamma[1 - 3\ eps]\ Gamma[2 - 2\ \
eps]\ Gamma[1 + eps + 2\ z3]\), {{eps \[Rule] 0}, {z2 \[Rule] \(-\(3\/8\)\), 
              z3 \[Rule] \(-\(1\/16\)\)}}]}, 
      MBint[\(-\(\((\((m\^2)\)\^\(\(-eps\) - z1 + z2\)\ \((\(-s\))\)\^z3\ \((\
\(-t\))\)\^\(\(-1\) - eps + z1 - z2 - z3\)\ Gamma[1 - 2\ eps - z1]\ Gamma[
                  1 + z1]\ Gamma[
                  eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) + z1 - z2 - \
z3]\^2\ Gamma[\(-z3\)]\ Gamma[1 + z3]\ Gamma[\(-z1\) + z3]\ Gamma[
                  1 + eps - z1 + z2 + z3]\ Gamma[
                  1 - z1 + 2\ z2 + 2\ z3])\)/\((Gamma[2 - 2\ eps]\ Gamma[
                  1 - 2\ eps + z1]\ Gamma[
                  1 - z1 + 2\ z3])\)\)\), {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(5\/48\)\), z2 \[Rule] \(-\(3\/8\)\), 
            z3 \[Rule] \(-\(1\/16\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ser = 
      MBexpand[{integrals}, 
        Exp[2*eps\ EulerGamma], \[IndentingNewLine]{eps, 
          0, \(-1\)}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({MBint[\(\((m\^2)\)\^z2\ \((\(-t\))\)\^\(-z2\)\ Gamma[\(-z2\)]\^3\ \
Gamma[1 + z2]\ Gamma[1 + 2\ z2]\)\/\(eps\ t\), {{eps \[Rule] 
              0}, {z2 \[Rule] \(-\(3\/8\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(num1 = 
      MBintegrate[ser, {s \[Rule] \(-1\)/2, t \[Rule] \(-3\), m \[Rule] 1}, 
        Verbose \[Rule] False]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({\(\(0.`\)\(\[InvisibleSpace]\)\) - 1.8000064132421716`\/eps, 
      0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(num2 = 
      MBintegrate[ser, {s \[Rule] \(-2\), t \[Rule] \(-1\)/3, m \[Rule] 1}, 
        Verbose \[Rule] False]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({\(\(0.`\)\(\[InvisibleSpace]\)\) - 6.734901466606443`\/eps, 
      0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]M . \ Czakon, \ J . G . , \ T . R . , \ 
      PRD71 \((2005)\)\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(Analyt = \(y\ \((\(2\ \[Pi]\^2\)\/3 + Log[y]\^2\/2 + 2\ PolyLog[2, \
y])\)\)\/\(\(-1\) + y\^2\);\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(x[
          s_] := \((Sqrt[\((s - 4)\)/s] - 1)\)/\((Sqrt[\((s - 4)\)/s] + 
              1)\);\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Analyt /. y \[Rule] x[\(-3\)] // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-1.800006394470895`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Analyt /. y \[Rule] x[\(-1\)/3] // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-6.734901353698208`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(num2\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({\(\(0.`\)\(\[InvisibleSpace]\)\) - 6.734901466606443`\/eps, 
      0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]ok, \ numerically\ the\ same, \ 
      now\ we\ should\ solve\ MB\ integral\ analytically, \ 
      we\ do\ it\ by\ matching\ series\ to\ the\ general\ base\ \
\[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(unknown = ser[\([1, 1]\)]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(\((m\^2)\)\^z2\ \((\(-t\))\)\^\(-z2\)\ Gamma[\(-z2\)]\^3\ Gamma[1 + \
z2]\ Gamma[1 + 2\ z2]\)\/\(eps\ t\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(poly[x_] = {x, 1, 1\/\(1 - x\), 1\/\(1 + x\)}\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({x, 1, 1\/\(1 - x\), 1\/\(1 + x\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ base, \ weight\ 2\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(baseHPL = 
      Union[\[IndentingNewLine]Join[{Zeta[2], PolyLog[2, y]}, 
          Flatten[Outer[
              Times, {Log[y], Log[1 - y]}, {Log[y], 
                Log[1 - y]}]]]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({\[Pi]\^2\/6, Log[1 - y]\^2, Log[1 - y]\ Log[y], Log[y]\^2, 
      PolyLog[2, y]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis = Flatten[Map[#*poly[y] &, baseHPL]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({\(\[Pi]\^2\ y\)\/6, \[Pi]\^2\/6, \[Pi]\^2\/\(6\ \((1 - y)\)\), \
\[Pi]\^2\/\(6\ \((1 + y)\)\), y\ Log[1 - y]\^2, Log[1 - y]\^2, 
      Log[1 - y]\^2\/\(1 - y\), Log[1 - y]\^2\/\(1 + y\), 
      y\ Log[1 - y]\ Log[y], 
      Log[1 - y]\ Log[
          y], \(Log[1 - y]\ Log[y]\)\/\(1 - y\), \(Log[1 - y]\ Log[y]\)\/\(1 \
+ y\), y\ Log[y]\^2, Log[y]\^2, Log[y]\^2\/\(1 - y\), Log[y]\^2\/\(1 + y\), 
      y\ PolyLog[2, y], PolyLog[2, y], PolyLog[2, y]\/\(1 - y\), 
      PolyLog[2, y]\/\(1 + y\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[basis]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(20\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(eq = Array[c, Length[basis]] . basis\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(1\/6\ \[Pi]\^2\ y\ c[1] + 
      1\/6\ \[Pi]\^2\ c[
          2] + \(\[Pi]\^2\ c[3]\)\/\(6\ \((1 - y)\)\) + \(\[Pi]\^2\ \
c[4]\)\/\(6\ \((1 + y)\)\) + y\ c[5]\ Log[1 - y]\^2 + 
      c[6]\ Log[1 - y]\^2 + \(c[7]\ Log[1 - y]\^2\)\/\(1 - y\) + \(c[8]\ \
Log[1 - y]\^2\)\/\(1 + y\) + y\ c[9]\ Log[1 - y]\ Log[y] + 
      c[10]\ Log[1 - y]\ Log[
          y] + \(c[11]\ Log[1 - y]\ Log[y]\)\/\(1 - y\) + \(c[12]\ Log[1 - y]\
\ Log[y]\)\/\(1 + y\) + y\ c[13]\ Log[y]\^2 + 
      c[14]\ Log[y]\^2 + \(c[15]\ Log[y]\^2\)\/\(1 - y\) + \(c[16]\ Log[y]\^2\
\)\/\(1 + y\) + y\ c[17]\ PolyLog[2, y] + 
      c[18]\ PolyLog[2, 
          y] + \(c[19]\ PolyLog[2, y]\)\/\(1 - y\) + \(c[20]\ PolyLog[2, y]\)\
\/\(1 + y\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(serEq1 = Normal[Series[eq, {y, 0, 20}]];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(unknown\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(\((m\^2)\)\^z2\ \((\(-t\))\)\^\(-z2\)\ Gamma[\(-z2\)]\^3\ Gamma[1 + \
z2]\ Gamma[1 + 2\ z2]\)\/\(eps\ t\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(eps\ unknown /. m \[Rule] 1\) /. 
      t \[Rule] \(-\((\((1 - y)\)^2/y)\)\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(\((\((1 - y)\)\^2\/y)\)\^\(-z2\)\ y\ Gamma[\(-z2\)]\^3\ Gamma[
              1 + z2]\ Gamma[1 + 2\ z2]\)\/\((1 - y)\)\^2\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Sum[\(-Residue[%, {z2, i}]\), {i, 0, 25}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(serEq2 = Normal[Series[%, {y, 0, 25}]] // Simplify;\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(serEq2\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-2\)\ y\^2 - 
      y\^3\/2 - \(20\ y\^4\)\/9 - \(5\ y\^5\)\/8 - \(518\ y\^6\)\/225 - \(49\ \
y\^7\)\/72 - \(25832\ y\^8\)\/11025 - \(205\ y\^9\)\/288 - \(234938\ \
y\^10\)\/99225 - \(5269\ y\^11\)\/7200 - \(28625948\ y\^12\)\/12006225 - \
\(5369\ y\^13\)\/7200 - \(4861797662\ y\^14\)\/2029052025 - \(266681\ y\^15\)\
\/352800 - \(975966736\ y\^16\)\/405810405 - \(1077749\ y\^17\)\/1411200 - \
\(282866007514\ y\^18\)\/117279207045 - \(9778141\ y\^19\)\/12700800 - \
\(102349187126644\ y\^20\)\/42337793743245 - \(1968329\ y\^21\)\/2540160 - \
\(102541195261534\ y\^22\)\/42337793743245 - \(239437889\ y\^23\)\/307359360 \
- \(54328967880837976\ y\^24\)\/22396692890176605 - \(240505109\ \
y\^25\)\/307359360 - 
      2\/3\ \[Pi]\^2\ \((y + y\^3 + y\^5 + y\^7 + y\^9 + y\^11 + y\^13 + 
            y\^15 + y\^17 + y\^19 + y\^21 + y\^23 + y\^25)\) - 
      1\/2\ \((y + y\^3 + y\^5 + y\^7 + y\^9 + y\^11 + y\^13 + y\^15 + 
            y\^17 + y\^19 + y\^21 + y\^23 + y\^25)\)\ Log[y]\^2\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(serEq1;\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(nologs = serEq1 - serEq2 /. a_. \ Log[y]^_.  \[Rule] 0;\)\)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(logs = serEq1 - serEq2 - nologs // Simplify\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(1\/232792560\)\((y\ \((y\^19\ \((12252240\ c[9] + 
                      11639628\ c[10] + 837527025\ c[11] - 
                      155685007\ c[12])\) + 
                19\ y\^17\ \((720720\ c[9] + 680680\ c[10] + 
                      42822903\ c[11] - 8161705\ c[12])\) + 
                323\ y\^15\ \((48048\ c[9] + 45045\ c[10] + 2436559\ c[11] - 
                      477745\ c[12])\) + 
                646\ y\^13\ \((27720\ c[9] + 25740\ c[10] + 1171733\ c[11] - 
                      237371\ c[12])\) + 
                8398\ y\^11\ \((2520\ c[9] + 2310\ c[10] + 86021\ c[11] - 
                      18107\ c[12])\) + 
                92378\ y\^9\ \((280\ c[9] + 252\ c[10] + 7381\ c[11] - 
                      1627\ c[12])\) + 
                277134\ y\^7\ \((120\ c[9] + 105\ c[10] + 2283\ c[11] - 
                      533\ c[12])\) + 
                3879876\ y\^5\ \((12\ c[9] + 10\ c[10] + 147\ c[11] - 
                      37\ c[12])\) + 
                19399380\ y\^3\ \((4\ c[9] + 3\ c[10] + 25\ c[11] - 
                      7\ c[12])\) + 
                116396280\ y\ \((2\ c[9] + c[10] + 3\ c[11] - c[12])\) + 
                232792560\ \((c[10] + c[11] + c[12])\) + 
                38798760\ y\^2\ \((3\ c[9] + 2\ c[10] + 11\ c[11] + 
                      5\ c[12])\) + 
                3879876\ y\^4\ \((15\ c[9] + 12\ c[10] + 137\ c[11] + 
                      47\ c[12])\) + 
                554268\ y\^6\ \((70\ c[9] + 60\ c[10] + 1089\ c[11] + 
                      319\ c[12])\) + 
                92378\ y\^8\ \((315\ c[9] + 280\ c[10] + 7129\ c[11] + 
                      1879\ c[12])\) + 
                8398\ y\^10\ \((2772\ c[9] + 2520\ c[10] + 83711\ c[11] + 
                      20417\ c[12])\) + 
                646\ y\^14\ \((25740\ c[9] + 24024\ c[10] + 1195757\ c[11] + 
                      261395\ c[12])\) + 
                646\ y\^12\ \((30030\ c[9] + 27720\ c[10] + 1145993\ c[11] + 
                      263111\ c[12])\) + 
                19\ y\^16\ \((765765\ c[9] + 720720\ c[10] + 
                      42142223\ c[11] + 8842385\ c[12])\) + 
                y\^18\ \((12932920\ c[9] + 12252240\ c[10] + 
                      825887397\ c[11] + 167324635\ c[12])\))\)\ Log[
              y])\)\)\) + 
      1\/2\ \((y\^21 + y\^23 + y\^25 + y\^3\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^5\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^7\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^9\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^11\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^13\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^15\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^17\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\^19\ \((1 + 2\ c[15] - 2\ c[16])\) + 
            y\ \((1 + 2\ c[13] + 2\ c[15] - 2\ c[16])\) + 
            2\ y\^2\ \((c[15] + c[16])\) + 2\ y\^4\ \((c[15] + c[16])\) + 
            2\ y\^6\ \((c[15] + c[16])\) + 2\ y\^8\ \((c[15] + c[16])\) + 
            2\ y\^10\ \((c[15] + c[16])\) + 2\ y\^12\ \((c[15] + c[16])\) + 
            2\ y\^14\ \((c[15] + c[16])\) + 2\ y\^16\ \((c[15] + c[16])\) + 
            2\ y\^18\ \((c[15] + c[16])\) + 2\ y\^20\ \((c[15] + c[16])\) + 
            2\ \((c[14] + c[15] + c[16])\))\)\ Log[y]\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[0 == Coefficient[nologs, y, i - 1], {i, 20}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({0 \[Equal] 
        1\/6\ \[Pi]\^2\ c[2] + 1\/6\ \[Pi]\^2\ c[3] + 1\/6\ \[Pi]\^2\ c[4], 
      0 \[Equal] \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[1] + 
          1\/6\ \[Pi]\^2\ c[3] - 1\/6\ \[Pi]\^2\ c[4] + c[18] + c[19] + 
          c[20], 0 \[Equal] 
        2 + 1\/6\ \[Pi]\^2\ c[3] + 1\/6\ \[Pi]\^2\ c[4] + c[6] + c[7] + 
          c[8] + c[17] + c[18]\/4 + \(5\ c[19]\)\/4 - \(3\ c[20]\)\/4, 
      0 \[Equal] 
        1\/2 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[4] + c[5] + c[6] + 2\ c[7] + c[17]\/4 + 
          c[18]\/9 + \(49\ c[19]\)\/36 + \(31\ c[20]\)\/36, 
      0 \[Equal] 
        20\/9 + 1\/6\ \[Pi]\^2\ c[3] + 1\/6\ \[Pi]\^2\ c[4] + 
          c[5] + \(11\ c[6]\)\/12 + \(35\ c[7]\)\/12 + \(11\ c[8]\)\/12 + 
          c[17]\/9 + c[18]\/16 + \(205\ c[19]\)\/144 - \(115\ c[20]\)\/144, 
      0 \[Equal] 
        5\/8 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(11\ c[5]\)\/12 + \(5\ c[6]\)\/6 + \(15\ c[7]\)\/4 - 
          c[8]\/12 + c[17]\/16 + 
          c[18]\/25 + \(5269\ c[19]\)\/3600 + \(3019\ c[20]\)\/3600, 
      0 \[Equal] 
        518\/225 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(5\ c[5]\)\/6 + \(137\ c[6]\)\/180 + \(203\ c[7]\)\/45 + \
\(38\ c[8]\)\/45 + c[17]\/25 + 
          c[18]\/36 + \(5369\ c[19]\)\/3600 - \(973\ c[20]\)\/1200, 
      0 \[Equal] 
        49\/72 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(137\ c[5]\)\/180 + \(7\ c[6]\)\/10 + \(469\ c[7]\)\/90 - \
\(13\ c[8]\)\/90 + c[17]\/36 + 
          c[18]\/49 + \(266681\ c[19]\)\/176400 + \(48877\ c[20]\)\/58800, 
      0 \[Equal] 
        25832\/11025 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(7\ c[5]\)\/10 + \(363\ c[6]\)\/560 + \(29531\ \
c[7]\)\/5040 + \(799\ c[8]\)\/1008 + c[17]\/49 + 
          c[18]\/64 + \(1077749\ c[19]\)\/705600 - \(191833\ c[20]\)\/235200, 
      0 \[Equal] 
        205\/288 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(363\ c[5]\)\/560 + \(761\ c[6]\)\/1260 + \(6515\ \
c[7]\)\/1008 - \(317\ c[8]\)\/1680 + c[17]\/64 + 
          c[18]\/81 + \(9778141\ c[19]\)\/6350400 + \(5257891\ \
c[20]\)\/6350400, 
      0 \[Equal] 
        234938\/99225 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(761\ c[5]\)\/1260 + \(7129\ c[6]\)\/12600 + \(177133\ \
c[7]\)\/25200 + \(19013\ c[8]\)\/25200 + c[17]\/81 + 
          c[18]\/100 + \(1968329\ c[19]\)\/1270080 - \(5194387\ \
c[20]\)\/6350400, 
      0 \[Equal] 
        5269\/7200 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(7129\ c[5]\)\/12600 + \(671\ c[6]\)\/1260 + \(190553\ \
c[7]\)\/25200 - \(799\ c[8]\)\/3600 + c[17]\/100 + 
          c[18]\/121 + \(239437889\ c[19]\)\/153679680 + \(634871227\ c[20]\)\
\/768398400, 
      0 \[Equal] 
        28625948\/12006225 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(671\ c[5]\)\/1260 + \(83711\ c[6]\)\/166320 + \(1676701\ \
c[7]\)\/207900 + \(150781\ c[8]\)\/207900 + c[17]\/121 + 
          c[18]\/144 + \(240505109\ c[19]\)\/153679680 - \(629535127\ c[20]\)\
\/768398400, 
      0 \[Equal] 
        5369\/7200 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(83711\ c[5]\)\/166320 + \(6617\ c[6]\)\/13860 + \(63427\ \
c[7]\)\/7425 - \(25763\ c[8]\)\/103950 + c[17]\/144 + 
          c[18]\/169 + \(40799043101\ c[19]\)\/25971865920 + \(107159834863\ \
c[20]\)\/129859329600, 
      0 \[Equal] 
        4861797662\/2029052025 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(6617\ c[5]\)\/13860 + \(1145993\ c[6]\)\/2522520 + \
\(30946717\ c[7]\)\/3439800 + \(26567627\ c[8]\)\/37837800 + c[17]\/169 + 
          c[18]\/196 + \(40931552621\ c[19]\)\/25971865920 - \(106497287263\ \
c[20]\)\/129859329600, 
      0 \[Equal] 
        266681\/352800 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(1145993\ c[5]\)\/2522520 + \(1171733\ c[6]\)\/2702700 + \
\(13215487\ c[7]\)\/1401400 - \(2032673\ c[8]\)\/7567560 + c[17]\/196 + 
          c[18]\/225 + \(205234915681\ c[19]\)\/129859329600 + \(107074439839\
\ c[20]\)\/129859329600, 
      0 \[Equal] 
        975966736\/405810405 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(1171733\ c[5]\)\/2702700 + \(1195757\ c[6]\)\/2882880 + \
\(993366559\ c[7]\)\/100900800 + \(41372281\ c[8]\)\/60540480 + c[17]\/225 + 
          c[18]\/256 + \(822968714749\ c[19]\)\/519437318400 - \(426268707331\
\ c[20]\)\/519437318400, 
      0 \[Equal] 
        1077749\/1411200 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(1195757\ c[5]\)\/2882880 + \(143327\ c[6]\)\/360360 + \
\(344499373\ c[7]\)\/33633600 - \(3458669\ c[8]\)\/12108096 + c[17]\/256 + 
          c[18]\/289 + \(238357395880861\ c[19]\)\/150117385017600 + \
\(123711093737059\ c[20]\)\/150117385017600, 
      0 \[Equal] 
        282866007514\/117279207045 + 1\/6\ \[Pi]\^2\ c[3] + 
          1\/6\ \[Pi]\^2\ c[
              4] + \(143327\ c[5]\)\/360360 + \(42142223\ c[6]\)\/110270160 + \
\(14911374857\ c[7]\)\/1403438400 + \(187449349\ c[8]\)\/280687680 + 
          c[17]\/289 + 
          c[18]\/324 + \(238820721143261\ c[19]\)\/150117385017600 - \
\(41082589491553\ c[20]\)\/50039128339200, 
      0 \[Equal] 
        9778141\/12700800 + \(2\ \[Pi]\^2\)\/3 + 1\/6\ \[Pi]\^2\ c[3] - 
          1\/6\ \[Pi]\^2\ c[
              4] + \(42142223\ c[5]\)\/110270160 + \(751279\ c[6]\)\/2042040 \
+ \(169704792667\ c[7]\)\/15437822400 - \(926008991\ c[8]\)\/3087564480 + 
          c[17]\/324 + 
          c[18]\/361 + \(86364397717734821\ c[19]\)\/54192375991353600 + \
\(14880853934789833\ c[20]\)\/18064125330451200}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, Array[c, 20]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(Solve::"svars"\), \(\(:\)\(\ \)\), "\<\"Equations may not give \
solutions for all \\\"solve\\\" variables. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Solve::svars\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{c[1] \[Rule] 0, c[2] \[Rule] 0, c[5] \[Rule] 0, c[3] \[Rule] \(-2\), 
        c[4] \[Rule] 2, c[6] \[Rule] 0, c[7] \[Rule] 0, c[8] \[Rule] 0, 
        c[17] \[Rule] 0, c[18] \[Rule] 0, c[19] \[Rule] \(-1\), 
        c[20] \[Rule] 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rule1 = %[\([1]\)]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({c[1] \[Rule] 0, c[2] \[Rule] 0, c[5] \[Rule] 0, c[3] \[Rule] \(-2\), 
      c[4] \[Rule] 2, c[6] \[Rule] 0, c[7] \[Rule] 0, c[8] \[Rule] 0, 
      c[17] \[Rule] 0, c[18] \[Rule] 0, c[19] \[Rule] \(-1\), 
      c[20] \[Rule] 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Coefficient[serEq1, c[9]] // Simplify\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\((\(-y\^2\) - y\^3\/2 - y\^4\/3 - y\^5\/4 - y\^6\/5 - y\^7\/6 - 
          y\^8\/7 - y\^9\/8 - y\^10\/9 - y\^11\/10 - y\^12\/11 - y\^13\/12 - 
          y\^14\/13 - y\^15\/14 - y\^16\/15 - y\^17\/16 - y\^18\/17 - 
          y\^19\/18 - y\^20\/19)\)\ Log[y]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[0 == Coefficient[logs, y, i - 1], {i, 20}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[%, Array[c, 20]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(Solve::"svars"\), \(\(:\)\(\ \)\), "\<\"Equations may not give \
solutions for all \\\"solve\\\" variables. \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"Solve::svars\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{c[13] \[Rule] 0, c[14] \[Rule] 0, c[9] \[Rule] 0, c[10] \[Rule] 0, 
        c[11] \[Rule] 0, c[12] \[Rule] 0, c[15] \[Rule] \(-\(1\/4\)\), 
        c[16] \[Rule] 1\/4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rule2 = %[\([1]\)]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({c[13] \[Rule] 0, c[14] \[Rule] 0, c[9] \[Rule] 0, c[10] \[Rule] 0, 
      c[11] \[Rule] 0, c[12] \[Rule] 0, c[15] \[Rule] \(-\(1\/4\)\), 
      c[16] \[Rule] 1\/4}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(eq /. rule1\) /. rule2 // Simplify\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(y\ \((4\ \[Pi]\^2 + 3\ Log[y]\^2 + 12\ PolyLog[2, y])\)\)\/\(6\ \
\((\(-1\) + y\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - Analyt // Simplify\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]let\ us\ look\ at\ analytic\ continuation\ in\ \
eps, \ how\ it\ really\ \(\(works\)\(?\)\)\ \[IndentingNewLine]*) \)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^\(\(-eps\) - z1 + z2\)\ \((\(-s\))\)\^z3\ \
\((\(-t\))\)\^\(\(-1\) - eps + z1 - z2 - z3\)\ Gamma[1 - 2\ eps - z1]\ Gamma[
              1 + z1]\ Gamma[
              eps + z1]\ Gamma[\(-z2\)]\ Gamma[\(-eps\) + z1 - z2 - z3]\^2\ \
Gamma[\(-z3\)]\ Gamma[1 + z3]\ Gamma[\(-z1\) + z3]\ Gamma[
              1 + eps - z1 + z2 + z3]\ Gamma[
              1 - z1 + 2\ z2 + 2\ z3])\)/\((Gamma[2 - 2\ eps]\ Gamma[
              1 - 2\ eps + z1]\ Gamma[1 - z1 + 2\ z3])\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?FindInstance\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{"\<\"FindInstance[expr, vars] finds an instance of vars that \
makes the statement expr be True. FindInstance[expr, vars, dom] finds an \
instance over the domain dom. Common choices of dom are Complexes, Reals, \
Integers and Booleans. FindInstance[expr, vars, dom, n] finds n \
instances.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"FindInstance",
        Active->True,
        ButtonStyle->"RefGuideLink"]}]], "Print",
  CellTags->"Info3384191249-1065177"]
}, Open  ]],

Cell[BoxData[
    \(\(backGamma = {G1[x__] \[Rule] Gamma[x], G2[x__] \[Rule] Gamma[x], 
          G3[x__] \[Rule] Gamma[x], G4[x__] \[Rule] Gamma[x], 
          G5[x__] \[Rule] Gamma[x], G6[x__] \[Rule] Gamma[x], 
          G7[x__] \[Rule] Gamma[x], G8[x__] \[Rule] Gamma[x], 
          G9[x__] \[Rule] Gamma[x], G10[x__] \[Rule] Gamma[x], 
          G11[x__] \[Rule] Gamma[x], G12[x__] \[Rule] Gamma[x]};\)\)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux0 = \(\(\(-\((\ \((m\^2)\)\^\(\(-eps\) - z1 + z2\)\ \((\(-s\))\)\^z3\
\ \((\(-t\))\)\^\(\(-1\) - eps + z1 - z2 - z3\)\ G1[1 - 2\ eps - z1]\ G2[
                      1 + z1]\ G3[
                      eps + z1]\ G4[\(-z2\)]\ G5[\(-eps\) + z1 - z2 - z3]\^2\ \
G6[\(-z3\)]\ G7[1 + z3]\ G8[\(-z1\) + z3]\ G9[1 + eps - z1 + z2 + z3]\ G10[
                      1 - z1 + 2\ z2 + 2\ z3])\)\)/\((G[2 - 2\ eps]\ G[
                    1 - 2\ eps + z1]\ G[1 - z1 + 2\ z3])\) /. m \[Rule] 1\) /. 
          s \[Rule] \(-1\)\) /. t \[Rule] \(-1\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1 - 2\ eps - z1]\ G10[1 - z1 + 2\ z2 + 2\ z3]\ G2[1 + z1]\ G3[
              eps + z1]\ G4[\(-z2\)]\ G5[\(-eps\) + z1 - z2 - z3]\^2\ \
G6[\(-z3\)]\ G7[1 + z3]\ G8[\(-z1\) + z3]\ G9[1 + eps - z1 + z2 + z3]\)\/\(G[
              2 - 2\ eps]\ G[1 - 2\ eps + z1]\ G[
              1 - z1 + 2\ z3]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\(Cases[Numerator[aux0] /. backGamma, Gamma[_]^n_. ] /. 
          Gamma[x_]^n_.  \[Rule] x > 0\) /. eps \[Rule] 0, {z1, z2, 
        z3}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\(Cases[Numerator[aux0] /. backGamma, Gamma[_]^n_. ] /. 
          Gamma[x_]^n_.  \[Rule] x > 0\) /. eps \[Rule] \(-1\)/10, {z1, z2, 
        z3}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindInstance[\(Cases[Numerator[aux0] /. backGamma, Gamma[_]^n_. ] /. 
          Gamma[x_]^n_.  \[Rule] x > 0\) /. eps \[Rule] 1/10, {z1, z2, 
        z3}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({{z1 \[Rule] \(-\(1\/20\)\), z2 \[Rule] \(-\(5\/16\)\), 
        z3 \[Rule] \(-\(1\/40\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subst = %[\([1]\)]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({z1 \[Rule] \(-\(1\/20\)\), z2 \[Rule] \(-\(5\/16\)\), 
      z3 \[Rule] \(-\(1\/40\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subst0 = Append[subst, eps \[Rule] 0]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({z1 \[Rule] \(-\(1\/20\)\), z2 \[Rule] \(-\(5\/16\)\), 
      z3 \[Rule] \(-\(1\/40\)\), eps \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(aux0 /. subst\) /. eps \[Rule] 1/10\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[17\/20]\ G10[3\/8]\ G2[19\/20]\ G3[1\/20]\ G4[
              5\/16]\ G5[3\/16]\^2\ G6[1\/40]\ G7[39\/40]\ G8[1\/40]\ G9[
              13\/16]\)\/\(G[3\/4]\ G[1]\ G[9\/5]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux0 /. subst0\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[21\/20]\ G10[3\/8]\ G2[19\/20]\ G3[\(-\(1\/20\)\)]\ G4[
              5\/16]\ G5[23\/80]\^2\ G6[1\/40]\ G7[39\/40]\ G8[1\/40]\ G9[
              57\/80]\)\/\(G[19\/20]\ G[1]\ G[2]\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]G3\ change\ \(sign : \ 
          goes\ through\ the\ pole\)\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[
      Series[\(aux0*Exp[2\ eps\ EulerGamma] /. backGamma\) /. 
          G[x_] \[Rule] Gamma[x], {eps, 0, \(-1\)}]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ adding\ residue\ at\ G3[0] : \ aux0\  \[Rule] \ 
        aux0\  + \ aux3\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\(**\)\(\ \)\(aux3\)\ ***) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux0\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1 - 2\ eps - z1]\ G10[1 - z1 + 2\ z2 + 2\ z3]\ G2[1 + z1]\ G3[
              eps + z1]\ G4[\(-z2\)]\ G5[\(-eps\) + z1 - z2 - z3]\^2\ \
G6[\(-z3\)]\ G7[1 + z3]\ G8[\(-z1\) + z3]\ G9[1 + eps - z1 + z2 + z3]\)\/\(G[
              2 - 2\ eps]\ G[1 - 2\ eps + z1]\ G[
              1 - z1 + 2\ z3]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux3 = 
      Residue[\(aux0 /. backGamma\) /. 
          G[x_] \[Rule] Gamma[x], {z1, \(-eps\)}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(Gamma[1 - eps]\^2\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ eps - z2 - \
z3]\^2\ Gamma[\(-z3\)]\ Gamma[1 + z3]\ Gamma[eps + z3]\ Gamma[
              1 + 2\ eps + z2 + z3]\ Gamma[
              1 + eps + 2\ z2 + 2\ z3]\)\/\(Gamma[1 - 3\ eps]\ Gamma[
              2 - 2\ eps]\ Gamma[1 + eps + 2\ z3]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux3 = \(-\((G1[1 - eps]\^2\ G2[\(-z2\)]\ G3[\(-2\)\ eps - z2 - z3]\^2\ \
G4[\(-z3\)]\ G5[1 + z3]\ G6[eps + z3]\ G7[1 + 2\ eps + z2 + z3]\ G8[
                1 + eps + 2\ z2 + 2\ z3])\)\)/\((G[1 - 3\ eps]\ G[
              2 - 2\ eps]\ G[1 + eps + 2\ z3])\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1 - eps]\^2\ G2[\(-z2\)]\ G3[\(-2\)\ eps - z2 - z3]\^2\ \
G4[\(-z3\)]\ G5[1 + z3]\ G6[eps + z3]\ G7[1 + 2\ eps + z2 + z3]\ G8[
              1 + eps + 2\ z2 + 2\ z3]\)\/\(G[1 - 3\ eps]\ G[2 - 2\ eps]\ G[
              1 + eps + 2\ z3]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[
      Series[\(aux3*Exp[2\ eps\ EulerGamma] /. backGamma\) /. 
          G[x_] \[Rule] Gamma[x], {eps, 0, \(-1\)}]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[z1 \[Equal] \(-eps\) /. subst, eps]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({{eps \[Rule] 1\/20}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(aux3 /. subst\) /. eps \[Rule] 1/20\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[19\/20]\^2\ G2[5\/16]\ G3[19\/80]\^2\ G4[1\/40]\ G5[
              39\/40]\ G6[1\/40]\ G7[61\/80]\ G8[3\/8]\)\/\(G[17\/20]\ G[
              1]\ G[19\/10]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(aux3 /. subst0\) /. eps \[Rule] 1/20\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1]\^2\ G2[5\/16]\ G3[27\/80]\^2\ G4[1\/40]\ G5[
              39\/40]\ G6[\(-\(1\/40\)\)]\ G7[53\/80]\ G8[13\/40]\)\/\(G[
              19\/20]\ G[1]\ G[2]\)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]G6\ change\ \(sign : \ 
          goes\ through\ the\ pole\)\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ adding\ residue\ at\ G6[0] : \ aux3\  \[Rule] \ 
        aux3\  + \ aux36\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\(**\)\(\ \)\(aux36\)\ ***) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux3\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1 - eps]\^2\ G2[\(-z2\)]\ G3[\(-2\)\ eps - z2 - z3]\^2\ \
G4[\(-z3\)]\ G5[1 + z3]\ G6[eps + z3]\ G7[1 + 2\ eps + z2 + z3]\ G8[
              1 + eps + 2\ z2 + 2\ z3]\)\/\(G[1 - 3\ eps]\ G[2 - 2\ eps]\ G[
              1 + eps + 2\ z3]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux36 = 
      Residue[\(aux3 /. backGamma\) /. 
          G[x_] \[Rule] Gamma[x], {z3, \(-eps\)}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(Gamma[1 - eps]\^2\ Gamma[
              eps]\ Gamma[\(-eps\) - z2]\^2\ Gamma[\(-z2\)]\ Gamma[
              1 + eps + z2]\ Gamma[1 - eps + 2\ z2]\)\/\(Gamma[
              1 - 3\ eps]\ Gamma[2 - 2\ eps]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[
      Series[\(aux36*Exp[2\ eps\ EulerGamma] /. backGamma\) /. 
          G[x_] \[Rule] Gamma[x], {eps, 0, \(-1\)}]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(Gamma[\(-z2\)]\^3\ Gamma[1 + z2]\ Gamma[
              1 + 2\ z2]\)\/eps\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux36 = \(-\(\(G1[1 - eps]\^2\ G2[
                eps]\ G3[\(-eps\) - z2]\^2\ G4[\(-z2\)]\ G5[1 + eps + z2]\ G6[
                1 - eps + 2\ z2]\)\/\(G[1 - 3\ eps]\ G[
                2 - 2\ eps]\)\)\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1 - eps]\^2\ G2[eps]\ G3[\(-eps\) - z2]\^2\ G4[\(-z2\)]\ G5[
              1 + eps + z2]\ G6[1 - eps + 2\ z2]\)\/\(G[1 - 3\ eps]\ G[
              2 - 2\ eps]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[z3 \[Equal] \(-eps\) /. subst, eps]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({{eps \[Rule] 1\/40}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(aux36 /. subst\) /. eps \[Rule] 1/40\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[39\/40]\^2\ G2[1\/40]\ G3[23\/80]\^2\ G4[5\/16]\ G5[
              57\/80]\ G6[7\/20]\)\/\(G[37\/40]\ G[39\/20]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(aux36 /. subst0\) /. eps \[Rule] 1/40\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(G1[1]\^2\ G2[0]\ G3[5\/16]\^2\ G4[5\/16]\ G5[11\/16]\ G6[
              3\/8]\)\/\(G[1]\ G[2]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[
      Series[\(aux36*Exp[2\ eps\ EulerGamma] /. backGamma\) /. 
          G[x_] \[Rule] Gamma[x], {eps, 0, \(-1\)}]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\(Gamma[\(-z2\)]\^3\ Gamma[1 + z2]\ Gamma[
              1 + 2\ z2]\)\/eps\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]let\ us\ compare\ with\ MB . 
          m\ result\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ser /. m \[Rule] 1\) /. t \[Rule] \(-1\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({MBint[\(-\(\(Gamma[\(-z2\)]\^3\ Gamma[1 + z2]\ Gamma[
                  1 + 2\ z2]\)\/eps\)\), {{eps \[Rule] 
              0}, {z2 \[Rule] \(-\(3\/8\)\)}}]}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
WindowSize->{1400, 989},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "gluza", \
"papers", "MBRbuilder", "examples"}, "warsawIteration.ps", CharacterEncoding \
-> "iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3384191249-1065177"->{
    Cell[39298, 1154, 544, 12, 39, "Print",
      CellTags->"Info3384191249-1065177"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3384191249-1065177", 52097, 1588}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 85, 3, 31, "Input"],
Cell[1864, 58, 41, 1, 23, "Print"],
Cell[1908, 61, 51, 1, 23, "Print"],
Cell[1962, 64, 62, 1, 23, "Print"],
Cell[2027, 67, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2122, 73, 88, 3, 31, "Input"],
Cell[2213, 78, 56, 1, 23, "Print"],
Cell[2272, 81, 60, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2369, 87, 96, 3, 31, "Input"],
Cell[2468, 92, 53, 1, 23, "Print"],
Cell[2524, 95, 64, 1, 23, "Print"]
}, Open  ]],
Cell[2603, 99, 172, 4, 31, "Input"],
Cell[2778, 105, 98, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[2901, 112, 114, 3, 31, "Input"],
Cell[3018, 117, 424, 7, 44, "Output"]
}, Open  ]],
Cell[3457, 127, 311, 6, 94, "Input"],
Cell[3771, 135, 286, 6, 73, "Input"],

Cell[CellGroupData[{
Cell[4082, 145, 88, 3, 31, "Input"],
Cell[4173, 150, 143, 3, 23, "Print"],
Cell[4319, 155, 282, 8, 23, "Print"],
Cell[4604, 165, 143, 3, 23, "Print"],
Cell[4750, 170, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4961, 178, 95, 3, 31, "Input"],
Cell[5059, 183, 264, 4, 23, "Print"],
Cell[5326, 189, 257, 5, 23, "Print"],
Cell[5586, 196, 50, 1, 23, "Print"],
Cell[5639, 199, 44, 1, 23, "Print"],
Cell[5686, 202, 50, 1, 23, "Print"],
Cell[5739, 205, 75, 1, 25, "Print"],
Cell[5817, 208, 215, 4, 23, "Print"],
Cell[6035, 214, 685, 15, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6757, 234, 88, 3, 31, "Input"],
Cell[6848, 239, 143, 3, 23, "Print"],
Cell[6994, 244, 544, 16, 23, "Print"],
Cell[7541, 262, 143, 3, 23, "Print"],
Cell[7687, 267, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7898, 275, 107, 3, 31, "Input"],
Cell[8008, 280, 264, 4, 23, "Print"],
Cell[8275, 286, 257, 5, 23, "Print"],
Cell[8535, 293, 50, 1, 23, "Print"],
Cell[8588, 296, 58, 1, 23, "Print"],
Cell[8649, 299, 50, 1, 23, "Print"],
Cell[8702, 302, 89, 1, 25, "Print"],
Cell[8794, 305, 56, 1, 23, "Print"],
Cell[8853, 308, 1014, 17, 65, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9904, 330, 98, 3, 31, "Input"],
Cell[10005, 335, 249, 5, 23, "Print"],
Cell[10257, 342, 226, 4, 23, "Print"],
Cell[10486, 348, 68, 3, 38, "Print"],
Cell[10557, 353, 80, 1, 23, "Print"],
Cell[10640, 356, 458, 12, 23, "Print"],
Cell[11101, 370, 197, 4, 23, "Print"],
Cell[11301, 376, 800, 12, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12138, 393, 170, 4, 31, "Input"],
Cell[12311, 399, 519, 8, 52, "Output"]
}, Open  ]],
Cell[12845, 410, 169, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[13039, 418, 133, 3, 31, "Input"],
Cell[13175, 423, 161, 3, 20, "Message"],
Cell[13339, 428, 161, 3, 20, "Message"],
Cell[13503, 433, 161, 3, 20, "Message"],
Cell[13667, 438, 337, 5, 20, "Message"],
Cell[14007, 445, 128, 2, 20, "Message"],
Cell[14138, 449, 128, 2, 20, "Message"],
Cell[14269, 453, 147, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14453, 460, 127, 3, 31, "Input"],
Cell[14583, 465, 365, 5, 20, "Message"],
Cell[14951, 472, 42, 1, 23, "Print"],
Cell[14996, 475, 293, 6, 23, "Print"],
Cell[15292, 483, 135, 3, 23, "Print"],
Cell[15430, 488, 145, 3, 23, "Print"],
Cell[15578, 493, 293, 6, 23, "Print"],
Cell[15874, 501, 135, 3, 23, "Print"],
Cell[16012, 506, 151, 3, 23, "Print"],
Cell[16166, 511, 159, 3, 23, "Print"],
Cell[16328, 516, 1463, 22, 192, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17828, 543, 193, 6, 52, "Input"],
Cell[18024, 551, 212, 3, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18273, 559, 193, 5, 31, "Input"],
Cell[18469, 566, 105, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18611, 573, 193, 5, 31, "Input"],
Cell[18807, 580, 104, 2, 47, "Output"]
}, Open  ]],
Cell[18926, 585, 189, 4, 73, "Input"],
Cell[19118, 591, 178, 4, 70, "Input"],
Cell[19299, 597, 177, 5, 31, "Input"],

Cell[CellGroupData[{
Cell[19501, 606, 112, 3, 31, "Input"],
Cell[19616, 611, 57, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19710, 617, 114, 3, 31, "Input"],
Cell[19827, 622, 57, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19921, 628, 82, 3, 31, "Input"],
Cell[20006, 633, 104, 2, 47, "Output"]
}, Open  ]],
Cell[20125, 638, 284, 6, 73, "Input"],

Cell[CellGroupData[{
Cell[20434, 648, 103, 3, 31, "Input"],
Cell[20540, 653, 141, 2, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20718, 660, 123, 3, 56, "Input"],
Cell[20844, 665, 68, 1, 44, "Output"]
}, Open  ]],
Cell[20927, 669, 105, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[21057, 676, 261, 7, 52, "Input"],
Cell[21321, 685, 115, 2, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21473, 692, 120, 3, 31, "Input"],
Cell[21596, 697, 529, 9, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22162, 711, 91, 3, 31, "Input"],
Cell[22256, 716, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22329, 722, 114, 3, 31, "Input"],
Cell[22446, 727, 739, 14, 91, "Output"]
}, Open  ]],
Cell[23200, 744, 122, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[23347, 751, 85, 3, 31, "Input"],
Cell[23435, 756, 141, 2, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23613, 763, 156, 4, 31, "Input"],
Cell[23772, 769, 165, 2, 61, "Output"]
}, Open  ]],
Cell[23952, 774, 124, 3, 31, "Input"],
Cell[24079, 779, 133, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[24237, 786, 84, 3, 31, "Input"],
Cell[24324, 791, 1023, 15, 122, "Output"]
}, Open  ]],
Cell[25362, 809, 89, 3, 31, "Input"],
Cell[25454, 814, 139, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[25618, 822, 121, 3, 31, "Input"],
Cell[25742, 827, 3309, 56, 243, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29088, 888, 128, 3, 31, "Input"],
Cell[29219, 893, 5964, 118, 676, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35220, 1016, 100, 3, 31, "Input"],
Cell[35323, 1021, 298, 4, 20, "Message"],
Cell[35624, 1027, 269, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35930, 1036, 96, 3, 31, "Input"],
Cell[36029, 1041, 261, 4, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36327, 1050, 115, 3, 31, "Input"],
Cell[36445, 1055, 291, 4, 51, "Output"]
}, Open  ]],
Cell[36751, 1062, 131, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[36907, 1069, 100, 3, 31, "Input"],
Cell[37010, 1074, 298, 4, 20, "Message"],
Cell[37311, 1080, 204, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37552, 1088, 96, 3, 31, "Input"],
Cell[37651, 1093, 198, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37886, 1101, 114, 3, 31, "Input"],
Cell[38003, 1106, 123, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38163, 1113, 100, 3, 31, "Input"],
Cell[38266, 1118, 35, 1, 27, "Output"]
}, Open  ]],
Cell[38316, 1122, 219, 5, 73, "Input"],

Cell[CellGroupData[{
Cell[38560, 1131, 81, 3, 31, "Input"],
Cell[38644, 1136, 519, 8, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39200, 1149, 95, 3, 31, "Input"],
Cell[39298, 1154, 544, 12, 39, "Print",
  CellTags->"Info3384191249-1065177"]
}, Open  ]],
Cell[39857, 1169, 467, 9, 73, "Input"],

Cell[CellGroupData[{
Cell[40349, 1182, 616, 10, 109, "Input"],
Cell[40968, 1194, 342, 5, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41347, 1204, 229, 5, 31, "Input"],
Cell[41579, 1211, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41652, 1217, 237, 5, 31, "Input"],
Cell[41892, 1224, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41965, 1230, 232, 5, 31, "Input"],
Cell[42200, 1237, 126, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42363, 1244, 96, 3, 31, "Input"],
Cell[42462, 1249, 122, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42621, 1256, 115, 3, 31, "Input"],
Cell[42739, 1261, 137, 2, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42913, 1268, 115, 3, 31, "Input"],
Cell[43031, 1273, 220, 3, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43288, 1281, 92, 3, 31, "Input"],
Cell[43383, 1286, 229, 3, 60, "Output"]
}, Open  ]],
Cell[43627, 1292, 186, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[43838, 1300, 201, 5, 31, "Input"],
Cell[44042, 1307, 35, 1, 27, "Output"]
}, Open  ]],
Cell[44092, 1311, 160, 4, 31, "Input"],
Cell[44255, 1317, 108, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[44388, 1324, 82, 3, 31, "Input"],
Cell[44473, 1329, 342, 5, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44852, 1339, 175, 5, 31, "Input"],
Cell[45030, 1346, 335, 5, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45402, 1356, 336, 6, 57, "Input"],
Cell[45741, 1364, 284, 4, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46062, 1373, 201, 5, 31, "Input"],
Cell[46266, 1380, 35, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46338, 1386, 119, 3, 31, "Input"],
Cell[46460, 1391, 55, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46552, 1397, 115, 3, 31, "Input"],
Cell[46670, 1402, 204, 3, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46911, 1410, 116, 3, 31, "Input"],
Cell[47030, 1415, 205, 3, 60, "Output"]
}, Open  ]],
Cell[47250, 1421, 186, 4, 73, "Input"],
Cell[47439, 1427, 161, 4, 31, "Input"],
Cell[47603, 1433, 109, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[47737, 1440, 82, 3, 31, "Input"],
Cell[47822, 1445, 284, 4, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48143, 1454, 176, 5, 31, "Input"],
Cell[48322, 1461, 249, 4, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48608, 1470, 202, 5, 31, "Input"],
Cell[48813, 1477, 117, 2, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48967, 1484, 281, 6, 60, "Input"],
Cell[49251, 1492, 208, 3, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49496, 1500, 119, 3, 31, "Input"],
Cell[49618, 1505, 55, 1, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49710, 1511, 116, 3, 31, "Input"],
Cell[49829, 1516, 161, 2, 60, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50027, 1523, 117, 3, 31, "Input"],
Cell[50147, 1528, 140, 2, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50324, 1535, 202, 5, 31, "Input"],
Cell[50529, 1542, 117, 2, 49, "Output"]
}, Open  ]],
Cell[50661, 1547, 175, 4, 73, "Input"],

Cell[CellGroupData[{
Cell[50861, 1555, 120, 3, 31, "Input"],
Cell[50984, 1560, 192, 3, 49, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

