(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37606,       1091]*)
(*NotebookOutlinePosition[     38238,       1113]*)
(*  CellTagsIndexPosition[     38194,       1109]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 29 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]B5nf\ with\ massless\ external\ \(masses : \
\[IndentingNewLine]only\ mass\ in\ SE\ insertion\)\[IndentingNewLine]*) \)], \
"Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< KinematicsGen.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("by K.Kajda ver:1.2"\)], "Print"],

Cell[BoxData[
    \("last modification 01 Feb 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(inv = {p1^2 \[Rule] 0, p2^2 \[Rule] 0, p3^2 \[Rule] 0, 
          p4^2 \[Rule] 0};\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(choice = {s, t};\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(invariants = Kinematics[inv, choice]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({p1\^2 \[Rule] 0, p2\^2 \[Rule] 0, p3\^2 \[Rule] 0, p4\^2 \[Rule] 0, 
      p1\ p2 \[Rule] s\/2, p1\ p3 \[Rule] 1\/2\ \((\(-s\) - t)\), 
      p2\ p3 \[Rule] t\/2, p1\ p4 \[Rule] t\/2, 
      p2\ p4 \[Rule] 1\/2\ \((\(-s\) - t)\), p3\ p4 \[Rule] s\/2}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Fullintegral[{1}, {DS[\(-p3\) + k2, 0, n1]*DS[k2, 0, n2]*
              DS[k2 + p1 + p4, 0, n3]*DS[k2 + p4, 0, n4]*DS[k1, m, n5]*
              DS[k2 - k1, m, n6] /. DS \[Rule] PR}, {k1, k2}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m, 
            n5]\ PR[\(-k1\) + k2, m, n6]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m, n5], 
          PR[ 
            Plus[ 
              Times[ -1, k1], k2], m, n6]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SubLoop[integral]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[2]]\^2 - PR[k2, 0]\ X[1]\ X[2]\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Representation after integrating over: "\
\[InvisibleSpace]"k1..."\),
      SequenceForm[ "Representation after integrating over: ", "k1..."],
      Editable->False]], "Print"],

Cell[BoxData[
    RowBox[{"SubLoop1", "[", 
      RowBox[{
        TagBox[
          
          StyleBox[\(\((\((\(-1\))\)\^\(2 - eps - z1\)\ \((m\^2)\)\^z1\ \
Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + n5 + n6 + z1]\ Gamma[
                    2 - eps - n5 + z1 - 
                      z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + z2]\ Gamma[
                    2 - eps - n6 - z1 + z2])\)/\((Gamma[n5]\ Gamma[
                    4 - 2\ eps - n5 - n6]\ Gamma[n6]\ Gamma[\(-2\)\ z1])\)\),
            FontColor->RGBColor[0, 0, 1]],
          (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)], ",", 
        TagBox[
          StyleBox[\(PR[k2, 0, 2 - eps - n5 - n6 - z1]\),
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]}], 
      "]"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[2]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k2, 
            0, \(-2\) + eps + n2 + n5 + n6 + z1]\ PR[k2 - p3, 0, n1]\ PR[
            k2 + p4, 0, n4]\ PR[k2 + p1 + p4, 0, n3]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k2, 0, 
            Plus[ -2, eps, n2, n5, n6, z1]], 
          PR[ 
            Plus[ k2, 
              Times[ -1, p3]], 0, n1], 
          PR[ 
            Plus[ k2, p4], 0, n4], 
          PR[ 
            Plus[ k2, p1, p4], 0, n3]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k2\),
      SequenceForm[ "momentum=", k2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]2\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k2\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 2, ": >>Integrating over ", k2, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2] + X[3] + X[4]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(\(-s\)\ X[2]\ X[3] - t\ X[1]\ X[4]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6\)\ \((m\^2)\)\
\^z1\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - \
n6 - z1 - z3\)\ Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + n5 + n6 + z1]\ Gamma[
                2 - eps - n5 + z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + 
                  z2]\ Gamma[2 - eps - n6 - z1 + z2]\ Gamma[
                2 - eps - n1 - n3 - n4 - z3]\ Gamma[
                4 - 2\ eps - n1 - n2 - n4 - n5 - n6 - z1 - 
                  z3]\ Gamma[\(-z3\)]\ Gamma[n1 + z3]\ Gamma[
                n4 + z3]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + n5 + 
                  n6 + z1 + z3])\)/\((Gamma[n1]\ Gamma[n3]\ Gamma[n4]\ Gamma[
                n5]\ Gamma[4 - 2\ eps - n5 - n6]\ Gamma[n6]\ Gamma[
                6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - 
                  z1]\ Gamma[\(-2\)\ z1]\ Gamma[\(-2\) + eps + n2 + n5 + n6 + 
                  z1])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rep = BarnesLemma[repr, 1]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z2}\[InvisibleSpace]" <<"\),
      SequenceForm[ ">> Barnes 1st Lemma will be checked for: ", {z2}, " <<"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]3\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 3, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z2...Barnes Lemma was applied.\
\>", "Print",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z2}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]2\),
      SequenceForm[ "   Obtained representation has: dim=", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^z3\ \((\(-t\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - \
z1 - z3\)\ Gamma[2 - eps - n5 - z1]\ Gamma[
            2 - eps - n6 - z1]\ Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + n5 + 
              n6 + z1]\ Gamma[2 - eps - n1 - n3 - n4 - z3]\ Gamma[
            4 - 2\ eps - n1 - n2 - n4 - n5 - n6 - z1 - 
              z3]\ Gamma[\(-z3\)]\ Gamma[n1 + z3]\ Gamma[
            n4 + z3]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + n5 + n6 + 
              z1 + z3])\)/\((Gamma[n1]\ Gamma[n3]\ Gamma[n4]\ Gamma[
            n5]\ Gamma[n6]\ Gamma[4 - 2\ eps - n5 - n6 - 2\ z1]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - z1]\ Gamma[\(-2\) + 
              eps + n2 + n5 + n6 + z1])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[rep, 2]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 2nd Lemma will be checked for: "\
\[InvisibleSpace]{}\[InvisibleSpace]" <<"\),
      SequenceForm[ ">> Barnes 2nd Lemma will be checked for: ", {}, " <<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]2\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 2, " representation..."],
      Editable->False]], "Print"],

Cell[BoxData[
    \(">> Representation after 2nd Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox["\<\"   Could not apply Barnes-Lemma\"\>",
        FontColor->RGBColor[1, 0, 0]],
      (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)]], "Print"],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(n1 + n2 + n3 + n4 + n5 + n6\)\ \((m\^2)\)\^z1\ \
\((\(-s\))\)\^z3\ \((\(-t\))\)\^\(4 - 2\ eps - n1 - n2 - n3 - n4 - n5 - n6 - \
z1 - z3\)\ Gamma[2 - eps - n5 - z1]\ Gamma[
            2 - eps - n6 - z1]\ Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + n5 + 
              n6 + z1]\ Gamma[2 - eps - n1 - n3 - n4 - z3]\ Gamma[
            4 - 2\ eps - n1 - n2 - n4 - n5 - n6 - z1 - 
              z3]\ Gamma[\(-z3\)]\ Gamma[n1 + z3]\ Gamma[
            n4 + z3]\ Gamma[\(-4\) + 2\ eps + n1 + n2 + n3 + n4 + n5 + n6 + 
              z1 + z3])\)/\((Gamma[n1]\ Gamma[n3]\ Gamma[n4]\ Gamma[
            n5]\ Gamma[n6]\ Gamma[4 - 2\ eps - n5 - n6 - 2\ z1]\ Gamma[
            6 - 3\ eps - n1 - n2 - n3 - n4 - n5 - n6 - z1]\ Gamma[\(-2\) + 
              eps + n2 + n5 + n6 + z1])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = \(\(\(\(\(rep /. n1 \[Rule] 1\) /. n2 \[Rule] 2\) /. 
              n3 \[Rule] 1\) /. n4 \[Rule] 1\) /. n5 \[Rule] 1\) /. 
        n6 \[Rule] 1\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-\(\((\((m\^2)\)\^z1\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(\(-3\) - 2\ \
eps - z1 - z3\)\ Gamma[1 - eps - z1]\^2\ Gamma[\(-z1\)]\ Gamma[
              eps + z1]\ Gamma[\(-1\) - eps - z3]\ Gamma[\(-2\) - 2\ eps - 
                z1 - z3]\ Gamma[\(-z3\)]\ Gamma[1 + z3]\^2\ Gamma[
              3 + 2\ eps + z1 + z3])\)/\((Gamma[
              2 - 2\ eps - 2\ z1]\ Gamma[\(-1\) - 3\ eps - z1]\ Gamma[
              2 + eps + z1])\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBrules[fin, eps \[Rule] 0, {}, {eps}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ no\ rules, \ analytic\ continuation\ in\ additional\ parameter, \ 
      what\ is\ interesting, \ 
      only\ n5\ makes\ the\ \(job!\)\[IndentingNewLine]and\ with\ \
representation\ before\ Barnes\ Lemmas\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(fin = \(\(\(\(\(repr /. n1 \[Rule] 1\) /. n2 \[Rule] 2\) /. 
              n3 \[Rule] 1\) /. n4 \[Rule] 1\) /. n5 \[Rule] 1 + eta\) /. 
        n6 \[Rule] 1\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\((\((\(-1\))\)\^\(7 + eta\)\ \((m\^2)\)\^z1\ \((\(-s\))\)\^z3\ \((\(-t\
\))\)\^\(\(-3\) - 2\ eps - eta - z1 - z3\)\ Gamma[\(-z1\)]\ Gamma[
            eps + eta + z1]\ Gamma[
            1 - eps - eta + z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + 
              z2]\ Gamma[
            1 - eps - z1 + z2]\ Gamma[\(-1\) - eps - z3]\ Gamma[\(-2\) - 
              2\ eps - eta - z1 - 
              z3]\ Gamma[\(-z3\)]\ Gamma[1 + z3]\^2\ Gamma[
            3 + 2\ eps + eta + z1 + z3])\)/\((Gamma[2 - 2\ eps - eta]\ Gamma[
            1 + eta]\ Gamma[\(-1\) - 3\ eps - eta - 
              z1]\ Gamma[\(-2\)\ z1]\ Gamma[
            2 + eps + eta + z1])\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBrules[fin, eta \[Rule] 0, {}, {eps, eta}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(eps + eta + \
z1\)]"\)], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(1 + eta + z2\)]"\)], \
"Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(3 + eps + z3\)]"\)], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBresidues :: \\\"contour\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(175\/64\)\), 
        eta \[Rule] 427\/64}, {z1 \[Rule] \(-\(457\/128\)\), 
        z2 \[Rule] \(-\(867\/128\)\), 
        z3 \[Rule] \(-\(145\/256\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[fin, eta \[Rule] 0, {}, {eps, eta}]\)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(eps + eta + \
z1\)]"\)], "Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(1 + eta + z2\)]"\)], \
"Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(3 + eps + z3\)]"\)], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBresidues :: \\\"contour\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBrules :: \\\"norules\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({{eps \[Rule] \(-\(9\/8\)\), 
        eta \[Rule] 53\/32}, {z1 \[Rule] \(-\(1\/2\)\), 
        z2 \[Rule] \(-\(3\/8\)\), z3 \[Rule] \(-\(31\/32\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Step1cont = MBcontinue[fin, eta \[Rule] 0, rules];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z1\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-eps\) - eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z1, " = ", 
        Plus[ 
          Times[ -1, eps], 
          Times[ -1, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z1\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z1, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z3\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-3\) - 2\ eps - eta - z1\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z3, " = ", 
        Plus[ -3, 
          Times[ -2, eps], 
          Times[ -1, eta], 
          Times[ -1, z1]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]2\),
      SequenceForm[ "Level ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1}\),
      SequenceForm[ "Integral ", {1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\)\ eps - 2\ eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Plus[ 
          Times[ -2, eps], 
          Times[ -2, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - 2\ eps - 2\ eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Plus[ -1, 
          Times[ -2, eps], 
          Times[ -2, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 2\ eps - 2\ eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Plus[ -2, 
          Times[ -2, eps], 
          Times[ -2, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2}\),
      SequenceForm[ "Integral ", {2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 2\ eps - 2\ eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Plus[ -2, 
          Times[ -2, eps], 
          Times[ -2, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3}\),
      SequenceForm[ "Integral ", {3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z1\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-1\) - eps - eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z1, " = ", 
        Plus[ -1, 
          Times[ -1, eps], 
          Times[ -1, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]3\),
      SequenceForm[ "Level ", 3],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 1}\),
      SequenceForm[ "Integral ", {1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 2}\),
      SequenceForm[ "Integral ", {1, 2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1, 3}\),
      SequenceForm[ "Integral ", {1, 3}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{2, 1}\),
      SequenceForm[ "Integral ", {2, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1}\),
      SequenceForm[ "Integral ", {3, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z2\
\[InvisibleSpace]" = "\[InvisibleSpace]\(\(-2\) - 2\ eps - 2\ eta\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z2, " = ", 
        Plus[ -2, 
          Times[ -2, eps], 
          Times[ -2, eta]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]4\),
      SequenceForm[ "Level ", 4],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{3, 1, 1}\),
      SequenceForm[ "Integral ", {3, 1, 1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(10\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 10, " integral(s) found"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(after = MBexpand[Step1cont, 1, {eta, 0, 0}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(after\\)\\\" is similar to existing symbol \
\\\"\\!\\(After\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals = 
      MBmerge[after /. 
          MBint[integrand_, rules_] \[RuleDelayed] 
            MBcontinue[integrand, eps \[Rule] 0, rules, 
              Verbose \[Rule] False]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({MBint[\((\((m\^2)\)\^\(-eps\)\ \((\(-s\))\)\^\(\(-2\) - eps\)\ Gamma[
                1 - 2\ eps]\ Gamma[
                eps]\ \((t\ Gamma[\(-1\) - eps]\^2\ Gamma[2 + eps] + 
                  s\ Gamma[\(-eps\)]\^2\ Gamma[
                      1 + eps]\ \((EulerGamma + Log[\(-s\)] - Log[\(-t\)] + 
                        2\ PolyGamma[0, \(-eps\)] - 
                        PolyGamma[0, 
                          1 + eps])\))\))\)/\((t\^2\ Gamma[\(-1\) - 
                  2\ eps]\ Gamma[2 - 2\ eps])\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {}}], 
      MBint[\((\((m\^2)\)\^\(-eps\)\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(\(-eps\
\) - z3\)\ Gamma[1 - 2\ eps]\ Gamma[
                eps]\ Gamma[\(-2\) - eps - z3]\ Gamma[\(-1\) - eps - 
                  z3]\ Gamma[\(-z3\)]\ Gamma[1 + z3]\^2\ Gamma[
                3 + eps + z3])\)/\((t\^3\ Gamma[\(-1\) - 2\ eps]\ Gamma[
                2 - 2\ eps])\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z3 \[Rule] \(-\(31\/32\)\)}}], 
      MBint[\((\((m\^2)\)\^\(\(-1\) - 2\ eps\)\ \((\(-s\))\)\^\(\(-2\) - \
eps\)\ Gamma[\(-z2\)]\ \((\((m\^2)\)\^\(1 + eps\)\ Gamma[1 - eps]\ Gamma[
                      eps]\ Gamma[2 + 4\ eps]\ Gamma[1 - 2\ eps - z2]\ Gamma[
                      1 + z2]\ Gamma[
                      2\ eps + 
                        z2]\ \((t\ Gamma[\(-1\) - eps]\^2\ Gamma[2 + eps] + 
                        s\ Gamma[\(-eps\)]\^2\ Gamma[
                            1 + eps]\ \((EulerGamma + Log[\(-s\)] - 
                              Log[\(-t\)] + 2\ PolyGamma[0, \(-eps\)] - 
                              PolyGamma[0, 
                                1 + eps])\))\) + \((\(-s\))\)\^eps\ s\ t\ \
Gamma[\(-1\) - 2\ eps]\ Gamma[\(-1\) - eps]\ Gamma[2\ eps]\ Gamma[
                      1 + 2\ eps]\ Gamma[\(-3\)\ eps - z2]\ Gamma[
                      2 + eps + z2]\ Gamma[
                      2 + 4\ eps + z2]\ \((EulerGamma + Log[m\^2] - 
                        Log[\(-s\)] + PolyGamma[0, \(-1\) - eps] - 
                        PolyGamma[0, 1 - eps] + 2\ PolyGamma[0, \(-eps\)] - 
                        PolyGamma[0, 1 + 2\ eps] + 
                        2\ PolyGamma[0, 2 + 4\ eps] + 
                        PolyGamma[0, \(-3\)\ eps - z2] - 
                        PolyGamma[0, 2 + eps + z2] - 
                        2\ PolyGamma[0, 
                            2 + 4\ eps + z2])\))\))\)/\((t\^2\ Gamma[\(-1\) - 
                  2\ eps]\ Gamma[2 - 2\ eps]\ Gamma[1 - eps]\ Gamma[
                2\ eps]\ Gamma[2 + 4\ eps])\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z2 \[Rule] \(-\(3\/8\)\)}}], 
      MBint[\((\((m\^2)\)\^\(-eps\)\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(\(-eps\
\) - z3\)\ Gamma[eps]\ Gamma[1 - 2\ eps - z2]\ Gamma[\(-z2\)]\ Gamma[
                1 + z2]\ Gamma[
                2\ eps + z2]\ Gamma[\(-2\) - eps - z3]\ Gamma[\(-1\) - eps - 
                  z3]\ Gamma[\(-z3\)]\ Gamma[1 + z3]\^2\ Gamma[
                3 + eps + z3])\)/\((t\^3\ Gamma[\(-1\) - 2\ eps]\ Gamma[
                2 - 2\ eps]\ Gamma[2\ eps])\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z2 \[Rule] \(-\(3\/8\)\), 
            z3 \[Rule] \(-\(31\/32\)\)}}], 
      MBint[\((\((m\^2)\)\^z1\ \((\(-s\))\)\^\(\(-2\) - 2\ eps - z1\)\ \
\((\(-t\))\)\^\(\(-2\) - eps - z1\)\ Gamma[\(-z1\)]\ Gamma[
                eps + z1]\ \((\((\(-s\))\)\^\(eps + z1\)\ s\ \
Gamma[\(-eps\)]\^2\ Gamma[1 + eps]\ Gamma[\(-1\) - eps - z1]\ Gamma[
                      2 + eps + 
                        z1] + \((\(-t\))\)\^\(eps + z1\)\ t\ Gamma[\(-1\) - 2\
\ eps - z1]\^2\ Gamma[1 + eps + z1]\ Gamma[2 + 2\ eps + z1])\)\ Gamma[
                1 - eps + z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + 
                  z2]\ Gamma[1 - eps - z1 + z2])\)/\((Gamma[
                2 - 2\ eps]\ Gamma[\(-1\) - 3\ eps - 
                  z1]\ Gamma[\(-2\)\ z1]\ Gamma[
                2 + eps + z1])\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(3\/8\)\)}}], 
      MBint[\((\((m\^2)\)\^z1\ \((\(-s\))\)\^z3\ \((\(-t\))\)\^\(\(-2\)\ eps \
- z1 - z3\)\ Gamma[\(-z1\)]\ Gamma[eps + z1]\ Gamma[
                1 - eps + z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + 
                  z2]\ Gamma[
                1 - eps - z1 + z2]\ Gamma[\(-1\) - eps - z3]\ Gamma[\(-2\) - 
                  2\ eps - z1 - z3]\ Gamma[\(-z3\)]\ Gamma[1 + z3]\^2\ Gamma[
                3 + 2\ eps + z1 + z3])\)/\((t\^3\ Gamma[
                2 - 2\ eps]\ Gamma[\(-1\) - 3\ eps - 
                  z1]\ Gamma[\(-2\)\ z1]\ Gamma[
                2 + eps + z1])\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(3\/8\)\), 
            z3 \[Rule] \(-\(31\/32\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(ser = 
        MBexpand[{integrals}, 
          Exp[2*eps\ EulerGamma], {eps, 0, 0}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBintegrate[ser, {m \[Rule] 1, s \[Rule] \(-3\), t \[Rule] \(-6\)}] // 
      AbsoluteTiming\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 4 1-dimensional integrations...1...2...3...4", "Print",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart1eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]3\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart1eps0", " (dim ", 3, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart2eps0"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart2eps0", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart3eps-1"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart3eps-1", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Preparing "\[InvisibleSpace]"MBpart4eps-2"\
\[InvisibleSpace]" (dim "\[InvisibleSpace]2\[InvisibleSpace]")"\),
      SequenceForm[ "Preparing ", "MBpart4eps-2", " (dim ", 2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart1eps0"\),
      SequenceForm[ "Running ", "MBpart1eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart2eps0"\),
      SequenceForm[ "Running ", "MBpart2eps0"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart3eps-1"\),
      SequenceForm[ "Running ", "MBpart3eps-1"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Running "\[InvisibleSpace]"MBpart4eps-2"\),
      SequenceForm[ "Running ", "MBpart4eps-2"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({7.51918`7.327715474926343\ Second, {\(\(0.2305456435895921`\)\(\
\[InvisibleSpace]\)\) - 0.037037037037037035`\/eps\^3 - 
          0.023660824017645018`\/eps\^2 + 
          0.11666937969264297`\/eps, {\(\(0.00001272345352208749`\)\(\
\[InvisibleSpace]\)\) + 5.94798866`*^-7\/eps\^2 + 1.02427328`*^-6\/eps, 
          0}}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ \[IndentingNewLine]independent\ result\ from\ sectors\ \
decomposition\ gives\[IndentingNewLine]{384.516031`\ Second, \
{{\(\(0.2303438530504856`\)\(\[InvisibleSpace]\)\) - 
                0.03703140603784769`\/ep\^3 - 0.023620384827166302`\/ep\^2 + 
                0.11656960511814657`\/ep, \(\(0.0021720237709356594`\)\(\
\[InvisibleSpace]\)\) + 0.000014978281607301051`\/ep\^3 + 
                0.0002501640728913597`\/ep\^2 + 
                0.0009140713288685385`\/ep, \(\(0.00024670084789069703`\)\(\
\[InvisibleSpace]\)\) + 0.0048605581643113`\/ep\^3 + 
                0.009680143809085856`\/ep\^2 + 
                0.08379717445538798`\/ep}}}\[IndentingNewLine]*) \)\(\
\[IndentingNewLine]\)\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(MBmerge[
      MBexpand[{integrals}, 
        Exp[2*eps\ EulerGamma], {eps, 0, \(-3\)}]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({MBint[
        4\/\(eps\^3\ s\ t\^2\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux = 
      MBmerge[MBexpand[{integrals}, 
          Exp[2*eps\ EulerGamma], {eps, 0, \(-2\)}]]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({MBint[\(-\(\(2\ \((\(-2\)\ s - 8\ eps\ s - eps\ t + 
                    2\ eps\ s\ Log[m\^2] + eps\ s\ Log[\(-s\)] + 
                    eps\ s\ Log[\(-t\)])\)\)\/\(eps\^3\ s\^2\ t\^2\)\)\), \
{{eps \[Rule] 0, eta \[Rule] 0}, {}}], 
      MBint[\(Gamma[\(-z2\)]\ \((8\ m\^2\ Gamma[1 - z2]\ Gamma[z2]\ Gamma[1 + \
z2] + 3\ t\ Gamma[\(-z2\)]\ Gamma[2 + z2]\^2)\)\)\/\(eps\^2\ m\^2\ s\ t\^2\), \
{{eps \[Rule] 0, eta \[Rule] 0}, {z2 \[Rule] \(-\(3\/8\)\)}}], 
      MBint[\(\((m\^2)\)\^z1\ \((\(-t\))\)\^\(\(-2\) - z1\)\ Gamma[\(-z1\)]\ \
Gamma[z1]\ Gamma[1 + z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + z2]\ \
Gamma[1 - z1 + z2]\)\/\(eps\^2\ s\ Gamma[\(-2\)\ z1]\), {{eps \[Rule] 0, 
            eta \[Rule] 0}, {z1 \[Rule] \(-\(1\/2\)\), 
            z2 \[Rule] \(-\(3\/8\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux[\([2, 1]\)]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(Gamma[\(-z2\)]\ \((8\ m\^2\ Gamma[1 - z2]\ Gamma[z2]\ Gamma[1 + z2] + \
3\ t\ Gamma[\(-z2\)]\ Gamma[2 + z2]\^2)\)\)\/\(eps\^2\ m\^2\ s\ t\^2\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux1 = \(\(%\ eps^2 /. m \[Rule] 1\) /. s \[Rule] 1\) /. 
        t \[Rule] 1\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(Gamma[\(-z2\)]\ \((8\ Gamma[1 - z2]\ Gamma[z2]\ Gamma[1 + z2] + 
          3\ Gamma[\(-z2\)]\ Gamma[2 + z2]\^2)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(aux1 // Expand\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(8\ Gamma[1 - z2]\ Gamma[\(-z2\)]\ Gamma[z2]\ Gamma[1 + z2] + 
      3\ Gamma[\(-z2\)]\^2\ Gamma[2 + z2]\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NIntegrate[
      Re[Gamma[\(-z2\)]\^2\ \(Gamma[2 + z2]\^2/\((y \((1 - 
                        y)\))\)\)/\((2\ Pi)\)] /. 
        z2 \[Rule] \(-3\)/8 - I\ Log[y/\((1 - y)\)], {y, 0, 1}, 
      PrecisionGoal \[Rule] 20, AccuracyGoal \[Rule] 20, 
      WorkingPrecision \[Rule] 50]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(0.16666666666666666666666400078110464333`20.034912561919967\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ matching\ e . g . \ by\ PSLQ\ algorithm, \ 
      here\ it\ is\ trivial\ number\ \((no\ Zeta[2], etc)\)\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[1/6, 20]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(0.16666666666666666666666666666666666667`20. \)], "Output"]
}, Open  ]]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
WindowSize->{1014, 714},
WindowMargins->{{159, Automatic}, {Automatic, 97}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 85, 3, 31, "Input"],
Cell[1864, 58, 41, 1, 23, "Print"],
Cell[1908, 61, 51, 1, 23, "Print"],
Cell[1962, 64, 62, 1, 23, "Print"],
Cell[2027, 67, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2122, 73, 88, 3, 31, "Input"],
Cell[2213, 78, 56, 1, 23, "Print"],
Cell[2272, 81, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2347, 85, 221, 5, 94, "Input"],

Cell[CellGroupData[{
Cell[2593, 94, 96, 3, 31, "Input"],
Cell[2692, 99, 53, 1, 23, "Print"],
Cell[2748, 102, 64, 1, 23, "Print"]
}, Open  ]],
Cell[2827, 106, 164, 4, 31, "Input"],
Cell[2994, 112, 98, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[3117, 119, 114, 3, 31, "Input"],
Cell[3234, 124, 285, 4, 44, "Output"]
}, Open  ]],
Cell[3534, 131, 274, 5, 73, "Input"],

Cell[CellGroupData[{
Cell[3833, 140, 88, 3, 31, "Input"],
Cell[3924, 145, 143, 3, 23, "Print"],
Cell[4070, 150, 314, 9, 23, "Print"],
Cell[4387, 161, 143, 3, 23, "Print"],
Cell[4533, 166, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4744, 174, 95, 3, 31, "Input"],
Cell[4842, 179, 264, 4, 23, "Print"],
Cell[5109, 185, 257, 5, 23, "Print"],
Cell[5369, 192, 50, 1, 23, "Print"],
Cell[5422, 195, 44, 1, 23, "Print"],
Cell[5469, 198, 50, 1, 23, "Print"],
Cell[5522, 201, 81, 1, 25, "Print"],
Cell[5606, 204, 215, 4, 23, "Print"],
Cell[5824, 210, 796, 17, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6657, 232, 88, 3, 31, "Input"],
Cell[6748, 237, 143, 3, 23, "Print"],
Cell[6894, 242, 544, 15, 23, "Print"],
Cell[7441, 259, 143, 3, 23, "Print"],
Cell[7587, 264, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7798, 272, 107, 3, 31, "Input"],
Cell[7908, 277, 264, 4, 23, "Print"],
Cell[8175, 283, 257, 5, 23, "Print"],
Cell[8435, 290, 50, 1, 23, "Print"],
Cell[8488, 293, 58, 1, 23, "Print"],
Cell[8549, 296, 50, 1, 23, "Print"],
Cell[8602, 299, 67, 1, 23, "Print"],
Cell[8672, 302, 56, 1, 23, "Print"],
Cell[8731, 305, 1068, 17, 98, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9836, 327, 104, 3, 31, "Input"],
Cell[9943, 332, 249, 5, 23, "Print"],
Cell[10195, 339, 226, 4, 23, "Print"],
Cell[10424, 345, 113, 5, 44, "Print"],
Cell[10540, 352, 80, 1, 23, "Print"],
Cell[10623, 355, 458, 12, 23, "Print"],
Cell[11084, 369, 197, 4, 23, "Print"],
Cell[11284, 375, 816, 12, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12137, 392, 97, 3, 31, "Input"],
Cell[12237, 397, 238, 4, 23, "Print"],
Cell[12478, 403, 226, 4, 23, "Print"],
Cell[12707, 409, 80, 1, 23, "Print"],
Cell[12790, 412, 190, 4, 23, "Print"],
Cell[12983, 418, 816, 12, 102, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13836, 435, 227, 5, 31, "Input"],
Cell[14066, 442, 467, 7, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14570, 454, 133, 3, 31, "Input"],
Cell[14706, 459, 128, 2, 20, "Message"],
Cell[14837, 463, 36, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14910, 469, 116, 3, 31, "Input"],
Cell[15029, 474, 128, 2, 20, "Message"],
Cell[15160, 478, 36, 1, 27, "Output"]
}, Open  ]],
Cell[15211, 482, 293, 6, 73, "Input"],

Cell[CellGroupData[{
Cell[15529, 492, 234, 5, 31, "Input"],
Cell[15766, 499, 689, 12, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16492, 516, 129, 3, 31, "Input"],
Cell[16624, 521, 151, 3, 20, "Message"],
Cell[16778, 526, 149, 3, 20, "Message"],
Cell[16930, 531, 149, 3, 20, "Message"],
Cell[17082, 536, 337, 5, 20, "Message"],
Cell[17422, 543, 206, 4, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17665, 552, 140, 4, 31, "Input"],
Cell[17808, 558, 151, 3, 20, "Message"],
Cell[17962, 563, 149, 3, 20, "Message"],
Cell[18114, 568, 149, 3, 20, "Message"],
Cell[18266, 573, 337, 5, 20, "Message"],
Cell[18606, 580, 128, 2, 20, "Message"],
Cell[18737, 584, 128, 2, 20, "Message"],
Cell[18868, 588, 128, 2, 20, "Message"],
Cell[18999, 592, 334, 5, 20, "Message"],
Cell[19336, 599, 183, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19556, 607, 132, 3, 31, "Input"],
Cell[19691, 612, 42, 1, 23, "Print"],
Cell[19736, 615, 349, 8, 23, "Print"],
Cell[20088, 625, 357, 8, 23, "Print"],
Cell[20448, 635, 392, 9, 23, "Print"],
Cell[20843, 646, 135, 3, 23, "Print"],
Cell[20981, 651, 145, 3, 23, "Print"],
Cell[21129, 656, 355, 8, 23, "Print"],
Cell[21487, 666, 363, 8, 23, "Print"],
Cell[21853, 676, 363, 8, 23, "Print"],
Cell[22219, 686, 145, 3, 23, "Print"],
Cell[22367, 691, 363, 8, 23, "Print"],
Cell[22733, 701, 145, 3, 23, "Print"],
Cell[22881, 706, 357, 8, 23, "Print"],
Cell[23241, 716, 135, 3, 23, "Print"],
Cell[23379, 721, 151, 3, 23, "Print"],
Cell[23533, 726, 151, 3, 23, "Print"],
Cell[23687, 731, 151, 3, 23, "Print"],
Cell[23841, 736, 151, 3, 23, "Print"],
Cell[23995, 741, 151, 3, 23, "Print"],
Cell[24149, 746, 363, 8, 23, "Print"],
Cell[24515, 756, 135, 3, 23, "Print"],
Cell[24653, 761, 157, 3, 23, "Print"],
Cell[24813, 766, 161, 3, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25011, 774, 126, 3, 31, "Input"],
Cell[25140, 779, 358, 5, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25535, 789, 261, 7, 73, "Input"],
Cell[25799, 798, 365, 5, 20, "Message"],
Cell[26167, 805, 4780, 79, 589, "Output"]
}, Open  ]],
Cell[30962, 887, 167, 5, 31, "Input"],

Cell[CellGroupData[{
Cell[31154, 896, 170, 4, 31, "Input"],
Cell[31327, 902, 55, 1, 23, "Print"],
Cell[31385, 905, 117, 2, 26, "Print"],
Cell[31505, 909, 63, 1, 23, "Print"],
Cell[31571, 912, 250, 4, 23, "Print"],
Cell[31824, 918, 250, 4, 23, "Print"],
Cell[32077, 924, 252, 4, 23, "Print"],
Cell[32332, 930, 252, 4, 23, "Print"],
Cell[32587, 936, 163, 3, 23, "Print"],
Cell[32753, 941, 163, 3, 23, "Print"],
Cell[32919, 946, 165, 3, 23, "Print"],
Cell[33087, 951, 165, 3, 23, "Print"],
Cell[33255, 956, 358, 6, 49, "Output"]
}, Open  ]],
Cell[33628, 965, 794, 14, 214, "Input"],

Cell[CellGroupData[{
Cell[34447, 983, 166, 5, 31, "Input"],
Cell[34616, 990, 125, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34778, 998, 174, 5, 31, "Input"],
Cell[34955, 1005, 816, 12, 171, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35808, 1022, 93, 3, 31, "Input"],
Cell[35904, 1027, 180, 3, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36121, 1035, 155, 4, 31, "Input"],
Cell[36279, 1041, 147, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36463, 1048, 92, 3, 31, "Input"],
Cell[36558, 1053, 140, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36735, 1060, 358, 8, 57, "Input"],
Cell[37096, 1070, 93, 1, 27, "Output"]
}, Open  ]],
Cell[37204, 1074, 191, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[37420, 1082, 88, 3, 31, "Input"],
Cell[37511, 1087, 79, 1, 27, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

