(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21981,        727]*)
(*NotebookOutlinePosition[     22614,        749]*)
(*  CellTagsIndexPosition[     22570,        745]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(<< MB.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("MB 1.1"\)], "Print"],

Cell[BoxData[
    \("by Michal Czakon"\)], "Print"],

Cell[BoxData[
    \("more info in hep-ph/0511200"\)], "Print"],

Cell[BoxData[
    \("last modified 28 Jan 06"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(<< AMBRE.m\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("by K.Kajda   ver: 1.0"\)], "Print"],

Cell[BoxData[
    \("last modified 29 Mar 2007"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(Fullintegral[{1}, {PR[k1, m, n1]*
            PR[k1 + p1, m, n2]}, {k1}];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(invariants = {p1^2 \[Rule] s};\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntPart[1]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("numerator="\[InvisibleSpace]1\),
      SequenceForm[ "numerator=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("integral="\[InvisibleSpace]\(PR[k1, m, n1]\ PR[
            k1 + p1, m, n2]\)\),
      SequenceForm[ "integral=", 
        Times[ 
          PR[ k1, m, n1], 
          PR[ 
            Plus[ k1, p1], m, n2]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("momentum="\[InvisibleSpace]k1\),
      SequenceForm[ "momentum=", k1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(Fauto::"mode" \(\(:\)\(\ \)\) 
      "U and F polynomials will be calculated in AUTO mode. In order to use \
MANUAL mode execute Fauto[0]."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(repr = SubLoop[integral];\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\("Iteration nr"\[InvisibleSpace]1\[InvisibleSpace]": \
>>Integrating over "\[InvisibleSpace]k1\[InvisibleSpace]"<<"\),
      SequenceForm[ "Iteration nr", 1, ": >>Integrating over ", k1, "<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Computing U & F polynomial in AUTO mode >>Fauto["\
\[InvisibleSpace]1\[InvisibleSpace]"]<<"\),
      SequenceForm[ 
      "Computing U & F polynomial in AUTO mode >>Fauto[", 1, "]<<"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("U polynomial..."\)], "Print"],

Cell[BoxData[
    \(X[1] + X[2]\)], "Print"],

Cell[BoxData[
    \("F polynomial..."\)], "Print"],

Cell[BoxData[
    \(m\^2\ FX[X[1] + X[2]]\^2 - s\ X[1]\ X[2]\)], "Print"],

Cell[BoxData[
    \("Final representation:"\)], "Print"],

Cell[BoxData[
    TagBox[
      StyleBox[\(\((\((\(-1\))\)\^\(n1 + n2\)\ \((m\^2)\)\^z1\ \((\(-s\))\)\^\
\(2 - eps - n1 - n2 - z1\)\ Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + n1 + n2 + 
                  z1]\ Gamma[
                2 - eps - n1 + z1 - z2]\ Gamma[\(-z2\)]\ Gamma[\(-2\)\ z1 + 
                  z2]\ Gamma[2 - eps - n2 - z1 + z2])\)/\((Gamma[n1]\ Gamma[
                4 - 2\ eps - n1 - n2]\ Gamma[n2]\ Gamma[\(-2\)\ z1])\)\),
        FontColor->RGBColor[0, 0, 1]],
      (StyleForm[ #, FontColor -> RGBColor[ 0, 0, 1]]&)]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BarnesLemma[repr, 1]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    InterpretationBox[\(">> Barnes 1st Lemma will be checked for: "\
\[InvisibleSpace]{z2}\[InvisibleSpace]" <<"\),
      SequenceForm[ ">> Barnes 1st Lemma will be checked for: ", {z2}, " <<"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Starting with dim="\[InvisibleSpace]2\
\[InvisibleSpace]" representation..."\),
      SequenceForm[ "   Starting with dim=", 2, " representation..."],
      Editable->False]], "Print"],

Cell["\<\

1. Checking z2...Barnes Lemma was applied.\
\>", "Print",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(">> Representation after 1st Barnes Lemma:  <<"\)], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
        TagBox[
          StyleBox["\<\"   1st Barnes Lemma was applied for: \"\>",
            FontColor->RGBColor[1, 0, 0]],
          (StyleForm[ #, FontColor -> RGBColor[ 1, 0, 0]]&)], 
        "\[InvisibleSpace]", \({z2}\)}],
      SequenceForm[ 
        StyleForm[ 
        "   1st Barnes Lemma was applied for: ", FontColor -> RGBColor[ 
          1, 0, 0]], {z2}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("   Obtained representation has: dim="\
\[InvisibleSpace]1\),
      SequenceForm[ "   Obtained representation has: dim=", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\((\(-1\))\)\^\(n1 + n2\)\ \((m\^2)\)\^z1\ \((\(-s\))\)\^\(2 - eps - \
n1 - n2 - z1\)\ Gamma[2 - eps - n1 - z1]\ Gamma[2 - eps - n2 - z1]\ \
Gamma[\(-z1\)]\ Gamma[\(-2\) + eps + n1 + n2 + z1]\)\/\(Gamma[n1]\ Gamma[n2]\ \
Gamma[4 - 2\ eps - n1 - n2 - 2\ z1]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SE2l2m = \(% /. n1 \[Rule] 1\) /. n2 \[Rule] 1\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(\((m\^2)\)\^z1\ \((\(-s\))\)\^\(\(-eps\) - z1\)\ Gamma[1 - eps - \
z1]\^2\ Gamma[\(-z1\)]\ Gamma[eps + z1]\)\/Gamma[2 - 2\ eps - 2\ z1]\)], \
"Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ sometimes\ it\ can\ happen\ with\ MB . m\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = MBoptimizedRules[SE2l2m, eps \[Rule] 0, {}, {eps}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(eps + z1\)]"\)], \
"Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(eps + z1\)]"\)], \
"Message"],

Cell[BoxData[
    \(MBresidues::"contour" \(\(:\)\(\ \)\) 
      "contour starts and/or ends on a pole of Gamma[\!\(eps + z1\)]"\)], \
"Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(MBresidues :: \\\"contour\\\"\\) will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \($Aborted\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ and\ we\ have\ to\ help\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(rules = 
      MBoptimizedRules[SE2l2m, 
        eps \[Rule] 0, {z1 > \(-1\)/4}, {eps}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(MBrules::"norules" \(\(:\)\(\ \)\) 
      "no rules could be found to regulate this integral"\)], "Message"],

Cell[BoxData[
    \({{eps \[Rule] 5\/8}, {z1 \[Rule] \(-\(1\/8\)\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ Re[eps]\ and\ Re[z1]\ makes\ integral\ well\ \(defined : \ 
          arguments\ of\ Gamma\ functions\ are\ positive\)\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Numerator[
        SE2l2m/\((\((m\^2)\)\^z1\ \((\(-s\))\)\^\(\(-eps\) - z1\))\) /. 
          Gamma[x_] \[Rule] gamma[x]] /. Flatten[rules]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(gamma\\)\\\" is similar to existing symbol \
\\\"\\!\\(Gamma\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(gamma[1\/8]\ gamma[1\/2]\^3\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ now\ analytic\ continuation\ in\ eps\  \[Rule] \ 0\ *) \)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(integrals = MBcontinue[SE2l2m, eps \[Rule] 0, rules]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(integrals\\)\\\" is similar to existing \
symbol \\\"\\!\\(integral\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \("Level 1"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Taking \
"\[InvisibleSpace]"+"\[InvisibleSpace]"residue in "\[InvisibleSpace]z1\
\[InvisibleSpace]" = "\[InvisibleSpace]\(-eps\)\),
      SequenceForm[ "Taking ", "+", "residue in ", z1, " = ", 
        Times[ -1, eps]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Level "\[InvisibleSpace]2\),
      SequenceForm[ "Level ", 2],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Integral "\[InvisibleSpace]{1}\),
      SequenceForm[ "Integral ", {1}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(2\[InvisibleSpace]" integral(s) found"\),
      SequenceForm[ 2, " integral(s) found"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{MBint[\((m\^2)\)\^\(-eps\)\ Gamma[eps], {{eps \[Rule] 0}, {}}]}, 
      MBint[\(\((m\^2)\)\^z1\ \((\(-s\))\)\^\(\(-eps\) - z1\)\ Gamma[1 - eps \
- z1]\^2\ Gamma[\(-z1\)]\ Gamma[eps + z1]\)\/Gamma[2 - 2\ eps - 2\ z1], {{eps \
\[Rule] 0}, {z1 \[Rule] \(-\(1\/8\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ how\ we\ get\ it?\ we\ will\ come\ into\ this\ in\ B5l2m2 . 
          nb\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(ser = MBexpand[integrals, Exp[eps*EulerGamma], {eps, 0, 0}]\)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({MBint[1\/eps - Log[m\^2], {{eps \[Rule] 0}, {}}], 
      MBint[\(\((m\^2)\)\^z1\ \((\(-s\))\)\^\(-z1\)\ Gamma[1 - z1]\^2\ Gamma[\
\(-z1\)]\ Gamma[z1]\)\/Gamma[2 - 2\ z1], {{eps \[Rule] 
              0}, {z1 \[Rule] \(-\(1\/8\)\)}}]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(num1 = MBintegrate[ser, {s \[Rule] \(-100\), m \[Rule] 1}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 1 1-dimensional integrations...1", "Print",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    \({\(-2.716467157902603`\) + 1\/eps, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(num2 = MBintegrate[ser, {s \[Rule] \(-1\)/100, m \[Rule] 1}]\)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Shifting contours..."\)], "Print"],

Cell["Performing 1 1-dimensional integrations...1", "Print",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \("Higher-dimensional integrals"\)], "Print"],

Cell[BoxData[
    \({\(-0.0016650023788578059`\) + 1\/eps, 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ actually\ there\ is\ one\ parameter\ ms\ in\ ser\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(ser[\([2, 1]\)] /. \((m\^2)\)\^z1\ \((\(-s\))\)\^\(-z1\) \[Rule] 
        ms^z1\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(ms\^z1\ Gamma[1 - z1]\^2\ Gamma[\(-z1\)]\ Gamma[z1]\)\/Gamma[2 - 2\ \
z1]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ Q : \ 
        can\ we\ sum\ up\ residues\ to\ \(\(Infinity\)\(?\)\)\ *) \)], "Input",\

  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ A : \ surely, \ not\ directly\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[Residue[ser[\([2, 1]\)], {z1, i}], {i, 0, Infinity}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(\[Infinity]::"indet"\), \(\(:\)\(\ \)\), "\<\"Indeterminate \
expression \\!\\(0\\\\ \[Infinity]\\) encountered. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::indet\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(Indeterminate\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Approximations\ \[IndentingNewLine]closing\ on\ \
right - half\ in\ a\ complex\ plane, \ 
      means\ s >> m^2\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(sum = 
      Sum[\(-Residue[ser[\([2, 1]\)], {z1, i}]\), {i, 0, 10}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(sum\\)\\\" is similar to existing symbol \
\\\"\\!\\(Sum\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(2 + Log[m\^2] - 
      Log[\(-s\)] - \(2\ \((\(-m\^2\) + m\^2\ Log[m\^2] - m\^2\ \
Log[\(-s\)])\)\)\/s - \(m\^4 + 2\ m\^4\ Log[m\^2] - 2\ m\^4\ Log[\(-s\)]\)\/s\
\^2 - \(2\ \((5\ m\^6 + 6\ m\^6\ Log[m\^2] - 6\ m\^6\ Log[\(-s\)])\)\)\/\(3\ \
s\^3\) - \(59\ m\^8 + 60\ m\^8\ Log[m\^2] - 60\ m\^8\ Log[\(-s\)]\)\/\(6\ \
s\^4\) - \(449\ m\^10 + 420\ m\^10\ Log[m\^2] - 420\ m\^10\ \
Log[\(-s\)]\)\/\(15\ s\^5\) - \(1417\ m\^12 + 1260\ m\^12\ Log[m\^2] - 1260\ \
m\^12\ Log[\(-s\)]\)\/\(15\ s\^6\) - \(2\ \((16127\ m\^14 + 13860\ m\^14\ \
Log[m\^2] - 13860\ m\^14\ Log[\(-s\)])\)\)\/\(105\ s\^7\) - \(429697\ m\^16 + \
360360\ m\^16\ Log[m\^2] - 360360\ m\^16\ Log[\(-s\)]\)\/\(420\ s\^8\) - \(5\ \
\((87541\ m\^18 + 72072\ m\^18\ Log[m\^2] - 72072\ m\^18\ \
Log[\(-s\)])\)\)\/\(126\ s\^9\) - \(7549093\ m\^20 + 6126120\ m\^20\ \
Log[m\^2] - 6126120\ m\^20\ Log[\(-s\)]\)\/\(630\ s\^10\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(sum /. m \[Rule] 1\) /. s \[Rule] \(-100\) // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-2.7164672904519596`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(num1\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \({\(-2.716467157902603`\) + 1\/eps, 0}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]let\ us\ compare\ this\ series\ with\ an\ exact\
\ result\ known\ from\ \(elsewhere : \ 
          e . g . \ DEqs\ method\)\ \ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(x[
          s_] := \((Sqrt[\((s - 4)\)/s] - 1)\)/\((Sqrt[\((s - 4)\)/s] + 
              1)\);\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]let\ us\ consider\ the\ constant\ term\ \
\[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(se = 2 - \(\((1 + x)\)\ Log[x]\)\/\(\(-1\) + x\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(se /. x \[Rule] x[\(-100\)] // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-2.7164672904519573`\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]fine, \ 
      we\ can\ make\ the\ same\ with\ the\ FF\ package\ \((LoopTools)\)\ \
\[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ \n\ \(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\) = 
        FF\ 2.0, \(a\ package\ to\ evaluate\ one - 
            loop\ integrals\)\n\(written\ by\ G . J . van\ Oldenborgh, 
          NIKHEF - H, 
          Amsterdam\)\n\ \
\(\(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\) = 
            for\ the\ algorithms\ used\ see\ preprint\ NIKHEF - 
              H\ 89/17, \(\('\) \(New\)\(\ \)\(Algorithms\)\(\ \)\(for\)\(\ \
\)\(One\)\) - loop\ Integrals', 
          by\ G . J . van\)\n\(Oldenborgh\ and\ J . A . M . Vermaseren, 
          published\ in\)\n\(Zeitschrift\ fuer\ Physik\ C46 \((1990)\) 
            425. \)\n\ \(\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(\
===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\(===\)\) = \
\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \(s\  = \ 
          100\ \ \((\(-2.49223029\), 3.07811959)\)\n
        \ \ Euclid\), \ 
      s\  = \ \(-100\)\ \((\(-2.71646729\), 
              0. )\)\n\[IndentingNewLine]\(total\ number\ of\ errors\ and\ \
warnings\)\n ===  ===  ===  ===  ===  ===  ===  ===  ===  ===  === \(\(\
\[Equal]\)\(fferr : no\ errors\)\)\[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ Q : \ what\ about\ small\ \(\(s\)\(?\)\)\ *) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(se /. x \[Rule] x[\(-1\)/100] // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-0.001665002376991076`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(sum /. m \[Rule] 1\) /. s \[Rule] \(-1\)/100 // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-5.659741174501553`*^24\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ \[IndentingNewLine]\(Wrong!\)\ \[IndentingNewLine]\(Q : \ 
          what\ to\ do?\[IndentingNewLine]\(A : \ 
                close\ contour\ in\ negative\ half - \(plane : \ 
                    s\ << \ 
                          m^2\)\)\)\[IndentingNewLine]*) \)\(\
\[IndentingNewLine]\)\)\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[Residue[ser[\([2, 1]\)], {z1, \(-i\)}], {i, 1, 10}]\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(s\/\(6\ m\^2\) + s\^2\/\(60\ m\^4\) + s\^3\/\(420\ m\^6\) + 
      s\^4\/\(2520\ m\^8\) + s\^5\/\(13860\ m\^10\) + 
      s\^6\/\(72072\ m\^12\) + s\^7\/\(360360\ m\^14\) + 
      s\^8\/\(1750320\ m\^16\) + s\^9\/\(8314020\ m\^18\) + 
      s\^10\/\(38798760\ m\^20\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. m \[Rule] 1\) /. s \[Rule] \(-1\)/100 // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-0.001665002376991328`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(se /. x \[Rule] x[\(-1\)/100] // N\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \(\(-0.001665002376991076`\)\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\(\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\
\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\(**\)\)*\ \
\[IndentingNewLine]what\ we\ have\ shown\ are\ so\ called\ expansions\ of\ MB\
\ integrals, \ \[IndentingNewLine]see\ e . g . \ M . \ Czakon, \ J . G . , \ 
      T . R . , \ 
      NPB751 \((2006)\) 
        1\[IndentingNewLine]for\ more\ complicated\ cases\[IndentingNewLine]*************************************************) \
\)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]Q : \ 
        when\ can\ we\ sum\ up\ residues\ to\ Infinity\ and\ obtained\ exact\ \
\(\(answer\)\(?\)\)\ \[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16],

Cell[BoxData[
    \( (*\ \[IndentingNewLine]A : \[IndentingNewLine]1. \ sometimes\ it\ is\ \
trivial\ and\ we\ can\ do\ it\ directly\ in\ \(Mathematica : \ 
            see\ the\ lecture\[IndentingNewLine]
          
          2. \ some\ special\ integrals\ can\ be\ solved\ using\ \(Xsummer : \
\ summation\ of\ \((nested)\)\ series\)\)\[IndentingNewLine]*) \)], "Input",
  FontFamily->"Courier new",
  FontSize->16]
},
FrontEndVersion->"5.0 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
WindowSize->{1014, 714},
WindowMargins->{{157, Automatic}, {Automatic, 154}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 85, 3, 31, "Input"],
Cell[1864, 58, 41, 1, 23, "Print"],
Cell[1908, 61, 51, 1, 23, "Print"],
Cell[1962, 64, 62, 1, 23, "Print"],
Cell[2027, 67, 58, 1, 23, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2122, 73, 88, 3, 31, "Input"],
Cell[2213, 78, 56, 1, 23, "Print"],
Cell[2272, 81, 60, 1, 23, "Print"]
}, Open  ]],
Cell[2347, 85, 155, 4, 31, "Input"],
Cell[2505, 91, 112, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[2642, 98, 88, 3, 31, "Input"],
Cell[2733, 103, 143, 3, 23, "Print"],
Cell[2879, 108, 282, 8, 23, "Print"],
Cell[3164, 118, 143, 3, 23, "Print"],
Cell[3310, 123, 174, 3, 20, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3521, 131, 107, 3, 31, "Input"],
Cell[3631, 136, 264, 4, 23, "Print"],
Cell[3898, 142, 257, 5, 23, "Print"],
Cell[4158, 149, 50, 1, 23, "Print"],
Cell[4211, 152, 44, 1, 23, "Print"],
Cell[4258, 155, 50, 1, 23, "Print"],
Cell[4311, 158, 73, 1, 25, "Print"],
Cell[4387, 161, 56, 1, 23, "Print"],
Cell[4446, 164, 545, 9, 48, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5028, 178, 98, 3, 31, "Input"],
Cell[5129, 183, 249, 5, 23, "Print"],
Cell[5381, 190, 226, 4, 23, "Print"],
Cell[5610, 196, 113, 5, 44, "Print"],
Cell[5726, 203, 80, 1, 23, "Print"],
Cell[5809, 206, 458, 12, 23, "Print"],
Cell[6270, 220, 197, 4, 23, "Print"],
Cell[6470, 226, 294, 4, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6801, 235, 124, 3, 31, "Input"],
Cell[6928, 240, 173, 3, 50, "Output"]
}, Open  ]],
Cell[7116, 246, 128, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[7269, 253, 136, 3, 31, "Input"],
Cell[7408, 258, 145, 3, 20, "Message"],
Cell[7556, 263, 145, 3, 20, "Message"],
Cell[7704, 268, 145, 3, 20, "Message"],
Cell[7852, 273, 337, 5, 20, "Message"],
Cell[8192, 280, 42, 1, 27, "Output"]
}, Open  ]],
Cell[8249, 284, 111, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[8385, 291, 165, 5, 31, "Input"],
Cell[8553, 298, 128, 2, 20, "Message"],
Cell[8684, 302, 82, 1, 44, "Output"]
}, Open  ]],
Cell[8781, 306, 206, 4, 52, "Input"],

Cell[CellGroupData[{
Cell[9012, 314, 217, 5, 38, "Input"],
Cell[9232, 321, 358, 5, 20, "Message"],
Cell[9593, 328, 61, 1, 45, "Output"]
}, Open  ]],
Cell[9669, 332, 140, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[9834, 340, 130, 3, 31, "Input"],
Cell[9967, 345, 365, 5, 20, "Message"],
Cell[10335, 352, 42, 1, 23, "Print"],
Cell[10380, 355, 293, 6, 23, "Print"],
Cell[10676, 363, 135, 3, 23, "Print"],
Cell[10814, 368, 145, 3, 23, "Print"],
Cell[10962, 373, 159, 3, 23, "Print"],
Cell[11124, 378, 302, 4, 76, "Output"]
}, Open  ]],
Cell[11441, 385, 161, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[11627, 393, 139, 4, 31, "Input"],
Cell[11769, 399, 268, 4, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12074, 408, 136, 3, 31, "Input"],
Cell[12213, 413, 55, 1, 23, "Print"],
Cell[12271, 416, 105, 2, 26, "Print"],
Cell[12379, 420, 63, 1, 23, "Print"],
Cell[12445, 423, 71, 1, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12553, 429, 140, 4, 31, "Input"],
Cell[12696, 435, 55, 1, 23, "Print"],
Cell[12754, 438, 105, 2, 26, "Print"],
Cell[12862, 442, 63, 1, 23, "Print"],
Cell[12928, 445, 75, 1, 47, "Output"]
}, Open  ]],
Cell[13018, 449, 136, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[13179, 456, 157, 4, 34, "Input"],
Cell[13339, 462, 109, 2, 48, "Output"]
}, Open  ]],
Cell[13463, 467, 158, 5, 31, "Input"],
Cell[13624, 474, 117, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[13766, 481, 134, 3, 31, "Input"],
Cell[13903, 486, 307, 5, 20, "Message"],
Cell[14213, 493, 47, 1, 27, "Output"]
}, Open  ]],
Cell[14275, 497, 237, 5, 94, "Input"],

Cell[CellGroupData[{
Cell[14537, 506, 146, 4, 31, "Input"],
Cell[14686, 512, 354, 5, 20, "Message"],
Cell[15043, 519, 916, 13, 160, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15996, 537, 127, 3, 31, "Input"],
Cell[16126, 542, 58, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16221, 548, 82, 3, 31, "Input"],
Cell[16306, 553, 71, 1, 47, "Output"]
}, Open  ]],
Cell[16392, 557, 251, 5, 73, "Input"],
Cell[16646, 564, 177, 5, 31, "Input"],
Cell[16826, 571, 166, 4, 73, "Input"],
Cell[16995, 577, 86, 1, 44, "Input"],

Cell[CellGroupData[{
Cell[17106, 582, 110, 3, 31, "Input"],
Cell[17219, 587, 58, 1, 27, "Output"]
}, Open  ]],
Cell[17292, 591, 208, 5, 73, "Input"],
Cell[17503, 598, 1389, 24, 367, "Input"],
Cell[18895, 624, 128, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[19048, 631, 112, 3, 31, "Input"],
Cell[19163, 636, 60, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19260, 642, 129, 3, 31, "Input"],
Cell[19392, 647, 61, 1, 29, "Output"]
}, Open  ]],
Cell[19468, 651, 378, 8, 136, "Input"],

Cell[CellGroupData[{
Cell[19871, 663, 133, 3, 31, "Input"],
Cell[20007, 668, 301, 5, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20345, 678, 127, 3, 31, "Input"],
Cell[20475, 683, 60, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20572, 689, 112, 3, 31, "Input"],
Cell[20687, 694, 60, 1, 27, "Output"]
}, Open  ]],
Cell[20762, 698, 560, 10, 115, "Input"],
Cell[21325, 710, 232, 5, 73, "Input"],
Cell[21560, 717, 417, 8, 115, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

